# localization

# region common
l_on = {
    'ru': "вкл",
    'en': "on",
    'es': "enc",
    'fr': "mar",
    'zh': "开",
    'ar': "تشغيل",
}
l_off = {
    'ru': "выкл",
    'en': "off",
    'es': "apag",
    'fr': "arr",
    'zh': "关",
    'ar': "إيقاف",
}
l_yes = {
    'ru': "да",
    'en': "yes",
    'es': "sí",
    'fr': "oui",
    'zh': "是",
    'ar': "نعم",
}
l_no = {
    'ru': "нет",
    'en': "no",
    'es': "no",
    'fr': "non",
    'zh': "否",
    'ar': "لا",
}
l_yes_percent = {
    'ru': "👩🏽‍💻 Да, 100%",
    'en': "👩🏽‍💻 Yes, 100%",
    'es': "👩🏽‍💻 Sí, 100%",
    'fr': "👩🏽‍💻 Oui, 100%",
    'zh': "👩🏽‍💻 是，100%",
    'ar': "👩🏽‍💻 نعم، 100%",
}
l_no_percent = {
    'ru': "👩🏽‍💻 Нет, 0%",
    'en': "👩🏽‍💻 No, 0%",
    'es': "👩🏽‍💻 No, 0%",
    'fr': "👩🏽‍💻 Non, 0%",
    'zh': "👩🏽‍💻 否，0%",
    'ar': "👩🏽‍💻 لا، 0%",
}
l_all_ans = {
    'ru': "все",
    'en': "all",
    'es': "todos",
    'fr': "tous",
    'zh': "全部",
    'ar': "الكل",
}
l_menu = {
    'ru': "🔙 Menu",
    'en': "🔙 Menu",
    'es': "🔙 Menú",
    'fr': "🔙 Menu",
    'zh': "🔙 菜单",
    'ar': "🔙 القائمة",
}
l_back = {
    'ru': "🔙 Назад",
    'en': "🔙 Back",
    'es': "🔙 Atrás",
    'fr': "🔙 Retour",
    'zh': "🔙 返回",
    'ar': "🔙 رجوع",
}
l_forever = {
    'ru': "навсегда",
    'en': "forever",
    'es': "para siempre",
    'fr': "pour toujours",
    'zh': "永远",
    'ar': "إلى الأبد",
}
l_members = {
    'ru': "участ.",
    'en': "memb.",
    'es': "miemb.",
    'fr': "memb.",
    'zh': "成员。",
    'ar': "عضو.",
}
l_add = {
    'ru': "✅ Добавить",
    'en': "✅ Add",
    'es': "✅ Agregar",
    'fr': "✅ Ajouter",
    'zh': "✅ 添加",
    'ar': "✅ إضافة",
}
l_untill = {
    'ru': "до",
    'en': "to",
    'es': "a",
    'fr': "à",
    'zh': "到",
    'ar': "ل",
}
l_remove = {
    'ru': "🚫 Удалить",
    'en': "🚫 Remove",
    'es': "🚫 Eliminar",
    'fr': "🚫 Supprimer",
    'zh': "🚫 删除",
    'ar': "🚫 حذف",
}
l_try_again = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> или попробуй позже",
    'en': "👩🏽‍💻 <b>Error</b> or try again later",
    'es': "👩🏽‍💻 <b>Error</b> o inténtalo más tarde",
    'fr': "👩🏽‍💻 <b>Erreur</b> ou réessayez plus tard",
    'zh': "👩🏽‍💻 <b>错误</b> 或稍后再试",
    'ar': "👩🏽‍💻 <b>خطأ</b> أو حاول لاحقًا",
}
l_hand_request = {
    'ru': "👩🏽‍💻 <i><b>Обработка</b> запроса..\n#длительность 1мин</i>",
    'en': "👩🏽‍💻 <i><b>Processing</b> request..\n#duration 1 min</i>",
    'es': "👩🏽‍💻 <i><b>Procesando</b> solicitud..\n#duración 1 min</i>",
    'fr': "👩🏽‍💻 <i><b>Traitement</b> demande..\n#durée 1 min</i>",
    'zh': "👩🏽‍💻<i><b>正在处理</b>请求..\n#duration 1 分钟</i>",
    'ar': "👩🏽‍💻 <i><b>جارٍ معالجة</b> الطلب..\n#المدة دقيقة واحدة</i>",
}
l_please_subscribe = {
    'ru': "👩🏽‍💻 Оформи ежемесячную 💨Подписку",
    'en': "👩🏽‍💻 Subscribe to a monthly 💨Subscription",
    'es': "👩🏽‍💻 Suscríbete a una 💨suscripción mensual",
    'fr': "👩🏽‍💻 Abonnez-vous à un 💨abonnement mensuel",
    'zh': "👩🏽‍💻 订阅每月💨订阅",
    'ar': "👩🏽‍💻 اشترك في 💨اشتراك شهري",
}
l_please_subscribe_need = {
    'ru': "👩🏽‍💻 <b>Необходимо</b> 💨Подписка",
    'en': "👩🏽‍💻 <b>Subscription</b> is required 💨",
    'es': "👩🏽‍💻 <b>Se requiere</b> una 💨suscripción",
    'fr': "👩🏽‍💻 <b>Une</b> 💨abonnement est <b>requis</b>",
    'zh': "👩🏽‍💻 需要 💨订阅",
    'ar': "👩🏽‍💻 <b>يتطلب</b> 💨اشتراك",
}
l_subscribe_spoiler = {
    'ru': "оформи 💨Подписку",
    'en': "get a 💨Subscription",
    'es': "activa una 💨suscripción",
    'fr': "prenez un 💨abonnement",
    'zh': "获取💨订阅",
    'ar': "احصل على 💨اشتراك",
}
l_subscribe_channel_for_post = {
    'ru': "👩🏽‍💻 <b>Подпишись</b> на @{0}, чтобы продолжить",
    'en': "👩🏽‍💻 <b>Subscribe</b> to @{0} to continue",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a @{0} para continuar",
    'fr': "👩🏽‍💻 <b>Abonnez-vous</b> à @{0} pour continuer",
    'zh': "👩🏽‍💻 <b>订阅</b>@{0} 以继续",
    'ar': "👩🏽‍💻 <b>اشترك</b> في @{0} للمتابعة",
}
l_sound = {
    'ru': "Звук",
    'en': "Sound",
    'es': "Sonido",
    'fr': "Son",
    'zh': "声音",
    'ar': "الصوت",
}
l_date = {
    'ru': "Дата",
    'en': "Date",
    'es': "Fecha",
    'fr': "Date",
    'zh': "日期",
    'ar': "التاريخ",
}
l_timer = {
    'ru': "Таймер",
    'en': "Timer",
    'es': "Temporizador",
    'fr': "Minuteur",
    'zh': "定时器",
    'ar': "مؤقت",
}
l_media = {
    'ru': "Медиа",
    'en': "Media",
    'es': "Multimedia",
    'fr': "Médias",
    'zh': "媒体",
    'ar': "الوسائط",
}
l_week = {
    'ru': "неделя",
    'en': "week",
    'es': "semana",
    'fr': "semaine",
    'zh': "周",
    'ar': "أسبوع",
}
l_subscribers = {
    'ru': "подписчики",
    'en': "subscribers",
    'es': "suscriptores",
    'fr': "abonnés",
    'zh': "订阅者",
    'ar': "المشتركين",
}
l_sec = {
    'ru': "сек",
    'en': "sec",
    'es': "seg",
    'fr': "sec",
    'zh': "秒",
    'ar': "ثانية",
}
l_min = {
    'ru': "мин",
    'en': "min",
    'es': "min",
    'fr': "min",
    'zh': "分",
    'ar': "دقيقة",
}
l_hours = {
    'ru': "часов",
    'en': "hours",
    'es': "horas",
    'fr': "heures",
    'zh': "小时",
    'ar': "ساعات",
}
l_days = {
    'ru': "дней",
    'en': "days",
    'es': "días",
    'fr': "jours",
    'zh': "天",
    'ar': "أيام",
}
l_length = {
    'ru': "Длина",
    'en': "Length",
    'es': "Longitud",
    'fr': "Longueur",
    'zh': "长度",
    'ar': "الطول",
}
l_post = {
    'ru': "пост",
    'en': "post",
    'es': "publicación",
    'fr': "publication",
    'zh': "帖子",
    'ar': "منشور",
}
l_post_upper = {
    'ru': "Пост",
    'en': "Post",
    'es': "Publicación",
    'fr': "Publication",
    'zh': "帖子",
    'ar': "منشور",
}
l_from_channel = {
    'ru': "из канала",
    'en': "from channel",
    'es': "del canal",
    'fr': "du canal",
    'zh': "来自频道",
    'ar': "من القناة",
}
l_choose_direction = {
    'ru': "👇🏽 <b>Выбери</b> направление",
    'en': "👇🏽 <b>Choose</b> direction",
    'es': "👇🏽 <b>Elige</b> dirección",
    'fr': "👇🏽 <b>Choisissez</b> la direction",
    'zh': "👇🏽<b>选择</b>方向",
    'ar': "👇🏽 <b>اختر</b> الاتجاه",
}
l_about = {
    'ru': "<b>👩🏽‍💻 Ferey проекты</b>:\n\n<blockquote>▪️проекты: <a href='https://t.me/FereyDemoBot?start=about'>Demo App</a>\n▪️конструктор: <a href='https://t.me/FereyBotBot?start=about'>Bot App</a>\n▪️приватные посты: <a href='https://t.me/FereyPostBot?start=about'>Post App</a>\n▪️публичные медиа: <a href='https://t.me/FereyMediaBot?start=about'>Media App</a>\n▪️администрирование: <a href='https://t.me/FereyChannelBot?start=about'>Channel App</a>\n▪️модерация: <a href='https://t.me/FereyGroupBot?start=about'>Group App</a>\n▪️поиск: <a href='https://t.me/FereyFindBot?start=about'>Find App</a>\n▪️инструменты: <a href='https://t.me/FereyToolsBot?start=about'>Tools App</a>\n▪️стикеры/эмоджи: <a href='https://t.me/FereyStickerBot?start=about'>Sticker App</a>\n▪️нейро: <a href='https://t.me/FereyAIBot?start=about'>AI App</a>\n▪️автоматизация: <a href='https://t.me/FereyUserBot?start=about'>User App</a>\n▪️блокчейн NFT/FT: <a href='https://t.me/FereyTONestBot?start=about'>TONest App</a>\n▪️кодекс/фест/лига: <a href='https://t.me/FereyCodexBot?start=about'>Codex App</a></blockquote>\n\n👩🏽‍💻 /content",
    'en': "<b>👩🏽‍💻 Ferey projects</b>:\n\n▪️projects: @FereyDemoBot\n▪️constructor: <a href=' https://t.me/FereyBotBot?start=isfree '> @FereyBotBot </a>\n▪️private posts: @FereyPostBot\n▪️public media: @FereyMediaBot\n▪️administration: <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️moderation: <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️search: @FereyFindBot\n▪️tools : @FereyToolsBot\n▪️vpn: @FereyVPNBot\n▪️ai: @FereyAIBot\n▪️automation: <a href=' https://t.me/FereyUserBot?start=isfree '> @FereyUserBot </a>\n▪️vacancies: @FereyWorkBot\n▪️advertising: @FereyAdsBot",
    'es': "<b>👩🏽‍💻 Proyectos de Ferey</b>:\n\n▪️proyectos: @FereyDemoBot\n▪️constructor: <a href=' https://t.me/FereyBotBot?start=isfree '> @FereyBotBot </a>\n▪️publicaciones privadas: @FereyPostBot\n▪️medios públicos: @FereyMediaBot\n▪️administración: <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️moderación: <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️búsqueda: @FereyFindBot\n▪️objetivo: @FereyTargetBot\n▪️herramientas : @FereyToolsBot\n▪️vpn: @FereyVPNBot\n▪️ai: @FereyAIBot\n▪️automatización: <a href=' https://t.me/FereyUserBot?start=isfree '> @FereyUserBot </a>\n▪️vacantes: @FereyWorkBot\n▪️publicidad: @FereyAdsBot",
    'fr': "<b>👩🏽‍💻 @FereyBotBot Ferey</b> :\n @FereyDemoBot nwithout </a>\n▪️posts privés : @FereyPostBot\n▪️médias publics : @FereyMediaBot\nnoyance️administration : <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️modération : <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️recherche : @FereyFindBot\nnoyancetarget : @FereyTargetBot\nnoyancetools : @FereyToolsBot\nƒ️vpn : @FereyVPNBot\nƒ️ai : @FereyAIBot\nƒ️automation : <a href=' https://t.me/FereyUserBot?start=isfree '> @FereyUserBot </a>\n▪️postes vacants : @FereyWorkBot\n▪️publicité : @FereyAdsBot\n\n❗️<b>Régulièrement</b>-mis à jour / contenu",
    'zh': "<b>👩🏽‍💻 Ferey 项目</b>：\n\n▪️项目： @FereyDemoBot\n▪️构造函数： <a href=' https://t.me/FereyBotBot?start=isfree '> @FereyBotBot </a>\n▪️私人帖子： @FereyPostBot\n▪️公共媒体： @FereyMediaBot\n▪️管理： <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️审核： <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️搜索： @FereyFindBot\n▪️目标： @FereyTargetBot\n▪️工具： @FereyToolsBot\n▪️vpn： @FereyVPNBot\n▪️ai： @FereyAIBot\n▪️自动化： <a href=' https://t.me/FereyUserBot?start=isfree '> @FereyUserBot </a>\n▪️职位空缺： @FereyWorkBot\n▪️广告： @FereyAdsBot\n\n❗️<b>定期</b>-更新/内容",
    'ar': "<b>👩🏽‍💻 مشاريع فيري</b>:\n\n▪️المشاريع: @FereyDemoBot\n▪️constructor: <a href=' https://t.me/FereyBotBot?start=isfree '> @FereyBotBot </a>\n▪️المشاركات الخاصة: @FereyPostBot\n▪️وسائل الإعلام العامة: @FereyMediaBot\n▪️administration: <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️moderation: <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️search: @FereyFindBot\n▪️target: @FereyTargetBot\n▪️tools @FereyToolsBot @FereyVPNBot @FereyAIBot _ @FereyUserBot ▪️الوظائف الشاغرة: @FereyWorkBot\n▪️advertising: @FereyAdsBot\n\n❗️<b>بانتظام</b>-يتم التحديث /المحتوى",
}
l_subscribe_btn = {
    'ru': "👩🏽‍💻 Я подписался",
    'en': "👩🏽‍💻 I subscribed",
    'es': "👩🏽‍💻 Me suscribí",
    'fr': "👩🏽‍💻 Je me suis abonné",
    'zh': "👩🏽‍💻我订阅了",
    'ar': "👩🏽‍💻 اشتركت",
}
l_subscribe_all = {
    'ru': "¹ Все боты и проекты",
    'en': "¹ All bots and projects",
    'es': "¹ Todos los bots y proyectos",
    'fr': "¹ Tous les robots et projets",
    'zh': "¹ 所有机器人和项目",
    'ar': "¹ جميع الروبوتات والمشاريع",
}
l_subscribe_already = {
    'ru': "👩🏽‍💻 У вас уже есть активная 💨Подписка",
    'en': "👩🏽‍💻 You already have an active 💨Subscription",
    'es': "👩🏽‍💻 Ya tienes una 💨Suscripción activa",
    'fr': "👩🏽‍💻 Vous avez déjà un 💨Abonnement actif",
    'zh': "👩🏽‍💻 您已经有一个活跃的💨订阅",
    'ar': "👩🏽‍💻 لديك بالفعل 💨اشتراك نشط",
}
l_donate = {
    'ru': "Донат",
    'en': "Donate",
    'es': "Donar",
    'fr': "Don",
    'zh': "捐赠",
    'ar': "تبرع",
}
l_progress = {
    'ru': "Прогресс",
    'en': "Progress",
    'es': "Progreso",
    'fr': "Progrès",
    'zh': "进度",
    'ar': "التقدم",
}
l_marketplace = {
    'ru': "Маркетплейс",
    'en': "Marketplace",
    'es': "Mercado",
    'fr': "Place de marché",
    'zh': "市场",
    'ar': "السوق",
}
l_subscription = {
    'ru': "Подписка",
    'en': "Subscription",
    'es': "Suscripción",
    'fr': "Abonnement",
    'zh': "订阅",
    'ar': "الاشتراك",
}
l_material = {
    'ru': "Материал",
    'en': "Material",
    'es': "Material",
    'fr': "Matériel",
    'zh': "材料",
    'ar': "المادة",
}
l_subscribe_success = {
    'ru': "👩🏽‍💻 <b>Успешный</b> донат!",
    'en': "👩🏽‍💻 <b>Successful</b> donation!",
    'es': "👩🏽‍💻 ¡Donación <b>exitosa</b>!",
    'fr': "👩🏽‍💻 Don <b>réussi</b> !",
    'zh': "👩🏽‍💻 <b>捐款成功</b>！",
    'ar': "👩🏽‍💻 <b>تبرع ناجح</b>!",
}
l_subscribe_balance = {
    'ru': "👩🏽‍💻 Текущий /balance {0}{1}",
    'en': "👩🏽‍💻 Current /balance {0}{1}",
    'es': "👩🏽‍💻 Saldo actual {0}{1}",
    'fr': "👩🏽‍💻 Solde actuel {0}{1}",
    'zh': "👩🏽‍💻 当前余额 {0}{1}",
    'ar': "👩🏽‍💻 الرصيد الحالي {0}{1}",
}
l_subscribe_deposit = {
    'ru': "² Донат на баланс",
    'en': "² Balance Donation",
    'es': "² Donación al saldo",
    'fr': "² Don au solde",
    'zh': "² 余额捐款",
    'ar': "² تبرع إلى الرصيد",
}
l_sub_to_private_channel = {
    "ru": "подписка на канал",
    "en": "subscription to the channel",
    "es": "suscripción al canal",
    "fr": "abonnement au canal",
    "zh": "订阅频道",
    "ar": "الاشتراك في القناة",
}
l_language_get = {
    "ru": "🌏 <b>Выбери</b> один из доступных языков",
    "en": "🌏 <b>Select</b> one of the available languages",
    "es": "🌏 <b>selecciona</b> uno de los idiomas disponibles",
    "fr": "🌏 <b>sélectionnez</b> une des langues disponibles",
    "zh": "🌏<b>选择</b>一种可用语言",
    "ar": "🌏 <b>اختر</b> إحدى اللغات المتاحة",
}
l_language_set = {
    "ru": "{0} Текущий язык: {1}\n\n👩🏽‍💻 Жми /start",
    "en": "{0} Current language: {1}\n\n👩🏽‍💻 Press /start",
    "es": "{0} Idioma actual: {1}\n\n👩🏽‍💻 Pulsa /start",
    "fr": "{0} Langue actuelle : {1}\n\n👩🏽‍💻 Appuyez sur /start",
    "zh": "{0}当前语言：{1}\n\n👩🏽‍💻 点击 /start",
    "ar": "{0} اللغة الحالية: {1}\n\n👩🏽‍💻 اضغط /start",
}
l_ferey_like = {
    "ru": "💔 Лайк",
    "en": "💔 Like",
    "es": "💔 me gusta",
    "fr": "💔 j'aime",
    "zh": "💔 喜欢",
    "ar": "💔 مثل",
}
l_subscribe_main = {
    "ru": "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n",
    "en": "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n",
    "es": "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n",
    "fr": "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n",
    "zh": "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n",
    "ar": "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n",
}
l_paysupport = {
    "ru": "👩🏽‍💻 <b>Возврат</b> средств согласно <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>условиям использования</a> возможен не позднее 21 дня командой /refund для разовых (нерекуррентных) операций",
    "en": "👩🏽‍💻 <b>Refund</b> of funds according to the <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>terms of use</a> is possible no later than 21 days using the /refund command for one-time (non-recurring) transactions",
    "es": "👩🏽‍💻 <b>Reembolso</b> de fondos según los <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>términos de uso</a> es posible no más tarde de 21 días usando el comando /refund para transacciones únicas (no recurrentes)",
    "fr": "👩🏽‍💻 <b>Remboursement</b> des fonds selon les <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>conditions d'utilisation</a> possible au plus tard 21 jours via la commande /refund pour les opérations ponctuelles (non récurrentes)",
    "zh": "👩🏽‍💻 <b>退款</b> 根据 <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>使用条款</a>，不迟于 21 天内可通过 /refund 命令对一次性（非定期）交易进行",
    "ar": "👩🏽‍💻 <b>استرداد الأموال</b> وفقًا لـ <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>شروط الاستخدام</a> ممكن خلال 21 يومًا باستخدام أمر /refund للمعاملات لمرة واحدة (غير المتكررة)",
}
l_refund_need_id = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> прислать ID-операции (более 100 символов), хранящийся в настройках телеграм аккаунта, с которого была произведена оплата в разделе [★ Мои звезды]",
    "en": "👩🏽‍💻 <b>You need</b> to send the transaction ID (more than 100 characters), stored in the Telegram account settings from which the payment was made, in the [★ My Stars] section",
    "es": "👩🏽‍💻 <b>Debe</b> enviar el ID de la transacción (más de 100 caracteres) almacenado en la configuración de la cuenta de Telegram desde la cual se realizó el pago, en la sección [★ Mis estrellas]",
    "fr": "👩🏽‍💻 <b>Vous devez</b> envoyer l'ID de transaction (plus de 100 caractères) stocké dans les paramètres du compte Telegram depuis lequel le paiement a été effectué, dans la section [★ Mes étoiles]",
    "zh": "👩🏽‍💻 <b>您需要</b> 发送存储在 Telegram 账户设置中的交易 ID（超过 100 个字符），该 ID 位于 [★ 我的星星] 部分",
    "ar": "👩🏽‍💻 <b>يجب</b> إرسال معرف المعاملة (أكثر من 100 حرف) المخزن في إعدادات حساب تيليجرام الذي تم الدفع منه، في قسم [★ نجومي]",
}
l_refund_title = {
    "ru": "Возврат",
    "en": "Refund",
    "es": "Reembolso",
    "fr": "Remboursement",
    "zh": "退款",
    "ar": "استرداد الأموال",
}
l_refund_already_done = {
    "ru": "👩🏽‍💻 <b>Возврат</b> уже был произведен ранее",
    "en": "👩🏽‍💻 <b>Refund</b> has already been processed earlier",
    "es": "👩🏽‍💻 <b>Reembolso</b> ya se ha realizado anteriormente",
    "fr": "👩🏽‍💻 <b>Remboursement</b> a déjà été effectué auparavant",
    "zh": "👩🏽‍💻 <b>退款</b> 已经提前处理",
    "ar": "👩🏽‍💻 <b>استرداد الأموال</b> تم معالجته مسبقًا",
}
l_refund_success = {
    "ru": "👩🏽‍💻 <b>Возврат</b> произведен успешно",
    "en": "👩🏽‍💻 <b>Refund</b> has been successfully processed",
    "es": "👩🏽‍💻 <b>Reembolso</b> se ha realizado con éxito",
    "fr": "👩🏽‍💻 <b>Remboursement</b> a été effectué avec succès",
    "zh": "👩🏽‍💻 <b>退款</b> 已成功处理",
    "ar": "👩🏽‍💻 <b>استرداد الأموال</b> تم بنجاح",
}
l_refund_incorrect = {
    "ru": "👩🏽‍💻 <b>Некорректный</b> ID-операции",
    "en": "👩🏽‍💻 <b>Incorrect</b> operation ID",
    "es": "👩🏽‍💻 <b>ID de operación</b> incorrecto",
    "fr": "👩🏽‍💻 <b>ID d'opération</b> incorrect",
    "zh": "👩🏽‍💻 <b>无效的</b> 操作 ID",
    "ar": "👩🏽‍💻 <b>معرف العملية</b> غير صالح",
}
l_refund_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> возврата (возврат не возможен после 21 дня)",
    "en": "👩🏽‍💻 <b>Refund</b> error (refund not possible after 21 days)",
    "es": "👩🏽‍💻 <b>Error</b> de reembolso (no es posible después de 21 días)",
    "fr": "👩🏽‍💻 <b>Erreur</b> de remboursement (non possible après 21 jours)",
    "zh": "👩🏽‍💻 <b>退款</b>错误（21天后无法退款）",
    "ar": "👩🏽‍💻 <b>خطأ</b> في الاسترداد (غير ممكن بعد 21 يومًا)",
}
l_payment_6_months = {
    "ru": "6 месяцев",
    "en": "6 months",
    "es": "6 meses",
    "fr": "6 mois",
    "zh": "6个月",
    "ar": "6 أشهر",
}
l_payment_1_months = {
    "ru": "1 месяц",
    "en": "1 month",
    "es": "1 mes",
    "fr": "1 mois",
    "zh": "1个月",
    "ar": "شهر واحد",
}
l_payment_success = {
    "ru": "👩🏽‍💻 <b>Успешная</b> отправка:",
    "en": "👩🏽‍💻 <b>Successful</b> submission:",
    "es": "👩🏽‍💻 <b>Envío</b> exitoso:",
    "fr": "👩🏽‍💻 <b>Envoi</b> réussi :",
    "zh": "👩🏽‍💻 <b>成功</b>提交：",
    "ar": "👩🏽‍💻 <b>إرسال</b> ناجح:",
}
l_payment_hashtag = {
    "ru": "#оплата",
    "en": "#payment",
    "es": "#pago",
    "fr": "#paiement",
    "zh": "#付款",
    "ar": "#الدفع",
}
l_payment = {
    "ru": "Оплата",
    "en": "Payment",
    "es": "Pago",
    "fr": "Paiement",
    "zh": "付款",
    "ar": "الدفع",
}
l_payment_check_token = {
    "ru": "👩🏽‍💻 <b>Проверьте</b> свой токен для получения платажей",
    "en": "👩🏽‍💻 <b>Check</b> your token to receive payments",
    "es": "👩🏽‍💻 <b>Verifique</b> su token para recibir pagos",
    "fr": "👩🏽‍💻 <b>Vérifiez</b> votre jeton pour recevoir des paiements",
    "zh": "👩🏽‍💻 <b>检查</b>您的令牌以接收付款",
    "ar": "👩🏽‍💻 <b>تحقق</b> من رمزك لتلقي المدفوعات",
}
l_payment_check_token_chn = {
    "ru": "👩🏽‍💻 <b>Проверьте</b> свой токен для получения платажей (бот для приема платежей также должен быть Администратором канала)",
    "en": "👩🏽‍💻 <b>Check</b> your token to receive payments (the payment bot must also be an Administrator of the channel)",
    "es": "👩🏽‍💻 <b>Verifique</b> su token para recibir pagos (el bot de pagos también debe ser Administrador del canal)",
    "fr": "👩🏽‍💻 <b>Vérifiez</b> votre jeton pour recevoir des paiements (le bot de paiement doit également être administrateur de la chaîne)",
    "zh": "👩🏽‍💻 <b>检查</b>您的令牌以接收付款（支付机器人也必须是频道管理员）",
    "ar": "👩🏽‍💻 <b>تحقق</b> من رمزك لتلقي المدفوعات (يجب أن يكون بوت الدفع أيضًا مسؤولاً عن القناة)",
}
l_media_content_successfully_changed = {
    "ru": "👩🏽‍💻 <b>Медиа</b>-контент успешно изменен",
    "en": "👩🏽‍💻 <b>Media</b> content successfully changed",
    "es": "👩🏽‍💻 <b>Contenido</b> multimedia cambiado con éxito",
    "fr": "👩🏽‍💻 <b>Contenu</b> média modifié avec succès",
    "zh": "👩🏽‍💻 <b>媒体</b>内容已成功更改",
    "ar": "👩🏽‍💻 <b>تم</b> تغيير المحتوى الإعلامي بنجاح",
}
l_waiting = {
    "ru": "Ожидание",
    "en": "Waiting",
    "es": "Esperando",
    "fr": "En attente",
    "zh": "等待中",
    "ar": "انتظار",
}
l_don_desc = {
    "ru": "★ Поддержка и развитие",
    "en": "★ Support and development",
    "es": "★ Apoyo y desarrollo",
    "fr": "★ Soutien et développement",
    "zh": "★ 支持与发展",
    "ar": "★ الدعم والتطوير",
}
l_bot_mention_in_story = {
    "ru": "Отметка в сториз",
    "en": "Mention in story",
    "es": "Mención en la historia",
    "fr": "Mention dans l'histoire",
    "zh": "故事中的标记",
    "ar": "الذكر في القصة",
}
l_boost_parse = {
    "ru": "👩🏽‍💻 <b>Boost</b> список",
    "en": "👩🏽‍💻 <b>Boost</b> list",
    "es": "👩🏽‍💻 Lista de <b>Boost</b>",
    "fr": "👩🏽‍💻 Liste <b>Boost</b>",
    "zh": "👩🏽‍💻 <b>Boost</b> 列表",
    "ar": "👩🏽‍💻 قائمة <b>Boost</b>",
}

l_admin_closed_group_reject = {
    "ru": "👩🏽‍💻 Администратор закрытой группы не принял заявки на вступление",
    "en": "👩🏽‍💻 The closed group admin did not accept join requests",
    "es": "👩🏽‍💻 El administrador del grupo cerrado no aceptó las solicitudes de ingreso",
    "fr": "👩🏽‍💻 L'administrateur du groupe fermé n'a pas accepté les demandes d'adhésion",
    "zh": "👩🏽‍💻 私密群组管理员未接受加入申请",
    "ar": "👩🏽‍💻 لم يقبل مسؤول المجموعة المغلقة طلبات الانضمام",
}
l_permissions_add_members = {
    "ru": "🚶 Зайди в «Разрешения» группы и включи <i>участникам группы</i> возможность: [Добавление участников]",
    "en": "🚶 Go to the group's «Permissions» and enable <i>group members</i> the ability to: [Add members]",
    "es": "🚶 Ve a «Permisos» del grupo y habilita a <i>los miembros del grupo</i> la posibilidad de: [Agregar miembros]",
    "fr": "🚶 Va dans les « Permissions » du groupe et active la possibilité pour les <i>membres du groupe</i> de : [Ajouter des membres]",
    "zh": "🚶 进入群组的«权限»，启用<i>群成员</i>的权限：[添加成员]",
    "ar": "🚶 اذهب إلى «الأذونات» الخاصة بالمجموعة وفعّل إمكانية <i>أعضاء المجموعة</i> لـ: [إضافة أعضاء]",
}
l_insert_group_link = {
    "ru": "🚶 Вставь ссылку на группу, а не канал",
    "en": "🚶 Insert the link to the group, not the channel",
    "es": "🚶 Inserta el enlace al grupo, no al canal",
    "fr": "🚶 Insère le lien vers le groupe, pas le canal",
    "zh": "🚶 插入群组链接，而不是频道链接",
    "ar": "🚶 أدخل رابط المجموعة، وليس القناة",
}
l_start_group_check = {
    "ru": "🚶 Начинаем проверку группы..\n#длительность 2мин",
    "en": "🚶 Starting group check..\n#duration 2min",
    "es": "🚶 Comenzando la revisión del grupo..\n#duración 2min",
    "fr": "🚶 Démarrage de la vérification du groupe..\n#durée 2min",
    "zh": "🚶 开始群组检查..\n#持续时间 2分钟",
    "ar": "🚶 بدء فحص المجموعة..\n#المدة 2 دقيقة",
}
l_check_group_members = {
    "ru": "🚶 Проверяем участников группы..\n#длительность 1мин",
    "en": "🚶 Checking group members..\n#duration 1min",
    "es": "🚶 Comprobando los miembros del grupo..\n#duración 1min",
    "fr": "🚶 Vérification des membres du groupe..\n#durée 1min",
    "zh": "🚶 正在检查群成员..\n#持续时间 1分钟",
    "ar": "🚶 جارٍ التحقق من أعضاء المجموعة..\n#المدة 1 دقيقة",
}
l_admin_rights_required = {
    "ru": "🔺 Требуются права админа",
    "en": "🔺 Admin rights required",
    "es": "🔺 Se requieren derechos de administrador",
    "fr": "🔺 Droits d'admin requis",
    "zh": "🔺 需要管理员权限",
    "ar": "🔺 حقوق المسؤول مطلوبة",
}

l_triggers = {
    'ru': "Триггеры",
    'en': "Triggers",
    'es': "Desencadenantes",
    'fr': "Déclencheurs",
    'zh': "触发器",
    'ar': "محفزات",
}
l_actions2 = {
    'ru': "Действия",
    'en': "Actions",
    'es': "Comportamiento",
    'fr': "Actions",
    'zh': "行动",
    'ar': "أجراءات",
}
l_messages = {
    'ru': "Сообщения",
    'en': "Messages",
    'es': "Mensajes",
    'fr': "Messages",
    'zh': "留言",
    'ar': "رسائل",
}
l_languages = {
    'ru': "Языки",
    'en': "Languages",
    'es': "Idiomas",
    'fr': "Langues",
    'zh': "语言",
    'ar': "اللغات",
}
l_buttons = {
    'ru': "Кнопки",
    'en': "Buttons",
    'es': "Botones",
    'fr': "Boutons",
    'zh': "纽扣",
    'ar': "أزرار",
}
l_medias = {
    'ru': "Медиа",
    'en': "Media",
    'es': "Medios de comunicación",
    'fr': "Médias",
    'zh': "媒体",
    'ar': "وسائط",
}
l_users = {
    'ru': "Пользователи",
    'en': "Users",
    'es': "Usuarios",
    'fr': "Utilisateurs",
    'zh': "用户",
    'ar': "المستخدمين",
}

l_cmember_parse = {
    'ru': "👥 <b>Cписок</b> подписчиков: <u>{0}</u>\n\n[✅ <i>Назначение администраторов</i>] - включение опции позволяет получить подписчиков до добавления @{1}-бота\n\n👩🏽‍💻 <b>Оформи</b> <a href='{2}'>💨Подписку</a> для получения имен пользователей",
    'en': "👥 <b>List</b> of subscribers: <u>{0}</u>\n\n[✅ <i>Assigning administrators</i>]-enabling this option allows you to get subscribers before adding @{1}-bot\n\n👩🏽‍💻 <b>Subscribe</b> <a href='{2}'>💨Subscribe</a> to receive usernames",
    'es': "👥 <b>Lista</b> de suscriptores: <u>{0}</u>\n\n[✅ <i>Asignar administradores</i>]-habilitar esta opción le permite obtener suscriptores antes de agregar @ {1}-bot\n\n👩🏽‍💻 <b>Suscríbete</b> <a href='{2}'>💨Suscríbete</a> para recibir nombres de usuario",
    'fr': "👥 <b>Liste</b> des abonnés : <u>{0}</u>\n\n[✅ <i>Attribution des administrateurs</i>]-l'activation de cette option vous permet d'obtenir des abonnés avant d'ajouter @ {1}-bot\n\n👩🏽‍💻 <b>Abonnez-vous</b> <a href='{2}'>💨Abonnez-vous</a> pour recevoir des noms d'utilisateur",
    'zh': "👥 订阅者<b>列表</b>：<u>{0}</u>\n\n[✅ <i>分配管理员</i>]-启用此选项可让您在添加 @ 之前获取订阅者{1}-机器人\n\n👩🏽‍💻 <b>订阅</b> <a href='{2}'>💨订阅</a>以接收用户名",
    'ar': "👥 <b>قائمة</b> المشتركين: <u>{0}</u>\n\n[✅ <i>تعيين المسؤولين</i>]-يتيح لك تمكين هذا الخيار الحصول على مشتركين قبل إضافة @ {1}-bot\n\n👩🏽‍💻 <b>اشتراك</b> <a href='{2}'>💨اشتراك</a> لتلقي أسماء المستخدمين",
}
l_parse_rights = {
    'ru': "👥 <b>В настройках</b> [Администраторы] вкл опцию для @{0}-бота:\n[✅ Назначение администраторов]\n🕚Подожди 1min\n👩🏽‍💻 Выполни команду /parse\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👥 <b>In settings</b> [Administrators] enable the option for @{0}-bot:\n[✅ Assigning administrators]\n🕚Wait 1min\n👩🏽‍💻 Run the command /parse\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👥 <b>En configuración</b> [Administradores] habilita la opción para @{0}-bot:\n[✅ Asignando administradores]\n🕚Espera 1 minuto\n👩🏽‍💻 Ejecuta el comando /parse\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👥 <b>Dans les paramètres</b> [Administrateurs] activez l'option pour @{0}-bot :\n[✅ Attribution des administrateurs]\n🕚Attendez 1 min\n👩🏽‍💻 Exécutez la commande /parse\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👥 <b>在设置中</b> [管理员]启用 @{0}-bot 的选项：\n[✅ 分配管理员]\n🕚等待 1 分钟\n👩🏽‍💻 运行命令 /parse\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👥 <b>في الإعدادات</b> [المسؤولون] قم بتمكين خيار @{0}-bot:\n[✅ تعيين المسؤولين]\n🕚انتظر دقيقة واحدة\n👩🏽‍💻 قم بتشغيل الأمر /parse\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_info_anonymous_for = {
    'ru': "Аноним для",
    'en': "Anonymous for",
    'es': "Anónimo para",
    'fr': "Anonyme pour",
    'zh': "匿名为",
    'ar': "مجهول ل",
}
l_info_oppforpart = {
    'ru': "Возможности участников",
    'en': "Participants' capabilities",
    'es': "Capacidades de los participantes.",
    'fr': "Capacités des participants",
    'zh': "参与者的能力",
    'ar': "قدرات المشاركين",
}
# endregion


# region post
l_post_media = {
    "ru": "✏️ 1. <b>Прикрепи медиа</b> контент для поста: <i>фото/гиф/видео/аудио/документ/стикер</i> или запиши <i>голосовое/телескоп</i>",
    "en": "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or record a <i>voice/telescope</i>",
    "es": "✏️ 1. <b>Adjunta contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/documento/pegatina</i> o graba un <i>mensaje de voz/telescopio</i>",
    "fr": "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/vidéo/audio/document/autocollant</i> ou enregistrez un <i>message vocal/télescope</i>",
    "zh": "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或录制<i>语音/望远镜</i>",
    "ar": "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو سجل <i>ملاحظة صوتية/تلسكوب</i>",
}
l_post_media_wait = {
    "ru": "👩🏽‍💻 <b>Обработка</b> {0}..\n#длительность {1}мин",
    "en": "👩🏽‍💻 <b>Processing</b> {0}..\n#duration {1}min",
    "es": "👩🏽‍💻 <b>Procesando</b> {0}..\n#duración {1}min",
    "fr": "👩🏽‍💻 <b>Traitement</b> {0}..\n#durée {1}min",
    "zh": "👩🏽‍💻 <b>正在处理</b> {0}..\n#时长 {1}分钟",
    "ar": "👩🏽‍💻 <b>المعالجة</b> {0}..\n#المدة {1}دقيقة",
}
l_post_media_toobig = {
    "ru": "👩🏽‍💻 Файл больше 20 Мб, загрузи меньший обьем",
    "en": "👩🏽‍💻 File is larger than 20 MB, upload a smaller file",
    "es": "👩🏽‍💻 El archivo es mayor de 20 MB, sube un archivo más pequeño",
    "fr": "👩🏽‍💻 Le fichier fait plus de 20 Mo, téléchargez un fichier plus petit",
    "zh": "👩🏽‍💻 文件大于20 MB，请上传更小的文件",
    "ar": "👩🏽‍💻 الملف أكبر من 20 ميجا، قم بتحميل ملف أصغر",
}
l_post_media_chat_not_found = {
    "ru": "👩🏽‍💻 Необходимо /start-запустить @{0}-бота перед выполнением операции",
    "en": "👩🏽‍💻 You must /start the @{0} bot before performing the operation",
    "es": "👩🏽‍💻 Debe /start iniciar el bot @{0} antes de realizar la operación",
    "fr": "👩🏽‍💻 Vous devez /start le bot @{0} avant d'exécuter l'opération",
    "zh": "👩🏽‍💻 必须先 /start 启动 @{0} 机器人，然后才能执行操作",
    "ar": "👩🏽‍💻 يجب عليك /start تشغيل البوت @{0} قبل تنفيذ العملية",
}
l_post_media_need_token = {
    "ru": "👩🏽‍💻 Необходимо создать @tg-бота для приема платежей и добавить его токен в настройках приложения",
    "en": "👩🏽‍💻 You need to create a @tg-bot for payment acceptance and add its token in the app settings",
    "es": "👩🏽‍💻 Necesita crear un @tg-bot para recibir pagos y añadir su token en la configuración de la aplicación",
    "fr": "👩🏽‍💻 Vous devez créer un @tg-bot pour accepter les paiements et ajouter son token dans les paramètres de l'application",
    "zh": "👩🏽‍💻 需要创建一个 @tg-机器人用于接收付款，并在应用设置中添加其令牌",
    "ar": "👩🏽‍💻 تحتاج إلى إنشاء @tg-bot لاستقبال المدفوعات وإضافة رمز التوكن الخاص به في إعدادات التطبيق",
}
l_post_sticker_toobig = {
    "ru": "👩🏽‍💻 Загрузи меньший обьем",
    "en": "👩🏽‍💻 Upload a smaller file",
    "es": "👩🏽‍💻 Sube un archivo más pequeño",
    "fr": "👩🏽‍💻 Téléchargez un fichier plus petit",
    "zh": "👩🏽‍💻 上传更小的文件",
    "ar": "👩🏽‍💻 قم بتحميل ملف أصغر",
}
l_media_isvideonote = {
    "ru": "👩🏽‍💻 <b>Использовать</b> это квадратное видео как <b>телескоп</b> <i>(круглая видео-заметка)</i>?",
    "en": "👩🏽‍💻 <b>Use</b> this square video as a <b>telescope</b> <i>(round video note)</i>?",
    "es": "👩🏽‍💻 ¿<b>usar</b> este vídeo cuadrado como <b>telescopio</b> <i>(nota de vídeo redonda)</i>?",
    "fr": "👩🏽‍💻 <b>Utiliser</b> cette vidéo carrée comme <b>télescope</b> <i>(note vidéo ronde)</i> ?",
    "zh": "👩🏽‍💻 <b>使用</b>此方形视频作为<b>望远镜</b><i>（圆形视频注释）</i>？",
    "ar": "👩🏽‍💻 <b>هل تستخدم</b> هذا الفيديو المربع كـ<b>تلسكوب</b> <i>(ملاحظة فيديو مستديرة)</i>؟",
}

l_post_text = {
    "ru": "✏️ 2. <b>Введи текст</b> (<i>не забудь использовать форматирование</i>)\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ 2. <b>Enter your text</b> (<i>don’t forget to use formatting</i>)\n\n<blockquote>or click “➡️️/Next” to skip this step</blockquote>",
    "es": "✏️ 2. <b>Ingresa tu texto</b> (<i>no olvides usar el formato</i>)\n\n<blockquote>o haz clic en “➡️️/Siguiente” para omitir este paso</blockquote>",
    "fr": "✏️ 2. <b>Saisissez votre texte</b> (<i>n'oubliez pas d'utiliser le formatage</i>)\n\n<blockquote>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</blockquote>",
    "zh": "✏️ 2. <b>输入您的文字</b>（<i>不要忘记使用格式</i>）\n\n<blockquote>或点击“➡️️/下一步”跳过此步骤</blockquote>",
    "ar": "✏️ 2. <b>أدخل النص</b> (<i>لا تنس استخدام التنسيق</i>)\n\n<blockquote>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</blockquote>",
}
l_post_text_limit = {
    "ru": "❗️ <b>Количество символов</b> текста (<i>включая форматирование</i>): <u>{0}</u> больше 1024",
    "en": "❗️ <b>Number of characters</b> of text (<i>including formatting</i>): <u>{0}</u> more than 1024",
    "es": "❗️ <b>Número de caracteres</b> de texto (<i>formato incluido</i>): <u>{0}</u> más de 1024",
    "fr": "❗️ <b>Nombre de caractères</b> du texte (<i>formatage compris</i>) : <u>{0}</u> supérieur à 1 024",
    "zh": "❗️ 文本<b>字符数</b>（<i>包括格式</i>）：<u>{0}</u> 超过 1024",
    "ar": "❗️ <b>عدد الأحرف</b> في النص (<i>بما في ذلك التنسيق</i>): <u>{0}</u> أكثر من 1024",
}
l_post_tgph = {
    "ru": "✏️ *2. Использовать загруженный <b>media</b>-контент в виде <u>предпросмотра</u> внизу поста (работает только с <i>jpg|png|gif|mp4</i>-файлами до 5Mb)?\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ *2. Use downloaded <b>media</b> content as a <u>preview</u> at the bottom of the post (only works with <i>jpg|png|gif|mp4</i> files up to 5Mb)?\n\n<blockquote>or click “➡️️/Next” to skip this step</blockquote>",
    "es": "✏️ *2. Utilice el contenido <b>media</b> descargado como una <u>vista previa</u> en la parte inferior de la publicación (solo funciona con archivos <i>jpg|png|gif|mp4</i> de hasta 5 MB) ?\n\n<blockquote>o haga clic en “➡️️/Siguiente” para omitir este paso</blockquote>",
    "fr": "✏️*2. Utiliser le contenu <b>média</b> téléchargé comme <u>aperçu</u> au bas de la publication (fonctionne uniquement avec les fichiers <i>jpg|png|gif|mp4</i> jusqu'à 5 Mo) ?\n\n<blockquote>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</blockquote>",
    "zh": "✏️*2。在帖子底部使用下载的<b>媒体</b>内容作为<u>预览</u>（仅适用于最大5Mb的<i>jpg|png|gif|mp4</i>文件） ?\n\n<blockquote>或点击“➡️️/下一步”跳过此步骤</blockquote>",
    "ar": "✏️*2. استخدم محتوى <b>الوسائط</b> الذي تم تنزيله ك<u>معاينة</u> أسفل المشاركة (يعمل فقط مع ملفات <i>jpg|png|gif|mp4</i> التي يصل حجمها إلى 5 ميجابايت) ?\n\n<blockquote>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</blockquote>",
}

l_post_tgph_yes = {
    "ru": "✅ Да",
    "en": "✅ Yes",
    "es": "✅ Sí",
    "fr": "✅ Oui",
    "zh": "✅ 是的",
    "ar": "✅ نعم",
}
l_post_tgph_no = {
    "ru": "☑️ Нет",
    "en": "☑️ No",
    "es": "☑️ No",
    "fr": "☑️ Non",
    "zh": "☑️ 没有",
    "ar": "☑️ لا",
}
l_post_button = {
    "ru": "✏️ 3. <b>Введи названия</b> для кнопок и <b>ссылки</b> в формате (одну или несколько; кликни на образец ниже, чтобы скопировать):\n\n<code>[🐳 Link | {0}]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ 3. <b>Enter names</b> for buttons and <b>links</b> in the format (one or more; click on the example below to copy):\n\n<code>[🐳 Link | {0}]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>or click “➡️️/Next” to skip this step</blockquote>",
    "es": "✏️ 3. <b>Ingrese nombres</b> para botones y <b>enlaces</b> en el formato (uno o más; haga clic en el siguiente ejemplo para copiar):\n\n<code>[🐳 Enlace | {0}]\n\n[❤️ Me gusta][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>o haga clic en “➡️️/Siguiente” para omitir este paso</blockquote>",
    "fr": "✏️ 3. <b>Entrez les noms</b> des boutons et des <b>liens</b> au format (un ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Lien | {0}]\n\n[❤️ J'aime][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</blockquote>",
    "zh": "✏️ 3. <b>输入按钮和<b>链接</b>的名称</b>，格式为（一个或多个；点击下面的示例进行复制）：\n\n<code>[🐳 链接 | {0}]\n\n[❤️ 喜欢][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>或点击“➡️️/下一步”跳过此步骤</blockquote>",
    "ar": "✏️ 3. <b>أدخل أسماء</b> للأزرار و<b>الروابط</b> بالتنسيق (واحد أو أكثر؛ انقر على المثال أدناه للنسخ):\n\n<code>[🐳 الرابط | {0}]\n\n[❤️ لايك][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</blockquote>",
}

l_post_button_chn = {
    "ru": "✏️ 3. <b>Введи названия</b> для кнопок и <b>ссылки</b> в формате (одну или несколько; кликни на образец ниже, чтобы скопировать):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ 3. <b>Enter names</b> for buttons and <b>links</b> in the format (one or more; click on the example below to copy):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    "es": "✏️ 3. <b>Ingrese nombres</b> para botones y <b>enlaces</b> en el formato (uno o más; haga clic en el siguiente ejemplo para copiar):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Me gusta][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    "fr": "✏️ 3. <b>Entrez les noms</b> des boutons et des <b>liens</b> au format (un ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ J'aime][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    "zh": "✏️ 3. <b>输入按钮和<b>链接</b>的名称</b>，格式如下（一个或多个；点击下面的示例进行复制）：\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ 喜欢][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>或点击“➡️️/下一步”跳过此步骤</i>)",
    "ar": "✏️ 3. <b>أدخل أسماء</b> للأزرار و<b>الروابط</b> بالتنسيق (واحد أو أكثر؛ انقر على المثال أدناه للنسخ):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ لايك][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}

l_post_button_urlinvalid = {
    "ru": "🔗 Ссылка {0} не действительна",
    "en": "🔗 Link {0} is not valid",
    "es": "🔗 El enlace {0} no es válido",
    "fr": "🔗 Le lien {0} n'est pas valide",
    "zh": "🔗 链接 {0} 无效",
    "ar": "🔗 الرابط {0} غير صالح",
}
l_post_date = {
    "ru": "✏️ <b>Выбери дату</b> на календаре\n\n<blockquote>или жми «➡️️/Next», чтобы не указывать дату</blockquote>",
    "en": "✏️ <b>Select a date</b> on the calendar\n\n(<i>or click “➡️️/Next” to not specify a date</i>)",
    "es": "✏️ <b>Seleccione una fecha</b> en el calendario\n\n(<i>o haga clic en “➡️️/Siguiente” para no especificar una fecha</i>)",
    "fr": "✏️ <b>Sélectionnez une date</b> sur le calendrier\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ne pas spécifier de date</i>)",
    "zh": "✏️<b>在日历上选择日期</b>\n\n（<i>或点击“➡️️/下一步”不指定日期</i>）",
    "ar": "✏️ <b>حدد تاريخًا</b> في التقويم\n\n(<i>أو انقر على '➡️️/التالي' لعدم تحديد تاريخ</i>)",
}
l_post_timer = {
    "ru": "✏️ <b>Выбери дату</b> на календаре для <b>авто-удаления</b> поста\n\n<blockquote>или жми «➡️️/Next», чтобы не указывать дату</blockquote>",
    "en": "✏️ <b>Select a date</b> on the calendar for <b>auto-deleting</b> post\n\n(<i>or click “➡️️/Next” to not specify the date</i>)",
    "es": "✏️ <b>Seleccione una fecha</b> en el calendario para la <b>eliminación automática</b> de la publicación\n\n(<i>o haga clic en “➡️️/Siguiente” para no especificar la fecha</i>)",
    "fr": "✏️ <b>Sélectionnez une date</b> sur le calendrier pour la <b>suppression automatique</b> de la publication\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ne pas spécifier la date</i>)",
    "zh": "✏️ 在日历上<b>选择日期</b><b>自动删除</b>帖子\n\n（<i>或点击“➡️️/下一步”不指定日期</i>）",
    "ar": "✏️ <b>حدد تاريخًا</b> في التقويم <b>للحذف التلقائي</b> لمنشور\n\n(<i>أو انقر على '➡️️/التالي' لعدم تحديد التاريخ</i>)",
}
l_post_window = {
    "ru": "✏️ *<b>Введи</b> текст для <i>диалогового окна</i> при нажатии на <u>кнопки</u> <b>поста</b>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ *<b>Enter</b> text for the <i>dialog box</i> when clicking the <u>button</u> <b>post</b>\n\n(<i>or click '➡️️/Next' to skip this step</i>)",
    "es": "✏️ *<b>Ingrese</b> texto para el <i>cuadro de diálogo</i> al hacer clic en el <u>botón</u> <b>publicación</b>\n\n(<i>o haga clic en '➡️/Siguiente' para omitir este paso</i>)",
    "fr": "✏️ *<b>Entrez</b> le texte pour la <i>boîte de dialogue</i> lorsque vous cliquez sur le <u>bouton</u> <b>publier</b>\n\n(<i>ou cliquez sur '➡️️/Suivant' pour ignorer cette étape</i>)",
    "zh": "✏️ *点击<u>按钮</u>时<b>在<i>对话框</i>中输入</b>文本<b>发布</b>\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    "ar": "✏️ *<b>أدخل</b> نص <i>مربع الحوار</i> عند النقر فوق الزر <u>الزر</u> <b>النشر</b>\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}

l_post_window_limit = {
    "ru": "❗️ <b>Количество символов</b> диалогового окна: <u>{0}</u> больше допустимых 200",
    "en": "❗️ <b>Number of characters</b> of the dialog box: <u>{0}</u> more than the allowed 200",
    "es": "❗️ <b>Número de caracteres</b> del cuadro de diálogo: <u>{0}</u> más de los 200 permitidos",
    "fr": "❗️ <b>Nombre de caractères</b> de la boîte de dialogue : <u>{0}</u> supérieur aux 200 autorisés",
    "zh": "❗️ 对话框的<b>字符数</b>：<u>{0}</u>超过允许的200个",
    "ar": "❗️ <b>عدد الأحرف</b> في مربع الحوار: <u>{0}</u> أكثر من 200 حرف المسموح به",
}
l_post_finish = {
    "ru": "✅ <b>Пост готов</b>\n\n<i>Нажми «➡️️/Next», чтобы подтвердить, а затем на кнопку: [🔗 Публикация]</i>",
    "en": "✅ <b>The post is ready</b>\n\n<i>Click “➡️️/Next” to confirm, and then click the button: [🔗 Publish]</i>",
    "es": "✅ <b>La publicación está lista</b>\n\n<i>Haga clic en “➡️️/Siguiente” para confirmar y luego haga clic en el botón: [🔗 Publicar]</i>",
    "fr": "✅ <b>La publication est prête</b>\n\n<i>Cliquez sur « ➡️️/Suivant » pour confirmer, puis cliquez sur le bouton : [🔗 Publier]</i>",
    "zh": "✅ <b>帖子已准备就绪</b>\n\n<i>点击“➡️️/下一步”确认，然后点击按钮：[🔗发布]</i>",
    "ar": "✅ <b>المنشور جاهز</b>\n\n<i>انقر على “➡️️/التالي” للتأكيد، ثم انقر على الزر: [🔗 نشر]</i>",
}
l_switch_pm_text = {
    "ru": "🔗 Создать пост с кнопкой",
    "en": "🔗 Create a post with a button",
    "es": "🔗 Crea una publicación con un botón",
    "fr": "🔗 Créer une publication avec un bouton",
    "zh": "🔗 使用按钮创建帖子",
    "ar": "🔗 إنشاء مشاركة بزر",
}
l_post_new = {
    "ru": "⛰ Создать",
    "en": "⛰ Create",
    "es": "⛰ Crear",
    "fr": "⛰ Créer",
    "zh": "⛰ 创建",
    "ar": "⛰ إنشاء",
}
l_post_delete = {
    "ru": "🚫 Удалить",
    "en": "🚫 Delete",
    "es": "🚫 Eliminar",
    "fr": "🚫 Supprimer",
    "zh": "🚫 删除",
    "ar": "🚫 حذف",
}
l_post_change = {
    "ru": "♻️ Изменить",
    "en": "♻️ Edit",
    "es": "♻️ Editar",
    "fr": "♻️ Modifier",
    "zh": "♻️ 编辑",
    "ar": "♻️ تحرير",
}
l_post_creation = {
    "ru": "<b>Дата создания</b>",
    "en": "<b>Date of creation</b>",
    "es": "<b>Fecha de creación</b>",
    "fr": "<b>Date de création</b>",
    "zh": "<b>创建日期</b>",
    "ar": "<b>تاريخ الإنشاء</b>",
}

l_post_publish = {
    "ru": "🔗 Публикация",
    "en": "🔗 Post",
    "es": "🔗 Publicar",
    "fr": "🔗 Publier",
    "zh": "🔗 发帖",
    "ar": "🔗 مشاركة",
}
l_post_pub = {
    "ru": "👩🏽‍💻 Пост опубликован",
    "en": "👩🏽‍💻 Post published",
    "es": "👩🏽‍💻 Publicación publicada",
    "fr": "👩🏽‍💻 Article publié",
    "zh": "👩🏽‍💻 帖子已发布",
    "ar": "👩🏽‍💻 تم نشر المنشور",
}
l_post_error = {
    "ru": "👩🏽‍💻 Ошибка опубликации",
    "en": "👩🏽‍💻 Posting error",
    "es": "👩🏽‍💻 Error de publicación",
    "fr": "👩🏽‍💻 Erreur de publication",
    "zh": "👩🏽‍💻 发帖错误",
    "ar": "👩🏽‍💻 خطأ في النشر",
}
l_post_btn_answer = {
    "ru": "✅ <b>Пользователь</b> <b>{0}</b> (username={1}, id={2}) <i>нажал</i> на [<b>{3}</b>] в посте #<u>{4}</u>",
    "en": "✅ <b>User</b> <b>{0}</b> (username={1}, id={2}) <i>clicked</i> on [<b>{3}</b>] in post #<u>{4}</u>",
    "es": "✅ <b>Usuario</b> <b>{0}</b> (nombre de usuario={1}, id={2}) <i>hizo clic</i> en [<b>{3}</b>] en la publicación #<u>{4}</u>",
    "fr": "✅ <b>Utilisateur</b> <b>{0}</b> (nom d'utilisateur={1}, id={2}) <i>cliqué</i> sur [<b>{3}</b>] dans le message n°<u>{4}</u>",
    "zh": "✅ <b>用户</b> <b>{0}</b>（用户名={1}，id={2}）<i>点击了</i> [<b>{3}</b>] 帖子#<u>{4}</u>",
    "ar": "✅ <b>المستخدم</b> <b>{0}</b> (اسم المستخدم={1}, المعرف={2}) <i>النقر</i> على [<b>{3}</b>] في المشاركة #<u>{4}</u>",
}

l_post_datetime = {
    "ru": "<b>Дата</b>",
    "en": "<b>Date</b>",
    "es": "<b>Fecha</b>",
    "fr": "<b>Date</b>",
    "zh": "<b>日期</b>",
    "ar": "<b>التاريخ</b>",
}
l_post_preview = {
    "ru": "<b>Превью</b>",
    "en": "<b>Preview</b>",
    "es": "<b>Vista previa</b>",
    "fr": "<b>Aperçu</b>",
    "zh": "<b>预览</b>",
    "ar": "<b>معاينة</b>",
}
l_post_buttons = {
    "ru": "<b>Кнопки</b>",
    "en": "<b>Buttons</b>",
    "es": "<b>Botones</b>",
    "fr": "<b>Boutons</b>",
    "zh": "<b>按钮</b>",
    "ar": "<b>الأزرار</b>",
}
l_post_pins = {
    "ru": "<b>Закреп</b>",
    "en": "<b>Pin</b>",
    "es": "<b>Fijar</b>",
    "fr": "<b>Épingler</b>",
    "zh": "<b>固定</b>",
    "ar": "<b>تثبيت</b>",
}

l_btn = {
    "ru": "кнопки",
    "en": "buttons",
    "es": "botones",
    "fr": "boutons",
    "zh": "纽扣",
    "ar": "أزرار",
}
l_default = {
    "ru": "по умолчанию",
    "en": "default",
    "es": "por defecto",
    "fr": "défaut",
    "zh": "默认",
    "ar": "افتراضي",
}
l_silence = {
    "ru": "тихо",
    "en": "quiet",
    "es": "tranquilo",
    "fr": "calme",
    "zh": "安静的",
    "ar": "هادئ",
}
l_pin = {
    "ru": "закреп",
    "en": "pin",
    "es": "fijar",
    "fr": "épingler",
    "zh": "固定",
    "ar": "تثبيت",
}
l_preview = {
    "ru": "превью",
    "en": "preview",
    "es": "avance",
    "fr": "aperçu",
    "zh": "预览",
    "ar": "معاينة",
}

l_spoiler = {
    "ru": "спойлер",
    "en": "spoiler",
    "es": "revelación",
    "fr": "divulgacher",
    "zh": "剧透",
    "ar": "المفسد",
}
l_podcast = {
    "ru": "подкаст",
    "en": "podcast",
    "es": "podcast",
    "fr": "podcast",
    "zh": "播客",
    "ar": "تدوين صوتي",
}
l_album = {
    "ru": "альбом",
    "en": "album",
    "es": "álbum",
    "fr": "album",
    "zh": "专辑",
    "ar": "الألبوم",
}
l_gallery = {
    "ru": "галерея",
    "en": "gallery",
    "es": "galería",
    "fr": "galerie",
    "zh": "画廊",
    "ar": "صالة عرض",
}
l_format = {
    "ru": "формат",
    "en": "format",
    "es": "formato",
    "fr": "format",
    "zh": "格式",
    "ar": "شكل",
}
l_reaction = {
    "ru": "реакция",
    "en": "reaction",
    "es": "reacción",
    "fr": "réaction",
    "zh": "反应",
    "ar": "رد فعل",
}
l_effect = {
    "ru": "эффект",
    "en": "effect",
    "es": "efecto",
    "fr": "effet",
    "zh": "效果",
    "ar": "تأثير",
}

l_blog = {
    "ru": "блог",
    "en": "blog",
    "es": "blog",
    "fr": "blog",
    "zh": "博客",
    "ar": "مدونة",
}
l_web = {
    "ru": "веб",
    "en": "web",
    "es": "web",
    "fr": "web",
    "zh": "网络",
    "ar": "الويب",
}
l_notice = {
    "ru": "нотис",
    "en": "notice",
    "es": "aviso",
    "fr": "avis",
    "zh": "注意",
    "ar": "إشعار",
}
l_window = {
    "ru": "окно",
    "en": "window",
    "es": "ventana",
    "fr": "fenêtre",
    "zh": "窗户",
    "ar": "نافذة",
}
l_remoji = {
    "ru": "Эмоджи",
    "en": "Emoji",
    "es": "Emojis",
    "fr": "Émoji",
    "zh": "表情符号",
    "ar": "الرموز التعبيرية",
}

l_theme = {
    "ru": "Тема",
    "en": "Topic",
    "es": "Tema",
    "fr": "Sujet",
    "zh": "话题",
    "ar": "عنوان",
}
l_destruct = {
    "ru": "Самоуничтожение контента",
    "en": "Self-destruct photo/video",
    "es": "Foto/video de autodestrucción",
    "fr": "Photo/vidéo d'autodestruction",
    "zh": "自毁照片/视频",
    "ar": "صورة/فيديو التدمير الذاتي",
}
l_tag = {
    "ru": "@tag",
    "en": "@tag",
    "es": "@etiqueta",
    "fr": "@étiqueter",
    "zh": "@标签",
    "ar": "@بطاقة شعار",
}
l_via = {
    "ru": "@via",
    "en": "@via",
    "es": "@a través de",
    "fr": "@via",
    "zh": "@通过",
    "ar": "@عبر",
}

l_buttons_text = {
    'ru': "👩🏽‍💻 Режим [✅ кнопки] доступен, если создана хотя бы 1 кнопка при создании поста",
    'en': "👩🏽‍💻 [✅ buttons] mode is available if at least 1 button is created when creating a post",
    'es': "👩🏽‍💻 El modo [✅ botones] está disponible si se crea al menos 1 botón al crear una publicación",
    'fr': "👩🏽‍💻 Le mode [✅ boutons] est disponible si au moins 1 bouton est créé lors de la création d'une publication",
    'zh': "👩🏽‍💻 创建帖子时至少创建 1 个按钮即可使用 [✅ 按钮] 模式",
    'ar': "👩🏽‍💻 يتوفر وضع [✔ الأزرار] في حالة إنشاء زر واحد على الأقل عند إنشاء منشور",
}
l_preview_text = {
    'ru': "👩🏽‍💻 Режим [✅ превью] используется с jpg|png|gif|mp4-файлами до 5Mb",
    'en': "👩🏽‍💻 [✅ preview] mode is used with jpg|png|gif|mp4 files up to 5Mb",
    'es': "👩🏽‍💻 El modo [✅ vista previa] se usa con archivos jpg|png|gif|mp4 de hasta 5Mb",
    'fr': "👩🏽‍💻 Le mode [✅ aperçu] est utilisé avec les fichiers jpg|png|gif|mp4 jusqu'à 5 Mo",
    'zh': "👩🏽‍💻 [✅预览]模式适用于最大5Mb的jpg|png|gif|mp4文件",
    'ar': "👩🏽‍💻 يُستخدم وضع [✅ المعاينة] مع ملفات jpg|png|gif|mp4 التي يصل حجمها إلى 5 ميجابايت",
}
l_gallery_text = {
    'ru': "👩🏽‍💻 Режим [✅ галерея] доступен для 2 и более медиа файлов",
    'en': "👩🏽‍💻 [✅ gallery] mode is available for 2 or more media files",
    'es': "👩🏽‍💻 El modo [✅ galería] está disponible para 2 o más archivos multimedia",
    'fr': "👩🏽‍💻 Le mode [✅ galerie] est disponible pour 2 fichiers multimédias ou plus",
    'zh': "👩🏽‍💻 [✅ 图库] 模式适用于 2 个或更多媒体文件",
    'ar': "👩🏽‍💻 وضع ​​[✔ المعرض] متاح لملفين وسائط أو أكثر",
}
l_spoiler_text = {
    'ru': "👩🏽‍💻 Режим [✅ спойлер] доступен для photo/gif/video контента",
    'en': "👩🏽‍💻 [✅ spoiler] mode is available for photo/gif/video content",
    'es': "👩🏽‍💻 El modo [✅ spoiler] está disponible para contenido de foto/gif/video",
    'fr': "👩🏽‍💻 Le mode [✅ spoiler] est disponible pour le contenu photo/gif/vidéo",
    'zh': "👩🏽‍💻 [✅剧透]模式适用于照片/gif/视频内容",
    'ar': "👩🏽‍💻 وضع ​​[✅ المفسد] متاح لمحتوى الصور / GIF / الفيديو",
}
l_podcast_call = {
    'ru': "👩🏽‍💻 Режим [✅ подкаст] доступен для audio/voice/video контента или youtube-ссылок в тексте",
    'en': "👩🏽‍💻 [✅ podcast] mode is available for audio/voice/video content",
    'es': "👩🏽‍💻 El modo [✅ podcast] está disponible para contenido de audio/voz/vídeo",
    'fr': "👩🏽‍💻 Le mode [✅ podcast] est disponible pour le contenu audio/voix/vidéo",
    'zh': "👩🏽‍💻 [✅ 播客] 模式可用于音频/语音/视频内容",
    'ar': "👩🏽‍💻 وضع ​​[✅ البودكاست] متاح لمحتوى الصوت/الصوت/الفيديو",
}
l_window_text = {
    'ru': "👩🏽‍💻 Режим [окно] доступен для постов с кнопками без ссылок",
    'en': "👩🏽‍💻 [Window] mode is available for posts with buttons without links",
    'es': "👩🏽‍💻 El modo [Ventana] está disponible para publicaciones con botones sin enlaces",
    'fr': "👩🏽‍💻 Le mode [Fenêtre] est disponible pour les publications avec des boutons sans liens",
    'zh': "👩🏽‍💻 [窗口]模式适用于带有按钮但没有链接的帖子",
    'ar': "👩🏽‍💻 وضع ​​[النافذة] متاح للمشاركات التي تحتوي على أزرار بدون روابط",
}

l_tag_text = {
    'ru': "👩🏽‍💻 Режим [✅ @tag] доступен для текста без режима @via-бот",
    'en': "👩🏽‍💻 [✅ @tag] mode is available for text without @via-bot mode",
    'es': "👩🏽‍💻 El modo [✅ @tag] está disponible para texto sin el modo @via-bot",
    'fr': "👩🏽‍💻 [✅ Le mode @tag] est disponible pour le texte sans le mode @via-bot",
    'zh': "👩🏽‍💻 [✅ @tag] 模式适用于没有 @via-bot 模式的文本",
    'ar': "👩🏽‍💻 وضع ​​[✅ @tag] متاح للنص بدون وضع @via-bot",
}
l_destruct_text = {
    'ru': "👩🏽‍💻 Режим [✅ Самоуничтожение] доступен для фото/видео/голосовое/телескоп-контента без режима @via-бот",
    'en': "👩🏽‍💻 [✅ Self-destruction] mode is available for photo/video content without @via-bot mode",
    'es': "👩🏽‍💻 [✅ El modo Autodestrucción] está disponible para contenido de foto/vídeo sin el modo @via-bot",
    'fr': "👩🏽‍💻 Le mode [✅ Autodestruction] est disponible pour le contenu photo/vidéo sans le mode @via-bot",
    'zh': "👩🏽‍💻 [✅自毁]模式适用于没有@via-bot模式的照片/视频内容",
    'ar': "👩🏽‍💻 وضع ​​[✅ التدمير الذاتي] متاح لمحتوى الصور/الفيديو بدون وضع @via-bot",
}
l_post_has_restricted = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> отправки видео-заметки/голосового для premium-аккаунта! В настройках <b>[Конфиденциальность]</b> добавь @{0} в <i>исключения</i> для <b>[Голосовые сообщения]</b>, чтобы отобразить видео-заметку/голосовое",
    'en': "👩🏽‍💻 You have a premium account! In <b>[Privacy]</b> settings, add @{0} to <i>exceptions</i> for <b>[Voice messages]</b> to display video note/voice",
    'es': "👩🏽‍💻 ¡Tienes una cuenta premium! En la configuración de <b>[Privacidad]</b>, agregue @{0} a las <i>excepciones</i> para <b>[Mensajes de voz]</b> para mostrar notas de video/voz.",
    'fr': "👩🏽‍💻 Vous disposez d'un compte premium ! Dans les paramètres <b>[Confidentialité]</b>, ajoutez @{0} aux <i>exceptions</i> pour <b>[Messages vocaux]</b> afin d'afficher la note vidéo/la voix.",
    'zh': "👩🏽‍💻 您有一个高级帐户！在<b>[隐私]</b>设置中，将@{0}添加到<b>[语音消息]</b>的<i>例外</i>中，以显示视频注释/语音",
    'ar': "👩🏽‍💻 لديك حساب مميز! في إعدادات <b>[الخصوصية]</b>، أضف @{0} إلى <i>الاستثناءات</i> لـ <b>[الرسائل الصوتية]</b> لعرض ملاحظة/صوت الفيديو",
}
l_post_tz = {
    'ru': "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 <b>Текущее</b> время: <u>{0}</u> ({1}{2} по Гринвичу)",
    'en': "📍 <b>Time zone</b> of the geolocation is set\n\n🕐 <b>Current</b> time: <u>{0}</u> ({1}{2} GMT)",
    'es': "📍 La <b>zona horaria</b> de la geolocalización está configurada\n\n🕐 Hora <b>actual</b>: <u>{0}</u> ({1}{2} GMT)",
    'fr': "📍 <b>Le fuseau horaire</b> de la géolocalisation est défini\n\n🕐 <b>Heure actuelle</b> : <u>{0}</u> ({1}{2} GMT)",
    'zh': "📍 地理位置的<b>时区</b>已设置\n\n🕐<b>当前</b>时间：<u>{0}</u>（{1}{2} GMT）",
    'ar': "📍 تم ضبط <b>المنطقة الزمنية</b> للموقع الجغرافي\n\n🕐 التوقيت <b>الحالي</b>: <u>{0}</u> ({1}{2} بتوقيت جرينتش)",
}
l_post_time_future = {
    'ru': "🕒 <b>Укажи</b> дату и время в будущем",
    'en': "🕒 <b>Specify</b> a date and time in the future",
    'es': "🕒 <b>Especifique</b> una fecha y hora en el futuro",
    'fr': "🕒 <b>Spécifiez</b> une date et une heure dans le futur",
    'zh': "🕒<b>指定</b>未来的日期和时间",
    'ar': "🕒 <b>حدد</b> التاريخ والوقت في المستقبل",
}
l_me = {
    'ru': "👤 Себе",
    'en': "👤 Yourself",
    'es': "👤 Tú mismo",
    'fr': "👤 Vous-même",
    'zh': "👤 你自己",
    'ar': "👤 نفسك",
}

l_all = {
    'ru': "👥 Всем",
    'en': "👥 Everyone",
    'es': "👥 Todos",
    'fr': "👥 Tout le monde",
    'zh': "👥 大家",
    'ar': "👥 الجميع",
}
l_usr = {
    'ru': "👩🏽‍💻 Юзер",
    'en': "👩🏽‍💻 User",
    'es': "👩🏽‍💻 Usuario",
    'fr': "👩🏽‍💻 Utilisateur",
    'zh': "👩🏽‍💻 用户",
    'ar': "👩🏽‍💻 المستخدم",
}
l_username = {
    'ru': "👩🏽‍💻 @username",
    'en': "👩🏽‍💻 @username",
    'es': "👩🏽‍💻 @username",
    'fr': "👩🏽‍💻 @username",
    'zh': "👩🏽‍💻 @username",
    'ar': "👩🏽‍💻 @username",
}
l_bot = {
    'ru': "👩🏽‍💻 Бот",
    'en': "👩🏽‍💻 Bot",
    'es': "👩🏽‍💻 robot",
    'fr': "👩🏽‍💻 Bot",
    'zh': "👩🏽‍💻 机器人",
    'ar': "👩🏽‍💻 بوت",
}
l_channel = {
    'ru': "👩🏽‍💻 Канал",
    'en': "👩🏽‍💻 Channel",
    'es': "👩🏽‍💻 Canal",
    'fr': "👩🏽‍💻 Chaîne",
    'zh': "👩🏽‍💻频道",
    'ar': "👩🏽‍💻 القناة",
}
l_chn = {
    'ru': "канал",
    'en': "сhannel",
    'es': "сanal",
    'fr': "сhaîne",
    'zh': "频道",
    'ar': "القناة",
}
l_group = {
    'ru': "👩🏽‍💻 Группа",
    'en': "👩🏽‍💻 Group",
    'es': "👩🏽‍💻 Grupo",
    'fr': "👩🏽‍💻 Groupe",
    'zh': "👩🏽‍💻组",
    'ar': "👩🏽‍💻 المجموعة",
}

l_user = {
    'ru': "👩🏽‍💻 Пользователи",
    'en': "👩🏽‍💻 Users",
    'es': "👩🏽‍💻 Usuarios",
    'fr': "👩🏽‍💻 Utilisateurs",
    'zh': "👩🏽‍💻 用户",
    'ar': "👩🏽‍💻 المستخدمين",
}
l_ids = {
    'ru': "🙌🏽 По id",
    'en': "🙌🏽 By id",
    'es': "🙌🏽 Por identificación",
    'fr': "🙌🏽 Par pièce d'identité",
    'zh': "🙌🏽 通过 ID",
    'ar': "🙌🏽 عن طريق الهوية",
}
l_recipient = {
    'ru': "👩🏽‍💻 <b>Выбери</b> получателя",
    'en': "👩🏽‍💻 <b>Choose</b> recipient",
    'es': "👩🏽‍💻 <b>Elegir</b> destinatario",
    'fr': "👩🏽‍💻 <b>Choisissez</b> le destinataire",
    'zh': "👩🏽‍💻<b>选择</b>收件人",
    'ar': "👩🏽‍💻 <b>اختر</b> المستلم",
}
l_enter = {
    'ru': "👩🏽‍💻 <b>Введи</b> Ids получателей через <i>пробелы/раздели</i>",
    'en': "👩🏽‍💻 <b>Enter</b> Recipients' Ids separated by <i>spaces/separate</i>",
    'es': "👩🏽‍💻 <b>Ingrese</b> los ID de los destinatarios separados por <i>espacios/separados</i>",
    'fr': "👩🏽‍💻 <b>Entrez</b> les identifiants des destinataires séparés par <i>espaces/séparés</i>",
    'zh': "👩🏽‍💻<b>输入</b>收件人 ID，以<i>空格/分隔</i>分隔",
    'ar': "👩🏽‍💻 <b>أدخل</b> معرفات المستلمين مفصولة <i>بمسافات/منفصلة</i>",
}

l_enter_username = {
    'ru': "👩🏽‍💻 <b>Введи</b> @username получателя",
    'en': "👩🏽‍💻 <b>Enter</b> @username of the recipient",
    'es': "👩🏽‍💻 <b>Ingrese</b> @username del destinatario",
    'fr': "👩🏽‍💻 <b>Entrez</b> @username utilisateur du destinataire",
    'zh': "👩🏽‍💻<b>输入</b>收件人的@username",
    'ar': "👩🏽‍💻 <b>أدخل</b> @username للمستلم",
}
l_post_time_zone = {
    'ru': "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 <b>Текущее</b> время: <u>{0}</u> ({1}{2} по Гринвичу)",
    'en': "📍 <b>Time zone</b> of the geolocation is set\n\n🕐 <b>Current</b> time: <u>{0}</u> ({1}{2} GMT)",
    'es': "📍 La <b>zona horaria</b> de la geolocalización está configurada\n\n🕐 Hora <b>actual</b>: <u>{0}</u> ({1}{2} GMT)",
    'fr': "📍 <b>Le fuseau horaire</b> de la géolocalisation est défini\n\n🕐 <b>Heure actuelle</b> : <u>{0}</u> ({1}{2} GMT)",
    'zh': "📍 地理位置的<b>时区</b>已设置\n\n🕐<b>当前</b>时间：<u>{0}</u>（{1}{2} GMT）",
    'ar': "📍 تم ضبط <b>المنطقة الزمنية</b> للموقع الجغرافي\n\n🕐 التوقيت <b>الحالي</b>: <u>{0}</u> ({1}{2} بتوقيت جرينتش)",
}
l_broadcast_plan = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Рассылка запланирована",
    'en': "👩🏽‍💻 <b>Done!</b> Mailing scheduled",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Envío programado",
    'fr': "👩🏽‍💻 <b>Fait !</b> Mailing prévu",
    'zh': "👩🏽‍💻 <b>完成！</b> 已安排邮寄",
    'ar': "👩🏽‍💻 <b>تم!</b> تمت جدولة المراسلة",
}
l_broadcast_plan_bot = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Рассылка запланирована в @{0}",
    'en': "👩🏽‍💻 <b>Done!</b> Newsletter scheduled at @{0}",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Boletín programado en @{0}",
    'fr': "👩🏽‍💻 <b>Terminé !</b> Newsletter programmée à @{0}",
    'zh': "👩🏽‍💻 <b>完成！</b> 时事通讯定于@{0}",
    'ar': "👩🏽‍💻 <b>تم!</b> تمت جدولة النشرة الإخبارية في @{0}",
}
l_broadcast_plan_ent = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Публикация запланирована: {0}",
    'en': "👩🏽‍💻 <b>Done!</b> Publication scheduled: {0}",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Publicación programada: {0}",
    'fr': "👩🏽‍💻 <b>Terminé !</b> Publication prévue : {0}",
    'zh': "👩🏽‍💻<b>完成！</b>计划发布：{0}",
    'ar': "👩🏽‍💻 <b>تم!</b> تمت جدولة النشر: {0}",
}

l_broadcast_start = {
    'ru': "📧 <b>Старт</b> рассылки{0}..\n#длительность {1} мин",
    'en': "📧 <b>Start</b> mailings..\n#duration {0}min",
    'es': "📧 <b>Iniciar</b> envíos de correo..\n#duración {0}min",
    'fr': "📧 <b>Démarrer</b> les mailings..\n#durée {0}min",
    'zh': "📧<b>开始</b>邮件..\n#duration {0}分钟",
    'ar': "📧 <b>ابدأ</b> المراسلات البريدية..\n#duration {0}min",
}
l_broadcast_process = {
    'ru': "📧 <b>Рассылка</b>..{0}%",
    'en': "📧 <b>Newsletter</b>..{0}%",
    'es': "📧 <b>Boletín</b>..{0}%",
    'fr': "📧 <b>Newsletter</b>..{0}%",
    'zh': "📧<b>时事通讯</b>..{0}%",
    'ar': "📧 <b>النشرة الإخبارية</b>..{0}%",
}
l_broadcast_finish = {
    'ru': "🏁 <b>Рассылка</b> завершена\n\n📧 <b>Количество</b> пользователей, получивших сообщение: <u>{0}</u>",
    'en': "🏁 <b>Mail mailing</b> completed\n\n📧 <b>Number</b> of users who received the message: <u>{0}</u>",
    'es': "🏁 <b>Envío de correo</b> completado\n\n📧 <b>Número</b> de usuarios que recibieron el mensaje: <u>{0}</u>",
    'fr': "🏁 <b>Envoi du courrier</b> terminé\n\n📧 <b>Nombre</b> d'utilisateurs ayant reçu le message : <u>{0}</u>",
    'zh': "🏁 <b>邮件发送</b>已完成\n\n📧 收到消息的<b>用户数量</b>：<u>{0}</u>",
    'ar': "🏁 <b>اكتمل إرسال البريد</b>\n\n📧 <b>عدد</b> المستخدمين الذين تلقوا الرسالة: <u>{0}</u>",
}
l_post_del_timer = {
    'ru': "👩🏽‍💻 <b>Пост</b> #{0} удален по таймеру в {1}",
    'en': "👩🏽‍💻 <b>Post</b> #{0} deleted by timer in {1}",
    'es': "👩🏽‍💻 <b>Publicación</b> #{0} eliminada por el temporizador en {1}",
    'fr': "👩🏽‍💻 <b>Post</b> #{0} supprimé par minuterie dans {1}",
    'zh': "👩🏽‍💻 <b>帖子</b> #{0} 已被计时器在 {1} 删除",
    'ar': "👩🏽‍💻 <b>المنشور</b> #{0} تم حذفه بواسطة المؤقت في {1}",
}

l_generate_calendar_time = {
    'ru': "🕒 <b>Отправь время</b> поста на {0} в формате {1}. Текущее время: <u>{2}</u> ({3} по Гринвичу)\n\n📍 Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    'en': "🕒 <b>Send the time</b> of the post to {0} in {1} format. Current time: <u>{2}</u> ({3} Greenwich Mean Time)\n\n📍 Send <b>geolocation</b> to <i>automatically</i> determine the time zone",
    'es': "🕒 <b>Envía la hora</b> de la publicación a {0} en formato {1}. Hora actual: <u>{2}</u> ({3} hora media de Greenwich)\n\n📍 Envía la <b>geolocalización</b> para <i>determinar automáticamente</i> la zona horaria",
    'fr': "🕒 <b>Envoyer l'heure</b> de la publication à {0} au format {1}. Heure actuelle : <u>{2}</u> ({3} heure moyenne de Greenwich)\n\n📍 Envoyez la <b>géolocalisation</b> pour <i>déterminer automatiquement</i> le fuseau horaire",
    'zh': "🕒 <b>以 {1} 格式将帖子时间发送到 {0}。当前时间：<u>{2}</u>（{3}格林威治标准时间）\n\n📍 发送<b>地理位置</b>以<i>自动</i>确定时区",
    'ar': "🕒 <b>أرسل وقت</b> المنشور إلى {0} بتنسيق {1}. الوقت الحالي: <u>{2}</u> ({3} توقيت غرينتش)\n\n📍 أرسل <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>تلقائيًا</i>",
}

l_time_timer = {
    'ru': "🕒 <b>Отправь время</b> <i>авто-удаления</i> поста на {0} в формате {1}. Текущее время: <u>{2}</u> ({3} по Гринвичу)\n\n📍 Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    'en': "🕒 <b>Send the time</b> <i>auto-deleting</i> post to {0} in {1} format. Current time: <u>{2}</u> ({3} Greenwich Mean Time)\n\n📍 Send <b>geolocation</b> to <i>automatically</i> determine the time zone",
    'es': "🕒 <b>Envía la hora</b> <i>de eliminación automática</i> de la publicación a {0} en formato {1}. Hora actual: <u>{2}</u> ({3} hora media de Greenwich)\n\n📍 Envía la <b>geolocalización</b> para <i>determinar automáticamente</i> la zona horaria",
    'fr': "🕒 <b>Envoyer l'heure</b> à la publication <i>à suppression automatique</i> à {0} au format {1}. Heure actuelle : <u>{2}</u> ({3} heure moyenne de Greenwich)\n\n📍 Envoyez la <b>géolocalisation</b> pour <i>déterminer automatiquement</i> le fuseau horaire",
    'zh': "🕒 <b>以 {1} 格式将时间</b><i>自动删除</i>帖子发送到 {0}。当前时间：<u>{2}</u>（{3}格林威治标准时间）\n\n📍 发送<b>地理位置</b>以<i>自动</i>确定时区",
    'ar': "🕒 <b>أرسل وقت</b> <i>الحذف التلقائي</i> للمنشور إلى {0} بتنسيق {1}. الوقت الحالي: <u>{2}</u> ({3} توقيت غرينتش)\n\n📍 أرسل <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>تلقائيًا</i>",
}

l_month_1 = {
    'ru': "Янв",
    'en': "Jan",
    'es': "Ene",
    'fr': "Jan",
    'zh': "一月",
    'ar': "يناير",
}
l_month_2 = {
    'ru': "Фев",
    'en': "Feb",
    'es': "Feb",
    'fr': "Fév",
    'zh': "二月",
    'ar': "فبراير",
}
l_month_3 = {
    'ru': "Мар",
    'en': "Mar",
    'es': "Mar",
    'fr': "Mar",
    'zh': "三月",
    'ar': "مارس",
}
l_month_4 = {
    'ru': "Апр",
    'en': "Apr",
    'es': "Abr",
    'fr': "Avr",
    'zh': "四月",
    'ar': "أبريل",
}

l_month_5 = {
    'ru': "Май",
    'en': "May",
    'es': "Mayo",
    'fr': "Mai",
    'zh': "五月",
    'ar': "مايو",
}
l_month_6 = {
    'ru': "Июн",
    'en': "June",
    'es': "Junio",
    'fr': "Juin",
    'zh': "六月",
    'ar': "يونيو",
}
l_month_7 = {
    'ru': "Июл",
    'en': "July",
    'es': "Julio",
    'fr': "Juillet",
    'zh': "七月",
    'ar': "يوليو",
}
l_month_8 = {
    'ru': "Авг",
    'en': "Aug",
    'es': "Ago",
    'fr': "Août",
    'zh': "八月",
    'ar': "أغسطس",
}
l_month_9 = {
    'ru': "Сен",
    'en': "Sep",
    'es': "Sep",
    'fr': "Sep",
    'zh': "九月",
    'ar': "سبتمبر",
}
l_month_10 = {
    'ru': "Окт",
    'en': "Oct",
    'es': "Oct",
    'fr': "Octobre",
    'zh': "十月",
    'ar': "أكتوبر",
}
l_month_11 = {
    'ru': "Ноя",
    'en': "Nov",
    'es': "Nov",
    'fr': "Novembre",
    'zh': "十一月",
    'ar': "نوفمبر",
}
l_month_12 = {
    'ru': "Дек",
    'en': "Dec",
    'es': "Dic",
    'fr': "Décembre",
    'zh': "十二月",
    'ar': "ديسمبر",
}

l_weekday_1 = {
    'ru': "пн",
    'en': "mon",
    'es': "lun",
    'fr': "lun",
    'zh': "周一",
    'ar': "الاثنين",
}
l_weekday_2 = {
    'ru': "вт",
    'en': "tue",
    'es': "mar",
    'fr': "mar",
    'zh': "周二",
    'ar': "الثلاثاء",
}
l_weekday_3 = {
    'ru': "ср",
    'en': "wed",
    'es': "mié",
    'fr': "mer",
    'zh': "周三",
    'ar': "الأربعاء",
}
l_weekday_4 = {
    'ru': "чт",
    'en': "thu",
    'es': "jue",
    'fr': "jeu",
    'zh': "周四",
    'ar': "الخميس",
}
l_weekday_5 = {
    'ru': "пт",
    'en': "fri",
    'es': "vie",
    'fr': "ven",
    'zh': "周五",
    'ar': "الجمعة",
}
l_weekday_6 = {
    'ru': "сб",
    'en': "sat",
    'es': "sáb",
    'fr': "sam",
    'zh': "周六",
    'ar': "السبت",
}
l_weekday_7 = {
    'ru': "вс",
    'en': "sun",
    'es': "dom",
    'fr': "dim",
    'zh': "周日",
    'ar': "الأحد",
}

l_inline_demo = {
    "ru": "демо проектов",
    "en": "demo projects",
    "es": "demo de proyectos",
    "fr": "démo des projets",
    "zh": "项目演示",
    "ar": "عرض المشاريع",
}
l_inline_bot = {
    "ru": "нейро-конструктор",
    "en": "neuro constructor",
    "es": "constructor neuro",
    "fr": "constructeur neuro",
    "zh": "神经构造器",
    "ar": "المنشئ العصبي",
}
l_inline_post = {
    "ru": "приватный постинг",
    "en": "private posting",
    "es": "publicaciones privadas",
    "fr": "messages privés",
    "zh": "私人帖子",
    "ar": "المشاركات الخاصة",
}
l_inline_media = {
    "ru": "публичные медиа",
    "en": "public media",
    "es": "medios públicos",
    "fr": "médias publics",
    "zh": "公共媒体",
    "ar": "وسائل الإعلام العامة",
}
l_inline_channel = {
    "ru": "администрирование каналов",
    "en": "channel administration",
    "es": "administración de canales",
    "fr": "administration des canaux",
    "zh": "渠道管理",
    "ar": "إدارة القنوات",
}
l_inline_group = {
    "ru": "модерация групп",
    "en": "group moderation",
    "es": "moderación de grupos",
    "fr": "modération de groupe",
    "zh": "群组审核",
    "ar": "إدارة المجموعات",
}
l_inline_find = {
    "ru": "премиум поиск",
    "en": "premium search",
    "es": "búsqueda premium",
    "fr": "recherche premium",
    "zh": "高级搜索",
    "ar": "بحث متميز",
}
l_inline_ai = {
    "ru": "нейро-генерация контента",
    "en": "neural content generation",
    "es": "generación de contenido neural",
    "fr": "génération de contenu neural",
    "zh": "神经内容生成",
    "ar": "توليد المحتوى العصبي",
}
l_inline_ads = {
    "ru": "телеграм реклама",
    "en": "telegram advertisement",
    "es": "anuncio de telegram",
    "fr": "publicité telegram",
    "zh": "电报广告",
    "ar": "إعلان تيليجرام",
}

l_inline_vpn = {
    "ru": "vpn настройки",
    "en": "vpn settings",
    "es": "configuraciones vpn",
    "fr": "paramètres vpn",
    "zh": "vpn 设置",
    "ar": "إعدادات vpn",
}
l_inline_sticker = {
    "ru": "стикеры/эмоджи",
    "en": "stickers/emojis",
    "es": "pegatinas/emojis",
    "fr": "autocollants/émojis",
    "zh": "贴纸/表情",
    "ar": "الملصقات/الرموز التعبيرية",
}
l_inline_target = {
    "ru": "телеграмм таргет",
    "en": "telegram target",
    "es": "objetivo telegram",
    "fr": "cible telegram",
    "zh": "电报目标",
    "ar": "هدف تيليجرام",
}
l_inline_user = {
    "ru": "автоматизация аккаунтов",
    "en": "account automation",
    "es": "automatización de cuentas",
    "fr": "automatisation des comptes",
    "zh": "账户自动化",
    "ar": "أتمتة الحسابات",
}
l_inline_tools = {
    "ru": "телеграм инструменты",
    "en": "telegram tools",
    "es": "herramientas de telegram",
    "fr": "outils telegram",
    "zh": "电报工具",
    "ar": "أدوات تيليجرام",
}
l_inline_work = {
    "ru": "вакансии проекта",
    "en": "project vacancies",
    "es": "vacantes del proyecto",
    "fr": "postes du projet",
    "zh": "项目职位空缺",
    "ar": "وظائف المشروع",
}
l_inline_tonest = {
    "ru": "блокчейн инструменты",
    "en": "blockchain tools",
    "es": "herramientas blockchain",
    "fr": "outils blockchain",
    "zh": "区块链工具",
    "ar": "أدوات البلوكشين",
}
l_inline_codex = {
    "ru": "кодекс/фест/лига",
    "en": "codex/fest/league",
    "es": "códice/fest/liga",
    "fr": "codex/fest/ligue",
    "zh": "法典/节日/联盟",
    "ar": "القانون/المهرجان/الرابطة",
}
l_inline_support = {
    "ru": "служба заботы",
    "en": "care service",
    "es": "servicio de atención",
    "fr": "service de soins",
    "zh": "关怀服务",
    "ar": "خدمة العناية",
}

l_post_is_paid = {
    "ru": "👩🏽‍💻 <b>Пользователь</b>:   успешно оплатил пост: {1}",
    "en": "👩🏽‍💻 <b>User</b>: successfully paid for the post: {1}",
    "es": "👩🏽‍💻 <b>Usuario</b>: pagó exitosamente la publicación: {1}",
    "fr": "👩🏽‍💻 <b>Utilisateur</b> : a payé avec succès le post : {1}",
    "zh": "👩🏽‍💻 <b>用户</b>：成功支付了帖子：{1}",
    "ar": "👩🏽‍💻 <b>المستخدم</b>: دفع المنشور بنجاح: {1}",
}
l_text = {
    "ru": "Текст",
    "en": "Text",
    "es": "Texto",
    "fr": "Texte",
    "zh": "文本",
    "ar": "نص",
}
l_photo = {
    "ru": "Фото",
    "en": "Photo",
    "es": "Foto",
    "fr": "Photo",
    "zh": "照片",
    "ar": "صورة",
}
l_gif = {
    "ru": "Гиф",
    "en": "Gif",
    "es": "Gif",
    "fr": "Gif",
    "zh": "动图",
    "ar": "صورة متحركة",
}
l_video = {
    "ru": "Видео",
    "en": "Video",
    "es": "Vídeo",
    "fr": "Vidéo",
    "zh": "视频",
    "ar": "فيديو",
}
l_telescope = {
    "ru": "Телескоп",
    "en": "Telescope",
    "es": "Telescopio",
    "fr": "Télescope",
    "zh": "望远镜",
    "ar": "تلسكوب",
}
l_audio = {
    "ru": "Аудио",
    "en": "Audio",
    "es": "Audio",
    "fr": "Audio",
    "zh": "音频",
    "ar": "صوتي",
}
l_voice = {
    "ru": "Голосовое",
    "en": "Voice",
    "es": "Voz",
    "fr": "Voix",
    "zh": "语音",
    "ar": "صوتي",
}
l_sticker = {
    "ru": "Стикер",
    "en": "Sticker",
    "es": "Pegatina",
    "fr": "Autocollant",
    "zh": "贴纸",
    "ar": "ملصق",
}
l_document = {
    "ru": "Документ",
    "en": "Document",
    "es": "Documento",
    "fr": "Document",
    "zh": "文件",
    "ar": "وثيقة",
}

l_voice_restricted = {
    "ru": "👩🏽‍💻 <b>Режим</b> отправки голосовых/телескопов заблокирован в настройках [Конфиденциальности]: будет использован режим [Авто-замена] для аудио/видео форматов",
    "en": "Document",
    "es": "Documento",
    "fr": "Document",
    "zh": "文件",
    "ar": "وثيقة",
}
# endregion


# region FereyDemoBot
l_demo_btn1 = {
    'ru': "👩🏽‍💻 Проекты",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_demo_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_demo_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> <b>Ferey</b>-проекта:\n\n<blockquote>▪️кодекс\n▪️фест\n▪️лига</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-application</i> <b>Ferey</b> project:\n\n<blockquote>▪️code\n▪️fest\n▪️league</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la <i>aplicación @tg</i> proyecto <b>Ferey</b>:\n\n<blockquote>▪️código\n▪️festival\n▪️liga</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans l’<i>application @tg</i> projet <b>Ferey</b> :\n\n<blockquote>▪️code\n▪️fête\n▪️ligue</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎使用<i>@tg应用</i><b>Ferey</b>项目：\n\n<blockquote>▪️守则\n▪️节日\n▪️联盟</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>تطبيق @tg</i> مشروع <b>Ferey</b>:\n\n<blockquote>▪️ميثاق\n▪️مهرجان\n▪️دوري</blockquote>",
}
l_subscribe_demo = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>22</u>%)]",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>22</u>%)]",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>22</u>%)]",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>22</u>%)]",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>22</u>%)]",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>22</u>%)]",
}

l_kind_1 = {
    'ru': "<b>👩🏽‍💻@FereyDemoBot</b>\n\n<blockquote>▪️<b>информация</b> о проектах\n▪️<b>telegraph</b>-/blog</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\nnounced<b>informations</b> sur les projets\nnounced️<b>télégraphe</b>-/blog",
    'zh': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客",
    'ar': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog",
}
l_kind_2 = {
    'ru': "<b>👩🏽‍💻@FereyBotBot</b> - нейро-конструктор ботов\n\n<blockquote>▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️авто-<b>перевод/оповещения</b>\n▪️<b>интеграции</b> и платежи\n▪️нейро-<b>генерация/клон</b> бота\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyBotBot </b>-#neuro-bot designer\n\n▪️<b>collection/ban/analytics</b> subscribers\n▪️auto-<b>translation/alerts</b >\n▪️<b>integration</b>and payments\n▪️neuro-<b>generation/clone</b>bot\n▪️<b>web-app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyBotBot </b>-diseñador de neurobots\n\n▪️<b>colección/ban/analítica</b> suscriptores\n▪️auto-<b>traducción/alertas</b >\n▪️<b>integración</b>y pagos\n▪️neuro-<b>generación/clon</b>bot\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyBotBot </b>-concepteur de neuro-bots\n\nwithout >\n▪️<b>intégration</b>et paiements\n▪️neuro-<b>génération/clone</b>bot\nnoyer<b>web-app/neuro</b>-publication",
    'zh': "<b>👩🏽‍💻 @FereyBotBot </b>-神经机器人设计师\n\n▪️<b>收集/禁止/分析</b>订阅者\n▪️自动-<b>翻译/警报</b >\n▪️<b>集成</b>和支付\n▪️neuro-<b>生成/克隆</b>机器人\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyBotBot </b>-مصمم الروبوتات العصبية\n\n▪️<b>جمع/حظر/تحليلات</b> المشتركين\n▪️auto-<b>ترجمة/تنبيهات</b >\n▪️<b>التكامل</b>والمدفوعات\n▪️neuro-<b>الجيل/الاستنساخ</b>bot\n▪️<b>web-app/neuro</b>-النشر",
}
l_kind_3 = {
    'ru': "<b>👩🏽‍💻@FereyChannelBot</b> - администрирование каналов\n\n<blockquote>▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️<b>авто-декор/подкасты</b> поста\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyChannelBot </b>-channel #administration\n\n▪️<b>collection/ban/analytics</b> subscribers\n▪️<b>auto-decor/podcasts</b> posts\n▪️button <b>counter</b>\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyChannelBot </b>-administración del canal\n\n▪️<b>colección/ban/analítica</b> suscriptores\n▪️<b>autodecoración/podcasts</b> publicaciones\n▪️botón <b>contador</b>\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyChannelBot </b>-administration des chaînes\n\nwithout\n▪️bouton <b>compteur</b>\n▪️<b>application web/neuro</b>-posting",
    'zh': "<b>👩🏽‍💻 @FereyChannelBot </b>-频道管理\n\n▪️<b>集合/禁止/分析</b>订阅者\n▪️<b>自动装饰/播客</b>帖子\n▪️按钮<b>计数器</b>\n▪️<b>网络应用程序/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyChannelBot </b>-إدارة القناة\n\n▪️<b>مجموعة/حظر/تحليلات</b> المشتركين\n▪️<b>ديكور تلقائي/بودكاست</b> منشورات\n▪️زر <b>عداد</b>\n▪️<b>تطبيق ويب/عصبي</b>-النشر",
}
l_kind_4 = {
    'ru': "<b>👩🏽‍💻@FereyGroupBot</b> - модерация групп\n\n<blockquote>▪️<b>защита</b> группы от шпионов\n▪️ограничение прав до <b>подписки</b>\n▪️<b>голосование</b>/бан-ограничения\n▪️аналитика и <b>вовлеченность</b>\n▪️<b>авто-ответы</b> и стоп-слова\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyGroupBot </b>-group #moderation\n\n▪️<b>protection</b> of the group from spies\n▪️limitation of rights to <b>subscription</b>\n▪️<b>organization</b> ban/anti-flood\n▪️analytics and <b>engagement</b>\n▪️<b>auto-responses</b> and stop words\n▪️button <b>counter </b>\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyGroupBot </b>-moderación del grupo\n\n▪️<b>protección</b> del grupo contra espías\n▪️limitación de derechos de <b>suscripción</b>\n▪️<b>organización</b> prohibición/anti-inundación\n▪️análisis y <b>compromiso</b>\n▪️<b>respuestas automáticas</b> y palabras vacías\n▪️botón <b >contador </b>\n▪️<b>aplicación web/publicación neuro</b>",
    'fr': "<b>👩🏽‍💻 @FereyGroupBot </b>-modération du groupe\n\nnounced<b>protection</b> du groupe contre les espions\nproducerlimitation des droits d'<b>abonnement</b>\nְ️<b>organisation</b> interdiction/lutte contre les inondations\nwithout >compteur </b>\n▪️<b>web app/neuro</b>-posting",
    'zh': "<b>👩🏽‍💻 @FereyGroupBot </b>-群组审核\n\n▪️<b>保护</b>群组免受间谍侵害\n▪️<b>订阅权利限制</b>\n▪️<b>组织</b>禁止/反泛洪\n▪️分析和<b>参与度</b>\n▪️<b>自动回复</b>和停用词\n▪️按钮<b >计数器</b>\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyGroupBot </b>-الإشراف على المجموعة\n\n▪️<b>حماية</b> المجموعة من الجواسيس\n▪️تحديد حقوق <b>الاشتراك</b>\n▪️<b>المنظمة</b> الحظر/مكافحة الفيضانات\n▪️التحليلات و<b>المشاركة</b>\n▪️<b>الردود التلقائية</b> وكلمات الإيقاف\n▪️زر <b >العداد </b>\n▪️<b>تطبيق الويب/العصبي</b>-النشر",
}
l_kind_5 = {
    'ru': "<b>👩🏽‍💻@FereyUserBot</b> - автоматизация аккаунтов\n\n<blockquote>▪️<b>авто</b>-перевод/транскрибация\n▪️<b>нейро-генерация</b> бота\n▪️<b>мониторинг</b> гео/слов\n▪️<b>авто-формат</b> и подкасты\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyUserBot </b>-account automation\n\n▪️<b>automatic</b>-translation/transcription\n▪️<b>neuro-generation</b> bot\n▪️ <b>monitoring</b> geo/words\n▪️<b>auto-format</b> and podcasts\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyUserBot </b>-automatización de cuentas\n\n▪️<b>traducción/transcripción automática</b>\n▪️<b>bot de neurogeneración</b>\n▪️ <b>monitoreo</b> geo/words\n▪️<b>formato automático</b> y podcasts\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyUserBot </b>-automatisation de compte\n\n▪️<b>automatique</b>-traduction/transcription\nnounced<b>bot de neuro-génération</b>\nwithout <b>surveillance</b> géo/mots\nnoyer️<b>formatage automatique</b> et podcasts\nnoyer️<b>application web/neuro</b>-publication",
    'zh': "<b>👩🏽‍💻 @FereyUserBot </b>-账户自动化\n\n▪️<b>自动</b>-翻译/转录\n▪️<b>神经生成</b>机器人\n▪️ <b>监控</b>地理/单词\n▪️<b>自动格式</b>和播客\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyUserBot </b>-أتمتة الحساب\n\n▪️<b>تلقائي</b>-ترجمة/نسخ\n▪️<b>روبوت التوليد العصبي</b>\n▪️ <b>مراقبة</b> الموقع الجغرافي/الكلمات\n▪️<b>التنسيق التلقائي</b> والبودكاست\n▪️<b>تطبيق الويب/العصبي</b>-النشر",
}
l_kind_6 = {
    'ru': "<b>👩🏽‍💻@FereyPostBot</b> - приватные посты\n\n<blockquote>▪️<b>кнопочный</b> счетчик\n▪️инлайн-<b>телескопы</b>\n▪️<b>клик</b>\n▪️<b>шёпот</b>-сообщения</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyPostBot </b>-private posts\n\n▪️<b>button</b> counter\n▪️inline-<b>telescopes</b>\n▪️parsing/notifications <b>clicks</b>\n▪️<b>whispers</b>-messages",
    'es': "<b>👩🏽‍💻 @FereyPostBot </b>-publicaciones privadas\n\n▪️<b>botón</b> contador\n▪️en línea-<b>telescopios</b>\n▪️análisis/notificaciones <b>clics</b>\n▪️<b>susurros</b>-mensajes",
    'fr': "<b>👩🏽‍💻 @FereyPostBot </b>-messages privés\n\nnoyer<b>compteur de boutons</b>\nArmoires en ligne-<b>télescopes</b>\n▪️analyse/notifications <b>clics</b>\n▪️<b>chuchotements</b>-messages",
    'zh': "<b>👩🏽‍💻 @FereyPostBot </b>-私人帖子\n\n▪️<b>按钮</b>计数器\n▪️内联-<b>望远镜</b>\n▪️解析/通知 <b>点击</b>\n▪️<b>窃窃私语</b>-消息",
    'ar': "<b>👩🏽‍💻 @FereyPostBot </b>-المنشورات الخاصة\n\n▪️<b>زر</b> عداد\n▪️inline-<b>التلسكوبات</b>\n▪️parsing/notifications <b>النقرات</b>\n▪️<b>همسات</b>-الرسائل",
}
l_kind_7 = {
    'ru': "<b>👩🏽‍💻@FereyMediaBot</b> - публичные медиа-креативы\n\n<blockquote>▪️<b>стикеры</b> из текста и фото\n▪️<b>аудио-тренды</b>\n▪️<b>видео-заметки</b>\n▪️инлайн-<b>телескопы</b>\n▪️<b>кнопочные</b> #нейро-титры</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyMediaBot </b>-public media notes\n\n▪️<b>stickers</b> from text and photos\n▪️<b>audio trends</b>\n▪️<b>video notes</b>\n▪️online<b>telescopes</b>\n▪️<b>button</b> media",
    'es': "<b>👩🏽‍💻 @FereyMediaBot </b>-notas de medios públicos\n\n▪️<b>pegatinas</b> de texto y fotos\n▪️<b>tendencias de audio</b>\n▪️<b>notas de vídeo</b>\n▪️online<b>telescopios</b>\n▪️<b>botón</b> medios",
    'fr': "<b>👩🏽‍💻 @FereyMediaBot </b> - notes des médias publics\n\nwithout b>notes vidéo</b>\nƒ️en ligne<b>télescopes</b>\nƒ️<b>bouton</b> média",
    'zh': "<b>👩🏽‍💻 @FereyMediaBot </b>-公共媒体笔记\n\n▪️来自文本和照片的<b>贴纸</b>\n▪️<b>音频趋势</b>\n▪️<b>视频笔记</b>\n▪️在线<b>望远镜</b>\n▪️<b>按钮</b>媒体",
    'ar': "<b>👩🏽‍💻 @FereyMediaBot </b>-ملاحظات الوسائط العامة\n\n▪️<b>ملصقات</b> من النصوص والصور\n▪️<b>الاتجاهات الصوتية</b>\n▪️<b>ملاحظات الفيديو</b>\n▪️على الإنترنت<b>التلسكوبات</b>\n▪️<b>زر</b> الوسائط",
}
l_kind_8 = {
    'ru': "<b>👩🏽‍💻@FereyFindBot</b> - премиум поиск\n\n<blockquote>▪️<b>top</b> каналы/группы\n▪️<b>vip</b> пользователи/боты\n▪️<b>geo</b> парсинг\n▪️<b>smm</b> пассивный маркетинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyFindBot </b>-premium search\n\n▪️<b>top</b> channels/groups\n▪️<b>vip</b> users/bots\n▪️<b>geo</b> parsing\n▪️<b>smm</b> passive marketing",
    'es': "<b>👩🏽‍💻 @FereyFindBot </b>-búsqueda premium\n\n▪️<b>canales/grupos principales</b>\n▪️usuarios/bots<b>vip</b>\n▪️<b>geo</b> análisis\n▪️<b>smm</b> marketing pasivo",
    'fr': "<b>👩🏽‍💻 @FereyFindBot </b> - recherche premium\n\nwithout b>géo</b> analyse\n▪️<b>smm</b> marketing passif",
    'zh': "<b>👩🏽‍💻 @FereyFindBot </b>-高级搜索\n\n▪️<b>热门</b>频道/组\n▪️<b>vip</b>用户/机器人\n▪️<b>geo</b>解析\n▪️<b>smm</b>被动营销",
    'ar': "<b>👩🏽‍💻 @FereyFindBot </b>-بحث متميز\n\n▪️<b>أهم</b> القنوات/المجموعات\n▪️<b>vip</b> المستخدمين/الروبوتات\n▪️<b>التحليل الجغرافي</b>\n▪️<b>smm</b> التسويق السلبي",
}
l_kind_9 = {
    'ru': "<b>👩🏽‍💻 @FereyAIBot</b> - нейро-генерация контента\n\n<blockquote>▪️<b>текст/изображение</b>\n▪️<b>нейро-анализ</b> @tg-tech-канала\n▪️<b>распознавание</b> речи\n▪️<b>очистка ⁰истории</b> /start</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyAIBot </b>-neuro-generation of content\n\n▪️<b>text/image</b>\n▪️<b>neuro-analysis</b> @tg-tech channel\n▪️<b>speech recognition</b>\n▪️<b>clearing ⁰history</b> /start",
    'es': "<b>👩🏽‍💻 @FereyAIBot </b>-neurogeneración de contenido\n\n▪️<b>texto/imagen</b>\n▪️<b>neuroanálisis</b> canal @tg-tech\n▪️<b>reconocimiento de voz</b>\n▪️<b>borrando ⁰historial</b> /inicio",
    'fr': "<b>👩🏽‍💻 @FereyAIBot </b>-neuro-génération de contenu\n\nnounced<b>texte/image</b>\nnoyam<b>neuro-analyse</b> @tg-tech canal\n▪️<b>reconnaissance vocale</b>\n▪️<b>effacer l'⁰historique</b> /start",
    'zh': "<b>👩🏽‍💻 @FereyAIBot </b>-内容的神经生成\n\n▪️<b>文本/图像</b>\n▪️<b>神经分析</b> @tg-tech频道\n▪️<b>语音识别</b>\n▪️<b>清除⁰历史记录</b> /start",
    'ar': "<b>👩🏽‍💻 @FereyAIBot </b>-التوليد العصبي للمحتوى\n\n▪️<b>نص/صورة</b>\n▪️<b>التحليل العصبي</b> قناة @tg-tech\n▪️<b>التعرف على الكلام</b>\n▪️<b>مسح ⁰السجل</b> /بدء",
}
l_kind_10 = {
    'ru': "<b>👩🏽‍💻 @FereyToolsBot</b> - телеграм инструменты\n\n<blockquote>▪️<b>преобразование</b> контента\n▪️<b>/json</b> информация о сообщ\n▪️<b>удаление</b> фона\n▪️<b>/id</b> группы/канала/бота\n▪️конвертация в <b>телескопы</b>\n▪️<b>/telegraph</b> фото/видео-ссылка\n▪️пустое сообщение <b>0-длины</b></blockquote>",
    'en': "<b>👩🏽‍💻 @FereyToolsBot </b>-telegram tools\n\n▪️<b>conversion</b> of content\n▪️<b>/json</b> message information\n▪️<b >removal</b> background\n▪️<b>/id</b> group/channel/bot\n▪️conversion to <b>telescopes</b>\n▪️<b>/telegraph</b> photo /video link\n▪️empty message <b>0-length</b>",
    'es': "<b>👩🏽‍💻 @FereyToolsBot </b>-herramientas de Telegram\n\n▪️<b>conversión</b> de contenido\n▪️<b>/json</b> información del mensaje\n▪️<b >eliminación</b> de fondo\n▪️<b>/id</b> grupo/canal/bot\n▪️conversión a <b>telescopios</b>\n▪️<b>/telegraph</b> foto /enlace de vídeo\n▪️mensaje vacío <b>0 longitud</b>",
    'fr': "<b>👩🏽‍💻 @FereyToolsBot </b>-outils de télégramme\n\nnoyer<b>conversion</b> du contenu\nnounced️<b>/json</b> informations sur les messages\nlessly️<b >suppression</b> de l'arrière-plan\nproduced</b> groupe/canal/bot\nwithout /lien vidéo\n▪️message vide <b>longueur 0</b>",
    'zh': "<b>👩🏽‍💻 @FereyToolsBot </b>-电报工具\n\n▪️<b>内容转换</b>\n▪️<b>/json</b>消息信息\n▪️<b >删除</b>背景\n▪️<b>/id</b>组/频道/机器人\n▪️转换为<b>望远镜</b>\n▪️<b>/电报</b>照片/视频链接\n▪️空消息<b>0-长度</b>",
    'ar': "<b>👩🏽‍💻 @FereyToolsBot </b>-أدوات التليجرام\n\n▪️<b>تحويل</b> المحتوى\n▪️<b>/json</b> معلومات الرسالة\n▪️<b >إزالة</b> الخلفية\n▪️<b>/id</b> المجموعة/القناة/bot\n▪️التحويل إلى صورة <b>التلسكوبات</b>\n▪️<b>/telegraph</b> /رابط الفيديو\n▪️رسالة فارغة <b>0-الطول</b>",
}
l_kind_11 = {
    'ru': "<b>👩🏽‍💻 @FereyStickerBot</b> - стикеры/эмоджи наборы\n\n<blockquote>▪️️стикеры static/video/animated\n▪️️эмоджи static/video/animated\n▪️️преобразование photo в video-стикер/эмоджи</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey advertising\n\n▪️️advertising in ferey-projects\n▪️️ordering advertising on the channel",
    'es': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicidad de ferey\n\n▪️️publicidad en proyectos de ferey\n▪️️pedido de publicidad en el canal",
    'fr': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicité ferey\n\nnoyer️publicité dans les projets ferey\nnoyer️commander de la publicité sur la chaîne",
    'zh': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey 广告\n\n▪️️ferey 项目中的广告\n▪️️在频道上订购广告",
    'ar': "<b>👩🏽‍💻 @FereyAdsBot </b>-إعلانات فيري\n\n▪️️إعلان في مشاريع فيري\n▪️️طلب إعلان على القناة",
}
l_kind_12 = {
    'ru': "<b>👩🏽‍💻 @FereyTONestBot</b> - блокчейн проекты\n\n<blockquote>▪️️соло/альбом NFT\n▪️️монеты (токены) FT\n▪️️нейро-парсинг смарт-контрактов</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey advertising\n\n▪️️advertising in ferey-projects\n▪️️ordering advertising on the channel",
    'es': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicidad de ferey\n\n▪️️publicidad en proyectos de ferey\n▪️️pedido de publicidad en el canal",
    'fr': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicité ferey\n\nnoyer️publicité dans les projets ferey\nnoyer️commander de la publicité sur la chaîne",
    'zh': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey 广告\n\n▪️️ferey 项目中的广告\n▪️️在频道上订购广告",
    'ar': "<b>👩🏽‍💻 @FereyAdsBot </b>-إعلانات فيري\n\n▪️️إعلان في مشاريع فيري\n▪️️طلب إعلان على القناة",
}
l_kind_13 = {
    'ru': "<b>👩🏽‍💻 @FereyCodexBot</b> - кодекс\n\n<blockquote>▪️️кодекс\n▪️️фест\n▪️️лига</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey advertising\n\n▪️️advertising in ferey-projects\n▪️️ordering advertising on the channel",
    'es': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicidad de ferey\n\n▪️️publicidad en proyectos de ferey\n▪️️pedido de publicidad en el canal",
    'fr': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicité ferey\n\nnoyer️publicité dans les projets ferey\nnoyer️commander de la publicité sur la chaîne",
    'zh': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey 广告\n\n▪️️ferey 项目中的广告\n▪️️在频道上订购广告",
    'ar': "<b>👩🏽‍💻 @FereyAdsBot </b>-إعلانات فيري\n\n▪️️إعلان في مشاريع فيري\n▪️️طلب إعلان على القناة",
}
# endregion


# region FereyToolsBot
l_tools_btn1 = {
    "ru": "👩🏽‍💻 Инструменты",
    "en": "👩🏽‍💻 Tools",
    "es": "👩🏽‍💻 Herramientas",
    "fr": "👩🏽‍💻 Outils",
    "zh": "👩🏽‍💻 工具",
    "ar": "👩🏽‍💻 الأدوات",
}
l_tools_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tools_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> <b>Telegram</b>-инструментов:\n\n<blockquote>▪️<b>преобразование</b> контента\n▪️<b>/json</b> информация о сообщ\n▪️<b>удаление</b> фона\n▪️<b>/id</b> группы/канала/бота\n▪️конвертация в <b>телескопы</b>\n▪️пустое сообщение <b>0-длины</b>\n▪️скачивание <b>tg-сториз</b>, <b>x/ig/tt/yt</b>-видео</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to <i>@tg-app</i> <b>Telegram</b> tools:\n\n<blockquote>▪️<b>content</b> conversion\n▪️<b>/json</b> message info\n▪️<b>background</b> removal\n▪️<b>/id</b> of group/channel/bot\n▪️convert to <b>telescopes</b>\n▪️empty message of <b>0-length</b>\n▪️download <b>tg-stories</b>, <b>x/ig/tt/yt</b> videos</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a las herramientas de <i>@tg-app</i> de <b>Telegram</b>:\n\n<blockquote>▪️<b>conversión</b> de contenido\n▪️<b>/json</b> información del mensaje\n▪️<b>eliminación</b> de fondo\n▪️<b>/id</b> de grupo/canal/bot\n▪️convertir a <b>telescopios</b>\n▪️mensaje vacío de <b>0-longitud</b>\n▪️descargar <b>tg-historias</b>, vídeos de <b>x/ig/tt/yt</b></blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue sur <i>@tg-app</i> outils <b>Telegram</b> :\n\n<blockquote>▪️<b>conversion</b> de contenu\n▪️info message <b>/json</b>\n▪️<b>suppression</b> de fond\n▪️<b>/id</b> du groupe/canal/bot\n▪️conversion en <b>télescopes</b>\n▪️message vide de <b>0-longueur</b>\n▪️téléchargement des <b>tg-stories</b>, vidéos <b>x/ig/tt/yt</b></blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎使用 <i>@tg-app</i> <b>Telegram</b> 工具：\n\n<blockquote>▪️<b>内容</b>转换\n▪️<b>/json</b> 消息信息\n▪️<b>背景</b>去除\n▪️<b>/id</b> 群组/频道/机器人\n▪️转换为<b>望远镜</b>\n▪️<b>0长度</b>的空消息\n▪️下载<b>tg故事</b>、<b>x/ig/tt/yt</b>视频</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-app</i> أدوات <b>Telegram</b>:\n\n<blockquote>▪️<b>تحويل</b> المحتوى\n▪️<b>/json</b> معلومات الرسائل\n▪️<b>إزالة</b> الخلفية\n▪️<b>/id</b> المجموعة/القناة/البوت\n▪️التحويل إلى <b>تلسكوبات</b>\n▪️رسالة فارغة بطول <b>0</b>\n▪️تحميل <b>tg-stories</b>، فيديوهات <b>x/ig/tt/yt</b></blockquote>",
}
l_subscribe_tools = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n<a href='{0}'>¹ [<b>Все боты</b> и проекты (-<u>22</u>%)]</a>\n\n<a href='{1}'>² Донат {2}</a>\n<a href='{3}'>​</a>",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>22</u>%)]",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>22</u>%)]",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>22</u>%)]",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>22</u>%)]",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>22</u>%)]",
}

l_image_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>изображения</i> в",
    "en": "👩🏽‍💻 <b>Choose</b> tools to convert <i>image</i> to",
    "es": "👩🏽‍💻 <b>Elige</b> herramientas para convertir <i>imagen</i> a",
    "fr": "👩🏽‍💻 <b>Choisissez</b> les outils pour convertir <i>image</i> en",
    "zh": "👩🏽‍💻<b>选择</b>工具将<i>图像</i>转换为",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>صورة</i> إلى",
}
l_image_jpg = {
    "ru": "🏞️ jpg",
    "en": "🏞️ jpg",
    "es": "🏞️ jpg",
    "fr": "🏞️ jpg",
    "zh": "🏞️ jpg",
    "ar": "🏞️ jpg",
}
l_image_png = {
    "ru": "🌁 png",
    "en": "🌁 png",
    "es": "🌁 png",
    "fr": "🌁 png",
    "zh": "🌁 png",
    "ar": "🌁 png",
}
l_image_mp4 = {
    "ru": "🎥 mp4",
    "en": "🎥 mp4",
    "es": "🎥 mp4",
    "fr": "🎥 mp4",
    "zh": "🎥 mp4",
    "ar": "🎥 mp4",
}
l_image_album = {
    "ru": "9️⃣ альбом⁹",
    "en": "9️⃣ album⁹",
    "es": "9️⃣ álbum⁹",
    "fr": "9️⃣ album⁹",
    "zh": "9️⃣ 专辑⁹",
    "ar": "9️⃣ الألبوم⁹",
}
l_image_collage = {
    "ru": "1️⃣ коллаж¹",
    "en": "1️⃣ collage¹",
    "es": "1️⃣ collage¹",
    "fr": "1️⃣ collage¹",
    "zh": "1️⃣ 拼贴¹",
    "ar": "1️⃣ الكولاج¹",
}
l_image_ico = {
    "ru": "🖼️ ico",
    "en": "🖼️ ico",
    "es": "🖼️ ico",
    "fr": "🖼️ ico",
    "zh": "🖼️ ico",
    "ar": "🖼️ ico",
}
l_image_sticker = {
    "ru": "🌌 стикер",
    "en": "🌌 sticker",
    "es": "🌌 pegatina",
    "fr": "🌌 autocollant",
    "zh": "🌌 贴纸",
    "ar": "🌌 ملصق",
}
l_image_rbg = {
    "ru": "🙌🏽 удалить фон",
    "en": "🙌🏽 remove background",
    "es": "🙌🏽 eliminar fondo",
    "fr": "🙌🏽 supprimer l’arrière-plan",
    "zh": "🙌🏽 删除背景",
    "ar": "🙌🏽 إزالة الخلفية",
}
l_image_slice = {
    "ru": "🔪 Срез",
    "en": "🔪 Slice",
    "es": "🔪 Corte",
    "fr": "🔪 Découpe",
    "zh": "🔪 切片",
    "ar": "🔪 شريحة",
}
l_image_slice_mini = {
    "ru": "🔪 срез",
    "en": "🔪 slice",
    "es": "🔪 corte",
    "fr": "🔪 découpe",
    "zh": "🔪 切片",
    "ar": "🔪 شريحة",
}
l_image_descpic = {
    "ru": "⿴ Bot Desc Pic",
    "en": "⿴ Bot Desc Pic",
    "es": "⿴ Imagen de descripción del bot",
    "fr": "⿴ Image de description du bot",
    "zh": "⿴机器人描述图片",
    "ar": "⿴ صورة وصف البوت",
}
l_image_watermark = {
    "ru": "🪼 Водяной знак",
    "en": "🪼 Watermark",
    "es": "🪼 Marca de agua",
    "fr": "🪼 Filigrane",
    "zh": "🪼 水印",
    "ar": "🪼 العلامة المائية",
}

l_image_jpg_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в jpg",
    "en": "👩🏽‍💻 <b>Attach</b> photo to convert to jpg",
    "es": "👩🏽‍💻 <b>Adjunta</b> foto para convertir a jpg",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en jpg",
    "zh": "👩🏽‍💻 <b>附加</b>照片以转换为jpg",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى jpg",
}
l_image_png_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в png",
    "en": "👩🏽‍💻 <b>Attach</b> photo to convert to png",
    "es": "👩🏽‍💻 <b>Adjunta</b> foto para convertir a png",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en png",
    "zh": "👩🏽‍💻 <b>附加</b>照片以转换为png",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى png",
}
l_image_mp4_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в mp4 (Telegram-аватарку)",
    "en": "👩🏽‍💻 <b>Attach</b> photo to convert to mp4 (Telegram avatar)",
    "es": "👩🏽‍💻 <b>Adjunta</b> foto para convertir a mp4 (avatar de Telegram)",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en mp4 (avatar Telegram)",
    "zh": "👩🏽‍💻 <b>附加</b>照片以转换为mp4（Telegram头像）",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى mp4 (صورة Telegram الرمزية)",
}
l_image_ico_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в ico-иконку (320x320)",
    "en": "👩🏽‍💻 <b>Attach</b> photo to convert into ico-icon (320x320)",
    "es": "👩🏽‍💻 <b>Adjunta</b> foto para convertirla en icono ico (320x320)",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en icône ico (320x320)",
    "zh": "👩🏽‍💻 <b>附加</b>照片以转换为ico图标（320x320）",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى أيقونة ico (320x320)",
}
l_image_sticker_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в стикер",
    "en": "👩🏽‍💻 <b>Attach</b> photo to convert into a sticker",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla en una pegatina",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en autocollant",
    "zh": "👩🏽‍💻 <b>附加</b>照片以转换为贴纸",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى ملصق",
}
l_image_album_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в альбом из 9 частей",
    "en": "👩🏽‍💻 <b>Attach</b> photo to convert into a 9-part album",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla en un álbum de 9 partes",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en album en 9 parties",
    "zh": "👩🏽‍💻 <b>附加</b>照片以转换为9部分相册",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى ألبوم من 9 أجزاء",
}
l_image_collage_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> альбом для преобразования в 1-единый коллаж",
    "en": "👩🏽‍💻 <b>Attach</b> album to convert into a single collage",
    "es": "👩🏽‍💻 <b>Adjunta</b> el álbum para convertirlo en un solo collage",
    "fr": "👩🏽‍💻 <b>Joins</b> l'album pour le convertir en un seul collage",
    "zh": "👩🏽‍💻 <b>附加</b>相册以转换为单个拼贴画",
    "ar": "👩🏽‍💻 <b>أرفق</b> الألبوم لتحويله إلى ملصقة واحدة",
}
l_image_rbg_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для удаления фона",
    "en": "👩🏽‍💻 <b>Attach</b> photo to remove the background",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para eliminar el fondo",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour supprimer l’arrière-plan",
    "zh": "👩🏽‍💻 <b>附加</b>照片以删除背景",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لإزالة الخلفية",
}
l_image_slice_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в узкую полоску фото (срез)",
    "en": "👩🏽‍💻 <b>Attach</b> photo to convert into a narrow photo strip (slice)",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla en una tira estrecha (recorte)",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en bande étroite (découpe)",
    "zh": "👩🏽‍💻 <b>附加</b>照片以转换为窄条状图片（切片）",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى شريط ضيق (قص)",
}
l_image_descpic_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в формат, необходимый для установки Description Picture для бота в @BotFather (640x360)",
    "en": "👩🏽‍💻 <b>Attach</b> photo to convert to format required to set Description Picture for bot in @BotFather (640x360)",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla al formato requerido para establecer la imagen de descripción del bot en @BotFather (640x360)",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir au format requis pour définir l’image de description du bot dans @BotFather (640x360)",
    "zh": "👩🏽‍💻 <b>附加</b>照片，将其转换为在 @BotFather 中为机器人设置描述图片所需的格式（640x360）",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى التنسيق المطلوب لتعيين صورة الوصف للروبوت في @BotFather (640×360)",
}
l_image_watermark_attach = {
    "ru": "👩🏽‍💻 <b>Отправь</b> фото с подписью для текста водяного знака до 32 символов",
    "en": "👩🏽‍💻 <b>Send</b> photo with caption for watermark text up to 32 characters",
    "es": "👩🏽‍💻 <b>Envía</b> una foto con subtítulo para el texto de marca de agua de hasta 32 caracteres",
    "fr": "👩🏽‍💻 <b>Envoie</b> une photo avec une légende pour le texte du filigrane jusqu'à 32 caractères",
    "zh": "👩🏽‍💻 <b>发送</b>带标题的照片用于最多32个字符的水印文本",
    "ar": "👩🏽‍💻 <b>أرسل</b> صورة مع تعليق نصي لعلامة مائية حتى 32 حرفًا",
}
l_image_watermark_error = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> отправить файл вместе с подписью",
    "en": "👩🏽‍💻 <b>You need</b> to send a file with a caption",
    "es": "👩🏽‍💻 <b>Debe</b> enviar un archivo con un subtítulo",
    "fr": "👩🏽‍💻 <b>Vous devez</b> envoyer un fichier avec une légende",
    "zh": "👩🏽‍💻 <b>必须</b>发送带标题的文件",
    "ar": "👩🏽‍💻 <b>يجب</b> إرسال ملف مع تعليق",
}

l_gif_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>гиф</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>GIF</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>GIF</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> les outils pour convertir les <i>GIF</i> en",
    'zh': "👩🏽‍💻<b>选择</b>工具将<i>GIF</i>转换为",
    'ar': "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>GIF</i> إلى",
}
l_gif_mp4 = {
    "ru": "🎥 mp4",
    "en": "🎥 mp4",
    "es": "🎥 mp4",
    "fr": "🎥 mp4",
    "zh": "🎥 mp4",
    "ar": "🎥 mp4",
}

l_gif_thumb = {
    "ru": "🖼️ ico",
    "en": "🖼️ ico",
    "es": "🖼️ ico",
    "fr": "🖼️ icône",
    "zh": "🖼️ ico",
    "ar": "🖼️ إيكو",
}
l_gif_descgif = {
    "ru": "⿴ Bot Desc Gif",
    "en": "⿴ Bottom Desc Gif",
    "es": "⿴ Gif de descripción inferior",
    "fr": "⿴ Gif de description du bas",
    "zh": "⿴ 底部描述 Gif",
    "ar": "⿴ صورة متحركة للأسفل",
}
l_gif_mp4_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в mp4",
    "en": "👩🏽‍💻 <b>Attach</b> GIF to convert to mp4",
    "es": "👩🏽‍💻 <b>Adjunte</b> GIF para convertir a mp4",
    "fr": "👩🏽‍💻 <b>Joindre</b> GIF pour convertir en mp4",
    "zh": "👩🏽‍💻 <b>附加</b> GIF 以转换为 mp4",
    "ar": "👩🏽‍💻 <b>أرفق</b> ملف GIF للتحويل إلى mp4",
}
l_gif_thumb_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в ico-иконку (320x320)",
    "en": "👩🏽‍💻 <b>Attach</b> GIF to convert to ico icon (320x320)",
    "es": "👩🏽‍💻 <b>Adjunte</b> GIF para convertirlo en ícono ico (320x320)",
    "fr": "👩🏽‍💻 <b>Joindre</b> GIF pour convertir en icône ico (320x320)",
    "zh": "👩🏽‍💻 <b>附加</b> GIF 转换为 ico 图标 (320x320)",
    "ar": "👩🏽‍💻 <b>أرفق</b> ملف GIF لتحويله إلى أيقونة ico (160×160)",
}
l_gif_descgif_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в формат, необходимый для установки Description Gif для бота в @BotFather (640x360). После формирования GIF нажимаем на нее через <u>мобильное</u> приложение (ожидая загрузки), далее Поделиться - приложение Telegram - @BotFather",
    "en": "👩🏽‍💻 <b>Attach</b> the GIF to convert to the format required to set the Description Gif for the bot in @BotFather (640x360). After generating the GIF, click on it through the <u>mobile</u> application (waiting for loading), then Share-Telegram application-@BotFather",
    "es": "👩🏽‍💻 <b>Adjunte</b> el GIF para convertirlo al formato requerido para configurar el GIF de descripción para el bot en @BotFather (640x360). Después de generar el GIF, haga clic en él a través de la aplicación <u>móvil</u> (esperando a que se cargue), luego Compartir-Aplicación Telegram-@BotFather",
    "fr": "👩🏽‍💻 <b>Joignez</b> le GIF à convertir au format requis pour définir le Gif de description du bot dans @BotFather (640x360). Après avoir généré le GIF, cliquez dessus via l'application <u>mobile</u> (en attente de chargement), puis Partager-Application Telegram-@BotFather",
    "zh": "👩🏽‍💻 <b>附加</b> GIF 以转换为在@BotFather (640x360) 中为机器人设置说明 Gif 所需的格式。生成 GIF 后，通过<u>移动</u>应用程序点击它（等待加载），然后分享-Telegram 应用程序-@BotFather",
    "ar": "👩🏽‍💻 <b>أرفق</b> ملف GIF للتحويل إلى التنسيق المطلوب لتعيين ملف Gif الوصفي للروبوت في @BotFather (640x360). بعد إنشاء الصورة المتحركة GIF اضغط عليها عبر تطبيق <u>الموبايل</u> (في انتظار التحميل)، ثم مشاركة-تطبيق تيليجرام-@BotFather",
}

l_video_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>видео</i> в",
    "en": "👩🏽‍💻 <b>Choose</b> tools to convert <i>video</i> to",
    "es": "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>vídeo</i> a",
    "fr": "👩🏽‍💻 <b>Choisissez</b> les outils pour convertir la <i>vidéo</i> en",
    "zh": "👩🏽‍💻<b>选择</b>工具将<i>视频</i>转换为",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>الفيديو</i> إلى",
}
l_video_mp3 = {
    "ru": "▶️ mp3",
    "en": "▶️ mp3",
    "es": "▶️ mp3",
    "fr": "▶️ mp3",
    "zh": "▶️ mp3",
    "ar": "▶️ mp3",
}
l_video_mp4 = {
    "ru": "🎥 mp4",
    "en": "🎥 mp4",
    "es": "🎥 mp4",
    "fr": "🎥 mp4",
    "zh": "🎥 mp4",
    "ar": "🎥 mp4",
}
l_video_album = {
    "ru": "9️⃣ альбом⁹",
    "en": "9️⃣ album⁹",
    "es": "9️⃣ álbum⁹",
    "fr": "9️⃣ album⁹",
    "zh": "9️⃣ 专辑⁹",
    "ar": "9️⃣ الألبوم⁹",
}
l_video_slide = {
    "ru": "1️⃣ слайд¹",
    "en": "1️⃣ slide¹",
    "es": "1️⃣ diapositiva¹",
    "fr": "1️⃣ diapositive¹",
    "zh": "1️⃣ 幻灯片¹",
    "ar": "1️⃣ شريحة¹",
}
l_video_thumb = {
    "ru": "🖼️ ico",
    "en": "🖼️ ico",
    "es": "🖼️ ico",
    "fr": "🖼️ icône",
    "zh": "🖼️ ico",
    "ar": "🖼️ إيكو",
}

l_video_gif = {
    "ru": "📽️ gif",
    "en": "📽️ gif",
    "es": "📽️ gif",
    "fr": "📽️ gif",
    "zh": "📽️ gif",
    "ar": "📽️ جيف",
}
l_video_sticker = {
    "ru": "🌌 стикер",
    "en": "🌌 sticker",
    "es": "🌌 etiqueta",
    "fr": "🌌 autocollant",
    "zh": "🌌 贴纸",
    "ar": "🌌 ملصق",
}
l_video_videonote = {
    "ru": "⚫️ телескоп",
    "en": "⚫️ telescope",
    "es": "⚫️ telescopio",
    "fr": "⚫️ télescope",
    "zh": "⚫️ 望远镜",
    "ar": "⚫️ التلسكوب",
}
l_video_slice = {
    "ru": "🔪 Срез",
    "en": "🔪 Slice",
    "es": "🔪 Corte",
    "fr": "🔪 Tranche",
    "zh": "🔪 切片",
    "ar": "🔪 شريحة",
}
l_video_slice_mini = {
    "ru": "🔪 срез",
    "en": "🔪 slice",
    "es": "🔪 corte",
    "fr": "🔪 tranche",
    "zh": "🔪 切片",
    "ar": "🔪 شريحة",
}
l_video_transcribe = {
    "ru": "🗣️ транскрибация",
    "en": "🗣️ transcription",
    "es": "🗣️ transcripción",
    "fr": "🗣️ transcription",
    "zh": "🗣️ 转录",
    "ar": "🗣️ النسخ",
}
l_video_mp3_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в mp3-аудио",
    "en": "👩🏽‍💻 <b>Attach</b> video to convert to mp3 audio",
    "es": "👩🏽‍💻 <b>Adjunta</b> video para convertir a audio mp3",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo pour la convertir en audio mp3",
    "zh": "👩🏽‍💻<b>附加</b>视频以转换为mp3音频",
    "ar": "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى صوت mp3",
}
l_video_mp4_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в mp4",
    "en": "👩🏽‍💻 <b>Attach</b> video to convert to mp4",
    "es": "👩🏽‍💻 <b>Adjunta</b> video para convertir a mp4",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo à convertir en mp4",
    "zh": "👩🏽‍💻<b>附加</b>视频以转换为mp4",
    "ar": "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى mp4",
}

l_video_gif_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в гиф",
    "en": "👩🏽‍💻 <b>Attach</b> video to convert to gif",
    "es": "👩🏽‍💻 <b>Adjunta</b> vídeo para convertirlo a gif",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo à convertir en gif",
    "zh": "👩🏽‍💻<b>附加</b>视频以转换为gif",
    "ar": "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى gif",
}
l_video_thumb_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в ico-иконку (320x320)",
    "en": "👩🏽‍💻 <b>Attach</b> video to convert to ico icon (320x320)",
    "es": "👩🏽‍💻 <b>Adjunta</b> video para convertirlo en ícono ico (320x320)",
    "fr": "👩🏽‍💻 <b>Joins</b> la vidéo à convertir en icône ico (320x320)",
    "zh": "👩🏽‍💻<b>附加</b>视频以转换为ico图标（320x320）",
    "ar": "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى أيقونة ico (320x320)",
}
l_video_sticker_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото/видео для преобразования в видео-стикер",
    "en": "👩🏽‍💻 <b>Attach</b> photo/video to convert to video sticker",
    "es": "👩🏽‍💻 <b>Adjunta</b> foto/vídeo para convertirlo en sticker de vídeo",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo/vidéo à convertir en sticker vidéo",
    "zh": "👩🏽‍💻<b>附加</b>照片/视频以转换为视频贴纸",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة/فيديو لتحويلها إلى ملصق فيديو",
}
l_video_album_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в альбом из 9 частей",
    "en": "👩🏽‍💻 <b>Attach</b> video to convert into a 9-part album",
    "es": "👩🏽‍💻 <b>Adjunta</b> vídeo para convertirlo en un álbum de 9 partes",
    "fr": "👩🏽‍💻 <b>Joins</b> la vidéo pour la convertir en un album en 9 parties",
    "zh": "👩🏽‍💻<b>附加</b>视频以转换为9部分专辑",
    "ar": "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى ألبوم مكون من 9 أجزاء",
}
l_video_slide_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> альбом из нескольких видео до 1мин для преобразования в слайдшоу",
    "en": "👩🏽‍💻 <b>Attach</b> album of several videos (up to 1 min) to convert to slideshow",
    "es": "👩🏽‍💻 <b>Adjunta</b> un álbum de varios vídeos (hasta 1 min) para convertirlo en presentación",
    "fr": "👩🏽‍💻 <b>Joins</b> un album de plusieurs vidéos (jusqu’à 1 min) à convertir en diaporama",
    "zh": "👩🏽‍💻<b>附加</b>多个视频（最多1分钟）组成的专辑以转换为幻灯片",
    "ar": "👩🏽‍💻 <b>أرفق</b> ألبومًا من عدة مقاطع فيديو (حتى دقيقة واحدة) لتحويله إلى عرض شرائح",
}
l_video_videonote_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в телескоп (круглую видео-заметку)",
    "en": "👩🏽‍💻 <b>Attach</b> video to convert to telescope (round video note)",
    "es": "👩🏽‍💻 <b>Adjunta</b> vídeo para convertirlo a telescopio (nota de vídeo redonda)",
    "fr": "👩🏽‍💻 <b>Joins</b> la vidéo à convertir en télescope (note vidéo ronde)",
    "zh": "👩🏽‍💻<b>附加</b>视频以转换为望远镜（圆形视频笔记）",
    "ar": "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى تلسكوب (ملاحظة فيديو دائرية)",
}
l_video_slice_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в узкую видео-полоску (срез)",
    "en": "👩🏽‍💻 <b>Attach</b> video to convert into narrow video strip (slice)",
    "es": "👩🏽‍💻 <b>Adjunta</b> vídeo para convertirlo en tira de vídeo estrecha (corte)",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo à convertir en bande vidéo étroite (tranche)",
    "zh": "👩🏽‍💻<b>附加</b>视频以转换为窄视频条（切片）",
    "ar": "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى شريط فيديو ضيق (شريحة)",
}
l_video_transcribe_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> круглую видео-заметку для извлечения текста",
    "en": "👩🏽‍💻 <b>Attach</b> round video note to extract text",
    "es": "👩🏽‍💻 <b>Adjunta</b> nota de vídeo redonda para extraer el texto",
    "fr": "👩🏽‍💻 <b>Joins</b> une note vidéo ronde pour en extraire le texte",
    "zh": "👩🏽‍💻<b>附加</b>圆形视频笔记以提取文本",
    "ar": "👩🏽‍💻 <b>أرفق</b> ملاحظة فيديو دائرية لاستخراج النص",
}

l_audio_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>audio</i> в",
    "en": "👩🏽‍💻 <b>Choose</b> tools to convert <i>audio</i> to",
    "es": "👩🏽‍💻 <b>Elige</b> herramientas para convertir <i>audio</i> a",
    "fr": "👩🏽‍💻 <b>Choisissez</b> des outils pour convertir <i>audio</i> en",
    "zh": "👩🏽‍💻<b>选择</b>将<i>音频</i>转换为的工具",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>الصوت</i> إلى",
}
l_audio_mp3 = {
    "ru": "▶️ mp3-аудио",
    "en": "▶️ mp3-audio",
    "es": "▶️ mp3-audio",
    "fr": "▶️ mp3-audio",
    "zh": "▶️ mp3-音频",
    "ar": "▶️ mp3-الصوت",
}
l_audio_ogg = {
    "ru": "🎤 ogg-голосовое",
    "en": "🎤 ogg-voice",
    "es": "🎤 ogg-voz",
    "fr": "🎤 ogg-voix",
    "zh": "🎤 ogg-语音",
    "ar": "🎤 ogg-الصوتي",
}
l_audio_vinyl = {
    "ru": "⚫️ винил-пластинка",
    "en": "⚫️ vinyl record",
    "es": "⚫️ disco de vinilo",
    "fr": "⚫️ disque vinyle",
    "zh": "⚫️ 黑胶唱片",
    "ar": "⚫️ أسطوانة فِينِيل",
}
l_audio_transcribe = {
    "ru": "🗣️ транскрибация",
    "en": "🗣️ transcription",
    "es": "🗣️ transcripción",
    "fr": "🗣️ transcription",
    "zh": "🗣️ 转录",
    "ar": "🗣️ النسخ",
}
l_audio_mp3_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> голосовое для преобразования в mp3",
    "en": "👩🏽‍💻 <b>Attach</b> voice message to convert to mp3",
    "es": "👩🏽‍💻 <b>Adjunta</b> un mensaje de voz para convertirlo a mp3",
    "fr": "👩🏽‍💻 <b>Joignez</b> un message vocal à convertir en mp3",
    "zh": "👩🏽‍💻<b>附加</b>语音消息以转换为mp3",
    "ar": "👩🏽‍💻 <b>أرفق</b> رسالة صوتية لتحويلها إلى mp3",
}
l_audio_ogg_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> аудио для преобразования в голосовое",
    "en": "👩🏽‍💻 <b>Attach</b> audio to convert to voice message",
    "es": "👩🏽‍💻 <b>Adjunta</b> audio para convertirlo en mensaje de voz",
    "fr": "👩🏽‍💻 <b>Joignez</b> un audio à convertir en message vocal",
    "zh": "👩🏽‍💻<b>附加</b>音频以转换为语音消息",
    "ar": "👩🏽‍💻 <b>أرفق</b> صوتًا لتحويله إلى رسالة صوتية",
}
l_audio_vinyl_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> аудио для преобразования в телескоп в виде виниловой пластинки",
    "en": "👩🏽‍💻 <b>Attach</b> audio to convert into a vinyl-record-style telescope",
    "es": "👩🏽‍💻 <b>Adjunta</b> audio para convertirlo en un telescopio estilo vinilo",
    "fr": "👩🏽‍💻 <b>Joins</b> un audio à convertir en télescope façon vinyle",
    "zh": "👩🏽‍💻<b>附加</b>音频以转换为黑胶唱片样式的望远镜",
    "ar": "👩🏽‍💻 <b>أرفق</b> صوتًا لتحويله إلى تلسكوب على شكل أسطوانة فينيل",
}
l_audio_transcribe_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> голосовое для преобразования в текст",
    "en": "👩🏽‍💻 <b>Attach</b> voice message to convert to text",
    "es": "👩🏽‍💻 <b>Adjunta</b> un mensaje de voz para convertirlo en texto",
    "fr": "👩🏽‍💻 <b>Joignez</b> un message vocal à convertir en texte",
    "zh": "👩🏽‍💻<b>附加</b>语音消息以转换为文本",
    "ar": "👩🏽‍💻 <b>أرفق</b> رسالة صوتية لتحويلها إلى نص",
}
l_audio_recognize = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> распознавания речи",
    "en": "👩🏽‍💻 <b>Error</b> in speech recognition",
    "es": "👩🏽‍💻 <b>Error</b> en el reconocimiento de voz",
    "fr": "👩🏽‍💻 <b>Erreur</b> de reconnaissance vocale",
    "zh": "👩🏽‍💻<b>错误</b> 语音识别",
    "ar": "👩🏽‍💻 <b>خطأ</b> في التعرف على الصوت",
}

l_text_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>текста</i> в",
    "en": "👩🏽‍💻 <b>Choose</b> tools to convert <i>text</i> to",
    "es": "👩🏽‍💻 <b>Elige</b> herramientas para convertir <i>texto</i> a",
    "fr": "👩🏽‍💻 <b>Choisissez</b> des outils pour convertir le <i>texte</i> en",
    "zh": "👩🏽‍💻<b>选择</b>工具将<i>文本</i>转换为",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>النص</i> إلى",
}
l_text_ocr = {
    "ru": "🔣 ocr",
    "en": "🔣 ocr",
    "es": "🔣 ocr",
    "fr": "🔣 ocr",
    "zh": "🔣 ocr",
    "ar": "🔣 ocr",
}
l_text_bin = {
    "ru": "🔢 bin",
    "en": "🔢 bin",
    "es": "🔢 binario",
    "fr": "🔢 binaire",
    "zh": "🔢 二进制",
    "ar": "🔢 ثنائي",
}
l_text_hex = {
    "ru": "🔠 hex",
    "en": "🔠 hex",
    "es": "🔠 hexadecimal",
    "fr": "🔠 hexadécimal",
    "zh": "🔠 十六进制",
    "ar": "🔠 ست عشري",
}
l_text_null = {
    "ru": "0️⃣ null",
    "en": "0️⃣ null",
    "es": "0️⃣ nulo",
    "fr": "0️⃣ nul",
    "zh": "0️⃣ 空值",
    "ar": "0️⃣ فارغ",
}
l_text_mp3 = {
    "ru": "▶️ mp3-аудио",
    "en": "▶️ mp3-audio",
    "es": "▶️ mp3-audio",
    "fr": "▶️ mp3-audio",
    "zh": "▶️ mp3-音频",
    "ar": "▶️ mp3-الصوت",
}
l_text_url = {
    "ru": "️🧾 url-encode",
    "en": "️🧾 url-encode",
    "es": "️🧾 codificación url",
    "fr": "️🧾 encodage url",
    "zh": "️🧾 url 编码",
    "ar": "️🧾 ترميز url",
}

l_text_ocr_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> файл для оптического распознавания текста",
    "en": "👩🏽‍💻 <b>Attach</b> file for optical text recognition",
    "es": "👩🏽‍💻 <b>Adjunta</b> un archivo para el reconocimiento óptico de texto",
    "fr": "👩🏽‍💻 <b>Joins</b> un fichier pour la reconnaissance optique de texte",
    "zh": "👩🏽‍💻 <b>附加</b>用于光学字符识别的文件",
    "ar": "👩🏽‍💻 <b>أرفق</b> ملفًا للتعرف البصري على النص",
}
l_text_bin_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в байтовый вид",
    "en": "👩🏽‍💻 <b>Attach</b> text to convert to byte format",
    "es": "👩🏽‍💻 <b>Adjunta</b> texto para convertirlo a formato de bytes",
    "fr": "👩🏽‍💻 <b>Joins</b> un texte à convertir en format octet",
    "zh": "👩🏽‍💻 <b>附加</b>文本以转换为字节格式",
    "ar": "👩🏽‍💻 <b>أرفق</b> نصًا لتحويله إلى صيغة البايت",
}
l_text_hex_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в hex-символы (шестнадцатиричное представление байт)",
    "en": "👩🏽‍💻 <b>Attach</b> text to convert to hex characters (hexadecimal representation of bytes)",
    "es": "👩🏽‍💻 <b>Adjunta</b> texto para convertirlo en caracteres hexadecimales (representación hexadecimal de bytes)",
    "fr": "👩🏽‍💻 <b>Joins</b> un texte à convertir en caractères hexadécimaux (représentation hexadécimale des octets)",
    "zh": "👩🏽‍💻 <b>附加</b>文本以转换为十六进制字符（字节的十六进制表示）",
    "ar": "👩🏽‍💻 <b>أرفق</b> نصًا لتحويله إلى رموز سداسية (تمثيل سداسي عشري للبايتات)",
}
l_text_mp3_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в голосовое",
    "en": "👩🏽‍💻 <b>Attach</b> text to convert to voice",
    "es": "👩🏽‍💻 <b>Adjunta</b> texto para convertirlo en voz",
    "fr": "👩🏽‍💻 <b>Joins</b> un texte à convertir en voix",
    "zh": "👩🏽‍💻 <b>附加</b>文本以转换为语音",
    "ar": "👩🏽‍💻 <b>أرفق</b> نصًا لتحويله إلى صوت",
}
l_text_url_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> текст для url-encode-преобразования (процентное и шестнадцатиричное кодирование как правило https-ссылок)",
    "en": "👩🏽‍💻 <b>Attach</b> text for url-encode conversion (percent and hexadecimal encoding, typically https links)",
    "es": "👩🏽‍💻 <b>Adjunta</b> texto para la conversión url-encode (codificación porcentual y hexadecimal, típicamente enlaces https)",
    "fr": "👩🏽‍💻 <b>Joins</b> un texte pour la conversion url-encode (encodage en pourcentage et hexadécimal, typiquement des liens https)",
    "zh": "👩🏽‍💻 <b>附加</b>文本以进行 url 编码转换（百分比和十六进制编码，通常是 https 链接）",
    "ar": "👩🏽‍💻 <b>أرفق</b> نصًا لتحويله إلى ترميز URL (الترميز النسبي والسداسي العشري، عادةً روابط https)",
}
l_text_text1024 = {
    "ru": "💭 Текст 1024 символа",
    "en": "💭 Text 1024 characters",
    "es": "💭 Texto de 1024 caracteres",
    "fr": "💭 Texte de 1024 caractères",
    "zh": "💭 文本 1024 个字符",
    "ar": "💭 نص من 1024 حرفًا",
}
l_text_text4096 = {
    "ru": "🗯️ Текст 4096 символа",
    "en": "🗯️ Text 4096 characters",
    "es": "🗯️ Texto de 4096 caracteres",
    "fr": "🗯️ Texte de 4096 caractères",
    "zh": "🗯️ 文本 4096 个字符",
    "ar": "🗯️ نص من 4096 حرفًا",
}

l_convert_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> преобразования контента (попробуй позже или загрузи другой файл)",
    "en": "👩🏽‍💻 <b>Error</b> converting content (try later or upload another file)",
    "es": "👩🏽‍💻 <b>Error</b> al convertir el contenido (inténtalo más tarde o sube otro archivo)",
    "fr": "👩🏽‍💻 <b>Erreur</b> de conversion de contenu (essayez plus tard ou téléchargez un autre fichier)",
    "zh": "👩🏽‍💻 <b>错误</b>转换内容（稍后再试或上传其他文件）",
    "ar": "👩🏽‍💻 <b>خطأ</b> في تحويل المحتوى (حاول لاحقًا أو قم بتحميل ملف آخر)",
}
l_convert_more_one = {
    "ru": "👩🏽‍💻 <b>Загрузи</b> более 1го файла как альбом",
    "en": "👩🏽‍💻 <b>Upload</b> more than one file as an album",
    "es": "👩🏽‍💻 <b>Sube</b> más de un archivo como álbum",
    "fr": "👩🏽‍💻 <b>Télécharge</b> plus d'un fichier en tant qu'album",
    "zh": "👩🏽‍💻 <b>上传</b>多个文件作为相册",
    "ar": "👩🏽‍💻 <b>حمّل</b> أكثر من ملف كألبوم",
}
l_telegraph_text = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> .jpg/.png/.gif/.mp4 - контент, чтобы создать ссылку",
    "en": "👩🏽‍💻 <b>Attach</b> .jpg/.png/.gif/.mp4 - content to create a link",
    "es": "👩🏽‍💻 <b>Adjunta</b> contenido .jpg/.png/.gif/.mp4 para crear un enlace",
    "fr": "👩🏽‍💻 <b>Joindre</b> du contenu .jpg/.png/.gif/.mp4 pour créer un lien",
    "zh": "👩🏽‍💻 <b>附加</b> .jpg/.png/.gif/.mp4 内容以创建链接",
    "ar": "👩🏽‍💻 <b>أرفق</b> محتوى .jpg/.png/.gif/.mp4 لإنشاء رابط",
}
l_telegraph_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> получения ссылки (попробуй позже или загрузи другой файл)",
    "en": "👩🏽‍💻 <b>Error</b> getting the link (try later or upload another file)",
    "es": "👩🏽‍💻 <b>Error</b> al obtener el enlace (inténtalo más tarde o sube otro archivo)",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors de l'obtention du lien (essayez plus tard ou téléchargez un autre fichier)",
    "zh": "👩🏽‍💻 <b>错误</b>获取链接（稍后再试或上传其他文件）",
    "ar": "👩🏽‍💻 <b>خطأ</b> في الحصول على الرابط (حاول لاحقًا أو قم بتحميل ملف آخر)",
}
l_json_text = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> любое сообщение или сделай пересылку",
    "en": "👩🏽‍💻 <b>Attach</b> any message or forward it",
    "es": "👩🏽‍💻 <b>Adjunta</b> cualquier mensaje o reenvíalo",
    "fr": "👩🏽‍💻 <b>Joindre</b> n'importe quel message ou le transférer",
    "zh": "👩🏽‍💻 <b>附加</b>任何消息或转发",
    "ar": "👩🏽‍💻 <b>أرفق</b> أي رسالة أو أعد توجيهها",
}

l_sticker_circle_on = {
    "ru": "✅ Закруглить",
    "en": "✅ Round corners",
    "es": "✅ Bordes redondeados",
    "fr": "✅ Arrondir les coins",
    "zh": "✅ 圆角",
    "ar": "✅ تدوير الزوايا",
}
l_sticker_circle_off = {
    "ru": "☑️ Закруглить",
    "en": "☑️ Round corners",
    "es": "☑️ Bordes redondeados",
    "fr": "☑️ Arrondir les coins",
    "zh": "☑️ 圆角",
    "ar": "☑️ تدوير الزوايا",
}
l_sticker_rbg_on = {
    "ru": "✅ Удалить фон",
    "en": "✅ Remove background",
    "es": "✅ Eliminar fondo",
    "fr": "✅ Supprimer le fond",
    "zh": "✅ 去除背景",
    "ar": "✅ إزالة الخلفية",
}
l_sticker_rbg_off = {
    "ru": "☑️ Удалить фон",
    "en": "☑️ Remove background",
    "es": "☑️ Eliminar fondo",
    "fr": "☑️ Supprimer le fond",
    "zh": "☑️ 去除背景",
    "ar": "☑️ إزالة الخلفية",
}

l_tools_need_link_story = {
    "ru": "👩🏽‍💻 Вставь ссылку на @-tg-историю или x/ig/tt/yt-видео",
    "en": "👩🏽‍💻 Insert a link to @-tg story or x/ig/tt/yt video",
    "es": "👩🏽‍💻 Inserta un enlace a la historia @-tg o video x/ig/tt/yt",
    "fr": "👩🏽‍💻 Insère un lien vers une histoire @-tg ou une vidéo x/ig/tt/yt",
    "zh": "👩🏽‍💻 插入 @-tg 故事或 x/ig/tt/yt 视频链接",
    "ar": "👩🏽‍💻 أدخل رابطًا لقصة @-tg أو فيديو x/ig/tt/yt",
}
l_tools_no_stories = {
    "ru": "👩🏽‍💻 Доступных для скачивания историй нет",
    "en": "👩🏽‍💻 No stories available for download",
    "es": "👩🏽‍💻 No hay historias disponibles para descargar",
    "fr": "👩🏽‍💻 Aucune histoire disponible au téléchargement",
    "zh": "👩🏽‍💻 没有可下载的故事",
    "ar": "👩🏽‍💻 لا توجد قصص متاحة للتنزيل",
}
l_tools_has_restricted = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> отправки видео-заметки/голосового для premium-аккаунта! В настройках <b>[Конфиденциальность]</b> добавь @{0} в <i>исключения</i> для <b>[Голосовые сообщения]</b>, чтобы отобразить видео-заметку/голосовое",
    "en": "👩🏽‍💻 <b>Error</b> sending video note/voice for premium account! In <b>[Privacy]</b> settings add @{0} to <i>exceptions</i> for <b>[Voice messages]</b> to display video note/voice",
    "es": "👩🏽‍💻 <b>Error</b> al enviar nota de video/voz para cuenta premium! En la configuración de <b>[Privacidad]</b>, agrega @{0} a las <i>excepciones</i> para <b>[Mensajes de voz]</b> para mostrar la nota de video/voz",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors de l'envoi de la note vidéo/voix pour un compte premium ! Dans les paramètres <b>[Confidentialité]</b>, ajoutez @{0} aux <i>exceptions</i> pour <b>[Messages vocaux]</b> pour afficher la note vidéo/voix",
    "zh": "👩🏽‍💻 发送视频笔记/语音失败，适用于高级账户！在<b>[隐私]</b>设置中，将@{0}添加到<b>[语音消息]</b>的<i>例外</i>中以显示视频笔记/语音",
    "ar": "👩🏽‍💻 <b>خطأ</b> في إرسال ملاحظة فيديو/صوت لحساب مميز! في إعدادات <b>[الخصوصية]</b> أضف @{0} إلى <i>الاستثناءات</i> لـ <b>[الرسائل الصوتية]</b> لعرض ملاحظة/صوت الفيديو",
}
l_tools_acc_age = {
    "ru": "<b>Возраст аккаунта</b>: {0}",
    "en": "<b>Account age</b>: {0}",
    "es": "<b>Antigüedad de la cuenta</b>: {0}",
    "fr": "<b>Âge du compte</b> : {0}",
    "zh": "<b>账户年龄</b>: {0}",
    "ar": "<b>عمر الحساب</b>: {0}",
}
l_tools_set_owner = {
    "ru": "👩🏽‍💻 <b>ID</b>-создателя набора ({0}):\n\n<blockquote><code>{1}</code></blockquote>",
    "en": "👩🏽‍💻 <b>Set creator ID</b> ({0}):\n\n<blockquote><code>{1}</code></blockquote>",
    "es": "👩🏽‍💻 <b>ID</b> del creador del conjunto ({0}):\n\n<blockquote><code>{1}</code></blockquote>",
    "fr": "👩🏽‍💻 <b>ID</b> du créateur du set ({0}) :\n\n<blockquote><code>{1}</code></blockquote>",
    "zh": "👩🏽‍💻 <b>集合创建者ID</b>（{0}）：\n\n<blockquote><code>{1}</code></blockquote>",
    "ar": "👩🏽‍💻 <b>معرف</b> منشئ المجموعة ({0}):\n\n<blockquote><code>{1}</code></blockquote>",
}
# endregion


# region FereyAIBot
l_ai_btn1 = {
    'ru': "👩🏽‍💻 Нейросети",
    'en': "👩🏽‍💻 Neural networks",
    'es': "👩🏽‍💻 Redes neuronales",
    'fr': "👩🏽‍💻 Réseaux de neurones",
    'zh': "👩🏽‍💻 神经网络",
    'ar': "👩🏽‍💻 الشبكات العصبية",
}
l_ai_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_ai_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> для #нейро-генерации контента:\n\n<blockquote>▪️<b>текст/изображение</b>\n▪️<b>#нейро-анализ</b> @tg-каналов\n▪️<b>распознавание</b> речи\n▪️<b>генерация</b> голоса\n▪️<b>очистка ⁰истории</b> /start</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-application</i> for #neuro-content generation:\n\n<blockquote>▪️<b>text/image</b>\n▪️<b>#neuro-analysis</b> of @tg-channels\n▪️<b>speech</b> recognition\n▪️<b>voice</b> generation\n▪️<b>cleaning ⁰history</b> /start</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la <i>@tg-aplicación</i> para la generación de contenido #neuro:\n\n<blockquote>▪️<b>texto/imagen</b>\n▪️<b>#neuro-análisis</b> de canales @tg\n▪️<b>reconocimiento</b> de voz\n▪️<b>generación</b> de voz\n▪️<b>limpieza del ⁰historial</b> /start</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans l'<i>@tg-application</i> pour la génération de contenu #neuro :\n\n<blockquote>▪️<b>texte/image</b>\n▪️<b>#neuro-analyse</b> des canaux @tg\n▪️<b>reconnaissance</b> vocale\n▪️<b>génération</b> vocale\n▪️<b>nettoyage de l’⁰historique</b> /start</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎来到<i>@tg-应用</i>用于#神经生成内容：\n\n<blockquote>▪️<b>文本/图像</b>\n▪️<b>#神经分析</b> @tg频道\n▪️<b>语音</b>识别\n▪️<b>语音</b>生成\n▪️<b>清理 ⁰历史</b> /start</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-تطبيق</i> لإنشاء المحتوى #العصبي:\n\n<blockquote>▪️<b>نص/صورة</b>\n▪️<b>#تحليل-عصبي</b> لقنوات @tg\n▪️<b>التعرف</b> على الكلام\n▪️<b>توليد</b> الصوت\n▪️<b>تنظيف ⁰السجل</b> /start</blockquote>",
}

l_gen_txt = {
    "ru": "📘 Текст{0}",
    "en": "📘 Text{0}",
    "es": "📘 Texto{0}",
    "fr": "📘 Texte{0}",
    "zh": "📘 文字{0}",
    "ar": "📘 نص{0}",
}
l_gen_voice = {
    "ru": "🗣️ Голос",
    "en": "🗣️ Voice",
    "es": "🗣️ Voz",
    "fr": "🗣️ Voix",
    "zh": "🗣️ 语音",
    "ar": "🗣️ صوت",
}
l_gen_img = {
    "ru": "🌌 Образ",
    "en": "🌌 Image",
    "es": "🌌 Imagen",
    "fr": "🌌 Image",
    "zh": "🌌 图片",
    "ar": "🌌 صورة",
}

l_gen_tlg = {
    "ru": "👩🏽‍💻 @tg-канал",
    "en": "👩🏽‍💻 @tg-channel",
    "es": "👩🏽‍💻 Canal @tg",
    "fr": "👩🏽‍💻 Chaîne @tg",
    "zh": "👩🏽‍💻 @tg频道",
    "ar": "👩🏽‍💻 قناة @tg",
}
l_generate_main = {
    "ru": "👩🏽‍💻 <b>Выбери режим</b>",
    "en": "👩🏽‍💻 <b>Choose mode</b>",
    "es": "👩🏽‍💻 <b>Elige modo</b>",
    "fr": "👩🏽‍💻 <b>Choisir le mode</b>",
    "zh": "👩🏽‍💻 <b>选择模式</b>",
    "ar": "👩🏽‍💻 <b>اختر الوضع</b>",
}
l_generate_prompt = {
    "ru": "👩🏽‍💻 <b>Введи</b> запрос для <b>{0}</b> 👇🏼..",
    "en": "👩🏽‍💻 <b>Enter</b> a request for <b>{0}</b> 👇🏼..",
    "es": "👩🏽‍💻 <b>Introduce</b> una solicitud para <b>{0}</b> 👇🏼..",
    "fr": "👩🏽‍💻 <b>Entrez</b> une requête pour <b>{0}</b> 👇🏼..",
    "zh": "👩🏽‍💻 <b>输入</b><b>{0}</b> 的请求 👇🏼..",
    "ar": "👩🏽‍💻 <b>أدخل</b> طلبًا لـ <b>{0}</b> 👇🏼..",
}
l_generate_chn = {
    "ru": "👩🏽‍💻 <b>Вставь</b> ссылку на @tg-канал для анализа финансовых показателей",
    "en": "👩🏽‍💻 <b>Insert</b> a link to @tg-channel to analyze financial indicators",
    "es": "👩🏽‍💻 <b>Pega</b> el enlace del canal @tg para analizar indicadores financieros",
    "fr": "👩🏽‍💻 <b>Collez</b> le lien vers la chaîne @tg pour analyser les indicateurs financiers",
    "zh": "👩🏽‍💻 <b>粘贴</b> @tg频道链接以分析财务指标",
    "ar": "👩🏽‍💻 <b>أدخل</b> رابط قناة @tg لتحليل المؤشرات المالية",
}

l_generate_wait = {
    "ru": "👩🏽‍💻 <b>Выбери режим</b> или <b>дождись</b> окончания генерации..",
    "en": "👩🏽‍💻 <b>Choose mode</b> or <b>wait</b> for the generation to finish..",
    "es": "👩🏽‍💻 <b>Elige modo</b> o <b>espera</b> a que termine la generación..",
    "fr": "👩🏽‍💻 <b>Choisir le mode</b> ou <b>attendre</b> la fin de la génération..",
    "zh": "👩🏽‍💻 <b>选择模式</b>或<b>等待</b>生成完成..",
    "ar": "👩🏽‍💻 <b>اختر الوضع</b> أو <b>انتظر</b> حتى انتهاء التوليد..",
}
l_generate_subcribe = {
    "ru": "👩🏽‍💻 Подожди {0} сек или оформи 💨Подписку",
    "en": "👩🏽‍💻 Wait {0} sec or get a 💨Subscription",
    "es": "👩🏽‍💻 Espera {0} seg o consigue una 💨Suscripción",
    "fr": "👩🏽‍💻 Attendez {0} sec ou prenez un 💨Abonnement",
    "zh": "👩🏽‍💻 等待 {0} 秒或获取 💨订阅",
    "ar": "👩🏽‍💻 انتظر {0} ثانية أو احصل على 💨اشتراك",
}
l_generate_subcribe2 = {
    "ru": "👩🏽‍💻 <b>Подожди</b> <i>{0}сек или <a href='{1}'>оформи 💨Подписку</a></i>",
    "en": "👩🏽‍💻 <b>Wait</b> <i>{0} sec or <a href='{1}'>get a 💨Subscription</a></i>",
    "es": "👩🏽‍💻 <b>Espera</b> <i>{0} seg o <a href='{1}'>consigue una 💨Suscripción</a></i>",
    "fr": "👩🏽‍💻 <b>Attendez</b> <i>{0} sec ou <a href='{1}'>prenez un 💨Abonnement</a></i>",
    "zh": "👩🏽‍💻<b>等待</b> <i>{0} 秒或 <a href='{1}'>获取 💨订阅</a></i>",
    "ar": "👩🏽‍💻 <b>انتظر</b> <i>{0} ثانية أو <a href='{1}'>احصل على 💨اشتراك</a></i>",
}
l_generate_subcribe_channel = {
    "ru": "👩🏽‍💻 Оформи 💨Подписку, чтобы узнать финансовый потенциал твоего @tg-канала",
    "en": "👩🏽‍💻 Get a 💨Subscription to find out the financial potential of your @tg-channel",
    "es": "👩🏽‍💻 Consigue una 💨Suscripción para conocer el potencial financiero de tu canal @tg",
    "fr": "👩🏽‍💻 Prenez un 💨Abonnement pour découvrir le potentiel financier de votre chaîne @tg",
    "zh": "👩🏽‍💻 获取 💨订阅以了解您 @tg 频道的财务潜力",
    "ar": "👩🏽‍💻 احصل على 💨اشتراك لمعرفة الإمكانيات المالية لقناتك @tg",
}

l_generate_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> генерации, повтори запрос позже",
    'en': "👩🏽‍💻 <b>Generation error</b>, please try again later",
    'es': "👩🏽‍💻 <b>Error de generación</b>, inténtalo de nuevo más tarde",
    'fr': "👩🏽‍💻 <b>Erreur de génération</b>, veuillez réessayer plus tard",
    'zh': "👩🏽‍💻 <b>生成错误</b>，请稍后重试",
    'ar': "👩🏽‍💻 <b>خطأ في التوليد</b>، يرجى المحاولة لاحقًا",
}

l_generate_error_clear = {
    'ru': "Ошибка генерации",
    'en': "Generation error",
    'es': "Error de generación",
    'fr': "Erreur de génération",
    'zh': "生成错误",
    'ar': "خطأ في التوليد",
}

l_process_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> преобразования",
    'en': "👩🏽‍💻 <b>Error</b> conversion",
    'es': "👩🏽‍💻 <b>Error</b> de conversión",
    'fr': "👩🏽‍💻 Conversion <b>Erreur</b>",
    'zh': "👩🏽‍💻<b>错误</b>转换",
    'ar': "👩🏽‍💻 <b>خطأ</b> في التحويل",
}
l_generate_errchn = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> доступа к каналу (попробуй позже или сделай канал публичным)",
    'en': "👩🏽‍💻 <b>Error</b> accessing the channel (try later or make the channel public)",
    'es': "👩🏽‍💻 <b>Error</b> al acceder al canal (inténtalo más tarde o haz público el canal)",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de l'accès à la chaîne (essayez plus tard ou rendez la chaîne publique)",
    'zh': "👩🏽‍💻 <b>访问频道时出错</b>（稍后重试或将频道公开）",
    'ar': "👩🏽‍💻 <b>خطأ</b> في الدخول إلى القناة (حاول لاحقًا أو اجعل القناة عامة)",
}
l_ai_request = {
    'ru': "👩🏽‍💻 <i><b>Обработка</b> запроса..\n#длительность 0 мин</i>",
    'en': "👩🏽‍💻 <i><b>Processing</b> request..\n#duration 0 min</i>",
    'es': "👩🏽‍💻 <i><b>Procesando</b> solicitud..\n#duración 0 min</i>",
    'fr': "👩🏽‍💻 <i><b>Traitement</b> demande..\n#durée 0 min</i>",
    'zh': "👩🏽‍💻<i><b>正在处理</b>请求..\n#duration 0 分钟</i>",
    'ar': "👩🏽‍💻 <i><b>جارٍ معالجة</b> الطلب..\n#المدة 0 دقيقة</i>",
}
# endregion


# --------


# region FereyBotBot
l_bot_btn1 = {
    "ru": "👩🏽‍💻 Приложения",
    "en": "👩🏽‍💻 Applications",
    "es": "👩🏽‍💻 Aplicaciones",
    "fr": "👩🏽‍💻 Applications",
    "zh": "👩🏽‍💻 应用",
    "ar": "👩🏽‍💻 التطبيقات",
}
l_bot_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_bot_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в #нейро-конструктор <b>@tg</b>-приложений:\n\n<blockquote>▪️монетизация и интеграции\n▪️нейро-перевод/оповещения\n▪️маркетплейс и геймификация\n▪️нейро-генерация приложений\n▪️веб-мини/нейро-постинг</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the #neuro-constructor of <b>@tg</b>-applications:\n\n<blockquote>▪️monetization and integrations\n▪️neuro-translation/notifications\n▪️marketplace and gamification\n▪️neuro-generation of applications\n▪️web-mini/neuro-posting</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido al #neuro-constructor de <b>@tg</b>-aplicaciones:\n\n<blockquote>▪️monetización e integraciones\n▪️neuro-traducción/notificaciones\n▪️marketplace y gamificación\n▪️neuro-generación de aplicaciones\n▪️web-mini/neuro-posting</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans le #neuro-constructor des <b>@tg</b>-applications:\n\n<blockquote>▪️monétisation et intégrations\n▪️neuro-traduction/notifications\n▪️marketplace et gamification\n▪️neuro-génération d'applications\n▪️web-mini/neuro-posting</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎来到 #neuro-constructor 的 <b>@tg</b>-应用:\n\n<blockquote>▪️变现与集成\n▪️神经翻译/通知\n▪️市场与游戏化\n▪️神经生成应用\n▪️网页-迷你/神经发布</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في #neuro-constructor لتطبيقات <b>@tg</b>:\n\n<blockquote>▪️تحقيق الدخل والتكاملات\n▪️الترجمة العصبية/الإشعارات\n▪️السوق والتلعيب\n▪️التوليد العصبي للتطبيقات\n▪️الويب-ميني/النشر العصبي</blockquote>",
}
l_wait_for_translate_bot = {
    "ru": "👩🏽‍💻 <b>Перевод</b> {0}-бота на <i>{1}</i>-язык\n\n#длительность 0мин",
    "en": "👩🏽‍💻 <b>Translation</b> of {0}-bot into <i>{1}</i>-language\n\n#duration 0min",
    "es": "👩🏽‍💻 <b>Traducción</b> de {0}-bot al <i>{1}</i>-idioma\n\n#duración 0min",
    "fr": "👩🏽‍💻 <b>Traduction</b> de {0}-bot en <i>{1}</i>-langue\n\n#durée 0min",
    "zh": "👩🏽‍💻 <b>翻译</b> {0}-机器人为<i>{1}</i>-语言\n\n#时长 0分钟",
    "ar": "👩🏽‍💻 <b>الترجمة</b> {0}-بوت إلى <i>{1}</i>-اللغة\n\n#المدة 0دقيقة",
}
l_template_is_ready = {
    "ru": "👩🏽‍💻 <b>Шаблон</b> для @{0} готов!",
    "en": "👩🏽‍💻 <b>Template</b> for @{0} is ready!",
    "es": "👩🏽‍💻 <b>Plantilla</b> para @{0} está lista!",
    "fr": "👩🏽‍💻 <b>Modèle</b> pour @{0} est prêt !",
    "zh": "👩🏽‍💻 <b>模板</b> @{0} 已准备就绪！",
    "ar": "👩🏽‍💻 <b>القالب</b> لـ @{0} جاهز!",
}
l_payment_successful = {
    "ru": "👩🏽‍💻 <b>Пользователь</b> {0} 💰Внес оплату в размере {1} {2}",
    "en": "👩🏽‍💻 <b>User</b> {0} 💰made a payment of {1} {2}",
    "es": "👩🏽‍💻 <b>Usuario</b> {0} 💰realizó un pago de {1} {2}",
    "fr": "👩🏽‍💻 <b>Utilisateur</b> {0} 💰a effectué un paiement de {1} {2}",
    "zh": "👩🏽‍💻 <b>用户</b> {0} 💰支付了 {1} {2}",
    "ar": "👩🏽‍💻 <b>المستخدم</b> {0} 💰قام بدفع مبلغ {1} {2}",
}
l_create_view_web = {
    "ru": "👩🏽‍💻 <b>Скрытая</b> ссылка на веб-страницу: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>Подлинная</b> телеграм-ссылка: <code>{0}</code>",
    "en": "👩🏽‍💻 <b>Hidden</b> link to the web page: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>Genuine</b> Telegram link: <code>{0}</code>",
    "es": "👩🏽‍💻 <b>Oculto</b> enlace a la página web: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>Enlace genuino</b> de Telegram: <code>{0}</code>",
    "fr": "👩🏽‍💻 <b>Caché</b> lien vers la page Web: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>Lien Telegram authentique</b>: <code>{0}</code>",
    "zh": "👩🏽‍💻 <b>隐藏</b> 的网页链接: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>真实的</b> Telegram 链接: <code>{0}</code>",
    "ar": "👩🏽‍💻 <b>الرابط المخفي</b> لصفحة الويب: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>الرابط الأصلي</b> لتليجرام: <code>{0}</code>"
}
l_admin_answer = {
    "ru": "👩🏽‍💻 <b>Администратор</b>: {0} to {1}:\n\n{2}",
    "en": "👩🏽‍💻 <b>Administrator</b>: {0} to {1}:\n\n{2}",
    "es": "👩🏽‍💻 <b>Administrador</b>: {0} a {1}:\n\n{2}",
    "fr": "👩🏽‍💻 <b>Administrateur</b> : {0} à {1} :\n\n{2}",
    "zh": "👩🏽‍💻 <b>管理员</b>：{0} 到 {1}：\n\n{2}",
    "ar": "👩🏽‍💻 <b>المسؤول</b>: {0} إلى {1}:\n\n{2}",
}
l_bot_need_start = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: /start-запустить @{0}-бота перед началом работы",
    "en": "👩🏽‍💻 <b>Required</b>: /start to launch the @{0} bot before starting work",
    "es": "👩🏽‍💻 <b>Requerido</b>: /start para iniciar el bot @{0} antes de comenzar",
    "fr": "👩🏽‍💻 <b>Requis</b> : /start pour lancer le bot @{0} avant de commencer",
    "zh": "👩🏽‍💻 <b>必需</b>：/start 在开始工作前启动 @{0} 机器人",
    "ar": "👩🏽‍💻 <b>مطلوب</b> : /start لتشغيل بوت @{0} قبل البدء",
}
l_bot_need_start_add = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: /start-запустить @{0}-бота, токен которого был добавлен, а также добавить бота в канал как администратора",
    "en": "👩🏽‍💻 <b>Required</b>: /start to launch the @{0} bot whose token was added, and also add the bot to the channel as an administrator",
    "es": "👩🏽‍💻 <b>Requerido</b>: /start para iniciar el bot @{0} cuyo token fue añadido, y también agregar el bot al canal como administrador",
    "fr": "👩🏽‍💻 <b>Requis</b> : /start pour lancer le bot @{0} dont le jeton a été ajouté, et également ajouter le bot au canal en tant qu'administrateur",
    "zh": "👩🏽‍💻 <b>必需</b>：/start 在已添加令牌的 @{0} 机器人上运行，并将机器人作为管理员添加到频道",
    "ar": "👩🏽‍💻 <b>مطلوب</b> : /start لتشغيل بوت @{0} الذي تمت إضافة رمزه، وأيضًا إضافة البوت إلى القناة كمسؤول",
}
l_bot_need_restart_extra_bot = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: /start-запустить @{0}-бота (токен которого был добавлен) для принятия оплат",
    "en": "👩🏽‍💻 <b>Required</b>: /start to launch the @{0} bot (whose token was added) to accept payments",
    "es": "👩🏽‍💻 <b>Requerido</b>: /start para iniciar el bot @{0} (cuyo token fue añadido) para aceptar pagos",
    "fr": "👩🏽‍💻 <b>Requis</b> : /start pour lancer le bot @{0} (dont le jeton a été ajouté) pour accepter les paiements",
    "zh": "👩🏽‍💻 <b>必需</b>：/start 运行已添加令牌的 @{0} 机器人以接受付款",
    "ar": "👩🏽‍💻 <b>مطلوب</b> : /start لتشغيل بوت @{0} (الذي تمت إضافة رمزه) لقبول المدفوعات",
}
l_bot_user_balls = {
    "ru": "👩🏽‍💻 <b>Баллы:</b> {0}",
    "en": "👩🏽‍💻 <b>Points:</b> {0}",
    "es": "👩🏽‍💻 <b>Puntos:</b> {0}",
    "fr": "👩🏽‍💻 <b>Points :</b> {0}",
    "zh": "👩🏽‍💻 <b>积分：</b> {0}",
    "ar": "👩🏽‍💻 <b>نقاط:</b> {0}",
}
l_bot_in_chn_added = {
    "ru": "👩🏽‍💻 <b>@{0}</b> успешно добавлен в канал <b>{1}</b> [id=<code>{2}</code>] и видит его подписчиков",
    "en": "👩🏽‍💻 <b>@{0}</b> was successfully added to channel <b>{1}</b> [id=<code>{2}</code>] and sees its subscribers",
    "es": "👩🏽‍💻 <b>@{0}</b> se añadió correctamente al canal <b>{1}</b> [id=<code>{2}</code>] y ve sus suscriptores",
    "fr": "👩🏽‍💻 <b>@{0}</b> a été ajouté avec succès au canal <b>{1}</b> [id=<code>{2}</code>] et voit ses abonnés",
    "zh": "👩🏽‍💻 <b>@{0}</b> 已成功添加到频道 <b>{1}</b> [id=<code>{2}</code>] 并查看其订阅者",
    "ar": "👩🏽‍💻 <b>@{0}</b> تم إضافته بنجاح إلى القناة <b>{1}</b> [id=<code>{2}</code>] ويرى المشتركين بها",
}
l_bot_in_chn_deleted = {
    "ru": "👩🏽‍💻 <b>@{0}</b> покинул канал: <b>{1}</b> [id=<code>{2}</code>] поскольку не является его администратором",
    "en": "👩🏽‍💻 <b>@{0}</b> was successfully added to the group <b>{1}</b> [id=<code>{2}</code>] and sees its members",
    "es": "👩🏽‍💻 <b>@{0}</b> se añadió correctamente al grupo <b>{1}</b> [id=<code>{2}</code>] y ve sus miembros",
    "fr": "👩🏽‍💻 <b>@{0}</b> a été ajouté avec succès au groupe <b>{1}</b> [id=<code>{2}</code>] et voit ses membres",
    "zh": "👩🏽‍💻 <b>@{0}</b> 已成功添加到群组 <b>{1}</b> [id=<code>{2}</code>] 并查看其成员",
    "ar": "👩🏽‍💻 <b>@{0}</b> تم إضافته بنجاح إلى المجموعة <b>{1}</b> [id=<code>{2}</code>] ويرى أعضائها",
}
l_bot_in_grp_added = {
    "ru": "👩🏽‍💻 <b>@{0}</b> успешно добавлен в группу: <b>{1}</b> [id=<code>{2}</code>] и видит ее участников",
    "en": "👩🏽‍💻 <b>@{0}</b> was successfully added to the group <b>{1}</b> [id=<code>{2}</code>] and sees its members",
    "es": "👩🏽‍💻 <b>@{0}</b> se añadió correctamente al grupo <b>{1}</b> [id=<code>{2}</code>] y ve sus miembros",
    "fr": "👩🏽‍💻 <b>@{0}</b> a été ajouté avec succès au groupe <b>{1}</b> [id=<code>{2}</code>] et voit ses membres",
    "zh": "👩🏽‍💻 <b>@{0}</b> 已成功添加到群组 <b>{1}</b> [id=<code>{2}</code>] 并查看其成员",
    "ar": "👩🏽‍💻 <b>@{0}</b> تم إضافته بنجاح إلى المجموعة <b>{1}</b> [id=<code>{2}</code>] ويرى أعضائها",
}
l_bot_in_grp_deleted = {
    "ru": "👩🏽‍💻 <b>@{0}</b> покинул группу: <b>{1}</b> [id=<code>{2}</code>] поскольку не является ее администратором",
    "en": "👩🏽‍💻 <b>@{0}</b> was successfully added to the group <b>{1}</b> [id=<code>{2}</code>] and sees its members",
    "es": "👩🏽‍💻 <b>@{0}</b> se añadió correctamente al grupo <b>{1}</b> [id=<code>{2}</code>] y ve sus miembros",
    "fr": "👩🏽‍💻 <b>@{0}</b> a été ajouté avec succès au groupe <b>{1}</b> [id=<code>{2}</code>] et voit ses membres",
    "zh": "👩🏽‍💻 <b>@{0}</b> 已成功添加到群组 <b>{1}</b> [id=<code>{2}</code>] 并查看其成员",
    "ar": "👩🏽‍💻 <b>@{0}</b> تم إضافته بنجاح إلى المجموعة <b>{1}</b> [id=<code>{2}</code>] ويرى أعضائها",
}
l_bot_pub_with_payment = {
    "ru": "★ Оплата публикации",
    "en": "★ Payment for publication",
    "es": "★ Pago de publicación",
    "fr": "★ Paiement de publication",
    "zh": "★ 发布付费",
    "ar": "★ الدفع للنشر",
}
l_bot_sub_with_payment = {
    "ru": "★ Оплата подписки",
    "en": "★ Payment for subscription",
    "es": "★ Pago de suscripción",
    "fr": "★ Paiement d'abonnement",
    "zh": "★ 订阅付费",
    "ar": "★ الدفع للاشتراك",
}
l_bot_msg_open = {
    "ru": "ᯅ Публикация",
    "en": "ᯅ Publication",
    "es": "ᯅ Publicación",
    "fr": "ᯅ Publication",
    "zh": "ᯅ 发布",
    "ar": "ᯅ منشور",
}
l_bot_off_handler_done = {
    'ru': "👩🏽‍💻 <b>@{0}</b>-@tg-приложение выключено",
    'en': "👩🏽‍💻 <b>@{0}</b>-bot is turned off",
    'es': "👩🏽‍💻 <b>@{0}</b>-bot está desactivado",
    'fr': "👩🏽‍💻 <b>@{0}</b>-bot est désactivé",
    'zh': "👩🏽‍💻 <b>@{0}</b>-机器人已关闭",
    'ar': "👩🏽‍💻 <b>@{0}</b>-تم إيقاف تشغيل الروبوت",
}
l_parse_text = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Парсинг пользователей (<u>{0}</u>) @{1}-бота\n\n<blockquote>👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/parse     <i>все пользователи бота</i>\n<code>/parse utm</code>   <i>utm-рефералы</i>\n<code>/parse ban</code>    <i>ban-пользователи</i>\n<code>/parse old</code>    <i>старые id-пользователи</i>\n<code>/parse admin</code>    <i>admin-пользователи</i>\n<code>/parse promo</code>    <i>promo-пользователи</i>\n<code>/parse premium</code>    <i>premium-пользователи</i>\n<code>/parse 1</code>    <i>кто лайкнул пост #1</i></blockquote>",
    'en': "👩🏽‍💻 <b>Done!</b> Parsing users (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>Commands</b>:\n/cmd-all commands\n/parse <i>all bot users</i>\n<code>/parse utm</code> <i>utm referrals</i>\n<code>/parse ban</code> <i>ban-users</i>\n<code>/parse old</code> <i>old id-users</i>\n<code>/parse admin</code> <i>admin-users</i>\n<code>/parse promo</code> <i>promo-users</i>\n<code>/parse premium</code> <i>premium-users </i>\n<code>/parse 1</code> <i>who liked post #1</i>",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Analizando usuarios (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>Comandos</b>:\n/cmd-todos los comandos\n/parse <i>todos los usuarios del bot</i>\n<code>/parse utm</code> <i>referencias utm</i>\n<code>/parse ban </code> <i>prohibir usuarios</i>\n<code>/parse old</code> <i>antiguos usuarios de id</i>\n<code>/parse admin</code> < i>usuarios-admin</i>\n<code>/parse promo</code> <i>usuarios-promo</i>\n<code>/parse premium</code> <i>usuarios premium < /i>\n<code>/parse 1</code> <i>a quién le gustó la publicación n.° 1</i>",
    'fr': "👩🏽‍💻 <b>Terminé !</b> Analyse des utilisateurs (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>Commandes</b> :\n/cmd-toutes les commandes\n/parse <i>tous les utilisateurs du bot</i>\n<code>/parse utm</code> <i>références utm</i>\n<code>/parse ban </code> <i>ban-users</i>\n<code>/analyser les anciens</code> <i>anciens identifiants d'utilisateurs</i>\n<code>/analyser l'administrateur</code> < i>utilisateurs-admin</i>\n<code>/parse promo</code> <i>utilisateurs-promo</i>\n<code>/parse premium</code> <i>utilisateurs premium < /i>\n<code>/parse 1</code> <i>qui a aimé le post n°1</i>",
    'zh': "👩🏽‍💻 <b>完成！</b> 解析用户 (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>命令</b>：\n/cmd-所有命令\n/parse <i>所有机器人用户</i>\n<code>/parse utm</code> <i>utm 推荐</i>\n<code>/parse ban </code> <i>禁止用户</i>\n<code>/parse old</code> <i>旧id-users</i>\n<code>/parse admin</code> < i>admin-users</i>\n<code>/parse promo</code> <i>promo-users</i>\n<code>/parse premium</code> <i>premium-users < /i>\n<code>/parse 1</code> <i>谁喜欢帖子 #1</i>",
    'ar': "👩🏽‍💻 <b>تم!</b> تحليل المستخدمين (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>الأوامر</b>:\n/cmd-جميع الأوامر\n/parse <i>جميع مستخدمي الروبوت</i>\n<code>/parse utm</code> <i>إحالات utm</i>\n<code>/parseban </code> <i>حظر المستخدمين</i>\n<code>/parse old</code> <i>مستخدمو المعرفات القديمة</i>\n<code>/parse admin</code> <<i>المستخدمون الإداريون</i>\n<code>/parse promo</code> <i>المستخدمون الترويجيون</i>\n<code>/parse premium</code> <i>المستخدمون المميزون < /i>\n<code>/parse 1</code> <i>من أبدى إعجابه بالمشاركة رقم 1</i>",
}
l_bot_business_self = {
    "ru": "👩🏽‍💻 Такое сообщение нельзя послать себе, только другим",
    "en": "👩🏽‍💻 You cannot send such a message to yourself, only to others",
    "es": "👩🏽‍💻 No puedes enviarte ese mensaje, solo a otros",
    "fr": "👩🏽‍💻 Vous ne pouvez pas envoyer un tel message à vous-même, seulement aux autres",
    "zh": "👩🏽‍💻 您不能将此消息发送给自己，只能发送给他人",
    "ar": "👩🏽‍💻 لا يمكنك إرسال مثل هذه الرسالة لنفسك، فقط للآخرين"
}
l_bot_business_settings = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> включить [Управление историями] в настройках [Телеграм для бизнеса]",
    "en": "👩🏽‍💻 <b>Required</b> to enable [Story Management] in [Telegram for Business] settings",
    "es": "👩🏽‍💻 <b>Es necesario</b> activar [Gestión de historias] en la configuración de [Telegram para empresas]",
    "fr": "👩🏽‍💻 <b>Nécessaire</b> d'activer [Gestion des stories] dans les paramètres de [Telegram pour les entreprises]",
    "zh": "👩🏽‍💻 <b>需要</b> 在 [Telegram 商业版] 的设置中启用 [故事管理]",
    "ar": "👩🏽‍💻 <b>مطلوب</b> تمكين [إدارة القصص] في إعدادات [Telegram للأعمال]"
}
l_bot_req_gen_photo = {
    "ru": "👩🏽‍💻 <b>Запрос</b> на генерацию фото",
    "en": "👩🏽‍💻 <b>Request</b> for photo generation",
    "es": "👩🏽‍💻 <b>Solicitud</b> para la generación de foto",
    "fr": "👩🏽‍💻 <b>Demande</b> de génération de photo",
    "zh": "👩🏽‍💻 <b>请求</b> 生成照片",
    "ar": "👩🏽‍💻 <b>طلب</b> لتوليد صورة"
}
l_bot_req_gen_voice = {
    "ru": "👩🏽‍💻 <b>Запрос</b> на запись голосового",
    "en": "👩🏽‍💻 <b>Request</b> to record a voice message",
    "es": "👩🏽‍💻 <b>Solicitud</b> para grabar un mensaje de voz",
    "fr": "👩🏽‍💻 <b>Demande</b> d'enregistrement d'un message vocal",
    "zh": "👩🏽‍💻 <b>请求</b> 录制语音消息",
    "ar": "👩🏽‍💻 <b>طلب</b> لتسجيل رسالة صوتية"
}
l_bot_req_gen_photo_prepare = {
    "ru": "👩🏽‍💻 <b>Отправка</b> фото..\n<blockquote>#длительность 1мин</blockquote>",
    "en": "👩🏽‍💻 <b>Sending</b> photo..\n<blockquote>#duration 1min</blockquote>",
    "es": "👩🏽‍💻 <b>Envío</b> de foto..\n<blockquote>#duración 1min</blockquote>",
    "fr": "👩🏽‍💻 <b>Envoi</b> de la photo..\n<blockquote>#durée 1min</blockquote>",
    "zh": "👩🏽‍💻 <b>发送</b> 照片..\n<blockquote>#时长 1分钟</blockquote>",
    "ar": "👩🏽‍💻 <b>إرسال</b> الصورة..\n<blockquote>#المدة 1دقيقة</blockquote>"
}
l_bot_req_gen_voice_prepare = {
    "ru": "👩🏽‍💻 <b>Запись</b> голосового..\n<blockquote>#длительность 1мин</blockquote>",
    "en": "👩🏽‍💻 <b>Recording</b> voice message..\n<blockquote>#duration 1min</blockquote>",
    "es": "👩🏽‍💻 <b>Grabando</b> mensaje de voz..\n<blockquote>#duración 1min</blockquote>",
    "fr": "👩🏽‍💻 <b>Enregistrement</b> du message vocal..\n<blockquote>#durée 1min</blockquote>",
    "zh": "👩🏽‍💻 <b>录制</b> 语音..\n<blockquote>#时长 1分钟</blockquote>",
    "ar": "👩🏽‍💻 <b>تسجيل</b> رسالة صوتية..\n<blockquote>#المدة 1دقيقة</blockquote>"
}
l_cdeleteanswer = {
    'ru': "🚫 <b>Бот</b> успешно откреплен [<b>{0}</b>]",
    'en': "🚫 <b>Bot</b> successfully unpinned [<b>{0}</b>]",
    'es': "🚫 <b>Bot</b> se desancló correctamente [<b>{0}</b>]",
    'fr': "🚫 <b>Bot</b> désépinglé avec succès [<b>{0}</b>]",
    'zh': "🚫 <b>机器人</b>已成功取消固定 [<b>{0}</b>]",
    'ar': "🚫 تمت إزالة تثبيت <b>البوت</b> بنجاح [<b>{0}</b>]",
}
l_transfer_success = {
    'ru': "👩🏽‍💻 <b>Права</b> владения на @{0}-@tg-приложением успешно переданы @{1}-аккаунту!\n\n👩🏽‍💻 Теперь для передачи прав/настройки можно использовать @botfather-бота",
    'en': "👩🏽‍💻 <b>Ownership rights</b> for @{0}-bot have been successfully transferred to @{1}-account!\n\n👩🏽‍💻 Now you can use @botfather-bot to transfer rights/setup",
    'es': "👩🏽‍💻 ¡Los <b>derechos de propiedad</b> para @{0}-bot se han transferido exitosamente a @{1}-cuenta!\n\n👩🏽‍💻 Ahora puedes usar @botfather-bot para transferir derechos/configuración",
    'fr': "👩🏽‍💻 <b>Les droits de propriété</b> pour @{0}-bot ont été transférés avec succès vers le compte @{1} !\n\n👩🏽‍💻 Vous pouvez désormais utiliser @botfather-bot pour transférer droits/configuration",
    'zh': "👩🏽‍💻 <b>@{0}-bot 的所有权</b>已成功转移至@{1}-账户！\n\n👩🏽‍💻 现在您可以使用@botfather-bot 进行转移权限/设置",
    'ar': "👩🏽‍💻 <b>حقوق الملكية</b> لـ @{0}-bot تم نقلها بنجاح إلى @{1}-account!\n\n👩🏽‍💻 الآن يمكنك استخدام @botfather-bot للنقل الحقوق/الإعداد",
}
l_bot_transfer_to = {
    'ru': "👩🏽‍💻 @{0}-@tg-приложение - успешно передано пользователю: <code>{1}</code>",
    'en': "👩🏽‍💻 @{0}-successfully transferred to the user: <code>{1}</code>",
    'es': "👩🏽‍💻 @{0}-transferido exitosamente al usuario: <code>{1}</code>",
    'fr': "👩🏽‍💻 @{0}-transféré avec succès à l'utilisateur : <code>{1}</code>",
    'zh': "👩🏽‍💻 @{0}-已成功转移给用户：<code>{1}</code>",
    'ar': "👩🏽‍💻 @{0}-تم النقل بنجاح إلى المستخدم: <code>{1}</code>",
}
l_bot_transfer_from = {
    'ru': "👩🏽‍💻 @{0}-@tg-приложение - успешно получено от пользователя: <code>{1}</code>",
    'en': "👩🏽‍💻 @{0}-successfully received from user: <code>{1}</code>",
    'es': "👩🏽‍💻 @{0}-recibido exitosamente del usuario: <code>{1}</code>",
    'fr': "👩🏽‍💻 @{0}-reçu avec succès de l'utilisateur : <code>{1}</code>",
    'zh': "👩🏽‍💻 @{0}-成功收到来自用户的消息：<code>{1}</code>",
    'ar': "👩🏽‍💻 @{0}-تم الاستلام بنجاح من المستخدم: <code>{1}</code>",
}
l_telegraph_title = {
    'ru': "📰 Telegra.ph блог",
    'en': "📰 Telegra.ph blog",
    'es': "📰 Blog de telégrafos",
    'fr': "📰Blog télégraphique",
    'zh': "📰 电讯报博客",
    'ar': "📰 مدونة التلغراف",
}
l_telegraph_blog = {
    "ru": "<figure><img src='{0}'/><figcaption>Фото профиля: @{1}</figcaption></figure><blockquote>Landing блог</blockquote>👩🏽‍💻 <b>@tg-приложение:</b> {2}<br>[<b>id</b>={3}]<br><b>Био:</b> {4}<br><aside>Канал</aside><a href='https://t.me/{5}'>@{5}</a>",
    "en": "<figure><img src='{0}'/><figcaption>Profile photo: @{1}</figcaption></figure><blockquote>Landing blog</blockquote>👩🏽‍💻 <b>@tg-app:</b> {2}<br>[<b>id</b>={3}]<br><b>Bio:</b> {4}<br><aside>Channel</aside><a href='https://t.me/{5}'>@{5}</a>",
    "es": "<figure><img src='{0}'/><figcaption>Foto de perfil: @{1}</figcaption></figure><blockquote>Blog de aterrizaje</blockquote>👩🏽‍💻 <b>@tg-aplicación:</b> {2}<br>[<b>id</b>={3}]<br><b>Bio:</b> {4}<br><aside>Canal</aside><a href='https://t.me/{5}'>@{5}</a>",
    "fr": "<figure><img src='{0}'/><figcaption>Photo de profil : @{1}</figcaption></figure><blockquote>Blog de landing</blockquote>👩🏽‍💻 <b>@tg-application :</b> {2}<br>[<b>id</b>={3}]<br><b>Bio :</b> {4}<br><aside>Canal</aside><a href='https://t.me/{5}'>@{5}</a>",
    "zh": "<figure><img src='{0}'/><figcaption>个人资料照片：@{1}</figcaption></figure><blockquote>落地博客</blockquote>👩🏽‍💻 <b>@tg-应用：</b> {2}<br>[<b>id</b>={3}]<br><b>简介：</b> {4}<br><aside>频道</aside><a href='https://t.me/{5}'>@{5}</a>",
    "ar": "<figure><img src='{0}'/><figcaption>صورة الملف الشخصي: @{1}</figcaption></figure><blockquote>صفحة الهبوط</blockquote>👩🏽‍💻 <b>@tg-تطبيق:</b> {2}<br>[<b>id</b>={3}]<br><b>نبذة:</b> {4}<br><aside>قناة</aside><a href='https://t.me/{5}'>@{5}</a>"
}
l_no_permission_table = {
    "ru": "👩🏽‍💻 <b>Нет прав</b> для записи в данную таблицу: {0}\n\n👩🏽‍💻 <b>Необходимо</b> заново добавить корректную ссылку на таблицу в @{1}-приложении",
    "en": "👩🏽‍💻 <b>No rights</b> to write to this table: {0}\n\n👩🏽‍💻 <b>It is necessary</b> to re-add the correct link to the table in the @{1}-app",
    "es": "👩🏽‍💻 <b>No hay derechos</b> para escribir en esta tabla: {0}\n\n👩🏽‍💻 <b>Es necesario</b> volver a agregar el enlace correcto a la tabla en @{1}-aplicación",
    "fr": "👩🏽‍💻 <b>Aucun droit</b> pour écrire dans ce tableau : {0}\n\n👩🏽‍💻 <b>Il est nécessaire</b> de réajouter le lien correct vers le tableau dans @{1}-application",
    "zh": "👩🏽‍💻 <b>无权</b> 写入此表：{0}\n\n👩🏽‍💻 <b>需要</b> 重新在 @{1}-应用 中添加正确的表链接",
    "ar": "👩🏽‍💻 <b>لا توجد حقوق</b> للكتابة في هذا الجدول: {0}\n\n👩🏽‍💻 <b>من الضروري</b> إعادة إضافة الرابط الصحيح إلى الجدول في @{1}-تطبيق"
}
l_web_version = {
    "ru": "👩🏽‍💻 <b>Веб</b>-версия:",
    "en": "👩🏽‍💻 <b>Web</b>-version:",
    "es": "👩🏽‍💻 <b>Web</b>-versión:",
    "fr": "👩🏽‍💻 <b>Web</b>-version:",
    "zh": "👩🏽‍💻 <b>网页</b>-版本:",
    "ar": "👩🏽‍💻 <b>نسخة الويب</b>:"
}
l_bot_del_done_usr = {
    "ru": "👩🏽‍💻 <b>Удаление</b> завершено: {0} (-{1})",
    "en": "👩🏽‍💻 <b>Deletion</b> completed: {0} (-{1})",
    "es": "👩🏽‍💻 <b>Eliminación</b> completada: {0} (-{1})",
    "fr": "👩🏽‍💻 <b>Suppression</b> terminée: {0} (-{1})",
    "zh": "👩🏽‍💻 <b>删除</b> 完成: {0} (-{1})",
    "ar": "👩🏽‍💻 <b>الحذف</b> اكتمل: {0} (-{1})"
}
l_bot_clr_done_usr = {
    "ru": "👩🏽‍💻 <b>Очистка</b> завершена: {0} (-{1})",
    "en": "👩🏽‍💻 <b>Cleanup</b> completed: {0} (-{1})",
    "es": "👩🏽‍💻 <b>Limpieza</b> completada: {0} (-{1})",
    "fr": "👩🏽‍💻 <b>Nettoyage</b> terminé: {0} (-{1})",
    "zh": "👩🏽‍💻 <b>清理</b> 完成: {0} (-{1})",
    "ar": "👩🏽‍💻 <b>التنظيف</b> اكتمل: {0} (-{1})"
}

l_bot_attach_csv_user_ids = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> csv-таблицу со столбцом с идентификаторами пользователей. В названии csv-файла должен быть ID-бота (который можно взять из токена бота до знака «:»)",
    "en": "👩🏽‍💻 <b>Attach</b> a CSV file with a column of user IDs. The CSV file name must include the bot ID (which can be taken from the bot token before the «:» character)",
    "es": "👩🏽‍💻 <b>Adjunta</b> una tabla CSV con una columna de identificadores de usuarios. El nombre del archivo CSV debe incluir el ID del bot (que se puede obtener del token del bot antes del signo «:»)",
    "fr": "👩🏽‍💻 <b>Joignez</b> un fichier CSV contenant une colonne d'identifiants d'utilisateurs. Le nom du fichier CSV doit inclure l'ID du bot (qui peut être extrait du token du bot avant le caractère «:»)",
    "zh": "👩🏽‍💻 <b>附上</b> 一个包含用户 ID 列的 csv 表格。csv 文件名必须包含机器人 ID（可从机器人令牌中在 «:» 符号之前获取）",
    "ar": "👩🏽‍💻 <b>أرفق</b> جدول csv يحتوي على عمود بمعرفات المستخدمين. يجب أن يتضمن اسم ملف csv معرف البوت (يمكن الحصول عليه من توكن البوت قبل العلامة «:»)"
}
l_bot_attach_csv_user_ids_start = {
    "ru": "👩🏽‍💻 <b>Старт</b> обновления списка пользователей ({0})..",
    "en": "👩🏽‍💻 <b>Start</b> updating the user list ({0})..",
    "es": "👩🏽‍💻 <b>Inicio</b> de la actualización de la lista de usuarios ({0})..",
    "fr": "👩🏽‍💻 <b>Début</b> de la mise à jour de la liste des utilisateurs ({0})..",
    "zh": "👩🏽‍💻 <b>开始</b> 更新用户列表 ({0})..",
    "ar": "👩🏽‍💻 <b>بدء</b> تحديث قائمة المستخدمين ({0}).."
}
l_bot_attach_csv_user_ids_finish = {
    "ru": "👩🏽‍💻 <b>Финиш</b> обновления списка пользователей ({0})..",
    "en": "👩🏽‍💻 <b>Finish</b> updating the user list ({0})..",
    "es": "👩🏽‍💻 <b>Fin</b> de la actualización de la lista de usuarios ({0})..",
    "fr": "👩🏽‍💻 <b>Fin</b> de la mise à jour de la liste des utilisateurs ({0})..",
    "zh": "👩🏽‍💻 <b>完成</b> 更新用户列表 ({0})..",
    "ar": "👩🏽‍💻 <b>انتهاء</b> تحديث قائمة المستخدمين ({0}).."
}

l_bot_donate_gift = {
    "ru": "🧸 Благотворительный подарок",
    "en": "👩🏽‍💻 <b>Cleanup</b> completed: {0} (-{1})",
    "es": "👩🏽‍💻 <b>Limpieza</b> completada: {0} (-{1})",
    "fr": "👩🏽‍💻 <b>Nettoyage</b> terminé: {0} (-{1})",
    "zh": "👩🏽‍💻 <b>清理</b> 完成: {0} (-{1})",
    "ar": "👩🏽‍💻 <b>التنظيف</b> اكتمل: {0} (-{1})"
}


# region extra bot
l_show_admin_panel_md = {
    'ru': "<b>👩🏽‍💻 Создание и редактирование блога</b>\n\n👩🏽‍💻 Выполнен вход в режиме <b>Администратор</b>: можно создавать и редактировать блоги, но не удалять их\n\n<blockquote>¹ Авторизация (в течение 10сек) по ссылке в браузере:\n<code>{0}</code>\n\n² Перейди (в течение 10сек) по нужной ссылке для редактирования публикации (жми, чтобы скопировать):</blockquote>\n\n",
    'en': "*👩🏽‍💻 Creating and editing a blog*\n\n👩🏽‍💻 You are logged in as *Administrator* and can create and edit blogs, but not delete them\n\n¹ Authorization (within 10 seconds) using the link in the browser:\n`{0}`\n\n² Follow (within 10 seconds) the required link to edit the publication (click to copy):\n\n",
    'es': "*👩🏽‍💻 Creando y editando un blog*\n\n👩🏽‍💻 Has iniciado sesión como *Administrador* y puedes crear y editar blogs, pero no eliminarlos\n\n¹ Autorización (dentro de 10 segundos) usando el enlace en el navegador:\n`{0}`\n\n² Siga (dentro de 10 segundos) el enlace requerido para editar la publicación (haga clic para copiar):\n\n",
    'fr': "*👩🏽‍💻 Création et modification d'un blog*\n\n👩🏽‍💻 Vous êtes connecté en tant qu'*Administrateur* et pouvez créer et modifier des blogs, mais pas les supprimer.\n\n¹ Autorisation (dans les 10 secondes) à l'aide du lien dans le navigateur :\n`{0}`\n\n² Suivez (dans les 10 secondes) le lien requis pour modifier la publication (cliquez pour copier) :\n\n",
    'zh': "*👩🏽‍💻 创建和编辑博客*\n\n👩🏽‍💻 您以*管理员* 身份登录，可以创建和编辑博客，但不能删除它们\n\n¹ 使用授权（10 秒内）浏览器中的链接：\n`{0}`\n\n² 按照（10 秒内）所需的链接编辑出版物（单击复制）：\n\n",
    'ar': "*👩🏽‍💻 إنشاء مدونة وتحريرها*\n\n👩🏽‍💻 لقد قمت بتسجيل الدخول بصفتك *مسؤول* ويمكنك إنشاء مدونات وتحريرها، ولكن لا يمكنك حذفها\n\n¹ التفويض (خلال 10 ثوانٍ) باستخدام الرابط الموجود في المستعرض:\n`{0}`\n\n² اتبع (خلال 10 ثوانٍ) الارتباط المطلوب لتحرير المنشور (انقر للنسخ):\n\n",
}
l_show_admin_panel_html = {
    'ru': "<b>👩🏽‍💻 Создание и редактирование блога</b>\n\n👩🏽‍💻 Вы зашли как <b>Администратор</b> и можете создавать и редактировать блоги, но не удалять их\n\n<blockquote>1. Авторизация по ссылке в браузере:\n{0}\n\n2. Перейди (в течение 10сек) по нужной ссылке для редактирования публикации (жми, чтобы скопировать):</blockquote>\n\n",
    'en': "<b>👩🏽‍💻 Creating and editing a blog</b>\n\n👩🏽‍💻 You are logged in as an <b>Administrator</b> and can create and edit blogs, but not delete them\n\n1. Authorization using the link in the browser:\n{0}\n\n2. Follow (within 10 seconds) the required link to edit the publication (click to copy):\n\n",
    'es': "<b>👩🏽‍💻 Creando y editando un blog</b>\n\n👩🏽‍💻 Has iniciado sesión como <b>Administrador</b> y puedes crear y editar blogs, pero no eliminarlos\n\n1. Autorización mediante el enlace en el navegador:\n{0}\n\n2. Siga (en 10 segundos) el enlace requerido para editar la publicación (haga clic para copiar):\n\n",
    'fr': "<b>👩🏽‍💻 Créer et modifier un blog</b>\n\n👩🏽‍💻 Vous êtes connecté en tant qu'<b>Administrateur</b> et pouvez créer et modifier des blogs, mais pas les supprimer\n\n1. Autorisation via le lien dans le navigateur :\n{0}\n\n2. Suivez (dans les 10 secondes) le lien requis pour modifier la publication (cliquez pour copier) :\n\n",
    'zh': "<b>👩🏽‍💻 创建和编辑博客</b>\n\n👩🏽‍💻 您以<b>管理员</b>身份登录，可以创建和编辑博客，但不能删除它们\n\n1.使用浏览器中的链接进行授权：\n{0}\n\n2.点击（10 秒内）所需的链接来编辑出版物（单击以复制）：\n\n",
    'ar': "<b>👩🏽‍💻 إنشاء مدونة وتحريرها</b>\n\n👩🏽‍💻 لقد قمت بتسجيل الدخول كـ <b>مسؤول</b> ويمكنك إنشاء مدونات وتحريرها، ولكن لا يمكنك حذفها ن\n1. التفويض باستخدام الرابط الموجود في المتصفح:\n{0}\n\n2. اتبع (خلال 10 ثوانٍ) الارتباط المطلوب لتحرير المنشور (انقر للنسخ):\n\n",
}
l_show_admin_panel_create = {
    'ru': "🆕 Создать",
    'en': "🆕 Create",
    'es': "🆕 Crear",
    'fr': "🆕 Créer",
    'zh': "🆕 创造",
    'ar': "🆕 إنشاء",
}
l_show_admin_panel_auth = {
    'ru': "👩🏽‍💻 Авторизация",
    'en': "👩🏽‍💻 Authorization",
    'es': "👩🏽‍💻 Autorización",
    'fr': "👩🏽‍💻 Autorisation",
    'zh': "👩🏽‍💻授权",
    'ar': "👩🏽‍💻 تصريح",
}

l_promos = {
    'ru': "Promo-пользователи",
    'en': "Promo users",
    'es': "Usuarios promocionales",
    'fr': "Utilisateurs promotionnels",
    'zh': "促销用户",
    'ar': "المستخدمين الترويجي",
}
l_utms = {
    'ru': "UTM-пользователи",
    'en': "UTM users",
    'es': "Usuarios UTM",
    'fr': "Utilisateurs UTM",
    'zh': "UTM用户",
    'ar': "مستخدمي UTM",
}
l_premiums = {
    'ru': "Premium-пользователи",
    'en': "Premium users",
    'es': "Usuarios premium",
    'fr': "Utilisateurs premium",
    'zh': "高级用户",
    'ar': "المستخدمين المتميزين",
}
l_bans = {
    'ru': "Бан-пользователи",
    'en': "Banned users",
    'es': "Usuarios prohibidos",
    'fr': "Utilisateurs bannis",
    'zh': "被禁止的用户",
    'ar': "المستخدمين المحظورين",
}
l_auto_translate = {
    'ru': "Авто-перевод",
    'en': "Auto-translation",
    'es': "Traducción automática",
    'fr': "Traduction automatique",
    'zh': "自动翻译",
    'ar': "الترجمة التلقائية",
}
l_auto_answer = {
    'ru': "Авто-ответ",
    'en': "Auto-reply",
    'es': "Respuesta automática",
    'fr': "Réponse automatique",
    'zh': "自动回复",
    'ar': "رد آلي",
}
l_auto_post = {
    'ru': "Авто-постинг",
    'en': "Auto-posting",
    'es': "Publicación automática",
    'fr': "Publication automatique",
    'zh': "自动发布",
    'ar': "النشر التلقائي",
}
# endregion


# region html
l_all_trg = {
    "ru": ": все триггеры",
    "en": ": all triggers",
    "es": ": todos los desencadenantes",
    "fr": ": tous les déclencheurs",
    "zh": "：所有触发器",
    "ar": ": جميع المشغلات",
}
l_one_trg = {
    "ru": ": 1 триггер",
    "en": ": 1 trigger",
    "es": ": 1 gatillo",
    "fr": ": 1 déclencheur",
    "zh": "：1个触发器",
    "ar": ": 1 الزناد",
}

l_order_act = {
    "ru": ": по порядку",
    "en": ": in order",
    "es": ": en orden",
    "fr": ": dans l'ordre",
    "zh": ": 按顺序",
    "ar": ": بالترتيب",
}
l_rand_act = {
    "ru": ": вразброс",
    "en": ": randomly",
    "es": ": al azar",
    "fr": ": au hasard",
    "zh": ": 随机",
    "ar": ": عشوائياً",
}
l_trigger = {
    "ru": "Триггер",
    "en": "Trigger",
    "es": "Gatillo",
    "fr": "Déclencheur",
    "zh": "触发器",
    "ar": "مشغل",
}
l_action = {
    "ru": "Действие",
    "en": "Action",
    "es": "Acción",
    "fr": "Action",
    "zh": "操作",
    "ar": "إجراء",
}
l_message = {
    "ru": "Сообщение",
    "en": "Message",
    "es": "Mensaje",
    "fr": "Message",
    "zh": "消息",
    "ar": "رسالة",
}

l_trg_add = {
    "ru": "+ Добавить Триггер",
    "en": "+ Add Trigger",
    "es": "+ Agregar disparador",
    "fr": "+ Ajouter un déclencheur",
    "zh": "+ 添加触发器",
    "ar": "+ إضافة مشغل",
}
l_trg_cmd = {
    "ru": "+ команда",
    "en": "+ command",
    "es": "+ comando",
    "fr": "+ commande",
    "zh": "+ 命令",
    "ar": "+ أمر",
}
l_trg_txt = {
    "ru": "+ сообщение",
    "en": "+ message",
    "es": "+ mensaje",
    "fr": "+ message",
    "zh": "+ 消息",
    "ar": "+ رسالة",
}
l_trg_bpm = {
    "ru": "+ бизнес лс",
    "en": "+ business pm",
    "es": "+ mensaje empresarial",
    "fr": "+ message d'entreprise",
    "zh": "+ 商务私信",
    "ar": "+ رسالة عمل",
}
l_trg_btn = {
    "ru": "+ кнопка",
    "en": "+ button",
    "es": "+ botón",
    "fr": "+ bouton",
    "zh": "+ 按钮",
    "ar": "+ زر",
}
l_trg_rct = {
    "ru": "+ реакция",
    "en": "+ reaction",
    "es": "+ reacción",
    "fr": "+ réaction",
    "zh": "+ 反应",
    "ar": "+ رد فعل",
}
l_trg_var = {
    "ru": "+ переменная",
    "en": "+ variable",
    "es": "+ variable",
    "fr": "+ variable",
    "zh": "+ 变量",
    "ar": "+ متغير",
}
l_trg_lst = {
    "ru": "+ список",
    "en": "+ list",
    "es": "+ lista",
    "fr": "+ liste",
    "zh": "+ 列表",
    "ar": "+ قائمة",
}

l_act_add = {
    "ru": "+ Добавить Действие",
    "en": "+ Add Action",
    "es": "+ Agregar acción",
    "fr": "+ Ajouter une action",
    "zh": "+ 添加动作",
    "ar": "+ إضافة إجراء"
}
l_act_dly = {
    "ru": "+ задержка",
    "en": "+ delay",
    "es": "+ retraso",
    "fr": "+ retard",
    "zh": "+ 延迟",
    "ar": "+ تأخير"
}
l_act_wait = {
    "ru": "+ ожидание",
    "en": "+ waiting",
    "es": "+ espera",
    "fr": "+ attente",
    "zh": "+ 等待",
    "ar": "+ الانتظار"
}
l_act_wait_title = {
    "ru": "Ожидание",
    "en": "Waiting",
    "es": "Espera",
    "fr": "Attente",
    "zh": "等待",
    "ar": "انتظار"
}
l_act_req = {
    "ru": "+ запрос",
    "en": "+ request",
    "es": "+ solicitud",
    "fr": "+ demande",
    "zh": "+ 请求",
    "ar": "+ طلب"
}
l_act_unpin = {
    "ru": "+ открепить все",
    "en": "+ unpin all",
    "es": "+ desanclar todo",
    "fr": "+ détacher tout",
    "zh": "+ 取消固定所有",
    "ar": "+ إلغاء تثبيت الكل"
}
l_act_unpin_title = {
    "ru": "Открепить все сообщения",
    "en": "Unpin all messages",
    "es": "Desanclar todos los mensajes",
    "fr": "Détacher tous les messages",
    "zh": "取消固定所有消息",
    "ar": "إلغاء تثبيت جميع الرسائل"
}
l_act_delkb = {
    "ru": "+ удалить нижнюю клавиатуру",
    "en": "+ remove bottom keyboard",
    "es": "+ eliminar teclado inferior",
    "fr": "+ supprimer le clavier inférieur",
    "zh": "+ 删除底部键盘",
    "ar": "+ إزالة لوحة المفاتيح السفلية"
}
l_act_delkb_title = {
    "ru": "Удалить нижнюю клавиатуру↓",
    "en": "Remove bottom keyboard↓",
    "es": "Eliminar teclado inferior↓",
    "fr": "Supprimer le clavier inférieur↓",
    "zh": "删除底部键盘↓",
    "ar": "إزالة لوحة المفاتيح السفلية↓"
}

l_msg_text = {
    "ru": ": текст",
    "en": ": text",
    "es": ": texto",
    "fr": ": texte",
    "zh": "：文本",
    "ar": ": نص"
}
l_msg_photo = {
    "ru": ": фото",
    "en": ": photo",
    "es": ": foto",
    "fr": ": photo",
    "zh": "：照片",
    "ar": ": صورة"
}
l_msg_gif = {
    "ru": ": гиф",
    "en": ": gif",
    "es": ": gif",
    "fr": ": gif",
    "zh": "：动图",
    "ar": ": جيف"
}
l_msg_video = {
    "ru": ": видео",
    "en": ": video",
    "es": ": video",
    "fr": ": vidéo",
    "zh": "：视频",
    "ar": ": فيديو"
}
l_msg_video_note = {
    "ru": ": телескоп",
    "en": ": telescope",
    "es": ": telescopio",
    "fr": ": télescope",
    "zh": "：望远镜",
    "ar": ": تلسكوب"
}
l_msg_audio = {
    "ru": ": аудио",
    "en": ": audio",
    "es": ": audio",
    "fr": ": audio",
    "zh": "：音频",
    "ar": ": صوتي"
}
l_msg_voice = {
    "ru": ": голосовое",
    "en": ": voice",
    "es": ": voz",
    "fr": ": voix",
    "zh": "：语音",
    "ar": ": صوت"
}
l_msg_document = {
    "ru": ": документ",
    "en": ": document",
    "es": ": documento",
    "fr": ": document",
    "zh": "：文档",
    "ar": ": وثيقة"
}
l_msg_sticker = {
    "ru": ": стикер",
    "en": ": sticker",
    "es": ": adhesivo",
    "fr": ": autocollant",
    "zh": "：贴纸",
    "ar": ": ملصق"
}
l_msg_quiz = {
    "ru": ": опрос",
    "en": ": poll",
    "es": ": encuesta",
    "fr": ": sondage",
    "zh": "：投票",
    "ar": ": استطلاع"
}
l_msg_dice = {
    "ru": ": игра",
    "en": ": game",
    "es": ": juego",
    "fr": ": jeu",
    "zh": "：游戏",
    "ar": ": لعبة"
}
l_msg_web = {
    "ru": ": веб",
    "en": ": web",
    "es": ": web",
    "fr": ": web",
    "zh": "：网页",
    "ar": ": الويب"
}

l_btn_button_in = {
    "ru": "✅ Кнопка ↑",
    "en": "✅ Button ↑",
    "es": "✅ Botón ↑",
    "fr": "✅ Bouton ↑",
    "zh": "✅ 按钮 ↑",
    "ar": "✅ زر ↑"
}
l_btn_link = {
    "ru": "🔗 Ссылка",
    "en": "🔗 Link",
    "es": "🔗 Enlace",
    "fr": "🔗 Lien",
    "zh": "🔗 链接",
    "ar": "🔗 رابط"
}
l_btn_search = {
    "ru": "🔎 Поиск",
    "en": "🔎 Search",
    "es": "🔎 Buscar",
    "fr": "🔎 Recherche",
    "zh": "🔎 搜索",
    "ar": "🔎 بحث"
}
l_btn_like = {
    "ru": "❤️ Лайк",
    "en": "❤️ Like",
    "es": "❤️ Me gusta",
    "fr": "❤️ J'aime",
    "zh": "❤️ 喜欢",
    "ar": "❤️ إعجاب"
}
l_btn_web = {
    "ru": "🌐 Веб",
    "en": "🌐 Web",
    "es": "🌐 Web",
    "fr": "🌐 Web",
    "zh": "🌐 网络",
    "ar": "🌐 ويب"
}
l_btn_story = {
    "ru": "🫥 Сториз",
    "en": "🫥 Story",
    "es": "🫥 Historia",
    "fr": "🫥 Story",
    "zh": "🫥 故事",
    "ar": "🫥 القصة"
}
l_btn_copy = {
    "ru": "📋 Копировать",
    "en": "📋 Copy",
    "es": "📋 Copiar",
    "fr": "📋 Copier",
    "zh": "📋 复制",
    "ar": "📋 نسخ"
}
l_btn_pay = {
    "ru": "⭐️ Оплата",
    "en": "⭐️ Payment",
    "es": "⭐️ Pago",
    "fr": "⭐️ Paiement",
    "zh": "⭐️ 支付",
    "ar": "⭐️ الدفع"
}
l_btn_share = {
    "ru": "↗️ Поделиться",
    "en": "↗️ Share",
    "es": "↗️ Compartir",
    "fr": "↗️ Partager",
    "zh": "↗️ 分享",
    "ar": "↗️ مشاركة"
}
l_btn_button_kb = {
    "ru": "✅ Кнопка ↓",
    "en": "✅ Button ↓",
    "es": "✅ Botón ↓",
    "fr": "✅ Bouton ↓",
    "zh": "✅ 按钮 ↓",
    "ar": "✅ زر ↓"
}
l_btn_contact = {
    "ru": "📞 Сотовый",
    "en": "📞 Mobile",
    "es": "📞 Móvil",
    "fr": "📞 Mobile",
    "zh": "📞 手机",
    "ar": "📞 جوال"
}
l_btn_geo = {
    "ru": "📍 Гео",
    "en": "📍 Geo",
    "es": "📍 Geo",
    "fr": "📍 Géo",
    "zh": "📍 地理",
    "ar": "📍 الموقع"
}
l_btn_blog = {
    "ru": "📰 Блог",
    "en": "📰 Blog",
    "es": "📰 Blog",
    "fr": "📰 Blog",
    "zh": "📰 博客",
    "ar": "📰 مدونة"
}
l_btn_name = {
    "ru": "Имя:",
    "en": "Name:",
    "es": "Nombre:",
    "fr": "Nom:",
    "zh": "姓名：",
    "ar": "الاسم:"
}
l_btn_type = {
    "ru": "Тип:",
    "en": "Type:",
    "es": "Tipo:",
    "fr": "Type:",
    "zh": "类型：",
    "ar": "النوع:"
}
# endregion


# region json
l_all_json = {
    "ru": ": *",
    "en": ": *",
    "es": ": *",
    "fr": ": *",
    "zh": ": *",
    "ar": ": *",
}
l_one_json = {
    "ru": ": 1",
    "en": ": 1",
    "es": ": 1",
    "fr": ": 1",
    "zh": ": 1",
    "ar": ": 1",
}
l_add_trg_json = {
    "ru": "+ Триггер",
    "en": "+ Trigger",
    "es": "+ Disparador",
    "fr": "+ Déclencheur",
    "zh": "+ 触发器",
    "ar": "+ مشغل",
}
l_add_act_json = {
    "ru": "+ Действие",
    "en": "+ Action",
    "es": "+ Acción",
    "fr": "+ Action",
    "zh": "+ 操作",
    "ar": "+ إجراء",
}
l_add_msg_json = {
    "ru": "+ Сообщение",
    "en": "+ Message",
    "es": "+ Mensaje",
    "fr": "+ Message",
    "zh": "+ 消息",
    "ar": "+ رسالة",
}
# endregion


# region sbt-ton
l_bot_collection_name = {
    "ru": "SBT-коллекция @{0}",
    "en": "SBT collection @{0}",
    "es": "Colección SBT @{0}",
    "fr": "Collection SBT @{0}",
    "zh": "SBT 收藏 @{0}",
    "ar": "مجموعة SBT @{0}",
}
l_bot_collection_desc = {
    "ru": "Уникальные sbt-награды за выдающиеся достижения в исследовании @tg-приложения",
    "en": "Unique sbt rewards for outstanding achievements in researching the @tg-application",
    "es": "Recompensas sbt únicas por logros destacados en la investigación de la aplicación @tg",
    "fr": "Récompenses sbt uniques pour des réalisations exceptionnelles dans l'étude de l'application @tg",
    "zh": "独特的 sbt 奖励，以表彰在研究 @tg 应用方面的杰出成就",
    "ar": "مكافآت sbt فريدة عن إنجازات بارزة في بحث تطبيق @tg",
}
l_bot_collection_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> коллекции:",
    "en": "👩🏽‍💻 <b>Collection</b> address:",
    "es": "👩🏽‍💻 <b>Dirección</b> de la colección:",
    "fr": "👩🏽‍💻 <b>Adresse</b> de la collection :",
    "zh": "👩🏽‍💻 <b>集合</b> 地址：",
    "ar": "👩🏽‍💻 <b>عنوان</b> المجموعة:",
}
l_bot_sbt_desc = {
    "ru": "SBT верифицирован в @{0}: @tg-приложение изучено на {1}%",
    "en": "SBT verified at @{0}: @tg application studied by {1}%",
    "es": "SBT verificado en @{0}: aplicación @tg estudiada en {1}%",
    "fr": "SBT vérifié sur @{0} : application @tg étudiée à {1}%",
    "zh": "SBT 已在 @{0} 验证：@tg 应用已研究 {1}%",
    "ar": "تم التحقق من SBT في @{0}: تم دراسة تطبيق @tg بنسبة {1}%",
}
l_bot_detach = {
    "ru": "👩🏽‍💻 Открепить nft от",
    "en": "👩🏽‍💻 Detach nft from",
    "es": "👩🏽‍💻 Desanclar nft de",
    "fr": "👩🏽‍💻 Détacher nft de",
    "zh": "👩🏽‍💻 从…分离 nft",
    "ar": "👩🏽‍💻 فصل nft من",
}
# endregion


# region menu films
l_bot_ya_legenda = {
    "ru": "Я легенда",
    "en": "I Am Legend",
    "es": "Yo soy leyenda",
    "fr": "Je suis une légende",
    "zh": "我是传奇",
    "ar": "أنا أسطورة"
}
l_bot_odin_den = {
    "ru": "Один день",
    "en": "One Day",
    "es": "Un día",
    "fr": "Un jour",
    "zh": "Один день",
    "ar": "يوم واحد"
}
l_bot_ancharted = {
    "ru": "Анчартед",
    "en": "Uncharted",
    "es": "Uncharted",
    "fr": "Uncharted",
    "zh": "Uncharted",
    "ar": "Uncharted"
}
l_bot_odisseya = {
    "ru": "Одиссея",
    "en": "Odyssey",
    "es": "Odisea",
    "fr": "Odyssée",
    "zh": "奥德赛",
    "ar": "أوديسي"
}
l_bot_shag_v_pered = {
    "ru": "Шаг в перед",
    "en": "Step forward",
    "es": "Paso adelante",
    "fr": "Pas en avant",
    "zh": "向前一步",
    "ar": "خطوة للأمام"
}
l_bot_gran_budushego = {
    "ru": "Грань будушего",
    "en": "Edge of Tomorrow",
    "es": "Al filo del mañana",
    "fr": "Edge of Tomorrow",
    "zh": "明日边缘",
    "ar": "حافة الغد"
}
l_bot_nazad_v_budushee = {
    "ru": "Назад в будущее",
    "en": "Back to the Future",
    "es": "Regreso al futuro",
    "fr": "Retour vers le futur",
    "zh": "回到未来",
    "ar": "العودة إلى المستقبل"
}
l_bot_interstellar = {
    "ru": "Интерстеллар",
    "en": "Interstellar",
    "es": "Interstellar",
    "fr": "Interstellar",
    "zh": "星际穿越",
    "ar": "بين النجوم"
}
l_bot_gravitaciya = {
    "ru": "Гравитация",
    "en": "Gravity",
    "es": "Gravedad",
    "fr": "Gravité",
    "zh": "重力",
    "ar": "الجاذبية"
}
l_bot_vspomnit_vse = {
    "ru": "Вспомнить все",
    "en": "Remember Everything",
    "es": "Recordar todo",
    "fr": "Se souvenir de tout",
    "zh": "记住一切",
    "ar": "تذكر كل شيء"
}
l_bot_la_la_lend = {
    "ru": "Ла-ла Ленд",
    "en": "La La Land",
    "es": "La La Land",
    "fr": "La La Land",
    "zh": "爱乐之城",
    "ar": "لا لا لاند"
}
l_bot_tihoe_mesto = {
    "ru": "Тихое место",
    "en": "Quiet Place",
    "es": "Lugar tranquilo",
    "fr": "Endroit tranquille",
    "zh": "安静的地方",
    "ar": "مكان هادئ"
}
l_bot_oblachnyy_atlas = {
    "ru": "Облачный атлас",
    "en": "Cloud Atlas",
    "es": "Atlas de las nubes",
    "fr": "Atlas des nuages",
    "zh": "云图",
    "ar": "أطلس السحاب"
}
l_bot_zvezdnyy_put = {
    "ru": "Звездный путь",
    "en": "Star Trek",
    "es": "Star Trek",
    "fr": "Star Trek",
    "zh": "星际迷航",
    "ar": "ستار تريك"
}
l_bot_moana = {
    "ru": "Моана",
    "en": "Moana",
    "es": "Moana",
    "fr": "Moana",
    "zh": "海洋奇缘",
    "ar": "موانا"
}
l_bot_vverh = {
    "ru": "Вверх",
    "en": "Up",
    "es": "Up",
    "fr": "Up",
    "zh": "飞屋环游记",
    "ar": "Up"
}
l_bot_menyu = {
    "ru": "Меню",
    "en": "Menu",
    "es": "Menú",
    "fr": "Menu",
    "zh": "菜单",
    "ar": "قائمة"
}
l_bot_intro = {
    "ru": "Интро",
    "en": "Intro",
    "es": "Intro",
    "fr": "Intro",
    "zh": "介绍",
    "ar": "مقدمة"
}
l_bot_sumerki = {
    "ru": "Сумерки",
    "en": "Twilight",
    "es": "Crepúsculo",
    "fr": "Twilight",
    "zh": "暮光之城",
    "ar": "الشفق"
}
l_bot_maynkraft = {
    "ru": "Майнкрафт",
    "en": "Minecraft",
    "es": "Minecraft",
    "fr": "Minecraft",
    "zh": "我的世界",
    "ar": "ماينكرافت"
}
l_bot_slushai_serdce = {
    "ru": "Слушай сердце",
    "en": "Listen to the Heart",
    "es": "Escucha al corazón",
    "fr": "Écoute le cœur",
    "zh": "倾听内心",
    "ar": "استمع إلى قلبك"
}
l_bot_khrabroe_serdce = {
    "ru": "Храброе сердце",
    "en": "Braveheart",
    "es": "Corazón valiente",
    "fr": "Braveheart",
    "zh": "勇敢的心",
    "ar": "قلب شجاع"
}
l_bot_iz_moego_okna = {
    "ru": "Из моего окна",
    "en": "From My Window",
    "es": "Desde mi ventana",
    "fr": "De ma fenêtre",
    "zh": "从我的窗户",
    "ar": "من نافذتي"
}
l_bot_voobrazharium = {
    "ru": "Воображариум",
    "en": "Imaginarium",
    "es": "Imaginarium",
    "fr": "Imaginarium",
    "zh": "想象馆",
    "ar": "عالم الخيال"
}
l_bot_voobrazi_drakonov = {
    "ru": "Вообрази драконов",
    "en": "Imagine Dragons",
    "es": "Imagine Dragons",
    "fr": "Imagine Dragons",
    "zh": "Imagine Dragons",
    "ar": "Imagine Dragons"
}
l_bot_skayfol = {
    "ru": "Скайфол",
    "en": "Skyfall",
    "es": "Skyfall",
    "fr": "Skyfall",
    "zh": "Skyfall",
    "ar": "Skyfall"
}
l_bot_vozvraschenie_domoy = {
    "ru": "Возвращение домой",
    "en": "Return Home",
    "es": "Regreso a casa",
    "fr": "Retour à la maison",
    "zh": "回家",
    "ar": "عودة إلى الوطن"
}
l_bot_nebo_polnoe_zvezd = {
    "ru": "Небо, полное звезд",
    "en": "Sky, full of stars",
    "es": "Cielo, lleno de estrellas",
    "fr": "Ciel, plein d'étoiles",
    "zh": "天空，满是繁星",
    "ar": "سماء، مليئة بالنجوم"
}
l_bot_7_lepestok = {
    "ru": "7 лепесток",
    "en": "7 petal",
    "es": "7 pétalo",
    "fr": "7 pétale",
    "zh": "7花瓣",
    "ar": "7 بتلة"
}
l_bot_7_simfoniya = {
    "ru": "7 симфония",
    "en": "7 symphony",
    "es": "7 sinfonía",
    "fr": "7 symphonie",
    "zh": "7交响曲",
    "ar": "7 سيمفونية"
}
l_bot_7_zhizney = {
    "ru": "7 жизней",
    "en": "7 lives",
    "es": "7 vidas",
    "fr": "7 vies",
    "zh": "7条生命",
    "ar": "7 حيوات"
}
l_bot_f1 = {
    "ru": "F1",
    "en": "F1",
    "es": "F1",
    "fr": "F1",
    "zh": "F1",
    "ar": "F1"
}
l_bot_proekt_h = {
    "ru": "Проект Х",
    "en": "Project X",
    "es": "Proyecto X",
    "fr": "Projet X",
    "zh": "项目 X",
    "ar": "المشروع X"
}
l_bot_snova_17 = {
    "ru": "Снова 17",
    "en": "Again 17",
    "es": "De nuevo 17",
    "fr": "Encore 17",
    "zh": "再次17",
    "ar": "مرة أخرى 17"
}
l_bot_legenda_17 = {
    "ru": "Легенда 17",
    "en": "Legend 17",
    "es": "Leyenda 17",
    "fr": "Légende 17",
    "zh": "传奇17",
    "ar": "أسطورة 17"
}
l_bot_za_kadrom = {
    "ru": "За кадром",
    "en": "Behind the Scenes",
    "es": "Detrás de las cámaras",
    "fr": "Derrière les coulisses",
    "zh": "幕后",
    "ar": "خلف الكواليس"
}
l_bot_eta_istoriya = {
    "ru": "Эта история",
    "en": "This Story",
    "es": "Esta historia",
    "fr": "Cette histoire",
    "zh": "这个故事",
    "ar": "هذه القصة"
}
l_bot_moy_mir = {
    "ru": "Мой мир",
    "en": "My World",
    "es": "Mi mundo",
    "fr": "Mon monde",
    "zh": "我的世界",
    "ar": "عالمي"
}
l_bot_moy_dom = {
    "ru": "Мой дом",
    "en": "My Home",
    "es": "Mi hogar",
    "fr": "Ma maison",
    "zh": "我的家",
    "ar": "بيتي"
}
l_bot_navigatsiya = {
    "ru": "Навигация",
    "en": "Navigation",
    "es": "Navegación",
    "fr": "Navigation",
    "zh": "导航",
    "ar": "التنقل"
}
l_bot_mne_nravitsya = {
    "ru": "Мне нравится",
    "en": "I Like It",
    "es": "Me gusta",
    "fr": "J'aime",
    "zh": "我喜欢",
    "ar": "أعجبني"
}
# endregion


# region progress
l_bot_progress_cmd = {
    "ru": "👩🏽‍💻 <b>Найдена</b> /-команда в @{0}-боте:\n\n<blockquote>{1}</blockquote>",
    "en": "👩🏽‍💻 <b>Found</b> /-command in @{0}-bot:\n\n<blockquote>{1}</blockquote>",
    "es": "👩🏽‍💻 <b>Encontrada</b> /-comando en @{0}-bot:\n\n<blockquote>{1}</blockquote>",
    "fr": "👩🏽‍💻 <b>Trouvée</b> /-commande dans @{0}-bot:\n\n<blockquote>{1}</blockquote>",
    "zh": "👩🏽‍💻 <b>已找到</b> /-命令 在 @{0}-机器人:\n\n<blockquote>{1}</blockquote>",
    "ar": "👩🏽‍💻 <b>تم العثور</b> على أمر /- في @{0}-بوت:\n\n<blockquote>{1}</blockquote>"
}
l_bot_progress_cmd_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал экстра команд, поэтому для прохождения задания можно использовать команду по умолчанию:\n\n<blockquote>/cmd_911</blockquote>",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created extra commands, so to complete the task you can use the default command:\n\n<blockquote>/cmd_911</blockquote>",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado comandos extra, por lo que para completar la tarea puedes usar el comando por defecto:\n\n<blockquote>/cmd_911</blockquote>",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de commandes supplémentaires, donc pour accomplir la tâche vous pouvez utiliser la commande par défaut:\n\n<blockquote>/cmd_911</blockquote>",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未 创建 额外命令，因此为完成任务可以使用默认命令:\n\n<blockquote>/cmd_911</blockquote>",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم يقم بعد بإنشاء أوامر إضافية، لذلك لإكمال المهمة يمكنك استخدام الأمر الافتراضي:\n\n<blockquote>/cmd_911</blockquote>"
}
l_bot_progress_cmd_done = {
    "ru": "👩🏽‍💻 <b>Команда</b> по умолчанию (/{cmd}) выполнена",
    "en": "👩🏽‍💻 <b>Default command</b> (/{cmd}) executed",
    "es": "👩🏽‍💻 <b>Comando predeterminado</b> (/{cmd}) ejecutado",
    "fr": "👩🏽‍💻 <b>Commande par défaut</b> (/{cmd}) exécutée",
    "zh": "👩🏽‍💻 <b>默认命令</b> (/{cmd}) 已执行",
    "ar": "👩🏽‍💻 <b>الأمر الافتراضي</b> (/{cmd}) تم تنفيذه"
}
l_bot_progress_promo = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота установил промокод, поэтому для прохождения задания необходимо его узнать и ввести",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has set a promo code, so to complete the task you need to find out and enter it",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot ha establecido un código promocional, por lo que para completar la tarea es necesario averiguarlo e introducirlo",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot a défini un code promo, donc pour accomplir la tâche il faut le découvrir et le saisir",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 已设置促销码，因此为完成任务需要找到并输入该码",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت قد وضع رمزًا ترويجيًا، لذلك لإكمال المهمة يجب اكتشافه وإدخاله"
}
l_bot_progress_promo_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал промокод, поэтому для прохождения задания можно использовать промокод по умолчанию:\n\n<blockquote><code>#911</code></blockquote>",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created a promo code, so to complete the task you can use the default promo code:\n\n<blockquote><code>#911</code></blockquote>",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado un código promocional, por lo que para completar la tarea puedes usar el código promocional por defecto:\n\n<blockquote><code>#911</code></blockquote>",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de code promo, donc pour accomplir la tâche vous pouvez utiliser le code promo par défaut:\n\n<blockquote><code>#911</code></blockquote>",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建促销码，因此为完成任务可以使用默认促销码:\n\n<blockquote><code>#911</code></blockquote>",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رمزًا ترويجيًا بعد، لذلك لإكمال المهمة يمكنك استخدام رمز الترويج الافتراضي:\n\n<blockquote><code>#911</code></blockquote>"
}
l_bot_progress_promo_done = {
    "ru": "👩🏽‍💻 <b>Промокод</b> <code>{0}</code> успешно распознан",
    "en": "👩🏽‍💻 <b>Promo code</b> <code>{0}</code> successfully recognized",
    "es": "👩🏽‍💻 <b>Código promocional</b> <code>{0}</code> reconocido con éxito",
    "fr": "👩🏽‍💻 <b>Code promo</b> <code>{0}</code> reconnu avec succès",
    "zh": "👩🏽‍💻 <b>促销码</b> <code>{0}</code> 识别成功",
    "ar": "👩🏽‍💻 <b>رمز الترويج</b> <code>{0}</code> تم التعرف عليه بنجاح"
}
l_bot_progress_react = {
    "ru": "👩🏽‍💻 <b>Установи</b> реакцию на сообщение в @{0}-боте",
    "en": "👩🏽‍💻 <b>Set</b> a reaction on the message in @{0}-bot",
    "es": "👩🏽‍💻 <b>Coloca</b> una reacción en el mensaje en @{0}-bot",
    "fr": "👩🏽‍💻 <b>Mets</b> une réaction sur le message dans @{0}-bot",
    "zh": "👩🏽‍💻 <b>设置</b> 对 @{0}-机器人 消息 的反应",
    "ar": "👩🏽‍💻 <b>ضع</b> تفاعلًا على الرسالة في @{0}-بوت"
}
l_bot_progress_pay_spoiler_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал платных сообщений, поэтому для прохождения задания можно совершить оплату следующего сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created paid messages, so to complete the task you can pay for the following message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes de pago, por lo que para completar la tarea puedes pagar el siguiente mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages payants, donc pour accomplir la tâche vous pouvez payer le message suivant",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建付费消息，因此为完成任务可以为下一个消息付款",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل مدفوعة بعد، لذلك لإكمال المهمة يمكنك دفع ثمن الرسالة التالية"
}
l_bot_progress_usual_btn = {
    "ru": "Обычная кнопка",
    "en": "Regular button",
    "es": "Botón normal",
    "fr": "Bouton ordinaire",
    "zh": "普通按钮",
    "ar": "زر عادي"
}
l_bot_progress_usual_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c обычной кнопкой, поэтому для прохождения задания можно совершить нажатие на кнопку этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a regular button, so to complete the task you can press the button of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con un botón normal, por lo que para completar la tarea puedes pulsar el botón de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton ordinaire, donc pour accomplir la tâche vous pouvez appuyer sur le bouton de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带有普通按钮的消息，因此为完成任务可以点击此消息的按钮",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل ذات زر عادي بعد، لذلك لإكمال المهمة يمكنك الضغط على زر هذه الرسالة"
}
l_bot_progress_usual_btn_done = {
    "ru": "👩🏽‍💻 <b>Нажатие</b> на обычную-кнопку выполнено",
    "en": "👩🏽‍💻 <b>Press</b> on the regular-button completed",
    "es": "👩🏽‍💻 <b>Pulsación</b> en el botón normal realizada",
    "fr": "👩🏽‍💻 <b>Clic</b> sur le bouton ordinaire effectué",
    "zh": "👩🏽‍💻 <b>点击</b> 普通按钮 已完成",
    "ar": "👩🏽‍💻 <b>تم الضغط</b> على الزر العادي"
}
l_bot_progress_pay_btn = {
    "ru": "Кнопка оплаты",
    "en": "Payment button",
    "es": "Botón de pago",
    "fr": "Bouton de paiement",
    "zh": "付款按钮",
    "ar": "زر الدفع"
}
l_bot_progress_pay_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c кнопкой оплаты, поэтому для прохождения задания можно совершить оплату по кнопке этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a payment button, so to complete the task you can make a payment using the button of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con un botón de pago, por lo que para completar la tarea puedes realizar el pago mediante el botón de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton de paiement, donc pour accomplir la tâche vous pouvez effectuer le paiement via le bouton de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带付款按钮的消息，因此为完成任务可以通过该消息的按钮进行付款",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل بها زر دفع بعد، لذلك لإكمال المهمة يمكنك الدفع عبر زر هذه الرسالة"
}
l_bot_progress_like_btn = {
    "ru": "Лайк кнопка",
    "en": "Like button",
    "es": "Botón de me gusta",
    "fr": "Bouton 'J'aime'",
    "zh": "点赞按钮",
    "ar": "زر الإعجاب"
}
l_bot_progress_like_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c лайк-кнопкой, поэтому для прохождения задания можно совершить нажатие на лайк-кнопку этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a like-button, so to complete the task you can press the like-button of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con botón de 'me gusta', por lo que para completar la tarea puedes pulsar el botón de me gusta de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton 'J'aime', donc pour accomplir la tâche vous pouvez appuyer sur le bouton 'J'aime' de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带点赞按钮的消息，因此为完成任务可以点击该消息的点赞按钮",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل بها زر الإعجاب بعد، لذلك لإكمال المهمة يمكنك الضغط على زر الإعجاب في هذه الرسالة"
}
l_bot_progress_like_btn_done = {
    "ru": "👩🏽‍💻 <b>Нажатие</b> на лайк-кнопку выполнено",
    "en": "👩🏽‍💻 <b>Press</b> on the like-button completed",
    "es": "👩🏽‍💻 <b>Pulsación</b> en el botón de me gusta realizada",
    "fr": "👩🏽‍💻 <b>Clic</b> sur le bouton 'J'aime' effectué",
    "zh": "👩🏽‍💻 <b>点击</b> 点赞按钮 已完成",
    "ar": "👩🏽‍💻 <b>تم الضغط</b> على زر الإعجاب"
}
l_bot_progress_search_btn = {
    "ru": "Кнопка поиска",
    "en": "Search button",
    "es": "Botón de búsqueda",
    "fr": "Bouton de recherche",
    "zh": "搜索按钮",
    "ar": "زر البحث"
}
l_bot_progress_search_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c кнопкой поиска, поэтому для прохождения задания можно совершить нажатие на кнопку поиска этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a search button, so to complete the task you can press the search button of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con un botón de búsqueda, por lo que para completar la tarea puedes pulsar el botón de búsqueda de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton de recherche, donc pour accomplir la tâche vous pouvez appuyer sur le bouton de recherche de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带有搜索按钮的消息，因此为完成任务可以点击该消息的搜索按钮",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل بها زر بحث بعد، لذلك لإكمال المهمة يمكنك الضغط على زر البحث في هذه الرسالة"
}
l_bot_progress_search_btn_done = {
    "ru": "👩🏽‍💻 <b>Нажатие</b> на кнопку поиска выполнено",
    "en": "👩🏽‍💻 <b>Press</b> on the search-button completed",
    "es": "👩🏽‍💻 <b>Pulsación</b> en el botón de búsqueda realizada",
    "fr": "👩🏽‍💻 <b>Clic</b> sur le bouton de recherche effectué",
    "zh": "👩🏽‍💻 <b>点击</b> 搜索按钮 已完成",
    "ar": "👩🏽‍💻 <b>تم الضغط</b> على زر البحث"
}
l_bot_progress_btn_done = {
    "ru": "Нажатие выполнено",
    "en": "Press completed",
    "es": "Pulsación realizada",
    "fr": "Clic effectué",
    "zh": "点击已完成",
    "ar": "تم الضغط"
}
l_bot_progress_contact_btn = {
    "ru": "Кнопка контакта",
    "en": "Contact button",
    "es": "Botón de contacto",
    "fr": "Bouton de contact",
    "zh": "联系按钮",
    "ar": "زر الاتصال"
}
l_bot_progress_contact_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c контакт-кнопкой, поэтому для прохождения задания можно совершить нажатие на контакт-кнопку этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a contact-button, so to complete the task you can press the contact-button of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con un botón de contacto, por lo que para completar la tarea puedes pulsar el botón de contacto de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton de contact, donc pour accomplir la tâche vous pouvez appuyer sur le bouton de contact de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带有联系按钮的消息，因此为完成任务可以点击该消息的联系按钮",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل بها زر الاتصال بعد، لذلك لإكمال المهمة يمكنك الضغط على زر الاتصال في هذه الرسالة"
}
l_bot_progress_geo_btn = {
    "ru": "Кнопка геолокации",
    "en": "Geolocation button",
    "es": "Botón de geolocalización",
    "fr": "Bouton de géolocalisation",
    "zh": "地理位置按钮",
    "ar": "زر تحديد الموقع"
}
l_bot_progress_geo_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c кнопкой геолокации, поэтому для прохождения задания можно совершить нажатие на кнопку геолокации этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a geolocation button, so to complete the task you can press the geolocation button of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con un botón de geolocalización, por lo que para completar la tarea puedes pulsar el botón de geolocalización de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton de géolocalisation, donc pour accomplir la tâche vous pouvez appuyer sur le bouton de géolocalisation de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带有地理位置按钮的消息，因此为完成任务可以点击该消息的地理位置按钮",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل بها زر تحديد الموقع بعد، لذلك لإكمال المهمة يمكنك الضغط على زر تحديد الموقع في هذه الرسالة"
}
l_bot_progress_blog_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c кнопкой telegra.ph блога, поэтому для прохождения задания можно совершить нажатие на кнопку блога этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a telegra.ph blog-button, so to complete the task you can press the blog-button of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con un botón de blog telegra.ph, por lo que para completar la tarea puedes pulsar el botón del blog de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton de blog telegra.ph, donc pour accomplir la tâche vous pouvez appuyer sur le bouton du blog de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带有 telegra.ph 博客按钮的消息，因此为完成任务可以点击该消息的博客按钮",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل بها زر مدونة telegra.ph بعد، لذلك لإكمال المهمة يمكنك الضغط على زر المدونة في هذه الرسالة"
}
l_bot_progress_blog_btn_done = {
    "ru": "👩🏽‍💻 <b>Нажатие</b> на кнопку блога выполнено",
    "en": "👩🏽‍💻 <b>Press</b> on the blog-button completed",
    "es": "👩🏽‍💻 <b>Pulsación</b> en el botón del blog realizada",
    "fr": "👩🏽‍💻 <b>Clic</b> sur le bouton du blog effectué",
    "zh": "👩🏽‍💻 <b>点击</b> 博客按钮 已完成",
    "ar": "👩🏽‍💻 <b>تم الضغط</b> على زر المدونة"
}
l_bot_progress_download_btn = {
    "ru": "Загрузка файла",
    "en": "File download",
    "es": "Descarga de archivo",
    "fr": "Téléchargement de fichier",
    "zh": "文件下载",
    "ar": "تحميل الملف"
}
l_bot_progress_download_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c документами для загрузки, поэтому для прохождения задания можно совершить нажатие на иконку загрузки (в правом верхнем углу) этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with documents to download, so to complete the task you can press the download icon (in the top right corner) of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con documentos para descargar, por lo que para completar la tarea puedes pulsar el icono de descarga (en la esquina superior derecha) de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec des documents à télécharger, donc pour accomplir la tâche vous pouvez appuyer sur l'icône de téléchargement (en haut à droite) de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带有可下载文档的消息，因此为完成任务可以点击该消息的下载图标（右上角）",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل تحتوي على مستندات للتنزيل بعد، لذلك لإكمال المهمة يمكنك الضغط على أيقونة التنزيل (في الزاوية اليمنى العليا) لهذه الرسالة"
}
l_bot_progress_web_btn = {
    "ru": "Веб кнопка",
    "en": "Web button",
    "es": "Botón web",
    "fr": "Bouton web",
    "zh": "网页按钮",
    "ar": "زر الويب"
}
l_bot_progress_web_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c веб-кнопкой, поэтому для прохождения задания можно совершить нажатие на веб-кнопку этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a web-button, so to complete the task you can press the web-button of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con un botón web, por lo que para completar la tarea puedes pulsar el botón web de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton web, donc pour accomplir la tâche vous pouvez appuyer sur le bouton web de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带有网页按钮的消息，因此为完成任务可以点击该消息的网页按钮",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل بها زر الويب بعد، لذلك لإكمال المهمة يمكنك الضغط على زر الويب في هذه الرسالة"
}
l_bot_progress_share_btn = {
    "ru": "Кнопка Поделиться (веб)",
    "en": "Share button (web)",
    "es": "Botón Compartir (web)",
    "fr": "Bouton Partager (web)",
    "zh": "分享按钮（网页）",
    "ar": "زر المشاركة (الويب)"
}
l_bot_progress_link_btn = {
    "ru": "Кнопка Ссылка (веб)",
    "en": "Link button (web)",
    "es": "Botón Enlace (web)",
    "fr": "Bouton Lien (web)",
    "zh": "链接按钮（网页）",
    "ar": "زر الرابط (الويب)"
}
l_bot_progress_share_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-бота еще не создал сообщений c кнопкой Поделиться (веб), поэтому для прохождения задания можно совершить нажатие на кнопку Поделиться (веб) этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{0}-bot has not yet created messages with a Share button (web), so to complete the task you can press the Share button (web) of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{0}-bot aún no ha creado mensajes con un botón Compartir (web), por lo que para completar la tarea puedes pulsar el botón Compartir (web) de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{0}-bot n'a pas encore créé de messages avec un bouton Partager (web), donc pour accomplir la tâche vous pouvez appuyer sur le bouton Partager (web) de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0}-机器人 尚未创建带有分享按钮（网页）的消息，因此为完成任务可以点击该消息的分享按钮（网页）",
    "ar": "👩🏽‍💻 <b>المالك</b> @{0}-بوت لم ينشئ رسائل بها زر المشاركة (الويب) بعد، لذلك لإكمال المهمة يمكنك الضغط على زر المشاركة (الويب) في هذه الرسالة"
}
l_bot_progress_link_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{BOT_USERNAME}-бота еще не создал сообщений c кнопкой Ссылка (веб), поэтому для прохождения задания можно совершить нажатие на кнопку Ссылка (веб) этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> @{BOT_USERNAME}-bot has not yet created messages with a Link button (web), so to complete the task you can press the Link button (web) of that message",
    "es": "👩🏽‍💻 <b>El propietario</b> @{BOT_USERNAME}-bot aún no ha creado mensajes con un botón Enlace (web), por lo que para completar la tarea puedes pulsar el botón Enlace (web) de ese mensaje",
    "fr": "👩🏽‍💻 <b>Le propriétaire</b> @{BOT_USERNAME}-bot n'a pas encore créé de messages avec un bouton Lien (web), donc pour accomplir la tâche vous pouvez appuyer sur le bouton Lien (web) de ce message",
    "zh": "👩🏽‍💻 <b>所有者</b> @{BOT_USERNAME}-机器人 尚未创建带有链接按钮（网页）的消息，因此为完成任务可以点击该消息的链接按钮（网页）",
    "ar": "👩🏽‍💻 <b>المالك</b> @{BOT_USERNAME}-بوت لم ينشئ رسائل بها زر الرابط (الويب) بعد، لذلك لإكمال المهمة يمكنك الضغط على زر الرابط (الويب) في هذه الرسالة"
}
# endregion
# endregion


# region FereyChannelBot
l_chn_btn1 = {
    "ru": "➕ Канал",
    "en": "➕ Channel",
    "es": "➕ Canal",
    "fr": "➕ Chaîne",
    "zh": "➕ 频道",
    "ar": "➕ القناة"
}
l_chn_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك"
}
l_chn_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> администрирования <b>Telegram</b>-каналов:\n\n<blockquote>▪️монетизация и донаты\n▪️NFT-посты канала\n▪️FT-токен канала\n▪️маркетплейс постов и геймификация\n▪️нейро-генерация постов</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-application</i> for administration of <b>Telegram</b>-channels:\n\n<blockquote>▪️monetization and donations\n▪️NFT-posts of the channel\n▪️FT-token of the channel\n▪️marketplace of posts and gamification\n▪️neuro-generation of posts</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la administración de la aplicación <i>@tg</i> para la gestión de canales <b>Telegram</b>:\n\n<blockquote>▪️monetización y donaciones\n▪️publicaciones NFT-del canal\n▪️token FT-del canal\n▪️mercado de publicaciones y gamificación\n▪️neuro-generación de publicaciones</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans l'application <i>@tg</i> d'administration des <b>Telegram</b>-chaînes:\n\n<blockquote>▪️monétisation et dons\n▪️publications NFT-de la chaîne\n▪️jeton FT-de la chaîne\n▪️place de marché des publications et gamification\n▪️neuro-génération des publications</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎使用 <i>@tg-应用</i> 管理 <b>Telegram</b>-频道：\n\n<blockquote>▪️变现和捐赠\n▪️频道的 NFT 帖子\n▪️频道的 FT 代币\n▪️帖子市场和游戏化\n▪️帖子神经-生成</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في تطبيق <i>@tg</i> لإدارة قنوات <b>Telegram</b>:\n\n<blockquote>▪️تحقيق الدخل والتبرعات\n▪️منشورات NFT للقناة\n▪️رمز FT للقناة\n▪️سوق المنشورات واللعبنة\n▪️التوليد العصبي للمنشورات</blockquote>"
}
l_cmd_txt_chn = {
    "ru": "👩🏽‍💻 <b>Жми</b> [➕ Добавить канал]",
    "en": "👩🏽‍💻 <b>Click</b> [➕ Add channel]",
    "es": "👩🏽‍💻 <b>Haz clic</b> [➕ Agregar canal]",
    "fr": "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter une chaîne]",
    "zh": "👩🏽‍💻 <b>点击</b> [➕ 添加频道]",
    "ar": "👩🏽‍💻 <b>انقر</b> [➕ إضافة قناة]"
}
l_channels = {
    "ru": "👩🏽‍💻 Каналы",
    "en": "👩🏽‍💻 Channels",
    "es": "👩🏽‍💻 Canales",
    "fr": "👩🏽‍💻 Chaînes",
    "zh": "👩🏽‍💻 频道",
    "ar": "👩🏽‍💻 القنوات"
}

l_add_chn_button = {
    "ru": "➕ Добавить канал",
    "en": "➕ Add channel",
    "es": "➕ Agregar canal",
    "fr": "➕ Ajouter une chaîne",
    "zh": "➕ 添加频道",
    "ar": "➕ إضافة قناة"
}
l_bot_removed = {
    "ru": "🚫 @{0}-бот удален из <b>{1}</b> [id=<code>{2}</code>]",
    "en": "🚫 @{0}-bot removed from <b>{1}</b> [id=<code>{2}</code>]",
    "es": "🚫 @{0}-bot eliminado de <b>{1}</b> [id=<code>{2}</code>]",
    "fr": "🚫 @{0}-bot supprimé de <b>{1}</b> [id=<code>{2}</code>]",
    "zh": "🚫 @{0}-bot 已从 <b>{1}</b> [id=<code>{2}</code>] 中删除",
    "ar": "🚫 @{0}-تمت إزالة الروبوت من <b>{1}</b> [id=<code>{2}</code>]"
}
l_top_hashtags = {
    "ru": "\n<b>Топ #hashtags</b>:\n{0}\n",
    "en": "\n<b>Top #hashtags</b>:\n{0}\n",
    "es": "\n<b>Principales #hashtags</b>:\n{0}\n",
    "fr": "\n<b>Meilleurs #hashtags</b>:\n{0}\n",
    "zh": "\n<b>热门#hashtags</b>：\n{0}\n",
    "ar": "\n<b>أهم #hashtags</b>:\n{0}\n"
}
l_info_reactions = {
    "ru": "Допуск emoji-реакций",
    "en": "Allowing emoji reactions",
    "es": "Permitir reacciones emoji",
    "fr": "Autoriser les réactions emoji",
    "zh": "允许表情符号反应",
    "ar": "السماح بتفاعلات الرموز التعبيرية"
}
l_admins = {
    "ru": "Администраторы",
    "en": "Administrators",
    "es": "Administradores",
    "fr": "Administrateurs",
    "zh": "管理员",
    "ar": "المسؤولين"
}
l_info_invite_admins = {
    "ru": "Назначение администраторов",
    "en": "Inviting other admins to",
    "es": "Invitar a otros administradores a",
    "fr": "Inviter d'autres administrateurs à",
    "zh": "邀请其他管理员",
    "ar": "دعوة المشرفين الآخرين إلى"
}
l_info_cmd = {
    "ru": "⚙️ <b>Команды</b> /cmd",
    "en": "⚙️ <b>Commands</b> /cmd",
    "es": "⚙️ <b>Comandos</b> /cmd",
    "fr": "⚙️ <b>Commandes</b> /cmd",
    "zh": "⚙️ <b>命令</b> /cmd",
    "ar": "⚙️ <b>الأوامر</b> /cmd"
}
l_info_protect = {
    "ru": "<b>Сохранение контента</b>: ",
    "en": "<b>Saving content</b>:",
    "es": "<b>Guardar contenido</b>:",
    "fr": "<b>Enregistrement du contenu</b>:",
    "zh": "<b>保存内容</b>：",
    "ar": "<b>حفظ المحتوى</b>:"
}
l_info_request = {
    "ru": "<b>Вступление после одобрения</b>: ",
    "en": "<b>Joining after approval</b>:",
    "es": "<b>Unirse después de la aprobación</b>:",
    "fr": "<b>Rejoindre après approbation</b>:",
    "zh": "<b>批准后加入</b>：",
    "ar": "<b>الانضمام بعد الموافقة</b>:"
}
l_info_send = {
    "ru": "<b>Возможность писать после вступления</b>: ",
    "en": "<b>Possibility to write after joining</b>:",
    "es": "<b>Posibilidad de escribir después de unirse</b>:",
    "fr": "<b>Possibilité d'écrire après l'adhésion</b>:",
    "zh": "<b>加入后可以写</b>：",
    "ar": "<b>إمكانية الكتابة بعد الانضمام</b>:"
}

l_info_subscribe = {
    "ru": "<b>Проверка 💨Подписки при вступлении в канал</b>: ",
    "en": "<b>Checking 💨Subscriptions when joining a channel</b>: ",
    "es": "<b>Comprobación de 💨Suscripciones al unirse a un canal</b>: ",
    "fr": "<b>Vérification des 💨abonnements lors de l'adhésion à un canal</b>: ",
    "zh": "<b>加入频道时检查💨订阅</b>: ",
    "ar": "<b>التحقق من 💨الاشتراكات عند الانضمام إلى قناة</b>: "
}
l_info_restrict = {
    "ru": "запрещено\n",
    "en": "prohibited\n",
    "es": "prohibido\n",
    "fr": "interdit\n",
    "zh": "禁止\n",
    "ar": "محظور\n"
}
l_info_allow = {
    "ru": "разрешено\n",
    "en": "allowed\n",
    "es": "permitido\n",
    "fr": "autorisé\n",
    "zh": "允许\n",
    "ar": "مسموح\n"
}
l_transfer_start = {
    "ru": "👩🏽‍💻 <b>Пользователь</b> {0} должен /start-запустить @{1}",
    "en": "👩🏽‍💻 <b>User</b> {0} must /start-run @{1}",
    "es": "👩🏽‍💻 <b>Usuario</b> {0} debe /start-ejecutar @{1}",
    "fr": "👩🏽‍💻 <b>Utilisateur</b> {0} doit /start-lancer @{1}",
    "zh": "👩🏽‍💻 <b>用户</b> {0} 必须 /start-运行 @{1}",
    "ar": "👩🏽‍💻 <b>المستخدم</b> {0} يجب /start-تشغيل @{1}"
}
l_transfer_admin = {
    "ru": "👩🏽‍💻 <b>Пользователь</b> {0} должен быть <b>администратором</b> в <b>{1}</b>",
    "en": "👩🏽‍💻 <b>User</b> {0} must be an <b>administrator</b> in <b>{1}</b>",
    "es": "👩🏽‍💻 <b>Usuario</b> {0} debe ser un <b>administrador</b> en <b>{1}</b>",
    "fr": "👩🏽‍💻 <b>Utilisateur</b> {0} doit être un <b>administrateur</b> dans <b>{1}</b>",
    "zh": "👩🏽‍💻 <b>用户</b> {0} 必须是 <b>{1}</b> 中的 <b>管理员</b>",
    "ar": "👩🏽‍💻 <b>المستخدم</b> {0} يجب أن يكون <b>مشرفًا</b> في <b>{1}</b>"
}
l_transfer_transfer = {
    "ru": "👩🏽‍💻 <b>Передать</b> права администратора на <b>{0}</b> пользователю {1} в @{2}-боте?",
    "en": "👩🏽‍💻 <b>Transfer</b> <b>admin</b>-rights on <b>{0}</b> to user {1} in @{2}-bot?",
    "es": "👩🏽‍💻 ¿<b>Transferir</b> derechos de <b>admin</b> sobre <b>{0}</b> al usuario {1} en @{2}-bot?",
    "fr": "👩🏽‍💻 <b>Transférer</b> les droits <b>admin</b> sur <b>{0}</b> à l'utilisateur {1} dans @{2}-bot ?",
    "zh": "👩🏽‍💻 <b>将</b> <b>admin</b>-权限 在 <b>{0}</b> 上 转移 给 @{2}-bot 中的用户 {1}？",
    "ar": "👩🏽‍💻 <b>نقل</b> حقوق <b>admin</b> على <b>{0}</b> إلى المستخدم {1} في @{2}-bot؟"
}
l_transfer_text = {
    "ru": "👩🏽‍💻 <b>Для</b> передачи admin-прав канала в @{0}-боте используй команду:\n/transfer ID-ПОЛЬЗОВАТЕЛЯ, где пользователь: администратор канала и участник @{0}-бота (/id)\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>To</b> transfer channel admin rights in @{0}-bot use the command:\n/transfer USER-ID, where user: channel administrator and @{0}-bot member (/id)\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Para</b> transferir derechos de admin del canal en @{0}-bot usa el comando:\n/transfer ID-USUARIO, donde usuario: administrador del canal y miembro de @{0}-bot (/id)\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Pour</b> transférer les droits d'admin du canal vers @{0}-bot, utilisez la commande:\n/transfer ID-UTILISATEUR, où l'utilisateur : administrateur du canal et membre de @{0}-bot (/id)\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>要将频道的 admin 权限 转移 到 @{0}-bot，请使用命令：</b>\n/transfer USER-ID，其中用户：频道管理员且为 @{0}-bot 成员（/id）\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>لـ</b> نقل حقوق admin القناة في @{0}-bot استخدم الأمر:\n/transfer USER-ID، حيث المستخدم: مسؤول القناة وعضو في @{0}-bot (/id)\n\n⚙️ <b>الأوامر</b> /cmd"
}
l_transfer_done_to = {
    "ru": "👩🏽‍💻 <b>Права</b> админиистратора на [<b>{0}</b>] успешно переданы {1}",
    "en": "👩🏽‍💻 <b>Admin</b>-rights on [<b>{0}</b>] successfully transferred to {1}",
    "es": "👩🏽‍💻 Los derechos de <b>Admin</b> en [<b>{0}</b>] se transfirieron correctamente a {1}",
    "fr": "👩🏽‍💻 Les droits <b>Admin</b> sur [<b>{0}</b>] ont été transférés avec succès à {1}",
    "zh": "👩🏽‍💻 <b>Admin</b> 权限 在 [<b>{0}</b>] 已成功转移 给 {1}",
    "ar": "👩🏽‍💻 تم نقل حقوق <b>Admin</b> على [<b>{0}</b>] بنجاح إلى {1}"
}
l_transfer_done_from = {
    "ru": "👩🏽‍💻 <b>Права</b> администратора на [<b>{0}</b>] успешно получены от {1}",
    "en": "👩🏽‍💻 <b>Admin</b>-rights on [<b>{0}</b>] successfully obtained from {1}",
    "es": "👩🏽‍💻 Derechos de <b>Admin</b> en [<b>{0}</b>] obtenidos con éxito de {1}",
    "fr": "👩🏽‍💻 Les droits <b>Admin</b> sur [<b>{0}</b>] obtenus avec succès de {1}",
    "zh": "👩🏽‍💻 <b>Admin</b> 权限 在 [<b>{0}</b>] 已成功从 {1} 获取",
    "ar": "👩🏽‍💻 تم الحصول على حقوق <b>Admin</b> على [<b>{0}</b>] بنجاح من {1}"
}

l_add_chn_text = {
    "ru": "👮🏽‍♀️ <b>Добавь</b> @{0}-бота как [<b>Администратор</b>] через настройки своего канала:\n\n<blockquote>[👤 Добавить администратора]</blockquote>",
    "en": "👮🏽‍♀️ <b>Add</b> @{0}-bot as <b>Administrator</b> through your channel settings:\n\n<blockquote>[👤 Add administrator]</blockquote>",
    "es": "👮🏽‍♀️ <b>Agrega</b> @{0}-bot como <b>Administrador</b> a través de la configuración de tu canal:\n\n<blockquote>[👤 Agregar administrador]</blockquote>",
    "fr": "👮🏽‍♀️ <b>Ajoutez</b> @{0}-bot en tant qu'<b>Administrateur</b> via les paramètres de votre chaîne :\n\n<blockquote>[👤 Ajouter un administrateur]</blockquote>",
    "zh": "👮🏽‍♀️ <b>添加</b> @{0}-bot 作为 <b>管理员</b>，通过您的频道设置：\n\n<blockquote>[👤 添加管理员]</blockquote>",
    "ar": "👮🏽‍♀️ <b>أضف</b> @{0}-bot كـ<b>مسؤول</b> عبر إعدادات قناتك:\n\n<blockquote>[👤 إضافة مسؤول]</blockquote>"
}
l_add_chn_txt_call = {
    "ru": "👮🏽‍♀️ Добавь @{0}-бота как Administrator через настройки своего канала: [👤Add Admin]",
    "en": "👮🏽‍♀️ Add @{0}-bot as Administrator through your channel settings: [👤Add Admin]",
    "es": "👮🏽‍♀️ Agrega @{0}-bot como Administrador a través de la configuración de tu canal: [👤Agregar administrador]",
    "fr": "👮🏽‍♀️ Ajoutez @{0}-bot en tant qu'administrateur via les paramètres de votre chaîne : [👤Ajouter un administrateur]",
    "zh": "👮🏽‍♀️ 通过您的频道设置将@{0}-bot 添加为管理员： [👤添加管理员]",
    "ar": "👮🏽‍♀️ أضف @{0}-bot كمسؤول من خلال إعدادات قناتك: [👤إضافة مسؤول]"
}
l_chn_check = {
    "ru": "👩🏽‍💻 <b>Добавь</b> @{0}-бота в канал для проверки подписки на него. Отправь мне корректную ссылку на канал:",
    "en": "👩🏽‍💻 <b>Add</b> @{0}-bot to the channel to check subscription to it. Send me the correct link to the channel:",
    "es": "👩🏽‍💻 <b>Agrega</b> @{0}-bot al canal para verificar tu suscripción. Envíame el enlace correcto al canal:",
    "fr": "👩🏽‍💻 <b>Ajoutez</b> @{0}-bot à la chaîne pour vérifier votre abonnement. Envoyez-moi le lien correct vers la chaîne :",
    "zh": "👩🏽‍💻 <b>添加</b> @{0}-bot 到频道以检查您对该频道的订阅。请向我发送正确的频道链接：",
    "ar": "👩🏽‍💻 <b>أضف</b> @{0}-bot إلى القناة للتحقق من اشتراكك فيها. أرسل لي الرابط الصحيح للقناة:"
}
l_podcast_rights = {
    "ru": "🎥 <b>В настройках</b> [Администраторы] вкл опцию для @{0}-бота:\n[✅ Назначение администраторов]\n[✅ Управление трансляциями]\n\n🕚Подожди 1min",
    "en": "🎥 <b>In settings</b> [Administrators] enable the option for @{0}-bot:\n[✅ Assigning administrators]\n[✅ Managing broadcasts]\n\n🕚Wait 1min",
    "es": "🎥 <b>En configuración</b> [Administradores] habilita la opción para @{0}-bot:\n[✅ Asignar administradores]\n[✅ Gestionar transmisiones]\n\n🕚Espera 1min",
    "fr": "🎥 <b>Dans les paramètres</b> [Administrateurs] activez l'option pour @{0}-bot :\n[✅ Attribution d'administrateurs]\n[✅ Gestion des diffusions]\n\n🕚Attendez 1min",
    "zh": "🎥 <b>在设置中</b> [管理员] 为 @{0}-bot 启用以下选项：\n[✅ 指定管理员]\n[✅ 管理广播]\n\n🕚等待 1min",
    "ar": "🎥 <b>في الإعدادات</b> [المسؤولون] فعِّل الخيار لـ @{0}-bot:\n[✅ تعيين المسؤولين]\n[✅ إدارة البث]\n\n🕚انتظر 1min"
}
l_podcast_handler = {
    "ru": "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i> [/podcast d h] каждый <u>d</u>-день (1-31) на <u>h</u>-часов (1-168). Текущее значение: /podcast {0}\n\n<code>/podcast 1 1</code>  ежедневный видео-анонс длительностью 1 час\n<code>/podcast 0</code>    отключение опции\n\n⚙️ <b>Команды</b> /cmd",
    "en": "🎥 <b>Auto-announcement</b> <i>video podcast</i> [/podcast d h] every <u>d</u> day (1-31) for <u>h</u> hours (1-168). Current value: /podcast {0}\n\n<code>/podcast 1 1</code> daily video announcement lasting 1 hour\n<code>/podcast 0</code> disable option\n\n⚙️ <b>Commands</b> /cmd",
    "es": "🎥 <b>Anuncio automático</b> <i>podcast de vídeo</i> [/podcast d h] cada <u>d</u> día (1-31) durante <u>h</u> horas (1-168). Valor actual: /podcast {0}\n\n<code>/podcast 1 1</code> anuncio de vídeo diario que dura 1 hora\n<code>/podcast 0</code> desactivar opción\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "🎥 <b>Annonce automatique</b> <i>podcast vidéo</i> [/podcast d h] tous les <u>d</u> jours (1-31) à <u>h</u> heures (1-168). Valeur actuelle : /podcast {0}\n\n<code>/podcast 1 1</code> annonce vidéo quotidienne d'une durée d'une heure\n<code>/podcast 0</code> désactiver l'option\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "🎥 <b>自动公告</b> <i>视频播客</i> [/podcast d h] 每 <u>d</u> 天 (1-31) 在 <u>h</u> 小时 (1-168)。当前值：/podcast {0}\n\n<code>/podcast 1 1</code> 每日视频公告，持续 1 小时\n<code>/podcast 0</code> 禁用选项\n\n⚙️ <b>命令</b> /cmd",
    "ar": "🎥 <b>إعلان تلقائي</b> <i>بودكاست فيديو</i> [/podcast d h] كل <u>d</u> يوم (1-31) عند <u>h</u> ساعة (1-168). القيمة الحالية: /podcast {0}\n\n<code>/podcast 1 1</code> إعلان فيديو يومي يدوم ساعة واحدة\n<code>/podcast 0</code> تعطيل الخيار\n\n⚙️ <b>الأوامر</b> /cmd"
}
l_podcast_on = {
    "ru": "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i>: каждый <u>{0}</u> день на <u>{1}</u> часов\n\n⚙️ <b>Команды</b> /cmd",
    "en": "🎥 <b>Auto-announcement</b> <i>video podcast</i>: every <u>{0}</u> day for <u>{1}</u> hours\n\n⚙️ <b>Commands</b> /cmd",
    "es": "🎥 <b>Anuncio automático</b> <i>podcast de vídeo</i>: cada <u>{0}</u> día durante <u>{1}</u> horas\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "🎥 <b>Annonce automatique</b> <i>podcast vidéo</i> : tous les <u>{0}</u> jours pendant <u>{1}</u> heures\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "🎥 <b>自动公告</b> <i>视频播客</i>：每 <u>{0}</u> 天，持续 <u>{1}</u> 小时\n\n⚙️ <b>命令</b> /cmd",
    "ar": "🎥 <b>إعلان تلقائي</b> <i>بودكاست فيديو</i>: كل <u>{0}</u> يوم لمدة <u>{1}</u> ساعة\n\n⚙️ <b>الأوامر</b> /cmd"
}
l_podcast_off = {
    "ru": "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i> отключен\n\n⚙️ <b>Команды</b> /cmd",
    "en": "🎥 <b>Auto-announcement</b> <i>video podcast</i> disabled\n\n⚙️ <b>Commands</b> /cmd",
    "es": "🎥 <b>Anuncio automático</b> <i>podcast de vídeo</i> deshabilitado\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "🎥 <b>Annonce automatique</b> <i>podcast vidéo</i> désactivé\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "🎥 <b>自动公告</b> <i>视频播客</i> 已禁用\n\n⚙️ <b>命令</b> /cmd",
    "ar": "🎥 <b>الإعلان التلقائي</b> <i>بودكاست فيديو</i> معطل\n\n⚙️ <b>الأوامر</b> /cmd"
}
l_podcast_start = {
    "ru": "👩🏽‍💻 Подкаст",
    "en": "👩🏽‍💻 Podcast",
    "es": "👩🏽‍💻 Podcast",
    "fr": "👩🏽‍💻 Podcast",
    "zh": "👩🏽‍💻 播客",
    "ar": "👩🏽‍💻 بودكاست"
}

l_chn_info_start1 = {
    "ru": "👩🏽‍💻 <b>Информация</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    "en": "👩🏽‍💻 <b>Information</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participants]{5}{6}{7}",
    "es": "👩🏽‍💻 <b>Información</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participantes]{5}{6}{7}",
    "fr": "👩🏽‍💻 <b>Informations</b>\n\n<b>Nom</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participants]{5}{6}{7}",
    "zh": "👩🏽‍💻 <b>信息</b>\n\n<b>名称</b>：{0} [id=<code>{1}</code>，<i>{2} {3}</i>，<u>{4}</u> 参与者]{5}{6}{7}",
    "ar": "👩🏽‍💻 <b>المعلومات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>، <u>{4}</u> مشاركون]{5}{6}{7}",
}
l_chn_stat_start1 = {
    "ru": "👩🏽‍💻 <b>Аналитика</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    "en": "👩🏽‍💻 <b>Analytics</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participants]{5}{6}{7}",
    "es": "👩🏽‍💻 <b>Análisis</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participantes]{5}{6}{7}",
    "fr": "👩🏽‍💻 <b>Analytics</b>\n\n<b>Nom</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participants]{5}{6}{7}",
    "zh": "👩🏽‍💻 <b>分析</b>\n\n<b>名称</b>：{0} [id=<code>{1}</code>，<i>{2} {3}</i>，<u>{4}</u> 参与者]{5}{6}{7}",
    "ar": "👩🏽‍💻 <b>التحليلات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>، <u>{4}</u> مشاركون]{5}{6}{7}",
}
l_chn_stat_start2 = {
    "ru": "\n<b>Ссылка</b>: {0}\n<b>Описание</b>: {1}\n<b>Привязанная группа</b>: <code>{2}</code>\n",
    "en": "\n<b>Link</b>: {0}\n<b>Description</b>: {1}\n<b>Linked group</b>: <code>{2}</code>\n",
    "es": "\n<b>Enlace</b>: {0}\n<b>Descripción</b>: {1}\n<b>Grupo vinculado</b>: <code>{2}</code>\n",
    "fr": "\n<b>Lien</b>: {0}\n<b>Description</b>: {1}\n<b>Groupe lié</b>: <code>{2}</code>\n",
    "zh": "\n<b>链接</b>：{0}\n<b>说明</b>：{1}\n<b>关联群组</b>：<code>{2}</code>\n",
    "ar": "\n<b>الرابط</b>: {0}\n<b>الوصف</b>: {1}\n<b>المجموعة المرتبطة</b>: <code>{2}</code>\n",
}
l_chn_stat_start3 = {
    "ru": "\n<b>ID последнего поста</b>: {0}\n<b>Посты</b>: {1}\n<b>Реакции</b>: {2}\n<b>Просмотры</b>: {3}\n<b>кѻмментарии</b>: {4}\n<b>$кэштеги</b>: {5}\n<b>#hashtag</b>: {6}\n",
    "en": "\n<b>Last post ID</b>: {0}\n<b>Posts</b>: {1}\n<b>Reactions</b>: {2}\n<b>Views</b>: {3}\n<b>Comments</b>: {4}\n<b>$cashtags</b>: {5}\n<b>#hashtags</b>: {6}\n",
    "es": "\n<b>ID de la última publicación</b>: {0}\n<b>Publicaciones</b>: {1}\n<b>Reacciones</b>: {2}\n<b>Vistas</b>: {3}\n<b>Comentarios</b>: {4}\n<b>$cashtags</b>: {5}\n<b>#hashtags</b>: {6}\n",
    "fr": "\n<b>ID du dernier post</b>: {0}\n<b>Posts</b>: {1}\n<b>Réactions</b>: {2}\n<b>Vues</b>: {3}\n<b>Commentaires</b>: {4}\n<b>$cashtags</b>: {5}\n<b>#hashtags</b>: {6}\n",
    "zh": "\n<b>最后帖子 ID</b>：{0}\n<b>帖子</b>：{1}\n<b>反应</b>：{2}\n<b>观看次数</b>：{3}\n<b>评论</b>：{4}\n<b>$cashtags</b>：{5}\n<b>#hashtags</b>：{6}\n",
    "ar": "\n<b>معرف آخر منشور</b>: {0}\n<b>المنشورات</b>: {1}\n<b>التفاعلات</b>: {2}\n<b>المشاهدات</b>: {3}\n<b>التعليقات</b>: {4}\n<b>$cashtags</b>: {5}\n<b>#hashtags</b>: {6}\n",
}
l_chn_commands_handler = {
    "ru": "⚙️ <b>Команды</b> /cmd для [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info информация о канале\n/stat статистика\n\n/parse [1] база подписчиков/лайков поста #1\n/random [1] рандомный лайкнувший пост #1\n/podcast 1 1 анонс видео-подкаста\n<code>/clean</code> очистка от deleted/scam-аккаунтов и по [<b>🕵🏽 Авто-бан</b>] правилам\n/delete <code>FROM TO</code> удаление за период\n/channel NAME канал проверки подписки\n/transfer передача ADMIN-прав</blockquote>\n\n💨 <b>Подписка</b>: <i>{3}</i>",
    "en": "⚙️ <b>Commands</b> /cmd for [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info channel information\n/stat statistics\n\n/parse [1] subscriber/likes base for post #1\n/random [1] random user who liked post #1\n/podcast 1 1 video-podcast announcement\n<code>/clean</code> clearing deleted/scam accounts and according to [<b>🕵🏽 Auto-ban</b>] rules\n/delete <code>FROM TO</code> delete for a period\n/channel NAME channel for subscription check\n/transfer transfer of admin rights</blockquote>\n\n💨 <b>Subscription</b>: <i>{3}</i>",
    "es": "⚙️ <b>Comandos</b> /cmd para [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info información del canal\n/stat estadísticas\n\n/parse [1] base de suscriptores/likes del post #1\n/random [1] usuario aleatorio que dio like al post #1\n/podcast 1 1 anuncio de video-podcast\n<code>/clean</code> limpieza de cuentas eliminadas/estafa y según reglas de [<b>🕵🏽 Prohibición automática</b>]\n/delete <code>FROM TO</code> eliminar por un período\n/channel NAME canal para verificación de suscripción\n/transfer transferencia de derechos de administrador</blockquote>\n\n💨 <b>Suscripción</b>: <i>{3}</i>",
    "fr": "⚙️ <b>Commandes</b> /cmd pour [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info informations sur la chaîne\n/stat statistiques\n\n/parse [1] base d'abonnés/likes du post #1\n/random [1] utilisateur aléatoire ayant liké le post #1\n/podcast 1 1 annonce du podcast vidéo\n<code>/clean</code> suppression des comptes supprimés/arnaques et selon les règles de [<b>🕵🏽 Auto-ban</b>]\n/delete <code>FROM TO</code> supprimer pour une période\n/channel NAME canal de vérification d'abonnement\n/transfer transfert des droits administrateur</blockquote>\n\n💨 <b>Abonnement</b>: <i>{3}</i>",
    "zh": "⚙️ <b>命令</b> /cmd 用于 [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info 频道信息\n/stat 统计\n\n/parse [1] 订阅者/点赞 基础（帖子 #1）\n/random [1] 随机点赞帖子 #1 的用户\n/podcast 1 1 视频播客公告\n<code>/clean</code> 清除已删除/诈骗账户并根据 [<b>🕵🏽 自动封禁</b>] 规则\n/delete <code>FROM TO</code> 删除一段时间内的内容\n/channel NAME 订阅验证频道\n/transfer 管理权限转移</blockquote>\n\n💨 <b>订阅</b>: <i>{3}</i>",
    "ar": "⚙️ <b>الأوامر</b> /cmd لإحصائيات [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info معلومات القناة\n/stat إحصاءات\n\n/parse [1] قاعدة المشتركين/الإعجابات للمنشور #1\n/random [1] مستخدم عشوائي أعجب بالمنشور #1\n/podcast 1 1 إعلان بودكاست فيديو\n<code>/clean</code> مسح الحسابات المحذوفة/الاحتيالية ووفق قواعد [<b>🕵🏽 الحظر التلقائي</b>]\n/delete <code>FROM TO</code> الحذف لفترة\n/channel NAME قناة للتحقق من الاشتراك\n/transfer نقل حقوق المدير</blockquote>\n\n💨 <b>الاشتراك</b>: <i>{3}</i>",
}
l_update_text = {
    "ru": "👩🏽‍💻 <b>Данные</b> о канале успешно обновлены:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Channel data</b> successfully updated:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Datos del canal</b> actualizados correctamente:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Données de la chaîne</b> mises à jour avec succès :\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>频道数据</b>已成功更新：\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 تم تحديث <b>بيانات القناة</b> بنجاح:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_change_chn_info = {
    "ru": "Изменение профиля канала",
    "en": "Changing channel profile",
    "es": "Cambio del perfil del canal",
    "fr": "Modification du profil de la chaîne",
    "zh": "更改频道配置文件",
    "ar": "تغيير ملف تعريف القناة",
}
l_send_messages = {
    "ru": "Отправка сообщений",
    "en": "Sending messages",
    "es": "Envío de mensajes",
    "fr": "Envoi de messages",
    "zh": "发送消息",
    "ar": "إرسال الرسائل",
}
l_chn_graph_yes = {
    "ru": "👩🏽‍💻 <b>Экстра</b>-статистика канала за неделю [{0}]\n\n▪️ Подписчики: {1} ({2}{3})\n▪️ Просмотры: {4} ({5}{6})\n▪️ Поделиться: {7} ({8}{9})\n▪️ Уведомления у {10}% подписчиков\n",
    "en": "👩🏽‍💻 <b>Extra</b>-channel statistics for the week [{0}]\n\n▪️ Subscribers: {1} ({2}{3})\n▪️ Views: {4} ({5}{6})\n▪️ Shares: {7} ({8}{9})\n▪️ Notifications enabled for {10}% of subscribers\n",
    "es": "👩🏽‍💻 Estadísticas <b>extra</b> del canal para la semana [{0}]\n\n▪️ Suscriptores: {1} ({2}{3})\n▪️ Vistas: {4} ({5}{6})\n▪️ Compartidos: {7} ({8}{9})\n▪️ Notificaciones activadas para el {10}% de suscriptores\n",
    "fr": "👩🏽‍💻 Statistiques <b>extra</b> de la chaîne pour la semaine [{0}]\n\n▪️ Abonnés : {1} ({2}{3})\n▪️ Vues : {4} ({5}{6})\n▪️ Parts : {7} ({8}{9})\n▪️ Notifications activées pour {10}% des abonnés\n",
    "zh": "👩🏽‍💻 <b>额外</b>-频道周统计 [{0}]\n\n▪️ 订阅者：{1} ({2}{3})\n▪️ 观看次数：{4} ({5}{6})\n▪️ 分享：{7} ({8}{9})\n▪️ 已为 {10}% 订阅者开启通知\n",
    "ar": "👩🏽‍💻 إحصائيات قناة <b>إضافية</b> للأسبوع [{0}]\n\n▪️ المشتركون: {1} ({2}{3})\n▪️ المشاهدات: {4} ({5}{6})\n▪️ المشاركات: {7} ({8}{9})\n▪️ الإشعارات ممكّنة لدى {10}% من المشتركين\n",
}
l_chn_graph_no = {
    "ru": "👩🏽‍💻 <b>Вкл</b> [✅ Назначение администраторов] для @{0}, чтобы вывести <b>экстра</b>-графику канала за неделю",
    "en": "👩🏽‍💻 Turn <b>On</b> [✅ Assign administrators] for @{0} to display <b>extra</b> channel graphics for the week",
    "es": "👩🏽‍💻 Activa <b>Asignar administradores</b> para @{0} para mostrar gráficos <b>adicionales</b> del canal para la semana",
    "fr": "👩🏽‍💻 Activez <b>Attribution d'administrateurs</b> pour @{0} afin d'afficher les graphiques <b>supplémentaires</b> de la chaîne pour la semaine",
    "zh": "👩🏽‍💻 为 @{0} <b>开启</b> [✅ 分配管理员]，以显示本周的<b>额外</b>频道图表",
    "ar": "👩🏽‍💻 قم <b>بتشغيل</b> [✅ تعيين مسؤولين] لـ @{0} لعرض رسومات القناة <b>الإضافية</b> لهذا الأسبوع",
}
l_chn_already_taken = {
    "ru": "👮🏽 <b>Канал</b> [<b>{0}</b>] уже <i>администрируется</i> в @{1}-боте",
    "en": "👮🏽 <b>Channel</b> [<b>{0}</b>] is already <i>administered</i> in @{1} bot",
    "es": "👮🏽 <b>Canal</b> [<b>{0}</b>] ya está <i>administrado</i> en @{1} bot",
    "fr": "👮🏽 <b>Chaîne</b> [<b>{0}</b>] est déjà <i>administrée</i> dans le bot @{1}",
    "zh": "👮🏽 <b>频道</b> [<b>{0}</b>] 已在 @{1} 机器人中被<i>管理</i>",
    "ar": "👮🏽 <b>القناة</b> [<b>{0}</b>] مُدارة بالفعل في بوت @{1}",
}
l_chn_subscribe_call = {
    "ru": "👩🏽‍💻 Необходима подписка на канал",
    "en": "👩🏽‍💻 Subscription to the channel is required",
    "es": "👩🏽‍💻 Se requiere suscripción al canal",
    "fr": "👩🏽‍💻 L'abonnement à la chaîne est requis",
    "zh": "👩🏽‍💻 需要订阅该频道",
    "ar": "👩🏽‍💻 الاشتراك في القناة مطلوب",
}
l_chn_boost_call = {
    "ru": "👩🏽‍💻 Необходим буст-голос за канал",
    "en": "👩🏽‍💻 A boost vote for the channel is required",
    "es": "👩🏽‍💻 Se requiere voto de impulso para el canal",
    "fr": "👩🏽‍💻 Un vote de boost pour la chaîne est requis",
    "zh": "👩🏽‍💻 需要为频道投票提升",
    "ar": "👩🏽‍💻 مطلوب تصويت تعزيز للقناة",
}
l_content_types_sub_button = {
    "ru": "👮🏽 Я подписался",
    "en": "👮🏽 I subscribed",
    "es": "👮🏽 Me suscribí",
    "fr": "👮🏽 Je me suis abonné",
    "zh": "👮🏽 我已订阅",
    "ar": "👮🏽 لقد اشتركت",
}
l_content_types_subscribe = {
    "ru": "👮🏽 {0}, подпишись на {1}, чтобы твоя заявка на вступление была одобрена",
    "en": "👮🏽 {0}, subscribe to {1} so that your application to join will be approved",
    "es": "👮🏽 {0}, suscríbete a {1} para que tu solicitud de incorporación sea aprobada",
    "fr": "👮🏽 {0}, abonnez-vous à {1} afin que votre demande d'adhésion soit approuvée",
    "zh": "👮🏽 {0}，订阅 {1}，以便您的加入申请获得批准",
    "ar": "👮🏽 {0}، اشترك في {1} حتى تتم الموافقة على طلبك للانضمام",
}
l_wait_1_min = {
    "ru": "🕐 Подожди 1мин",
    "en": "🕐 Wait 1 min",
    "es": "🕐 Espera 1 min",
    "fr": "🕐 Attendez 1 min",
    "zh": "🕐 等待1分钟",
    "ar": "🕐 انتظر دقيقة واحدة",
}
l_chat_join_request_handler = {
    "ru": "👮🏽 {0}, ты отправил(а) заявку на вступление в <b>{1}</b>\n\n👩🏽‍💻 <b>Выбери</b> <i>правильный вариант</i> в соответствии с заданием на картинке, чтобы твоя <i>заявка</i> на вступление была <b>одобрена</b>",
    "en": "👮🏽 {0}, you have sent an application to join <b>{1}</b>\n\n👩🏽‍💻 <b>Choose</b> <i>the correct option</i> according to the task in the picture so that your <i>application</i> to join will be <b>approved</b>",
    "es": "👮🏽 {0}, has enviado una solicitud para unirte a <b>{1}</b>\n\n👩🏽‍💻 <b>Elige</b> <i>la opción correcta</i> según la tarea en la imagen para que tu <i>solicitud</i> de incorporación sea <b>aprobada</b>",
    "fr": "👮🏽 {0}, vous avez envoyé une demande pour rejoindre <b>{1}</b>\n\n👩🏽‍💻 <b>Choisissez</b> <i>la bonne option</i> conformément à la tâche sur l'image afin que votre <i>demande</i> d'adhésion soit <b>approuvée</b>",
    "zh": "👮🏽 {0}，您已向 <b>{1}</b> 发送加入申请\n\n👩🏽‍💻 <b>请选择</b> <i>正确的选项</i>，按照图片中的任务操作，以便您的<i>加入申请</i>获得<b>通过</b>",
    "ar": "👮🏽 {0}، لقد أرسلت طلبًا للانضمام إلى <b>{1}</b>\n\n👩🏽‍💻 <b>اختر</b> <i>الخيار الصحيح</i> وفقًا للمهمة في الصورة حتى تتم الموافقة على <i>طلبك</i> للانضمام.",
}
l_chn_need_sub_for_more_than_1_chn = {
    "ru": "👩🏽‍💻 <b>Оформи</b> подписку, чтобы добавлять более 1 канала",
    "en": "👩🏽‍💻 <b>Get</b> a subscription to add more than 1 channel",
    "es": "👩🏽‍💻 <b>Obtén</b> una suscripción para añadir más de 1 canal",
    "fr": "👩🏽‍💻 <b>Obtenez</b> un abonnement pour ajouter plus d'1 chaîne",
    "zh": "👩🏽‍💻 <b>购买</b>订阅以添加超过 1 个频道",
    "ar": "👩🏽‍💻 <b>اشترك</b> للحصول على إمكانية إضافة أكثر من قناة واحدة",
}
l_chn_need_sub_for_more_than_2_chn = {
    "ru": "👩🏽‍💻 <b>Оформи</b> подписку, чтобы добавлять более 2 каналов",
    "en": "👩🏽‍💻 <b>Get</b> a subscription to add more than 2 channels",
    "es": "👩🏽‍💻 <b>Obtén</b> una suscripción para añadir más de 2 canales",
    "fr": "👩🏽‍💻 <b>Obtenez</b> un abonnement pour ajouter plus de 2 chaînes",
    "zh": "👩🏽‍💻 <b>购买</b>订阅以添加超过 2 个频道",
    "ar": "👩🏽‍💻 <b>اشترك</b> للحصول على إمكانية إضافة أكثر من قناتين",
}
l_cdelete_answer = {
    "ru": "🚫 @{0}-приложение отсоединено от [<b>{1}</b>] и не числится его в участниках!",
    "en": "🚫 @{0} application has been disconnected from [<b>{1}</b>] and is not listed among its participants!",
    "es": "🚫 La aplicación @{0} se ha desvinculado de [<b>{1}</b>] y no figura entre sus participantes!",
    "fr": "🚫 L'application @{0} a été dissociée de [<b>{1}</b>] et ne figure pas parmi ses participants !",
    "zh": "🚫 @{0} 应用已从 [<b>{1}</b>] 断开，并且未列为其参与者！",
    "ar": "🚫 تم فصل التطبيق @{0} عن [<b>{1}</b>] ولا يظهر ضمن المشاركين فيه!",
}
l_chn_done = {
    'ru': "👮🏽 <b>Готово!</b> Проверка подписки на {0} настроена\n\nОпцию можно включить в настройках, нажав [✅☑Вкл подписку]\n\n⚙️ Команды /cmd",
    'en': "👮🏽 <b>Done!</b> Subscription check for {0} is configured\n\nThe option can be enabled in the settings by clicking [✅☑On subscription]\n\n⚙️ Commands /cmd",
    'es': "👮🏽 <b>¡Listo!</b> La verificación de suscripción para {0} está configurada\n\nLa opción se puede habilitar en la configuración haciendo clic en [✅☑En suscripción]\n\n⚙️ Comandos /cmd",
    'fr': "👮🏽 <b>Terminé !</b> La vérification de l'abonnement pour {0} est configurée\n\nL'option peut être activée dans les paramètres en cliquant sur [✅☑Sur abonnement]\n\n⚙️ Commandes /cmd",
    'zh': "👮🏽 <b>完成！</b> 已配置 {0} 的订阅检查\n\n可以通过单击 [✅☑订阅时] 在设置中启用该选项\n\n⚙️ 命令 /cmd",
    'ar': "👮🏽 <b>تم!</b> تم تكوين التحقق من الاشتراك لـ {0}\n\nيمكن تمكين الخيار في الإعدادات بالنقر فوق [✅☑عند الاشتراك]\n\n⚙️ الأوامر /cmd",
}

l_ban_users_start = {
    "ru": "👩🏽‍💻 <b>Очистка</b> запущена. <b>Текущее</b> количество пользователей в базе: <u>{0}</u>",
    "en": "👩🏽‍💻 <b>Cleaning</b> started. <b>Current</b> number of users in the database: <u>{0}</u>",
    "es": "👩🏽‍💻 <b>Limpieza</b> iniciada. Número <b>actual</b> de usuarios en la base de datos: <u>{0}</u>",
    "fr": "👩🏽‍💻 <b>Nettoyage</b> lancé. <b>Nombre actuel</b> d'utilisateurs dans la base de données : <u>{0}</u>",
    "zh": "👩🏽‍💻 <b>清理</b>已开始。数据库中<b>当前</b>用户数：<u>{0}</u>",
    "ar": "👩🏽‍💻 <b>التنظيف</b> بدأ. <b>العدد الحالي</b> للمستخدمين في قاعدة البيانات: <u>{0}</u>"
}
l_ban_users_stop = {
    "ru": "👩🏽‍💻 <b>Очистка</b> завершена. <b>Текущее</b> количество пользователей в базе: <u>{0}</u> (-{1})",
    "en": "👩🏽‍💻 <b>Cleaning</b> completed. <b>Current</b> number of users in the database: <u>{0}</u> (-{1})",
    "es": "👩🏽‍💻 <b>Limpieza</b> completada. Número <b>actual</b> de usuarios en la base de datos: <u>{0}</u> (-{1})",
    "fr": "👩🏽‍💻 <b>Nettoyage</b> terminé. <b>Nombre actuel</b> d'utilisateurs dans la base de données : <u>{0}</u> (-{1})",
    "zh": "👩🏽‍💻 <b>清理</b>完成。数据库中<b>当前</b>用户数：<u>{0}</u> (-{1})",
    "ar": "👩🏽‍💻 <b>التنظيف</b> اكتمل. <b>العدد الحالي</b> للمستخدمين في قاعدة البيانات: <u>{0}</u> (-{1})"
}
l_chn_delete_parse = {
    "ru": "👩🏽‍💻 <b>Введи</b> дату начала/конца для удаления подписчиков из /parse-базы:\n<code>/delete {0} {1}</code>",
    "en": "👩🏽‍💻 <b>Enter</b> the start/end date to delete subscribers from the /parse database:\n<code>/delete {0} {1}</code>",
    "es": "👩🏽‍💻 <b>Introduce</b> la fecha de inicio/fin para eliminar suscriptores de la base /parse:\n<code>/delete {0} {1}</code>",
    "fr": "👩🏽‍💻 <b>Entrez</b> la date de début/fin pour supprimer des abonnés de la base /parse :\n<code>/delete {0} {1}</code>",
    "zh": "👩🏽‍💻 <b>输入</b>开始/结束日期以从 /parse 数据库中删除订阅者：\n<code>/delete {0} {1}</code>",
    "ar": "👩🏽‍💻 <b>أدخل</b> تاريخ البدء/الانتهاء لحذف المشتركين من قاعدة /parse:\n<code>/delete {0} {1}</code>"
}
l_chn_delete_start = {
    "ru": "👩🏽‍💻 <b>Начинаем</b> удаление за период:\n<code>{0}</code>\n<code>{1}</code>",
    "en": "👩🏽‍💻 <b>Starting</b> deletion for the period:\n<code>{0}</code>\n<code>{1}</code>",
    "es": "👩🏽‍💻 <b>Comenzamos</b> eliminación para el período:\n<code>{0}</code>\n<code>{1}</code>",
    "fr": "👩🏽‍💻 <b>Nous commençons</b> la suppression pour la période :\n<code>{0}</code>\n<code>{1}</code>",
    "zh": "👩🏽‍💻 <b>开始</b>按期间删除：\n<code>{0}</code>\n<code>{1}</code>",
    "ar": "👩🏽‍💻 <b>نبدأ</b> بحذف الفترة:\n<code>{0}</code>\n<code>{1}</code>"
}
l_chn_delete_finish = {
    "ru": "👩🏽‍💻 <b>Удаление</b> пользователей завершено:\n<u>{0}</u> [-{1}]",
    "en": "👩🏽‍💻 <b>Deletion</b> of users completed:\n<u>{0}</u> [-{1}]",
    "es": "👩🏽‍💻 <b>Eliminación</b> de usuarios completada:\n<u>{0}</u> [-{1}]",
    "fr": "👩🏽‍💻 <b>Suppression</b> des utilisateurs terminée :\n<u>{0}</u> [-{1}]",
    "zh": "👩🏽‍💻 <b>删除</b>用户已完成：\n<u>{0}</u> [-{1}]",
    "ar": "👩🏽‍💻 <b>حذف المستخدمين</b> اكتمل:\n<u>{0}</u> [-{1}]"
}
l_ccheck_btn_name = {
    "ru": "✔ Я человек",
    "en": "✔ I'm human",
    "es": "✔ Soy humano",
    "fr": "✔ Je suis humain",
    "zh": "✔ 我是人类",
    "ar": "✔ أنا إنسان"
}
l_ccheck_hello_txt = {
    "ru": "🌱 {name}, добро пожаловать в нашу <b>канал</b> {title}!",
    "en": "🌱 {name}, welcome to our <b>channel</b> {title}!",
    "es": "🌱 {name}, ¡bienvenido a nuestro <b>canal</b> {title}!",
    "fr": "🌱 {name}, bienvenue sur notre <b>chaîne</b> {title} !",
    "zh": "🌱 {name}，欢迎来到我们的<b>频道</b> {title}！",
    "ar": "🌱 {name}، مرحبًا بك في قناتنا <b>{title}</b>!"
}
l_ccheck_add_channel = {
    "ru": "👮🏽 Для <i>проверки подписки</i> необходимо добавить канал командой:\n\n/channel ССЫЛКА НА КАНАЛ",
    "en": "👮🏽 To <i>check subscription</i> you need to add a channel with the command:\n\n/channel LINK TO CHANNEL",
    "es": "👮🏽 Para <i>verificar suscripción</i> necesitas agregar un canal con el comando:\n\n/canal ENLACE AL CANAL",
    "fr": "👮🏽 Pour <i>vérifier l'abonnement</i> vous devez ajouter une chaîne avec la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    "zh": "👮🏽 要<i>检查订阅</i>，需要使用以下命令添加频道：\n\n/channel 频道链接",
    "ar": "👮🏽 من أجل <i>التحقق من الاشتراك</i> يجب إضافة قناة باستخدام الأمر:\n\n/channel رابط القناة"
}
l_chn_for_sub_pay = {
    "ru": "👩🏽‍💻 Для оплаты подписки",
    "en": "👩🏽‍💻 For subscription payment",
    "es": "👩🏽‍💻 Para el pago de la suscripción",
    "fr": "👩🏽‍💻 Pour le paiement de l'abonnement",
    "zh": "👩🏽‍💻 用于订阅付款",
    "ar": "👩🏽‍💻 لدفع الاشتراك"
}
l_chn_need_boost_for_story = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: {0}-буст-голосов для публикации сториз",
    "en": "👩🏽‍💻 <b>Required</b>: {0}-boost-votes to publish stories",
    "es": "👩🏽‍💻 <b>Necesario</b>: {0}-boost-votos para publicar historias",
    "fr": "👩🏽‍💻 <b>Nécessaire</b> : {0}-boost-votes pour publier des stories",
    "zh": "👩🏽‍💻 <b>需要</b>：发布故事需 {0}-boost 投票",
    "ar": "👩🏽‍💻 <b>مطلوب</b>: {0}-boost-أصوات لنشر الستوري"
}
l_chn_no_rights_for_media = {
    "ru": "👩🏽‍💻 <b>Отсутствуют</b> административные права управления ботом: {0}-покидает канал",
    "en": "👩🏽‍💻 <b>Missing</b> administrative rights to manage the bot: {0} is leaving the channel",
    "es": "👩🏽‍💻 <b>No hay</b> derechos administrativos para gestionar el bot: {0} abandona el canal",
    "fr": "👩🏽‍💻 <b>Absence</b> des droits administratifs pour gérer le bot : {0} quitte le canal",
    "zh": "👩🏽‍💻 <b>缺少</b> 管理机器人权限：{0} 正在离开频道",
    "ar": "👩🏽‍💻 <b>لا توجد</b> صلاحيات إدارية لإدارة الروبوت: {0} يغادر القناة"
}

l_chn_collection_name = {
    "ru": "Коллекция постов канала",
    "en": "Channel posts collection",
    "es": "Colección de publicaciones del canal",
    "fr": "Collection de publications du canal",
    "zh": "频道帖子集合",
    "ar": "مجموعة منشورات القناة",
}
l_chn_collection_desc = {
    "ru": "Уникальные nft-посты, привязанные к реальным id-постам канала",
    "en": "Unique NFT posts linked to real channel post IDs",
    "es": "Publicaciones NFT únicas vinculadas a identificadores reales de publicaciones del canal",
    "fr": "Publications NFT uniques liées aux identifiants réels des publications du canal",
    "zh": "与频道真实帖子 ID 绑定的独特 NFT 帖子",
    "ar": "مشاركات NFT فريدة مرتبطة بمعرّفات المنشورات الحقيقية للقناة",
}
l_chn_collection_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> коллекции:",
    "en": "👩🏽‍💻 <b>Collection address</b>:",
    "es": "👩🏽‍💻 <b>Dirección</b> de la colección:",
    "fr": "👩🏽‍💻 <b>Adresse</b> de la collection:",
    "zh": "👩🏽‍💻 <b>集合地址</b>:",
    "ar": "👩🏽‍💻 <b>عنوان</b> المجموعة:",
}
l_chn_post_already_in_col = {
    "ru": "👩🏽‍💻 Пост уже в коллекции",
    "en": "👩🏽‍💻 Post already in collection",
    "es": "👩🏽‍💻 Publicación ya en la colección",
    "fr": "👩🏽‍💻 Publication déjà dans la collection",
    "zh": "👩🏽‍💻 帖子已在集合中",
    "ar": "👩🏽‍💻 المنشور موجود بالفعل في المجموعة",
}
l_chn_no_nft_logo = {
    "ru": "👩🏽‍💻 Генерация NFT-поста, повторите попытку позже",
    "en": "👩🏽‍💻 NFT post generation, please try again later",
    "es": "👩🏽‍💻 Generación de publicación NFT, intente de nuevo más tarde",
    "fr": "👩🏽‍💻 Génération de la publication NFT, veuillez réessayer plus tard",
    "zh": "👩🏽‍💻 NFT 帖子正在生成, пожалуйста попробуйте позже",
    "ar": "👩🏽‍💻 جاري إنشاء منشور NFT، الرجاء المحاولة لاحقًا",
}
l_chn_jetton_of_channel = {
    "ru": "Токен канала:",
    "en": "Channel token:",
    "es": "Token del canal:",
    "fr": "Jeton du canal:",
    "zh": "频道代币:",
    "ar": "رمز القناة:",
}
l_chn_jetton_master_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> мастера-токена:",
    "en": "👩🏽‍💻 <b>Master token address</b>:",
    "es": "👩🏽‍💻 <b>Dirección</b> maestra del token:",
    "fr": "👩🏽‍💻 <b>Adresse</b> du maître du jeton:",
    "zh": "👩🏽‍💻 <b>主代币地址</b>:",
    "ar": "👩🏽‍💻 <b>عنوان</b> التوكن الرئيسي:",
}
l_chn_detach = {
    "ru": "👩🏽‍💻 Открепить nft от",
    "en": "👩🏽‍💻 Detach NFT from",
    "es": "👩🏽‍💻 Desvincular NFT de",
    "fr": "👩🏽‍💻 Détacher le NFT de",
    "zh": "👩🏽‍💻 解除 NFT 与",
    "ar": "👩🏽‍💻 فصل NFT عن",
}
l_chn_err_transfer_rights = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> передачи прав: оба участника должны быть администраторами канала и запустить @{0}",
    "en": "👩🏽‍💻 <b>Error</b> transferring rights: both participants must be channel administrators and run @{0}",
    "es": "👩🏽‍💻 <b>Error</b> al transferir derechos: ambos participantes deben ser administradores del canal y ejecutar @{0}",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors du transfert des droits: les deux participants doivent être administrateurs du canal et lancer @{0}",
    "zh": "👩🏽‍💻 <b>错误</b> 转移权限：双方必须是频道管理员并运行 @{0}",
    "ar": "👩🏽‍💻 <b>خطأ</b> في نقل الحقوق: يجب أن يكون كلا المشاركين من مشرفي القناة وتشغيل @{0}",
}
# endregion


# region FereyGroupBot
l_grp_btn1 = {
    "ru": "➕ Группа",
    "en": "➕ Group",
    "es": "➕ Grupo",
    "fr": "➕ Groupe",
    "zh": "➕ 群组",
    "ar": "➕ مجموعة",
}
l_grp_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_grp_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> модерации <b>Telegram</b>-групп:\n\n<blockquote>▪️платная подписка и донаты\n▪️<b>голосование</b>/бан-ограничения\n▪️NFT-диалоги и блокчейн геймификация\n▪️нейро-диалог и стоп-слова\n▪️веб/платный постинг</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-application</i> moderation of <b>Telegram</b>-groups:\n\n<blockquote>▪️paid subscriptions and donations\n▪️ban/anti-flood organization\n▪️NFT-dialogs and blockchain gamification\n▪️neuro-dialog and stop-words\n▪️web/paid posting</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la moderación de <b>Telegram</b>-grupos vía <i>@tg-aplicación</i>:\n\n<blockquote>▪️suscripciones pagas y donaciones\n▪️organización de baneos/anti-flood\n▪️diálogos NFT y gamificación blockchain\n▪️neuro-diálogo y palabras prohibidas\n▪️publicaciones web/pagas</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans la modération des <b>Telegram</b>-groupes via l'<i>@tg-application</i> :\n\n<blockquote>▪️abonnements payants et dons\n▪️organisation des bans/anti-flood\n▪️dialogues NFT et gamification blockchain\n▪️neuro-dialogue et mots interdits\n▪️publication web/payante</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎使用 <i>@tg-应用</i> 对 <b>Telegram</b>-群组 进行管理：\n\n<blockquote>▪️付费订阅和捐赠\n▪️封禁/防刷 管理\n▪️NFT-对话 与 区块链 游戏化\n▪️神经对话 与 停用词\n▪️网页/付费 发布</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في إشراف <b>Telegram</b>-المجموعات عبر <i>@tg-تطبيق</i>:\n\n<blockquote>▪️الاشتراكات المدفوعة والتبرعات\n▪️تنظيم الحظر/مكافحة الفيضانات\n▪️حوارات NFT وألعاب البلوكتشين\n▪️الحوار العصبي والكلمات الموقوفة\n▪️النشر عبر الويب/مدفوع</blockquote>",
}
l_cmd_txt_grp = {
    "ru": "👩🏽‍💻 <b>Жми</b> [➕ Добавить группу]",
    "en": "👩🏽‍💻 <b>Click</b> [➕ Add group]",
    "es": "👩🏽‍💻 <b>Haga clic</b> [➕ Agregar grupo]",
    "fr": "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter un groupe]",
    "zh": "👩🏽‍💻 <b>点击</b> [➕ 添加群组]",
    "ar": "👩🏽‍💻 <b>انقر</b> [➕ إضافة مجموعة]",
}
l_add_group_text = {
    "ru": "👇🏽 <b>Жми</b> на [➕ Добавить группу], чтобы добавить в свою группу (с настройками по ум) бота: @{0}\n\n<blockquote>👮🏽‍♀️ <b>Или</b> добавь бота как [<b>Администратор</b>] через настройки своей группы:\n[👤 Добавить администратора]\n\n👮🏽‍♀️ <b>Если</b> не добавляется группа, то измени <b>Должность</b> (см. скрин)</blockquote>",
    "en": "👇🏽 <b>Click</b> on [➕ Add group] to add the bot to your group (with default settings): @{0}\n\n<blockquote>👮🏽‍♀️ <b>Or</b> add the bot as <b>Administrator</b> through your group's settings:\n[👤 Add administrator]\n\n👮🏽‍♀️ <b>If</b> the group is not added, change the <b>Role</b> (see screenshot)</blockquote>",
    "es": "👇🏽 <b>Haga clic</b> en [➕ Agregar grupo] para añadir el bot a su grupo (con configuración por defecto): @{0}\n\n<blockquote>👮🏽‍♀️ <b>O</b> añade el bot como <b>Administrador</b> desde la configuración de tu grupo:\n[👤 Agregar administrador]\n\n👮🏽‍♀️ <b>Si</b> el grupo no se añade, cambia la <b>Posición</b> (ver captura de pantalla)</blockquote>",
    "fr": "👇🏽 <b>Cliquez</b> sur [➕ Ajouter un groupe] pour ajouter le bot à votre groupe (avec paramètres par défaut) : @{0}\n\n<blockquote>👮🏽‍♀️ <b>Ou</b> ajoutez le bot en tant qu'<b>Administrateur</b> via les paramètres de votre groupe :\n[👤 Ajouter un administrateur]\n\n👮🏽‍♀️ <b>Si</b> le groupe n'est pas ajouté, modifiez la <b>Position</b> (voir capture d'écran)</blockquote>",
    "zh": "👇🏽 <b>点击</b> [➕ 添加群组] 将机器人添加到您的群组（默认设置）：@{0}\n\n<blockquote>👮🏽‍♀️ <b>或</b> 将机器人通过群组设置添加为 <b>管理员</b>：\n[👤 添加管理员]\n\n👮🏽‍♀️ <b>如果</b> 无法添加群组，请更改 <b>职务</b>（见截图）</blockquote>",
    "ar": "👇🏽 <b>انقر</b> على [➕ إضافة مجموعة] لإضافة الروبوت إلى مجموعتك (بإعدادات افتراضية): @{0}\n\n<blockquote>👮🏽‍♀️ <b>أو</b> أضف الروبوت كـ <b>مسؤول</b> عبر إعدادات مجموعتك:\n[👤 إضافة مسؤول]\n\n👮🏽‍♀️ <b>إذا</b> لم تُضاف المجموعة، فغيّر <b>المنصب</b> (انظر لقطة الشاشة)</blockquote>",
}
l_add_group_button = {
    "ru": "➕ Добавить группу",
    "en": "➕ Add group",
    "es": "➕ Agregar grupo",
    "fr": "➕ Ajouter un groupe",
    "zh": "➕ 添加群组",
    "ar": "➕ إضافة مجموعة",
}
l_grp_already_taken = {
    "ru": "👮🏽 <b>Группа</b> [<b>{0}</b>] уже <i>модерируется</i> в @{1}-боте",
    "en": "👮🏽 <b>Group</b> [<b>{0}</b>] is already <i>moderated</i> in @{1}-bot",
    "es": "👮🏽 <b>Grupo</b> [<b>{0}</b>] ya está <i>moderado</i> en @{1}-bot",
    "fr": "👮🏽 <b>Groupe</b> [<b>{0}</b>] est déjà <i>modéré</i> dans @{1}-bot",
    "zh": "👮🏽 <b>群组</b> [<b>{0}</b>] 已在 @{1}-bot 中 <i>被管理</i>",
    "ar": "👮🏽 <b>المجموعة</b> [<b>{0}</b>] مُدارة بالفعل في @{1}-بوت",
}
l_grp_subscribe_call = {
    "ru": "👩🏽‍💻 Необходима подписка на группу",
    "en": "👩🏽‍💻 Subscription to the group is required",
    "es": "👩🏽‍💻 Se requiere suscripción al grupo",
    "fr": "👩🏽‍💻 Abonnement au groupe requis",
    "zh": "👩🏽‍💻 需要群组订阅",
    "ar": "👩🏽‍💻 الاشتراك في المجموعة مطلوب",
}

l_groups = {
    "ru": "👩🏽‍💻 Группы",
    "en": "👩🏽‍💻 Groups",
    "es": "👩🏽‍💻 Grupos",
    "fr": "👩🏽‍💻 Groupes",
    "zh": "👩🏽‍💻 群组",
    "ar": "👩🏽‍💻 المجموعات"
}
l_add_grp_button = {
    "ru": "➕ Добавить группу",
    "en": "➕ Add group",
    "es": "➕ Agregar grupo",
    "fr": "➕ Ajouter un groupe",
    "zh": "➕ 添加群组",
    "ar": "➕ إضافة مجموعة"
}
l_add_grp_text = {
    "ru": "👮🏽‍♀️ <b>Добавь</b> @{0}-бота как [<b>Администратор</b>] через настройки своей группы:\n\n<blockquote>[👤 Добавить администратора]</blockquote>",
    "en": "👮🏽‍♀️ <b>Add</b> @{0}-bot as <b>Administrator</b> through your group settings:\n\n<blockquote>[👤 Add administrator]</blockquote>",
    "es": "👮🏽‍♀️ <b>Agrega</b> @{0}-bot como <b>Administrador</b> a través de la configuración de tu grupo:\n\n<blockquote>[👤 Agregar administrador]</blockquote>",
    "fr": "👮🏽‍♀️ <b>Ajoutez</b> @{0}-bot en tant qu'<b>Administrateur</b> via les paramètres de votre groupe :\n\n<blockquote>[👤 Ajouter un administrateur]</blockquote>",
    "zh": "👮🏽‍♀️ <b>添加</b> @{0}-bot 作为 <b>管理员</b>，通过您的群组设置：\n\n<blockquote>[👤 添加管理员]</blockquote>",
    "ar": "👮🏽‍♀️ <b>أضف</b> @{0}-bot كـ<b>مسؤول</b> عبر إعدادات مجموعتك:\n\n<blockquote>[👤 إضافة مسؤول]</blockquote>"
}
l_add_grp_txt_call = {
    "ru": "👮🏽‍♀️ Добавь @{0}-бота как Администратора через настройки своей группы: [👤Добавить администратора]",
    "en": "👮🏽‍♀️ Add @{0}-bot as Administrator through your group settings: [👤Add Admin]",
    "es": "👮🏽‍♀️ Agrega @{0}-bot como Administrador a través de la configuración de tu grupo: [👤Agregar administrador]",
    "fr": "👮🏽‍♀️ Ajoutez @{0}-bot en tant qu'administrateur via les paramètres de votre groupe : [👤Ajouter un administrateur]",
    "zh": "👮🏽‍♀️ 通过您的群组设置将 @{0}-bot 添加为管理员： [👤添加管理员]",
    "ar": "👮🏽‍♀️ أضف @{0}-bot كمسؤول من خلال إعدادات مجموعتك: [👤إضافة مسؤول]"
}
l_grp_check = {
    "ru": "👩🏽‍💻 <b>Добавь</b> @{0}-бота в группу для проверки подписки на нее. Отправь мне корректную ссылку на канал:",
    "en": "👩🏽‍💻 <b>Add</b> @{0}-bot to the group to check subscription to it. Send me the correct link to the channel:",
    "es": "👩🏽‍💻 <b>Agrega</b> @{0}-bot al grupo para verificar la suscripción. Envíame el enlace correcto al canal:",
    "fr": "👩🏽‍💻 <b>Ajoutez</b> @{0}-bot au groupe pour vérifier l'abonnement. Envoyez-moi le lien correct vers la chaîne :",
    "zh": "👩🏽‍💻 <b>添加</b> @{0}-bot 到群组以检查订阅。请发送给我正确的频道链接：",
    "ar": "👩🏽‍💻 <b>أضف</b> @{0}-bot إلى المجموعة للتحقق من الاشتراك فيها. أرسل لي الرابط الصحيح للقناة:"
}
l_grp_info_start1 = {
    "ru": "👩🏽‍💻 <b>Информация</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    "en": "👩🏽‍💻 <b>Information</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> members]{5}{6}{7}",
    "es": "👩🏽‍💻 <b>Información</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> miembros]{5}{6}{7}",
    "fr": "👩🏽‍💻 <b>Informations</b>\n\n<b>Nom</b> : {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> membres]{5}{6}{7}",
    "zh": "👩🏽‍💻 <b>信息</b>\n\n<b>名称</b>：{0} [id=<code>{1}</code>，<i>{2} {3}</i>，<u>{4}</u> 成员]{5}{6}{7}",
    "ar": "👩🏽‍💻 <b>المعلومات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>، <u>{4}</u> أعضاء]{5}{6}{7}"
}
l_grp_stat_start1 = {
    "ru": "👩🏽‍💻 <b>Аналитика</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    "en": "👩🏽‍💻 <b>Analytics</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> members]{5}{6}{7}",
    "es": "👩🏽‍💻 <b>Análisis</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> miembros]{5}{6}{7}",
    "fr": "👩🏽‍💻 <b>Analytics</b>\n\n<b>Nom</b> : {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> membres]{5}{6}{7}",
    "zh": "👩🏽‍💻 <b>分析</b>\n\n<b>名称</b>：{0} [id=<code>{1}</code>，<i>{2} {3}</i>，<u>{4}</u> 成员]{5}{6}{7}",
    "ar": "👩🏽‍💻 <b>التحليلات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>، <u>{4}</u> أعضاء]{5}{6}{7}"
}
l_grp_stat_start2 = {
    "ru": "\n<b>Ссылка</b>: {0}\n<b>Описание</b>: {1}\n<b>Привязанный канал</b>: <code>{2}</code>\n",
    "en": "\n<b>Link</b>: {0}\n<b>Description</b>: {1}\n<b>Linked channel</b>: <code>{2}</code>\n",
    "es": "\n<b>Enlace</b>: {0}\n<b>Descripción</b>: {1}\n<b>Canal vinculado</b>: <code>{2}</code>\n",
    "fr": "\n<b>Lien</b> : {0}\n<b>Description</b> : {1}\n<b>Chaîne liée</b> : <code>{2}</code>\n",
    "zh": "\n<b>链接</b>：{0}\n<b>说明</b>：{1}\n<b>关联频道</b>：<code>{2}</code>\n",
    "ar": "\n<b>الرابط</b>: {0}\n<b>الوصف</b>: {1}\n<b>القناة المرتبطة</b>: <code>{2}</code>\n"
}
l_grp_stat_start3 = {
    "ru": "\n<b>ID последнего поста</b>: {0}\n<b>Посты</b>: {1}\n<b>Реакции</b>: {2}\n<b>Просмотры</b>: {3}\n<b>кѻмментарии</b>: {4}\n<b>$кэштеги</b>: {5}\n<b>#hashtag</b>: {6}\n",
    "en": "\n<b>Last post ID</b>: {0}\n<b>Posts</b>: {1}\n<b>Reactions</b>: {2}\n<b>Views</b>: {3}\n<b>Comments</b>: {4}\n<b>$cashtags</b>: {5}\n<b>#hashtags</b>: {6}\n",
    "es": "\n<b>ID de la última publicación</b>: {0}\n<b>Publicaciones</b>: {1}\n<b>Reacciones</b>: {2}\n<b>Vistas</b>: {3}\n<b>Comentarios</b>: {4}\n<b>$cashtags</b>: {5}\n<b>#hashtags</b>: {6}\n",
    "fr": "\n<b>ID du dernier post</b> : {0}\n<b>Posts</b> : {1}\n<b>Réactions</b> : {2}\n<b>Vues</b> : {3}\n<b>Commentaires</b> : {4}\n<b>$cashtags</b> : {5}\n<b>#hashtags</b> : {6}\n",
    "zh": "\n<b>最后帖子 ID</b>：{0}\n<b>帖子</b>：{1}\n<b>反应</b>：{2}\n<b>观看次数</b>：{3}\n<b>评论</b>：{4}\n<b>$cashtags</b>：{5}\n<b>#hashtags</b>：{6}\n",
    "ar": "\n<b>معرف آخر منشور</b>: {0}\n<b>المنشورات</b>: {1}\n<b>التفاعلات</b>: {2}\n<b>المشاهدات</b>: {3}\n<b>التعليقات</b>: {4}\n<b>$cashtags</b>: {5}\n<b>#hashtags</b>: {6}\n"
}
l_grp_commands_handler = {
    "ru": "⚙️ <b>Команды</b> /cmd для [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info информация о группе\n/stat статистика\n\n/parse [1] база подписчиков/лайков поста #1\n/random [1] рандомный лайкнувший пост #1\n/podcast 1 1 анонс видео-подкаста\n<code>/clean</code> очистка от deleted/scam-аккаунтов и по [<b>🕵🏽 Авто-бан</b>] правилам\n/delete <code>FROM TO</code> удаление за период\n/channel NAME канал проверки подписки\n/transfer передача ADMIN-прав</blockquote>\n\n💨 <b>Подписка</b>: <i>{3}</i>",
    "en": "⚙️ <b>Commands</b> /cmd for [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info channel information\n/stat statistics\n\n/parse [1] subscriber/likes base for post #1\n/random [1] random user who liked post #1\n/podcast 1 1 video-podcast announcement\n<code>/clean</code> clearing deleted/scam accounts and according to [<b>🕵🏽 Auto-ban</b>] rules\n/delete <code>FROM TO</code> delete for a period\n/channel NAME channel for subscription check\n/transfer transfer of admin rights</blockquote>\n\n💨 <b>Subscription</b>: <i>{3}</i>",
    "es": "⚙️ <b>Comandos</b> /cmd para [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info información del canal\n/stat estadísticas\n\n/parse [1] base de suscriptores/likes del post #1\n/random [1] usuario aleatorio que dio like al post #1\n/podcast 1 1 anuncio de video-podcast\n<code>/clean</code> limpieza de cuentas eliminadas/estafa y según reglas de [<b>🕵🏽 Prohibición automática</b>]\n/delete <code>FROM TO</code> eliminar por un período\n/channel NAME canal para verificación de suscripción\n/transfer transferencia de derechos de administrador</blockquote>\n\n💨 <b>Suscripción</b>: <i>{3}</i>",
    "fr": "⚙️ <b>Commandes</b> /cmd pour [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info informations sur la chaîne\n/stat statistiques\n\n/parse [1] base d'abonnés/likes du post #1\n/random [1] utilisateur aléatoire ayant liké le post #1\n/podcast 1 1 annonce du podcast vidéo\n<code>/clean</code> suppression des comptes supprimés/arnaques et selon les règles de [<b>🕵🏽 Auto-ban</b>]\n/delete <code>FROM TO</code> supprimer pour une période\n/channel NAME canal de vérification d'abonnement\n/transfer transfert des droits administrateur</blockquote>\n\n💨 <b>Abonnement</b>: <i>{3}</i>",
    "zh": "⚙️ <b>命令</b> /cmd 用于 [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info 频道信息\n/stat 统计\n\n/parse [1] 订阅者/点赞 基础（帖子 #1）\n/random [1] 随机点赞帖子 #1 的用户\n/podcast 1 1 视频播客公告\n<code>/clean</code> 清除已删除/诈骗账户并根据 [<b>🕵🏽 自动封禁</b>] 规则\n/delete <code>FROM TO</code> 删除一段时间内的内容\n/channel NAME 订阅验证频道\n/transfer 管理权限转移</blockquote>\n\n💨 <b>订阅</b>: <i>{3}</i>",
    "ar": "⚙️ <b>الأوامر</b> /cmd لإحصائيات [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info معلومات القناة\n/stat إحصاءات\n\n/parse [1] قاعدة المشتركين/الإعجابات للمنشور #1\n/random [1] مستخدم عشوائي أعجب بالمنشور #1\n/podcast 1 1 إعلان بودكاست فيديو\n<code>/clean</code> مسح الحسابات المحذوفة/الاحتيالية ووفق قواعد [<b>🕵🏽 الحظر التلقائي</b>]\n/delete <code>FROM TO</code> الحذف لفترة\n/channel NAME قناة للتحقق من الاشتراك\n/transfer نقل حقوق المدير</blockquote>\n\n💨 <b>الاشتراك</b>: <i>{3}</i>"
}
l_change_grp_info = {
    "ru": "Изменение профиля группы",
    "en": "Changing group profile",
    "es": "Cambio del perfil del grupo",
    "fr": "Modification du profil du groupe",
    "zh": "更改群组配置文件",
    "ar": "تغيير ملف تعريف المجموعة"
}
l_grp_graph_yes = {
    "ru": "👩🏽‍💻 <b>Экстра</b>-статистика группы за неделю [{0}]\n\n▪️ Подписчики: {1} ({2}{3})\n▪️ Просмотры: {4} ({5}{6})\n▪️ Поделиться: {7} ({8}{9})\n▪️ Уведомления у {10}% подписчиков\n",
    "en": "👩🏽‍💻 <b>Extra</b>-group statistics for the week [{0}]\n\n▪️ Subscribers: {1} ({2}{3})\n▪️ Views: {4} ({5}{6})\n▪️ Shares: {7} ({8}{9})\n▪️ Notifications enabled for {10}% of subscribers\n",
    "es": "👩🏽‍💻 Estadísticas <b>extra</b> del grupo para la semana [{0}]\n\n▪️ Suscriptores: {1} ({2}{3})\n▪️ Vistas: {4} ({5}{6})\n▪️ Compartidos: {7} ({8}{9})\n▪️ Notificaciones activadas para el {10}% de suscriptores\n",
    "fr": "👩🏽‍💻 Statistiques <b>supplémentaires</b> du groupe pour la semaine [{0}]\n\n▪️ Abonnés : {1} ({2}{3})\n▪️ Vues : {4} ({5}{6})\n▪️ Partages : {7} ({8}{9})\n▪️ Notifications activées pour {10}% des abonnés\n",
    "zh": "👩🏽‍💻 <b>额外</b>-群组周统计 [{0}]\n\n▪️ 订阅者：{1} ({2}{3})\n▪️ 观看次数：{4} ({5}{6})\n▪️ 分享：{7} ({8}{9})\n▪️ 已为 {10}% 订阅者开启通知\n",
    "ar": "👩🏽‍💻 إحصائيات المجموعة <b>الإضافية</b> للأسبوع [{0}]\n\n▪️ المشتركون: {1} ({2}{3})\n▪️ المشاهدات: {4} ({5}{6})\n▪️ المشاركات: {7} ({8}{9})\n▪️ الإشعارات مفعّلة لدى {10}% من المشتركين\n"
}
l_grp_graph_no = {
    "ru": "👩🏽‍💻 <b>Вкл</b> [✅ Назначение администраторов] для @{0}, чтобы вывести <b>экстра</b>-графику группы за неделю",
    "en": "👩🏽‍💻 Turn <b>On</b> [✅ Assign administrators] for @{0} to display <b>extra</b>-group graphics for the week",
    "es": "👩🏽‍💻 Activa <b>Asignar administradores</b> para @{0} para mostrar gráficos <b>adicionales</b> del grupo para la semana",
    "fr": "👩🏽‍💻 Activez <b>Attribution d'administrateurs</b> pour @{0} afin d'afficher les graphiques <b>supplémentaires</b> du groupe pour la semaine",
    "zh": "👩🏽‍💻 为 @{0} <b>开启</b> [✅ 分配管理员]，以显示本周的<b>额外</b>群组图表",
    "ar": "👩🏽‍💻 قم <b>بتشغيل</b> [✅ تعيين مسؤولين] لـ @{0} لعرض رسوم المجموعة <b>الإضافية</b> لهذا الأسبوع"
}
l_grp_boost_call = {
    "ru": "👩🏽‍💻 Необходим буст-голос за группу",
    "en": "👩🏽‍💻 A boost vote for the group is required",
    "es": "👩🏽‍💻 Se requiere un voto de impulso para el grupo",
    "fr": "👩🏽‍💻 Un vote de boost pour le groupe est requis",
    "zh": "👩🏽‍💻 需要为群组投票提升",
    "ar": "👩🏽‍💻 مطلوب تصويت تعزيز للمجموعة"
}
l_grp_need_sub_for_more_than_1_grp = {
    "ru": "👩🏽‍💻 <b>Оформи</b> подписку, чтобы добавлять более 1 группы",
    "en": "👩🏽‍💻 <b>Get</b> a subscription to add more than 1 group",
    "es": "👩🏽‍💻 <b>Obtén</b> una suscripción para añadir más de 1 grupo",
    "fr": "👩🏽‍💻 <b>Obtenez</b> un abonnement pour ajouter plus d'1 groupe",
    "zh": "👩🏽‍💻 <b>购买</b>订阅以添加超过 1 个群组",
    "ar": "👩🏽‍💻 <b>اشترك</b> للحصول على إمكانية إضافة أكثر من مجموعة واحدة"
}
l_grp_need_sub_for_more_than_2_grp = {
    "ru": "👩🏽‍💻 <b>Оформи</b> подписку, чтобы добавлять более 2 групп",
    "en": "👩🏽‍💻 <b>Get</b> a subscription to add more than 2 groups",
    "es": "👩🏽‍💻 <b>Obtén</b> una suscripción para añadir más de 2 grupos",
    "fr": "👩🏽‍💻 <b>Obtenez</b> un abonnement pour ajouter plus de 2 groupes",
    "zh": "👩🏽‍💻 <b>购买</b>订阅以添加超过 2 个群组",
    "ar": "👩🏽‍💻 <b>اشترك</b> للحصول على إمكانية إضافة أكثر من مجموعتين"
}

l_grp_delete_parse = {
    "ru": "👩🏽‍💻 <b>Введи</b> дату начала/конца для удаления подписчиков из /parse-базы:\n<code>/delete {0} {1}</code>",
    "en": "👩🏽‍💻 <b>Enter</b> the start/end date to delete subscribers from the /parse database:\n<code>/delete {0} {1}</code>",
    "es": "👩🏽‍💻 <b>Introduce</b> la fecha de inicio/fin para eliminar suscriptores de la base /parse:\n<code>/delete {0} {1}</code>",
    "fr": "👩🏽‍💻 <b>Entrez</b> la date de début/fin pour supprimer des abonnés de la base /parse :\n<code>/delete {0} {1}</code>",
    "zh": "👩🏽‍💻 <b>输入</b>开始/结束日期以从 /parse 数据库中删除订阅者：\n<code>/delete {0} {1}</code>",
    "ar": "👩🏽‍💻 <b>أدخل</b> تاريخ البدء/النهاية لحذف المشتركين من قاعدة /parse:\n<code>/delete {0} {1}</code>"
}
l_grp_delete_start = {
    "ru": "👩🏽‍💻 <b>Начинаем</b> удаление за период:\n<code>{0}</code>\n<code>{1}</code>",
    "en": "👩🏽‍💻 <b>Starting</b> deletion for the period:\n<code>{0}</code>\n<code>{1}</code>",
    "es": "👩🏽‍💻 <b>Comenzamos</b> la eliminación para el período:\n<code>{0}</code>\n<code>{1}</code>",
    "fr": "👩🏽‍💻 <b>Nous commençons</b> la suppression pour la période :\n<code>{0}</code>\n<code>{1}</code>",
    "zh": "👩🏽‍💻 <b>开始</b>按期间删除：\n<code>{0}</code>\n<code>{1}</code>",
    "ar": "👩🏽‍💻 <b>نبدأ</b> بحذف الفترة:\n<code>{0}</code>\n<code>{1}</code>"
}
l_grp_delete_finish = {
    "ru": "👩🏽‍💻 <b>Удаление</b> пользователей завершено:\n<u>{0}</u> [-{1}]",
    "en": "👩🏽‍💻 <b>Deletion</b> of users completed:\n<u>{0}</u> [-{1}]",
    "es": "👩🏽‍💻 <b>Eliminación</b> de usuarios completada:\n<u>{0}</u> [-{1}]",
    "fr": "👩🏽‍💻 <b>Suppression</b> des utilisateurs terminée :\n<u>{0}</u> [-{1}]",
    "zh": "👩🏽‍💻 <b>删除</b>用户已完成：\n<u>{0}</u> [-{1}]",
    "ar": "👩🏽‍💻 <b>حذف المستخدمين</b> اكتمل:\n<u>{0}</u> [-{1}]"
}
l_ccheck_add_group = {
    "ru": "👮🏽 Для <i>проверки подписки</i> необходимо добавить группу командой:\n\n/group ССЫЛКА НА ГРУППУ",
    "en": "👮🏽 To <i>check subscription</i> you need to add a group with the command:\n\n/group LINK TO GROUP",
    "es": "👮🏽 Para <i>verificar suscripción</i> necesitas agregar un grupo con el comando:\n\n/group ENLACE AL GRUPO",
    "fr": "👮🏽 Pour <i>vérifier l'abonnement</i> vous devez ajouter un groupe avec la commande :\n\n/group LIEN VERS LE GROUPE",
    "zh": "👮🏽 要<i>检查订阅</i>，需要使用以下命令添加群组：\n\n/group 群组链接",
    "ar": "👮🏽 من أجل <i>التحقق من الاشتراك</i> يجب إضافة مجموعة باستخدام الأمر:\n\n/group رابط المجموعة"
}
l_grp_for_sub_pay = {
    "ru": "👩🏽‍💻 Для оплаты подписки",
    "en": "👩🏽‍💻 For subscription payment",
    "es": "👩🏽‍💻 Para el pago de la suscripción",
    "fr": "👩🏽‍💻 Pour le paiement de l'abonnement",
    "zh": "👩🏽‍💻 用于订阅付款",
    "ar": "👩🏽‍💻 لدفع الاشتراك"
}
l_grp_need_boost_for_story = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: {0}-буст-голосов для публикации сториз",
    "en": "👩🏽‍💻 <b>Required</b>: {0}-boost-votes to publish stories",
    "es": "👩🏽‍💻 <b>Necesario</b>: {0}-boost-votos para publicar historias",
    "fr": "👩🏽‍💻 <b>Nécessaire</b> : {0}-boost-votes pour publier des stories",
    "zh": "👩🏽‍💻 <b>需要</b>：{0}-boost 投票以发布故事",
    "ar": "👩🏽‍💻 <b>مطلوب</b>: {0}-boost-أصوات لنشر الستوري"
}
l_grp_no_rights_for_media = {
    "ru": "👩🏽‍💻 <b>Отсутствуют</b> административные права управления ботом: {0}-покидает группу",
    "en": "👩🏽‍💻 <b>Missing</b> administrative rights to manage the bot: {0} is leaving the group",
    "es": "👩🏽‍💻 <b>No hay</b> derechos administrativos para gestionar el бot: {0} abandona el grupo",
    "fr": "👩🏽‍💻 <b>Absence</b> des droits administratifs pour gérer le bot : {0} quitte le groupe",
    "zh": "👩🏽‍💻 <b>缺少</b> 管理机器人权限：{0} 正在离开群组",
    "ar": "👩🏽‍💻 <b>لا توجد</b> صلاحيات إدارية لإدارة الروبوت: {0} يغادر المجموعة"
}
l_grp_collection_name = {
    "ru": "Коллекция NFT-диалогов группы",
    "en": "Group NFT-dialogs collection",
    "es": "Colección de diálogos NFT del grupo",
    "fr": "Collection de dialogues NFT du groupe",
    "zh": "群组的 NFT 对话集合",
    "ar": "مجموعة حوارات NFT للمجموعة"
}
l_grp_collection_desc = {
    "ru": "NFT-диалоги, привязанные к реальным сообщениям группы",
    "en": "NFT-dialogs linked to real group messages",
    "es": "Diálogos NFT vinculados a mensajes reales del grupo",
    "fr": "Dialogues NFT liés aux messages réels du groupe",
    "zh": "与群组真实消息关联的 NFT 对话",
    "ar": "حوارات NFT مرتبطة بالرسائل الحقيقية للمجموعة"
}

l_grp_collection_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> коллекции:",
    "en": "👩🏽‍💻 <b>Collection address</b>:",
    "es": "👩🏽‍💻 <b>Dirección</b> de la colección:",
    "fr": "👩🏽‍💻 <b>Adresse</b> de la collection:",
    "zh": "👩🏽‍💻 <b>集合地址</b>:",
    "ar": "👩🏽‍💻 <b>عنوان</b> المجموعة:",
}
l_grp_post_already_in_col = {
    "ru": "👩🏽‍💻 NFT-диалог уже в коллекции",
    "en": "👩🏽‍💻 NFT-dialog already in collection",
    "es": "👩🏽‍💻 NFT-diálogo ya en la colección",
    "fr": "👩🏽‍💻 NFT-dialogue déjà dans la collection",
    "zh": "👩🏽‍💻 NFT-对话已在集合中",
    "ar": "👩🏽‍💻 NFT-حوار موجود بالفعل في المجموعة",
}
l_grp_no_nft_logo = {
    "ru": "👩🏽‍💻 Генерация NFT-диалогов, повторите попытку позже",
    "en": "👩🏽‍💻 NFT-dialog generation, please try again later",
    "es": "👩🏽‍💻 Generación de diálogos NFT, inténtelo de nuevo más tarde",
    "fr": "👩🏽‍💻 Génération des dialogues NFT, veuillez réessayer plus tard",
    "zh": "👩🏽‍💻 NFT 对话正在生成，请稍后重试",
    "ar": "👩🏽‍💻 جاري إنشاء محادثات NFT، الرجاء المحاولة لاحقًا",
}
l_grp_jetton_of_group = {
    "ru": "Токен группы:",
    "en": "Group token:",
    "es": "Token del grupo:",
    "fr": "Jeton du groupe:",
    "zh": "群组代币:",
    "ar": "رمز المجموعة:",
}
l_grp_jetton_master_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> мастера-токена:",
    "en": "👩🏽‍💻 <b>Master token address</b>:",
    "es": "👩🏽‍💻 <b>Dirección</b> maestra del token:",
    "fr": "👩🏽‍💻 <b>Adresse</b> du maître du jeton:",
    "zh": "👩🏽‍💻 <b>主代币地址</b>:",
    "ar": "👩🏽‍💻 <b>عنوان</b> التوكن الرئيسي:",
}
l_grp_detach = {
    "ru": "👩🏽‍💻 Открепить NFT от",
    "en": "👩🏽‍💻 Detach NFT from",
    "es": "👩🏽‍💻 Desvincular NFT de",
    "fr": "👩🏽‍💻 Détacher le NFT de",
    "zh": "👩🏽‍💻 解除 NFT 与",
    "ar": "👩🏽‍💻 فصل NFT عن",
}
l_grp_err_transfer_rights = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> передачи прав: оба участника должны быть администраторами группы и запустить @{0}",
    "en": "👩🏽‍💻 <b>Error</b> transferring rights: both participants must be group administrators and run @{0}",
    "es": "👩🏽‍💻 <b>Error</b> al transferir derechos: ambos participantes deben ser administradores del grupo y ejecutar @{0}",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors du transfert des droits : les deux participants doivent être administrateurs du groupe et lancer @{0}",
    "zh": "👩🏽‍💻 <b>错误</b> 转移权限：双方必须是群组管理员并运行 @{0}",
    "ar": "👩🏽‍💻 <b>خطأ</b> في نقل الحقوق: يجب أن يكون كلا المشاركين من مشرفي المجموعة وتشغيل @{0}",
}
l_payment_check_token_grp = {
    "ru": "👩🏽‍💻 <b>Проверьте</b> свой токен для получения платажей (бот для приема платежей также должен быть Администратором группы)",
    "en": "👩🏽‍💻 <b>Check</b> your token to receive payments (the payment bot must also be an Administrator of the group)",
    "es": "👩🏽‍💻 <b>Verifique</b> su token para recibir pagos (el bot de pagos también debe ser administrador del grupo)",
    "fr": "👩🏽‍💻 <b>Vérifiez</b> votre jeton pour recevoir des paiements (le bot de paiement doit également être administrateur du groupe)",
    "zh": "👩🏽‍💻 <b>检查</b>您的令牌以接收付款（支付机器人也必须是群组管理员）",
    "ar": "👩🏽‍💻 <b>تحقق</b> من رمزك لتلقي المدفوعات (يجب أن يكون بوت الدفع أيضًا مسؤولاً عن المجموعة)",
}
l_from_group = {
    "ru": "из группы",
    "en": "from group",
    "es": "del grupo",
    "fr": "du groupe",
    "zh": "来自群组",
    "ar": "من المجموعة",
}

l_hand_msg_len = {
    'ru': "<blockquote>👩🏽‍💻 <b>Сообщение</b> более {0} символов</blockquote>",
    'en': "👩🏽‍💻 <b>Message</b> more than {0} characters",
    'es': "👩🏽‍💻 <b>Mensaje</b> más de {0} caracteres",
    'fr': "👩🏽‍💻 <b>Message</b> de plus de {0} caractères",
    'zh': "👩🏽‍💻<b>消息</b>超过 {0} 个字符",
    'ar': "👩🏽‍💻 <b>الرسالة</b> أكثر من {0} حرف",
}
l_hand_msg_timer = {
    'ru': "<blockquote>👩🏽‍💻 <b>Кѻмментарий</b> написан слишком быстро</blockquote>",
    'en': "👩🏽‍💻 <b>Comment</b> written too quickly",
    'es': "👩🏽‍💻 <b>Comentario</b> escrito demasiado rápido",
    'fr': "👩🏽‍💻 <b>Commentaire</b> écrit trop vite",
    'zh': "👩🏽‍💻<b>评论</b>写得太快",
    'ar': "👩🏽‍💻 <b>التعليق</b> مكتوب بسرعة كبيرة",
}
l_hand_msg_flood = {
    'ru': "<blockquote>💬 <i>Флуд</i>-сообщения</blockquote>",
    'en': "💬 <i>Flood</i>-messages",
    'es': "💬 <i>Inundación</i>-mensajes",
    'fr': "💬 <i>Inondations</i>-messages",
    'zh': "💬<i>洪水</i>-消息",
    'ar': "💬<i>الفيضانات</i>-رسائل",
}
l_hand_msg_via_bot = {
    'ru': "<blockquote>🔗 <b>Сообщения</b> <i>от имени бота</i> не разрешены</blockquote>",
    'en': "🔗 <b>Messages</b> <i>on behalf of a bot</i> are not allowed",
    'es': "🗣 <b>Mensajes</b> <i>en nombre de un bot</i> no están permitidos",
    'fr': "🗣 Les <b>Messages</b> <i>de la part d'un bot</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b> <i>代表机器人</i>",
    'ar': "🗣 <b>الرسائل</b> <i>بالنيابة عن الروبوت</i> غير مسموح بها",
}
l_hand_msg_channel = {
    'ru': "<blockquote>🫥 <b>Сообщения</b> <i>от имени канала</i> не разрешены</blockquote>",
    'en': "🫥 <b>Messages</b> <i>on behalf of the channel</i> are not allowed",
    'es': "🫥 <b>Mensajes</b> <i>en nombre del canal</i> no están permitidos",
    'fr': "🫥 Les <b>Messages</b> <i>au nom de la chaîne</i> ne sont pas autorisés",
    'zh': "🫥 不允许<b>消息</b> <i>代表频道</i>",
    'ar': "🫥 <b>الرسائل</b> <i>بالنيابة عن القناة</i> غير مسموح بها",
}
l_hand_msg_emoji = {
    'ru': "<blockquote>🫥 <b>Сообщения</b> <i>c эмоджи</i> не разрешены</blockquote>",
    'en': "🫥 <b>Messages</b> <i>with emoji</i> are not allowed",
    'es': "🗣 <b>Mensajes</b> <i>con emoji</i> no están permitidos",
    'fr': "🗣 Les <b>Messages</b> <i>avec emoji</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b> <i>带有表情符号</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على رموز تعبيرية</i> غير مسموح بها",
}
l_hand_msg_http = {
    'ru': "<blockquote>🔗 <b>Сообщения</b> <i>c внешними ссылками</i> не разрешены</blockquote>",
    'en': "🔗 <b>Messages</b> <i>with external links</i> are not allowed",
    'es': "🔗 No se permiten <b>Mensajes</b> <i>con enlaces externos</i>",
    'fr': "🔗 Les <b>Messages</b> <i>avec des liens externes</i> ne sont pas autorisés",
    'zh': "🔗 不允许<b>消息</b> <i>带有外部链接</i>",
    'ar': "🔗 <b>الرسائل</b> <i>ذات الروابط الخارجية</i> غير مسموح بها",
}
l_hand_msg_telegram = {
    'ru': "<blockquote>🔗 <b>Сообщения</b> <i>c телеграм-ссылками</i> не разрешены</blockquote>",
    'en': "🔗 <b>Messages</b> <i>with telegram links</i> are not allowed",
    'es': "🔗 No se permiten <b>Mensajes</b> <i>con enlaces de Telegram</i>",
    'fr': "🔗 Les <b>Messages</b> <i>avec des liens de télégramme</i> ne sont pas autorisés",
    'zh': "🔗 不允许<b>消息</b> <i>带有电报链接</i>",
    'ar': "🔗 <b>الرسائل</b> <i>التي تحتوي على روابط تيليجرام</i> غير مسموح بها",
}
l_hand_msg_forward = {
    'ru': "<blockquote>🔗 <b>Сообщения</b> <i>c форвард-ссылками</i> не разрешены</blockquote>",
    'en': "🔗 <b>Messages</b> <i>with forward links</i> are not allowed",
    'es': "🔗 No se permiten <b>Mensajes</b> <i>con enlaces directos</i>",
    'fr': "🔗 Les <b>Messages</b> <i>avec liens de transfert</i> ne sont pas autorisés",
    'zh': "🔗 不允许<b>消息</b> <i>带有转发链接</i>",
    'ar': "🔗 <b>الرسائل</b> <i>ذات الروابط الأمامية</i> غير مسموح بها",
}
l_hand_msg_zalgo = {
    'ru': "<blockquote>文 <b>Сообщения</b> <i>c <a href='https://www.zalgo.org'>zalgo-символами</a></i> не разрешены</blockquote>",
    'en': "文 <b>Messages</b> <i>c <a href=' https://www.zalgo.org '> zalgo-characters</a></i> are not allowed",
    'es': "文 <b>Mensajes</b> <i>c <a href=' https://www.zalgo.org '> caracteres-zalgo</a></i> no están permitidos",
    'fr': "文 <b>Messages</b> <i>c <a href=' https://www.zalgo.org '> les caractères zalgo</a></i> ne sont pas autorisés",
    'zh': "文 <b>消息</b> <i>c <a href=' https://www.zalgo.org '> zalgo-characters</a></i> 不允许",
    'ar': "文 <b>الرسائل</b> <i>c <a href=' https://www.zalgo.org '> zalgo-characters</a></i> غير مسموح بها",
}
l_hand_msg_symbols = {
    'ru': "<blockquote>文 <b>Сообщения</b> <i>c 文ب-glyth символами</i> не разрешены</blockquote>",
    'en': "文 <b>Messages</b> <i>with 文ب-alphabets</i> are not allowed",
    'es': "文 <b>Mensajes</b> <i>con 文ب-alfabetos</i> no están permitidos",
    'fr': "文 <b>Les messages</b> <i>avec les alphabets 文ب</i> ne sont pas autorisés",
    'zh': "不允许使用带有文巴字母的<b>消息</b><i>",
    'ar': "文 <b>الرسائل</b> <i>التي تحتوي على حروف 文ب</i> غير مسموح بها",
}
l_hand_msg_stop = {
    'ru': "<blockquote>🧾 <b>Сообщение</b> содержит <i>стоп-слова</i></blockquote>",
    'en': "🧾 <b>Message</b> contains <i>safe words</i>",
    'es': "🧾 El <b>Mensaje</b> contiene <i>palabras seguras</i>",
    'fr': "🧾 <b>Le message</b> contient des <i>mots sûrs</i>",
    'zh': "🧾<b>消息</b>包含<i>安全词</i>",
    'ar': "🧾 <b>الرسالة</b> تحتوي على <i>كلمات آمنة</i>",
}
l_hand_msg_edit = {
    'ru': "<blockquote>👥 <b>Редактирование</b> сообщений не разрешено</blockquote>",
    'en': "👥 <b>Editing</b> messages is not allowed",
    'es': "👥 No se permite <b>editar</b> mensajes",
    'fr': "👥 <b>Modifier</b> les messages n'est pas autorisé",
    'zh': "👥 不允许<b>编辑</b>消息",
    'ar': "👥 <b>تحرير</b> الرسائل غير مسموح به",
}
l_ccomment_button = {
    'ru': "🪙 Оплата кѻмментов",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_content_types_invite_user_bot = {
    'ru': "<blockquote>🚶🏽 <b>Приглашение</b> @username/@name_bot не разрешено</blockquote>",
    'en': "🚶🏽 <b>Invite</b> @username / @name_bot not allowed",
    'es': "🚶🏽 <b>Invitar</b> @username / @name_bot no permitido",
    'fr': "🚶🏽 <b>Inviter</b> @username / @name_bot non autorisé",
    'zh': "🚶🏽 <b>邀请</b> @username / @name_bot不允许",
    'ar': "🚶🏽 <b>دعوة</b> @username / @name_bot غير مسموح بها",
}
l_content_types_invite_user = {
    'ru': "<blockquote>🚶🏽 <b>Приглашение</b> @username не разрешено</blockquote>",
    'en': "🚶🏽 <b>Invite</b> @username not allowed",
    'es': "🚶🏽 <b>Invitar</b> @username no permitido",
    'fr': "🚶🏽 <b>Inviter</b> @username non autorisé",
    'zh': "🚶🏽 <b>邀请</b> @username不允许",
    'ar': "🚶🏽 <b>الدعوة</b> @username غير مسموح به",
}
l_content_types_invite_bot = {
    'ru': "<blockquote>🚶🏽 <b>Приглашение</b> @name_bot не разрешено</blockquote>",
    'en': "🚶🏽 <b>Invitation</b> @name_bot is not allowed",
    'es': "🚶🏽 <b>Invitación</b> @name_bot no está permitida",
    'fr': "🚶🏽 <b>Invitation</b> @name_bot n'est pas autorisé",
    'zh': "🚶🏽 不允许<b>邀请</b> @name_bot",
    'ar': "🚶🏽 <b>الدعوة</b> @name_bot غير مسموح بها",
}
l_content_types_button = {
    'ru': "<blockquote>👮🏽 {0}, <b>жми</b> на кнопку, чтобы вс︎тупить в группу</blockquote>",
    'en': "👮🏽 {0}, <b>click</b> the button to join the group",
    'es': "👮🏽 {0}, <b>haz clic</b> en el botón para unirte al grupo",
    'fr': "👮🏽 {0}, <b>cliquez</b> sur le bouton pour rejoindre le groupe",
    'zh': "👮🏽 {0}，<b>点击</b>按钮加入群组",
    'ar': "👮🏽 {0}, <b>انقر</b> على الزر للانضمام إلى المجموعة",
}
l_content_types_captcha = {
    'ru': "<blockquote>👮🏽 {0}, выбери <i>правильный вариант</i> ответа, чтобы вс︎тупить в группу:\n\n{1}</blockquote>",
    'en': "👮🏽 {0}, choose the <i>correct</i> answer to join the group:\n\n{1}",
    'es': "👮🏽 {0}, elige la respuesta <i>correcta</i> para unirte al grupo:\n\n{1}",
    'fr': "👮🏽 {0}, choisissez la réponse <i>bonne</i> pour rejoindre le groupe :\n\n{1}",
    'zh': "👮🏽 {0}，选择<i>正确</i>答案加入群组：\n\n{1}",
    'ar': "👮🏽 {0}، اختر الإجابة <i>الصحيحة</i> للانضمام إلى المجموعة:\n\n{1}",
}
l_hand_msg_FLOOD_USERNAME = {
    'ru': "<blockquote>💬 <b>Пользователь</b> @{0} изменил <b>name/@username</b>! Возможно, шпион!</blockquote>",
    'en': "💬 <b>User</b> @{0} changed <b>name/ @username </b>! Possibly a spy!",
    'es': "💬 ¡El <b>Usuario</b> @{0} cambió <b>nombre/ @username </b>! ¡Posiblemente un espía!",
    'fr': "💬 <b>Utilisateur</b> @{0} a changé <b>nom/ @username </b> ! Peut-être un espion !",
    'zh': "💬<b>用户</b>@{0}更改了<b>名称/ @username </b>！可能是间谍！",
    'ar': "💬 قام <b>المستخدم</b> @{0} بتغيير <b>الاسم/ @username </b>! ربما جاسوس!",
}
l_grp_vote = {
    'ru': "🪻 Голосование",
    'en': "🪻 Vote",
    'es': "👩🏽‍💻 <b>Mensaje</b> más de {0} caracteres",
    'fr': "👩🏽‍💻 <b>Message</b> de plus de {0} caractères",
    'zh': "👩🏽‍💻<b>消息</b>超过 {0} 个字符",
    'ar': "👩🏽‍💻 <b>الرسالة</b> أكثر من {0} حرف",
}
l_grp_no_original_group_id = {
    'ru': "🫧 <b>Все классно</b>! Но не удается найти идентификатор группы. Возможные решения:\n\n<blockquote>▪️ проверить наличие @FereyGroupBot в группе с правами [Администратор]\n▪️ в пересылаемые сообщения добавить хотя бы одно ‘свежее’ сообщение с текстом (потом его можно будет удалить)\n▪️ для создания любых NFT-далогов без группы (в том числе приватных) можно сделать пересылку в @FereyTONestBot</blockquote>",
    'en': "👩🏽‍💻 <b>Message</b> more than {0} characters",
    'es': "👩🏽‍💻 <b>Mensaje</b> más de {0} caracteres",
    'fr': "👩🏽‍💻 <b>Message</b> de plus de {0} caractères",
    'zh': "👩🏽‍💻<b>消息</b>超过 {0} 个字符",
    'ar': "👩🏽‍💻 <b>الرسالة</b> أكثر من {0} حرف",
}
l_grp_no_collection_addr = {
    'ru': "🫧 <b>Необходимо</b> сообщить владельцу группы, чтобы он создал в разделе [NFT-диалог] коллекцию, иначе пользователи не смогут превратить пересланные сообщения в NFT",
    'en': "👩🏽‍💻 <b>Message</b> more than {0} characters",
    'es': "👩🏽‍💻 <b>Mensaje</b> más de {0} caracteres",
    'fr': "👩🏽‍💻 <b>Message</b> de plus de {0} caractères",
    'zh': "👩🏽‍💻<b>消息</b>超过 {0} 个字符",
    'ar': "👩🏽‍💻 <b>الرسالة</b> أكثر من {0} حرف",
}

l_ban_handler = {
    'ru': "<blockquote>🪦 <b>Пользователь</b> {0} в /ban-списке на {1}</blockquote>",
    'en': "🪦 <b>User</b> {0} in /ban list on {1}",
    'es': "🪦 <b>Usuario</b> {0} en la lista /ban en {1}",
    'fr': "🪦 <b>Utilisateur</b> {0} dans la liste /ban sur {1}",
    'zh': "🪦 <b>用户</b> {0} 在 {1} 的 /ban 列表中",
    'ar': "🪦 <b>المستخدم</b> {0} في قائمة /الحظر في {1}",
}
l_ban_handler_chn = {
    'ru': "<blockquote>🪦 <b>Канал</b> <b>{0}</b> в /ban-списке на {1}</blockquote>",
    'en': "🪦 <b>User</b> {0} in /ban list on {1}",
    'es': "🪦 <b>Usuario</b> {0} en la lista /ban en {1}",
    'fr': "🪦 <b>Utilisateur</b> {0} dans la liste /ban sur {1}",
    'zh': "🪦 <b>用户</b> {0} 在 {1} 的 /ban 列表中",
    'ar': "🪦 <b>المستخدم</b> {0} في قائمة /الحظر في {1}",
}
l_ban_error = {
    'ru': "<blockquote>🪦 <b>Формат</b> /ban-команды: /ban (1m|1h|10d)</blockquote>",
    'en': "🪦 <b>Format</b> /ban commands: /ban (1m|1h|10d)",
    'es': "🪦 <b>Formato</b> comandos /ban: /ban (1m|1h|10d)",
    'fr': "🪦 <b>Format</b> commandes /ban : /ban (1m|1h|10j)",
    'zh': "🪦 <b>格式</b> /ban 命令：/ban (1m|1h|10d)",
    'ar': "🪦 أوامر <b>التنسيق</b> /ban: /ban (1m|1h|10d)",
}
l_ban_unban = {
    'ru': "<blockquote>🪦 <b>Пользователь</b> {0} удален из /ban-списка</blockquote>",
    'en': "🪦 <b>User</b> {0} removed from /ban list",
    'es': "🪦 <b>Usuario</b> {0} eliminado de la lista /ban",
    'fr': "🪦 <b>Utilisateur</b> {0} supprimé de la liste /ban",
    'zh': "🪦 <b>用户</b> {0} 已从/禁止列表中删除",
    'ar': "🪦 تمت إزالة <b>المستخدم</b> {0} من قائمة / الحظر",
}
l_ban_unban_chn = {
    'ru': "<blockquote>🪦 <b>Канал</b> <b>{0}</b> удален из /ban-списка</blockquote>",
    'en': "🪦 <b>User</b> {0} removed from /ban list",
    'es': "🪦 <b>Usuario</b> {0} eliminado de la lista /ban",
    'fr': "🪦 <b>Utilisateur</b> {0} supprimé de la liste /ban",
    'zh': "🪦 <b>用户</b> {0} 已从/禁止列表中删除",
    'ar': "🪦 تمت إزالة <b>المستخدم</b> {0} من قائمة / الحظر",
}
l_mute_handler = {
    'ru': "<blockquote>💤 <b>Пользователь</b> {0} обеззвучен на {1}</blockquote>",
    'en': "💤 <b>User</b> {0} muted on {1}",
    'es': "💤 <b>Usuario</b> {0} silenciado el {1}",
    'fr': "💤 <b>Utilisateur</b> {0} mis en sourdine sur {1}",
    'zh': "💤 <b>用户</b> {0} 在 {1} 静音",
    'ar': "💤 تم تجاهل <b>المستخدم</b> {0} في {1}",
}
l_mute_handler_chn = {
    'ru': "<blockquote>💤 <b>Канал</b> <b>{0}</b> обеззвучен на {1}</blockquote>",
    'en': "💤 <b>User</b> {0} muted on {1}",
    'es': "💤 <b>Usuario</b> {0} silenciado el {1}",
    'fr': "💤 <b>Utilisateur</b> {0} mis en sourdine sur {1}",
    'zh': "💤 <b>用户</b> {0} 在 {1} 静音",
    'ar': "💤 تم تجاهل <b>المستخدم</b> {0} في {1}",
}
l_mute_error = {
    'ru': "<blockquote>💤 <b>Формат</b> /mute-команды: /mute (1m|1h|10d)</blockquote>",
    'en': "💤 <b>Format</b> /mute commands: /mute (1m|1h|10d)",
    'es': "💤 <b>Formato</b> /comandos de silencio: /mute (1m|1h|10d)",
    'fr': "💤 Commandes <b>Formater</b> /mute : /mute (1m|1h|10j)",
    'zh': "💤 <b>格式</b> /mute 命令：/mute (1m|1h|10d)",
    'ar': "💤 أوامر <b>التنسيق</b> /كتم الصوت: /mute (1m|1h|10d)",
}
l_mute_unmute = {
    'ru': "<blockquote>💤 <b>Пользователь</b> {0} больше не обеззвучен</blockquote>",
    'en': "💤 <b>User</b> {0} is no longer muted",
    'es': "💤 El <b>Usuario</b> {0} ya no está silenciado",
    'fr': "💤 L'<b>utilisateur</b> {0} n'est plus mis en sourdine",
    'zh': "💤 <b>用户</b> {0} 不再静音",
    'ar': "💤 لم يعد <b>المستخدم</b> {0} مكتومًا",
}
l_mute_unmute_chn = {
    'ru': "<blockquote>💤 <b>Канал</b> <b>{0}</b> больше не обеззвучен</blockquote>",
    'en': "💤 <b>User</b> {0} is no longer muted",
    'es': "💤 El <b>Usuario</b> {0} ya no está silenciado",
    'fr': "💤 L'<b>utilisateur</b> {0} n'est plus mis en sourdine",
    'zh': "💤 <b>用户</b> {0} 不再静音",
    'ar': "💤 لم يعد <b>المستخدم</b> {0} مكتومًا",
}
l_warn_handler = {
    'ru': "<blockquote>👩🏽‍💻 <b>От имени</b> группы <b>{0}</b> выносится предупреждение {1}{2}</blockquote>",
    'en': "👩🏽‍💻 <b>On behalf of</b> group <b>{0}</b> warning {1}{2} is issued",
    'es': "👩🏽‍💻 <b>En nombre del</b> grupo <b>{0}</b> se emite la advertencia {1}{2}",
    'fr': "👩🏽‍💻 <b>Au nom du</b> groupe <b>{0}</b> un avertissement {1}{2} est émis",
    'zh': "👩🏽‍💻 <b>代表</b>组 <b>{0}</b> 发出警告 {1}{2}",
    'ar': "👩🏽‍💻 <b>نيابة عن</b> المجموعة <b>{0}</b> تم إصدار تحذير {1}{2}",
}
l_add_members = {
    'ru': "Добавление участников",
    'en': "Adding Participants",
    'es': "Agregar participantes",
    'fr': "Ajouter des participants",
    'zh': "添加参与者",
    'ar': "إضافة المشاركين",
}
l_embed_links = {
    'ru': "Предпросмотр ссылок",
    'en': "Link Preview",
    'es': "Vista previa del enlace",
    'fr': "Aperçu du lien",
    'zh': "链接预览",
    'ar': "معاينة الارتباط",
}
l_send_media = {
    'ru': "Отправка фото и видео",
    'en': "Sending photos and videos",
    'es': "Envío de fotos y vídeos",
    'fr': "Envoi de photos et de vidéos",
    'zh': "发送照片和视频",
    'ar': "إرسال الصور ومقاطع الفيديو",
}
l_send_polls = {
    'ru': "Отправка опросов",
    'en': "Submitting surveys",
    'es': "Enviar encuestas",
    'fr': "Soumettre des enquêtes",
    'zh': "提交调查",
    'ar': "تقديم الدراسات الاستقصائية",
}
l_send_stickers = {
    'ru': "Отправка sticker/giff/via_bot",
    'en': "Sending sticker/giff/via_bot",
    'es': "Enviando pegatina/giff/via_bot",
    'fr': "Envoi d'autocollant/giff/via_bot",
    'zh': "发送贴纸/giff/via_bot",
    'ar': "إرسال الملصق/gif/via_bot",
}
l_stat_msg_cnt = {
    'ru': "Количество сообщ",
    'en': "Number of messages",
    'es': "Número de mensajes",
    'fr': "Nombre de messages",
    'zh': "消息数量",
    'ar': "عدد الرسائل",
}
l_stat_history_for_new = {
    'ru': "История для новых участников",
    'en': "History for new members",
    'es': "Historia para nuevos miembros",
    'fr': "Histoire pour les nouveaux membres",
    'zh': "新会员的历史",
    'ar': "التاريخ للأعضاء الجدد",
}
l_stat_history_turn_on = {
    'ru': "(для просмотра статистики <u>включите</u> [Историю группы])",
    'en': "(to view statistics, <u>turn on</u> [Group History])",
    'es': "(para ver estadísticas, <u>activa</u> [Historial de grupo])",
    'fr': "(pour afficher les statistiques, <u>activez</u> [Historique du groupe])",
    'zh': "（要查看统计信息，请<u>打开</u>[群组历史记录]）",
    'ar': "(لعرض الإحصائيات، <u>قم بتشغيل</u> [سجل المجموعة])",
}
l_stat_first_msg_date = {
    'ru': "Дата 1-го сообщ",
    'en': "Date of 1st communication",
    'es': "Fecha de la 1.ª comunicación",
    'fr': "Date de la 1ère communication",
    'zh': "第一次沟通的日期",
    'ar': "تاريخ أول اتصال",
}
l_stat_involved = {
    'ru': "Вовлеченность в чате",
    'en': "Chat engagement",
    'es': "Participación en el chat",
    'fr': "Engagement par chat",
    'zh': "聊天参与度",
    'ar': "مشاركة الدردشة",
}
l_stat_sent = {
    'ru': "{0}\n@{1} написал(а): {2}  сообщ",
    'en': "{0}\n@{1} wrote: {2} message",
    'es': "{0}\n@{1} escribió: {2} mensaje",
    'fr': "{0}\n@{1} a écrit : {2} message",
    'zh': "{0}\n@{1} 写道：{2} 条消息",
    'ar': "كتب {0}\n@{1}: {2} رسالة",
}
l_stat_meet = {
    'ru': "{0}\n{1}. <i>{2}</i>..: встретилось {3} раз",
    'en': "{0}\n{1}. <i>{2}</i>..: occurred {3} times",
    'es': "{0}\n{1}. <i>{2}</i>..: ocurrió {3} veces",
    'fr': "{0}\n{1}. <i>{2}</i>.. : s'est produit {3} fois",
    'zh': "{0}\n{1}。 <i>{2}</i>..：发生了 {3} 次",
    'ar': "{0}\n{1}. <i>{2}</i>..: حدث {3} مرة",
}
l_stat_top5users = {
    'ru': "Топ 5 пользователей (на 1000 сообщ)",
    'en': "Top 5 users (per 1000 posts)",
    'es': "5 usuarios principales (por cada 1000 publicaciones)",
    'fr': "5 principaux utilisateurs (pour 1 000 publications)",
    'zh': "前 5 位用户（每 1000 个帖子）",
    'ar': "أعلى 5 مستخدمين (لكل 1000 مشاركة)",
}
l_stat_top5msgs = {
    'ru': "Топ 5 сообщ (из 1000)",
    'en': "Top 5 messages (out of 1000)",
    'es': "Los 5 mensajes principales (de 1000)",
    'fr': "Top 5 des messages (sur 1000)",
    'zh': "前 5 条消息（共 1000 条）",
    'ar': "أفضل 5 رسائل (من 1000)",
}
l_status_for = {
    'ru': "<blockquote>👩🏽‍💻 <b>Статус</b> <b>{0}</b> для {1}:\n\n</blockquote>",
    'en': "👩🏽‍💻 <b>Status</b> <b>{0}</b> for {1}:\n\n",
    'es': "👩🏽‍💻 <b>Estado</b> <b>{0}</b> para {1}:\n\n",
    'fr': "👩🏽‍💻 <b>Statut</b> <b>{0}</b> pour {1} :\n\n",
    'zh': "👩🏽‍💻 <b>状态</b> <b>{0}</b>（{1}）：\n\n",
    'ar': "👩🏽‍💻 <b>الحالة</b> <b>{0}</b> لـ {1}:\n\n",
}
l_participants = {
    'ru': "участ.",
    'en': "participation.",
    'es': "participación.",
    'fr': "participation.",
    'zh': "参与。",
    'ar': "مشاركة.",
}

l_timer0_text = {
    'ru': "👩🏽‍💻 <b>Введи</b> <i>число</i> секунд задержки для 1го кѻмментария в привязанном канале {1}\n\n👩🏽‍💻 <b>Текущее</b> /timer-значение: {0}\n<code>/timer 100</code> задержка 1го кѻмментария\n<code>/timer 0</code> отключение опции",
    'en': "👩🏽‍💻 <b>Enter</b> <i>number</i> seconds of delay for the 1st comment in the linked channel {1}\n\n👩🏽‍💻 <b>Current</b> /timer-value: {0}\n<code>/timer 100</code> delay of 1st comment\n<code>/timer 0</code> disable option",
    'es': "👩🏽‍💻 <b>Ingrese</b> <i>número</i> segundos de retraso para el primer comentario en el canal vinculado {1}\n\n👩🏽‍💻 <b>Actual</b> /timer-valor: {0}\n<code>/timer 100</code> retraso del primer comentario\n<code>/timer 0</code> opción de desactivación",
    'fr': "👩🏽‍💻 <b>Entrez</b> <i>nombre</i> secondes de délai pour le 1er commentaire dans le canal lié {1}\n\n👩🏽‍💻 <b>Actuel</b> /timer-value : {0}\n<code>/timer 100</code> délai du 1er commentaire\n<code>/timer 0</code> option de désactivation",
    'zh': "👩🏽‍💻 <b>输入</b> 链接频道中第一条评论的延迟<i>数字</i>秒{1}\n\n👩🏽‍💻 <b>当前</b> /timer-值：{0}\n<code>/timer 100</code> 第一条评论延迟\n<code>/timer 0</code> 禁用选项",
    'ar': "👩🏽‍💻 <b>أدخل</b> <i>رقم</i> ثانية من التأخير للتعليق الأول في القناة المرتبطة {1}\n\n👩🏽‍💻 <b>الحالي</b> /timer-value: خيار تعطيل {0}\n<code>/timer 100</code> للتعليق الأول\n<code>/timer 0</code>",
}
l_timer_finish = {
    'ru': "👩🏽‍💻 <b>Текущее</b> /timer-значение: {0}\n\n<code>/timer 100</code>  задержка 1го кѻмментария\n<code>/timer 0</code> отключение опции\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Current</b> /timer-value: {0}\n\n<code>/timer 100</code> delay of the 1st comment\n<code>/timer 0</code> disable options\n\n⚙️ Commands /cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /valor-temporizador: {0}\n\n<code>/timer 100</code> retraso del primer comentario\n<code>/timer 0</code > desactivar opciones\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Actuel</b> /timer-value : {0}\n\n<code>/timer 100</code> délai du 1er commentaire\n<code>/timer 0</code > désactiver les options\n\n⚙️ Commandes /cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /timer-value：{0}\n\n<code>/timer 100</code> 第一条评论的延迟\n<code>/timer 0</code > 禁用选项\n\n⚙️ 命令 /cmd",
    'ar': "👩🏽‍💻 <b>الحالية</b> /قيمة المؤقت: {0}\n\n<code>/timer 100</code> تأخير التعليق الأول\n<code>/timer 0</code > تعطيل الخيارات\n\n⚙️ الأوامر /cmd",
}
l_work_text = {
    'ru': "👩🏽‍💻 <b>Введи</b> часы работы (возможность писать в группе)\n\n👩🏽‍💻 <b>Текущее</b> /work-значение: {0}\n<code>/work 09:00 21:00</code>   часы работы\n<code>/work 0</code> отключение опции\n\n📍 <b>Текущее</b> время: <u>{1}</u> ({2} по Гринвичу). Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    'en': "👩🏽‍💻 <b>Enter</b> working hours (possibility to write in a group)\n\n👩🏽‍💻 <b>Current</b> /work-value: {0}\n<code>/ work 09:00 21:00</code> working hours\n<code>/work 0</code> disabling the option\n\n📍 <b>Current</b> time: <u>{1}</ u> ({2} GMT). Send <b>geolocation</b> to <i>automatically</i> determine the time zone",
    'es': "👩🏽‍💻 <b>Ingrese</b> horas de trabajo (posibilidad de escribir en grupo)\n\n👩🏽‍💻 <b>Actual</b> /valor-trabajo: {0}\n<código >/ trabajo 09:00 21:00</code> horario laboral\n<code>/work 0</code> deshabilitando la opción\n\n📍 Hora <b>actual</b>: <u>{1 }</ u> ({2} GMT). Envía <b>geolocalización</b> para determinar <i>automáticamente</i> la zona horaria",
    'fr': "👩🏽‍💻 <b>Entrer</b> les heures de travail (possibilité d'écrire en groupe)\n\n👩🏽‍💻 <b>Actuel</b> /work-value : {0}\n<code >/ travail 09:00 21:00</code> heures de travail\n<code>/travail 0</code> en désactivant l'option\n\n📍 <b>Heure actuelle</b> : <u>{1 </u> ({2} GMT). Envoyer une <b>géolocalisation</b> pour déterminer <i>automatiquement</i> le fuseau horaire",
    'zh': "👩🏽‍💻<b>输入</b>工作时间（可以在小组中书写）\n\n👩🏽‍💻<b>当前</b>/工作值：{0}\n<code >/ work 09:00 21:00</code> 工作时间\n<code>/work 0</code> 禁用该选项\n\n📍 <b>当前</b>时间：<u>{1 }</u>（{2}GMT）。发送<b>地理位置</b>以<i>自动</i>确定时区",
    'ar': "👩🏽‍💻 <b>أدخل</b> ساعات العمل (إمكانية الكتابة في مجموعة)\n\n👩🏽‍💻 <b>الحالية</b> /قيمة العمل: {0}\n<code >/ العمل 09:00 21:00</code> ساعات العمل\n<code>/work 0</code> تعطيل الخيار\n\n📍 <b>الوقت الحالي</b>: <u>{1 }</ u> ({2} بتوقيت جرينتش). أرسل <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>تلقائيًا</i>",
}
l_work_finish = {
    'ru': "👩🏽‍💻 <b>Текущее</b> /work-значение: {0}\n\n<code>/work 09:00 21:00</code>    часы работы\n<code>/work 0</code>   отключение опции\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Current</b> /work-value: {0}\n\n<code>/work 09:00 21:00</code> working hours\n<code>/work 0< /code> disable option\n\n⚙️ Commands /cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /valor-trabajo: {0}\n\n<code>/trabajo 09:00 21:00</code> horas laborables\n<code>/trabajo 0< /code> desactivar opción\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Actuel</b> /work-value : {0}\n\n<code>/work 09h00 21h00</code> heures de travail\n<code>/work 0< /code> désactiver l'option\n\n⚙️ Commandes /cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /工作值：{0}\n\n<code>/work 09:00 21:00</code> 工作时间\n<code>/work 0< /code> 禁用选项\n\n⚙️ 命令 /cmd",
    'ar': "👩🏽‍💻 <b>الحالية</b> /قيمة العمل: {0}\n\n<code>/العمل 09:00 21:00</code> ساعات العمل\n<code>/العمل 0< /code> خيار التعطيل\n\n⚙️ الأوامر /cmd",
}
l_work_msg = {
    'ru': "👩🏽‍💻 <b>Часы</b> работы группы: {0}-{1}",
    'en': "👩🏽‍💻 <b>Hours</b> of the group: {0} [UTC: {1}]",
    'es': "👩🏽‍💻 <b>Horario</b> del grupo: {0} [UTC: {1}]",
    'fr': "👩🏽‍💻 <b>Heures</b> du groupe : {0} [UTC : {1}]",
    'zh': "👩🏽‍💻 群组<b>时间</b>：{0} [UTC：{1}]",
    'ar': "👩🏽‍💻 <b>ساعات العمل</b> للمجموعة: {0} [التوقيت العالمي: {1}]",
}
l_help_handler = {
    "ru": "<blockquote>👩🏽‍💻 <b>Команды</b> пользователя:\n\n/report - сообщить о нарушении\n/happy - получить радость\n/thanks - поблагодарить\n/birthday - поздравить\n/vote - голосовать\n\n👩🏽‍💻 <b>Добавь</b> <i>кѻмментарий</i> после команды если необходимо</blockquote>",
    "en": "👩🏽‍💻 <b>Commands</b> for users:\n\n/rules - group rules\n/report - report a violation\n/happy - get joy\n/thanks - thank\n/birthday - congratulations\n\n👩🏽‍💻 <b>Add</b> <i>a comment</i> after the command if necessary",
    "es": "👩🏽‍💻 <b>Comandos</b> de usuario:\n\n/rules - reglas del grupo\n/report - informar de una infracción\n/happy - obtener alegría\n/thanks - agradecer\n/birthday - felicitación\n\n👩🏽‍💻 <b>Añade</b> <i>un comentario</i> después del comando si es necesario",
    "fr": "👩🏽‍💻 <b>Commandes</b> utilisateur:\n\n/rules - règles du groupe\n/report - signaler une violation\n/happy - recevoir de la joie\n/thanks - remercier\n/birthday - félicitations\n\n👩🏽‍💻 <b>Ajoute</b> <i>un commentaire</i> après la commande si nécessaire",
    "zh": "👩🏽‍💻 <b>命令</b> 用户：\n\n/rules - 群组规则\n/report - 举报违规\n/happy - 获得喜悦\n/thanks - 致谢\n/birthday - 祝贺\n\n👩🏽‍💻 <b>在命令后添加</b> <i>注释</i> 如果有必要",
    "ar": "👩🏽‍💻 <b>أوامر</b> المستخدم:\n\n/rules - قواعد المجموعة\n/report - الإبلاغ عن مخالفة\n/happy - الحصول على السعادة\n/thanks - شكر\n/birthday - تهنئة\n\n👩🏽‍💻 <b>أضف</b> <i>تعليقًا</i> بعد الأمر إذا لزم الأمر",
}
l_report_handler = {
    'ru': "<blockquote>❗️<b>Информация</b> передана администратору. Пользователь {0} взят на карандаш</blockquote>",
    'en': "❗️<b>Information</b> has been transferred to the administrator. User {0} taken on pencil",
    'es': "❗️<b>La información</b> ha sido transferida al administrador. Usuario {0} tomado con lápiz",
    'fr': "❗️<b>Les informations</b> ont été transférées à l'administrateur. Utilisateur {0} pris au crayon",
    'zh': "❗️<b>信息</b>已转移给管理员。用户 {0} 用铅笔拍摄",
    'ar': "❗️<b>المعلومات</b> تم نقلها إلى المسؤول. تم التقاط المستخدم {0} بالقلم الرصاص",
}
l_report_handler_chn = {
    'ru': "<blockquote>❗️<b>Информация</b> передана администратору. Канал <b>{0}</b> взят на карандаш</blockquote>",
    'en': "❗️<b>Information</b> has been transferred to the administrator. User {0} taken on pencil",
    'es': "❗️<b>La información</b> ha sido transferida al administrador. Usuario {0} tomado con lápiz",
    'fr': "❗️<b>Les informations</b> ont été transférées à l'administrateur. Utilisateur {0} pris au crayon",
    'zh': "❗️<b>信息</b>已转移给管理员。用户 {0} 用铅笔拍摄",
    'ar': "❗️<b>المعلومات</b> تم نقلها إلى المسؤول. تم التقاط المستخدم {0} بالقلم الرصاص",
}
l_report_admin = {
    'ru': "<blockquote>❗️ <b>Пользователь</b> {0} в группе <b>{1}</b> просит обратить внимание на сообщение {2}{3}</blockquote>",
    'en': "❗️ <b>User</b> {0} in group <b>{1}</b> asks you to pay attention to the message {2}{3}",
    'es': "❗️ El <b>Usuario</b> {0} del grupo <b>{1}</b> te pide que prestes atención al mensaje {2}{3}",
    'fr': "❗️ L'<b>Utilisateur</b> {0} du groupe <b>{1}</b> vous demande de prêter attention au message {2}{3}",
    'zh': "❗️ <b>{1}</b> 组中的<b>用户</b> {0} 要求您注意消息 {2}{3}",
    'ar': "❗️ <b>المستخدم</b> {0} في المجموعة <b>{1}</b> يطلب منك الانتباه إلى الرسالة {2}{3}",
}
l_report_reply = {
    'ru': "<blockquote>❗ <b>Отправь</b> команду в ответ на сообщение пользователя</blockquote>",
    'en': "❗ <b>Send</b> this command in response to a message",
    'es': "❗ <b>Enviar</b> este comando en respuesta a un mensaje",
    'fr': "❗ <b>Envoyer</b> cette commande en réponse à un message",
    'zh': "❗ <b>发送</b>此命令以响应消息",
    'ar': "❗ <b>أرسل</b> هذا الأمر ردًا على رسالة",
}
l_thanks_handler = {
    'ru': "<blockquote>🎉 <b>От имени</b> группы <b>{0}</b> обьявляется благодарность {1}{2}</blockquote>",
    'en': "🎉 <b>On behalf of</b> the group <b>{0}</b> we express gratitude to {1}{2}",
    'es': "🎉 <b>En nombre de</b> el grupo <b>{0}</b> expresamos nuestro agradecimiento a {1}{2}",
    'fr': "🎉 <b>Au nom</b> du groupe <b>{0}</b> nous exprimons notre gratitude à {1}{2}",
    'zh': "🎉 <b>代表</b>团体<b>{0}</b>，我们向{1}{2}表示感谢",
    'ar': "🎉 <b>بالنيابة عن</b> المجموعة <b>{0}</b> نعرب عن امتناننا لـ {1}{2}",
}
l_thanks_reply = {
    'ru': "<blockquote>🎉 <b>Отправь</b> команду в ответ на сообщение пользователя</blockquote>",
    'en': "🎉 <b>Send</b> this command in response to a message",
    'es': "🎉 <b>Enviar</b> este comando en respuesta a un mensaje",
    'fr': "🎉 <b>Envoyer</b> cette commande en réponse à un message",
    'zh': "🎉<b>发送</b>此命令以响应消息",
    'ar': "🎉 <b>أرسل</b> هذا الأمر ردًا على رسالة",
}
l_birthday_handler = {
    'ru': "<blockquote>🥳 <b>От</b> имени группы <b>{0}</b> поздравляем с днем рождения {1}{2}</blockquote>",
    'en': "🥳 <b>On behalf of</b> the group <b>{0}</b> happy birthday {1}{2}",
    'es': "🥳 <b>En nombre de</b> el grupo <b>{0}</b> feliz cumpleaños {1}{2}",
    'fr': "🥳 <b>Au nom</b> du groupe <b>{0}</b> joyeux anniversaire {1}{2}",
    'zh': "🥳<b>代表</b>群组<b>{0}</b>生日快乐{1}{2}",
    'ar': "🥳 <b>نيابة عن</b> المجموعة <b>{0}</b> عيد ميلاد سعيد {1}{2}",
}
l_vote_reply = {
    'ru': "<blockquote>🪻 <b>Отправь</b> команду в ответ на сообщение пользователя</blockquote>",
    'en': "🎉 <b>Send</b> this command in response to a message",
    'es': "🎉 <b>Enviar</b> este comando en respuesta a un mensaje",
    'fr': "🎉 <b>Envoyer</b> cette commande en réponse à un message",
    'zh': "🎉<b>发送</b>此命令以响应消息",
    'ar': "🎉 <b>أرسل</b> هذا الأمر ردًا على رسالة",
}

l_len_text = {
    'ru': "👩🏽‍💻 <b>Введи</b> max <i>длину</i> текста сообщения\n\n👩🏽‍💻 <b>Текущее</b> /len-значение: {0}\n<code>/len 160</code>  max-длина 160 символов\n<code>/len 0</code> отключение опции",
    'en': "👩🏽‍💻 <b>Enter</b> max <i>length</i> of the message text\n\n👩🏽‍💻 <b>Current</b> /len-value: {0}\n< code>/len 160</code> max-length 160 characters\n<code>/len 0</code> disable option",
    'es': "👩🏽‍💻 <b>Ingrese</b> <i>longitud</i> máxima del texto del mensaje\n\n👩🏽‍💻 <b>Actual</b> /valor-len: {0}\n< code>/len 160</code> longitud máxima 160 caracteres\n<code>/len 0</code> opción de desactivación",
    'fr': "👩🏽‍💻 <b>Entrez</b> la <i>longueur</i> maximale du texte du message\n\n👩🏽‍💻 <b>Actuel</b> /len-value : {0}\n< code>/len 160</code> longueur maximale 160 caractères\n<code>/len 0</code> option de désactivation",
    'zh': "👩🏽‍💻<b>输入</b>消息文本的最大<i>长度</i>\n\n👩🏽‍💻<b>当前</b>/len-值：{0}\n<code>/len 160</code> 最大长度 160 个字符\n<code>/len 0</code> 禁用选项",
    'ar': "👩🏽‍💻 <b>أدخل</b> أقصى <i>طول</i> لنص الرسالة\n\n👩🏽‍💻 <b>القيمة الحالية</b> /len-value: {0}\n<code>/len 160</code> الحد الأقصى للطول 160 حرفًا\n<code>/len 0</code> خيار التعطيل",
}
l_len_finish = {
    'ru': "👩🏽‍💻 <b>Текущее</b> /len-значение: {0}\n\n<code>/len 160</code>  max-длина 160 символов\n<code>/len 0</code> отключение опции\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Current</b> /len-value: {0}\n\n<code>/len 160</code> max-length 160 characters\n<code>/len 0</code > disable the option\n\n⚙️ Commands /cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /len-value: {0}\n\n<code>/len 160</code> longitud máxima 160 caracteres\n<code>/len 0</code > desactivar la opción\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Actuelle</b> /len-value : {0}\n\n<code>/len 160</code> longueur maximale 160 caractères\n<code>/len 0</code > désactivez l'option\n\n⚙️ Commandes /cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /len-值：{0}\n\n<code>/len 160</code> 最大长度 160 个字符\n<code>/len 0</code > 禁用该选项\n\n⚙️ 命令 /cmd",
    'ar': "👩🏽‍💻 <b>القيمة الحالية</b> /len-value: {0}\n\n<code>/len 160</code> الحد الأقصى للطول 160 حرفًا\n<code>/len 0</code > تعطيل الخيار\n\n⚙️ Commands /cmd",
}
l_cmd_reply = {
    'ru': "<blockquote>👩🏽‍💻 <b>Отправь</b> команду в ответ на сообщение </blockquote>",
    'en': "👩🏽‍💻 <b>Send</b> this command in response to a message",
    'es': "👩🏽‍💻 <b>Enviar</b> este comando en respuesta a un mensaje",
    'fr': "👩🏽‍💻 <b>Envoyer</b> cette commande en réponse à un message",
    'zh': "👩🏽‍💻<b>发送</b>此命令以响应消息",
    'ar': "👩🏽‍💻 <b>أرسل</b> هذا الأمر ردًا على رسالة",
}
l_status_pin = {
    'ru': "Закреп сообщ",
    'en': "Pinned message",
    'es': "Mensaje fijado",
    'fr': "Message épinglé",
    'zh': "固定消息",
    'ar': "رسالة مثبتة",
}
l_status_profile = {
    'ru': "Изменение профиля группы",
    'en': "Changing a Group Profile",
    'es': "Cambiar un perfil de grupo",
    'fr': "Modification d'un profil de groupe",
    'zh': "更改群组资料",
    'ar': "تغيير ملف تعريف المجموعة",
}
l_sendmsg = {
    'ru': "Отправка сообщ",
    'en': "Sending messages",
    'es': "Enviando mensajes",
    'fr': "Envoi de messages",
    'zh': "发送消息",
    'ar': "إرسال الرسائل",
}
l_status_limit = {
    'ru': "Ограничения до",
    'en': "Restrictions to",
    'es': "Restricciones a",
    'fr': "Restrictions à",
    'zh': "限制",
    'ar': "القيود على",
}
l_status_without = {
    'ru': "(отсутствует) для",
    'en': "(missing) for",
    'es': "(desaparecido) para",
    'fr': "(manquant) pour",
    'zh': "（缺失）对于",
    'ar': "(مفقود) ل",
}
l_karma_current = {
    'ru': "<blockquote><b>Текущая</b> карма пользователя</blockquote>",
    'en': "<b>Current</b> user karma",
    'es': "Karma del usuario <b>actual</b>",
    'fr': "Karma de l'utilisateur <b>actuel</b>",
    'zh': "<b>当前</b>用户业力",
    'ar': "<b>الحالي</b> كارما المستخدم",
}
l_karma_add = {
    'ru': "👩🏽‍💻 <code>/k+</code> добавить карму",
    'en': "👩🏽‍💻 <code>/k+</code> add karma",
    'es': "👩🏽‍💻 <code>/k+</code> agrega karma",
    'fr': "👩🏽‍💻 <code>/k+</code> ajouter du karma",
    'zh': "👩🏽‍💻 <code>/k+</code> 添加业力",
    'ar': "👩🏽‍💻 <code>/k+</code> أضف الكارما",
}
l_karma_in_group = {
    'ru': "в группе",
    'en': "in Group",
    'es': "en grupo",
    'fr': "en groupe",
    'zh': "组内",
    'ar': "في مجموعة",
}
l_karma_all = {
    'ru': "<blockquote>🪺 <b>Карма</b> пользователей группы <b>{0}</b></blockquote>",
    'en': "🪺 <b>Karma</b> users of group <b>{0}</b>",
    'es': "🪺 Usuarios de <b>Karma</b> del grupo <b>{0}</b>",
    'fr': "🪺 <b>Karma</b> utilisateurs du groupe <b>{0}</b>",
    'zh': "🪺 <b>{0}</b> 组的 <b>Karma</b> 用户",
    'ar': "🪺 مستخدمي <b>الكرمة</b> في المجموعة <b>{0}</b>",
}
l_karma_off = {
    'ru': "<blockquote>🪹 <b>Карма</b> пользователей группы <b>{0}</b> не установлена</blockquote>",
    'en': "🪹 <b>Karma</b> of users of group <b>{0}</b> is not installed",
    'es': "🪹 El <b>Karma</b> de los usuarios del grupo <b>{0}</b> no está instalado",
    'fr': "🪹 Le <b>Karma</b> des utilisateurs du groupe <b>{0}</b> n'est pas installé",
    'zh': "🪹 <b>{0}</b> 组用户的 <b>Karma</b> 未安装",
    'ar': "🪹 <b>الكارما</b> لمستخدمي المجموعة <b>{0}</b> غير مثبتة",
}
l_tag_handler = {
    'ru': "<blockquote>👩🏽‍💻 <b>Введи</b> сообщение при @-упоминании пользователей в формате:\n<code>/tag сообщение</code></blockquote>",
    'en': "👩🏽‍💻 <b>Enter</b> message when @-mentioning users in the format:\n<code>/tag message</code>",
    'es': "👩🏽‍💻 <b>Ingrese</b> mensaje cuando @-mencione usuarios en el formato:\n<code>/etiqueta de mensaje</code>",
    'fr': "👩🏽‍💻 Message <b>Entrer</b> lorsque @-mentionne des utilisateurs au format :\n<code>/tag message</code>",
    'zh': "👩🏽‍💻 @提及用户时<b>输入</b>消息，格式为：\n<code>/tag message</code>",
    'ar': "👩🏽‍💻 <b>أدخل</b> الرسالة عند الإشارة @ إلى المستخدمين بالتنسيق:\n<code>/tag message</code>",
}
l_ccheck_call = {
    'ru': "👮🏽 Для проверки подписки необходимо добавить @{0}-бота в дополнительный канал и выполнить команду:\n\n/channel ССЫЛКА НА КАНАЛ",
    'en': "👮🏽 To check the subscription, you need to add @{0}-bot to an additional channel and run the command:\n\n/channel LINK TO CHANNEL",
    'es': "👮🏽 Para verificar la suscripción, debe agregar @{0}-bot a un canal adicional y ejecutar el comando:\n\n/channel ENLACE AL CANAL",
    'fr': "👮🏽 Pour vérifier l'abonnement, vous devez ajouter @{0}-bot à une chaîne supplémentaire et exécuter la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    'zh': "👮🏽 要检查订阅情况，您需要将 @{0}-bot 添加到其他频道并运行命令：\n\n/channel LINK TO CHANNEL",
    'ar': "👮🏽 للتحقق من الاشتراك، يلزمك إضافة @{0}-bot إلى قناة إضافية وتشغيل الأمر:\n\n/channel LINK TO CHANNEL",
}
l_delay_text = {
    'ru': "<blockquote>👥 <b>Введи</b> корректное <i>число</i> минут для первичного ограничения новых пользователей (перед написанием их <u>1</u>го сообщ)\n\n👩🏽‍💻 <b>Текущее</b> /delay-значение: {0}\n<code>/delay 3</code>   ограничение на 3 мин\n<code>/delay 0</code>  отключение опции</blockquote>",
    'en': "👥 <b>Enter</b> the correct <i>number</i> minutes for the initial restriction of new users (before writing their <u>1</u>th message)\n\n👩🏽‍💻 <b> Current</b>/delay value: {0}\n<code>/delay 3</code> 3 minute limit\n<code>/delay 0</code> disable option",
    'es': "👥 <b>Ingrese</b> el <i>número</i> de minutos correcto para la restricción inicial de nuevos usuarios (antes de escribir su <u>1</u> mensaje)\n\n👩🏽‍💻 <b> Valor actual</b>/retraso: {0}\n<code>/retraso 3</code> Límite de 3 minutos\n<code>/retraso 0</code> opción de desactivación",
    'fr': "👥 <b>Entrez</b> le <i>nombre</i> de minutes correct pour la restriction initiale des nouveaux utilisateurs (avant d'écrire leur <u>1</u>ème message)\n\n👩🏽‍💻 <b> Valeur actuelle</b>/délai : {0}\n<code>/delay 3</code> limite de 3 minutes\n<code>/delay 0</code> option de désactivation",
    'zh': "👥<b>输入</b>正确的<i>数字</i>分钟作为新用户的初始限制（在写入第<u>1</u>条消息之前）\n\n👩🏽‍💻 <b> 当前</b>/延迟值：{0}\n<code>/delay 3</code> 3 分钟限制\n<code>/delay 0</code> 禁用选项",
    'ar': "👥 <b>أدخل</b> <i>الرقم</i> الدقائق الصحيحة للقيود الأولية للمستخدمين الجدد (قبل كتابة <u>الرسالة</u>الأولى)\n\n👩🏽‍💻 <b> قيمة</b>/التأخير الحالية: {0}\n<code>/delay 3</code> حد 3 دقائق\n<code>/delay 0</code> خيار التعطيل",
}
l_delay_finish = {
    'ru': "<blockquote>👩🏽‍💻 <b>Текущее</b> /delay-значение: {0}\n\n<code>/delay 3</code>    ограничение на 3 мин\n<code>/delay 0</code>   отключение опции\n\n⚙️ Команды /cmd</blockquote>",
    'en': "👩🏽‍💻 <b>Current</b> /delay value: {0}\n\n<code>/delay 3</code> limit for 3 minutes\n<code>/delay 0</code> disabling the option\n\n⚙️ Commands /cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /valor de retraso: {0}\n\n<code>/retraso 3</code> límite de 3 minutos\n<code>/retraso 0</code> deshabilitación la opción\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Valeur actuelle</b>/délai : {0}\n\n<code>/delay 3</code> limite pendant 3 minutes\n<code>/delay 0</code> désactivation l'option\n\n⚙️ Commandes / cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /delay 值：{0}\n\n<code>/delay 3</code> 限制 3 分钟\n<code>/delay 0</code> 禁用选项\n\n⚙️ 命令 /cmd",
    'ar': "👩🏽‍💻 <b>القيمة الحالية</b> /التأخير: {0}\n\n<code>/delay 3</code> حد لمدة 3 دقائق\n<code>/delay 0</code> تعطيل الخيار\n\n⚙️ الأوامر /cmd",
}
l_chn_correct = {
    'ru': "<blockquote>👮🏽 <b>Добавь</b> @{0}-бота в канал и отправь корректную <i>ссылку</i> этого канала\n\n👩🏽‍💻 Например, <code>/channel {1}</code></blockquote>",
    'en': "👮🏽 <b>Add</b> @{0}-bot to the channel and send the correct <i>link</i> of this channel\n\n👩🏽‍💻 For example, <code>/channel {1}< /code>",
    'es': "👮🏽 <b>Agrega</b> @{0}-bot al canal y envía el <i>enlace</i> correcto de este canal\n\n👩🏽‍💻 Por ejemplo, <código>/canal {1}< /código>",
    'fr': "👮🏽 <b>Ajoutez</b> @{0}-bot à la chaîne et envoyez le <i>lien</i> correct de cette chaîne\n\n👩🏽‍💻 Par exemple, <code>/channel {1}</code>",
    'zh': "👮🏽<b>添加</b>@{0}-bot到频道并发送该频道的正确<i>链接</i>\n\n👩🏽‍💻例如<code>/channel {1}</code>",
    'ar': "👮🏽 <b>أضف</b> @{0}-bot إلى القناة وأرسل <i>الرابط</i> الصحيح لهذه القناة\n\n👩🏽‍💻 على سبيل المثال، <code>/channel {1}< /كود>",
}
l_fsm_stop_add_caption = {
    'ru': "<blockquote>🧾 <b>Готово!</b> <b>Текущее</b> количество стоп-слов в {0}-файле: <u>{1}</u></blockquote>",
    'en': "🧾 <b>Done!</b> <b>Current</b> number of stop words in the {0} file: <u>{1}</u>",
    'es': "🧾 <b>¡Listo!</b> Número <b>actual</b> de palabras vacías en el archivo {0}: <u>{1}</u>",
    'fr': "🧾 <b>Terminé !</b> <b>Nombre actuel</b> de mots vides dans le fichier {0} : <u>{1}</u>",
    'zh': "🧾 <b>完成！</b> {0} 文件中<b>当前</b> 个停用词数量：<u>{1}</u>",
    'ar': "🧾 <b>تم!</b> <b>العدد الحالي</b> لكلمات التوقف في الملف {0}: <u>{1}</u>",
}
l_button_handler = {
    'ru': "<blockquote>👮🏽 <b>Готово!</b> Текущее <b>имя кнопки</b> на <i>входном контроле</i> установлено: {0}\n\n⚙️ Команды /cmd</blockquote>",
    'en': "👮🏽 <b>Done!</b> The current <b>button name</b> on the <i>input control</i> is set to: {0}\n\n⚙️ Commands /cmd",
    'es': "👮🏽 <b>¡Listo!</b> El <b>nombre del botón</b> actual en el <i>control de entrada</i> está configurado en: {0}\n\n⚙️ Comandos /cmd",
    'fr': "👮🏽 <b>Terminé !</b> Le <b>nom du bouton</b> actuel sur le <i>contrôle d'entrée</i> est défini sur : {0}\n\n⚙️ Commandes /cmd",
    'zh': "👮🏽<b>完成！</b><i>输入控件</i>上的当前<b>按钮名称</b>设置为：{0}\n\n⚙️ Commands /cmd",
    'ar': "👮🏽 <b>تم!</b> تم تعيين <b>اسم الزر</b> الحالي في <i>عنصر التحكم في الإدخال</i> على: {0}\n\n⚙️ Commands /cmd",
}
l_button_correct = {
    'ru': "<blockquote>👮🏽 <b>Введи</b> корректное название <i>для имени кнопки</i> 👮🏽 Входного контроля\n\n👩🏽‍💻 Например, <code>/button {0}</code></blockquote>",
    'en': "👮🏽 <b>Enter</b> the correct name <i>for the name of the button</i> 👮🏽 Input control\n\n👩🏽‍💻 For example, <code>/button {0}</code>",
    'es': "👮🏽 <b>Ingrese</b> el nombre correcto <i>para el nombre del botón</i> 👮🏽 Control de entrada\n\n👩🏽‍💻 Por ejemplo, <código>/botón {0}< /código>",
    'fr': "👮🏽 <b>Entrez</b> le nom correct <i>pour le nom du bouton</i> 👮🏽 Contrôle de saisie\n\n👩🏽‍💻 Par exemple, <code>/bouton {0}< /code>",
    'zh': "👮🏽 <b>输入</b>正确的按钮名称<i></i> 👮🏽 输入控件\n\n👩🏽‍💻 例如，<code>/button {0}< /代码>",
    'ar': "👮🏽 <b>أدخل</b> الاسم الصحيح <i>لاسم الزر</i> 👮🏽 التحكم في الإدخال\n\n👩🏽‍💻 على سبيل المثال، <code>/button {0}< /كود>",
}
l_GROUPP_CCHECKBTNNAME = {
    'ru': "✔ Я человек",
    'en': "✔ I'm human",
    'es': "✔soy humano",
    'fr': "✔ Je suis humain",
    'zh': "✔ 我是人类",
    'ar': "✔ أنا إنسان",
}

_ccheck_other_person = {
    'ru': "👮🏽 Эта кнопка не для тебя",
    'en': "👮🏽 This button is not for you",
    'es': "👮🏽 Este botón no es para ti",
    'fr': "👮🏽 Ce bouton n'est pas pour vous",
    'zh': "👮🏽 此按钮不适合您",
    'ar': "👮🏽 هذا الزر ليس لك",
}
l_ccheckchannel_link = {
    'ru': "👮🏽 Ссылка на {0} не доступна",
    'en': "👮🏽 Link to {0} not available",
    'es': "👮🏽 Enlace a {0} no disponible",
    'fr': "👮🏽 Lien vers {0} non disponible",
    'zh': "👮🏽 指向 {0} 的链接不可用",
    'ar': "👮🏽 الرابط إلى {0} غير متوفر",
}
l_ccheckchannel_chn = {
    'ru': "👮🏽 Необходимо вступить в {0}\n\nПопробуй ещё раз позже",
    'en': "👮🏽You haven't joined {0}\n\nTry again later",
    'es': "👮🏽No te has unido a {0}\n\nVuelve a intentarlo más tarde",
    'fr': "👮🏽Vous n'avez pas rejoint {0}\n\nRéessayez plus tard",
    'zh': "👮🏽您尚未加入{0}\n\n请稍后重试",
    'ar': "👮🏽لم تنضم {0}\n\nحاول مرة أخرى لاحقًا",
}
l_ccheck_ban = {
    'ru': "👮🏽‍ <b>Пользователь</b> {0} не прошел входной контроль и был удален из группы",
    'en': "👮🏽‍ <b>User</b> {0} failed entry control and was removed from the group",
    'es': "👮🏽‍ El <b>Usuario</b> {0} falló en el control de entrada y fue eliminado del grupo",
    'fr': "👮🏽‍ <b>Utilisateur</b> {0} a échoué au contrôle d'entrée et a été supprimé du groupe",
    'zh': "👮🏽‍ <b>用户</b> {0} 未通过进入控制并已从群组中删除",
    'ar': "👮🏽‍ <b>المستخدم</b> {0} فشل في التحكم في الدخول وتمت إزالته من المجموعة",
}
l_ccheckchannel_error = {
    'ru': "👮🏽 Ошибка проверки",
    'en': "👮🏽 Validation error",
    'es': "👮🏽 Error de validación",
    'fr': "👮🏽 Erreur de validation",
    'zh': "👮🏽 验证错误",
    'ar': "👮🏽 خطأ في التحقق",
}
l_ccheck_wrong = {
    'ru': "👮🏽 К сожалению, ответ неверный\n\nПопробуй ещё раз позже",
    'en': "👮🏽 Unfortunately, the answer is incorrect\n\nTry again later",
    'es': "👮🏽 Lamentablemente, la respuesta es incorrecta\n\nInténtalo de nuevo más tarde",
    'fr': "👮🏽 Malheureusement, la réponse est incorrecte\n\nRéessayez plus tard",
    'zh': "👮🏽 不幸的是，答案不正确\n\n请稍后再试",
    'ar': "👮🏽 للأسف الإجابة غير صحيحة\n\nحاول مرة أخرى لاحقاً",
}
l_ccheck_time = {
    'ru': "👮🏽 Входной контроль пройден за {0} сек",
    'en': "👮🏽 Input control passed in {0} seconds",
    'es': "👮🏽 El control de entrada pasó en {0} segundos",
    'fr': "👮🏽 Contrôle d'entrée réussi en {0} secondes",
    'zh': "👮🏽 输入控制在 {0} 秒内传递",
    'ar': "👮🏽تم تمرير التحكم في الإدخال خلال {0} ثانية",
}
l_ccheck_other_person = {
    'ru': "👮🏽 Эта кнопка не для тебя",
    'en': "👮🏽 This button is not for you",
    'es': "👮🏽 Este botón no es para ti",
    'fr': "👮🏽 Ce bouton n'est pas pour vous",
    'zh': "👮🏽 此按钮不适合您",
    'ar': "👮🏽 هذا الزر ليس لك",
}
l_grp_need_super = {
    "ru": "🚫 @{0}-бот удален из <b>{1}</b> [id=<code>{2}</code>]. Группа слишком маленькая, необходимо дождаться преобразовавния в супергруппу",
    "en": "🚫 @{0}-bot removed from <b>{1}</b> [id=<code>{2}</code>]",
    "es": "🚫 @{0}-bot eliminado de <b>{1}</b> [id=<code>{2}</code>]",
    "fr": "🚫 @{0}-bot supprimé de <b>{1}</b> [id=<code>{2}</code>]",
    "zh": "🚫 @{0}-bot 已从 <b>{1}</b> [id=<code>{2}</code>] 中删除",
    "ar": "🚫 @{0}-تمت إزالة الروبوت من <b>{1}</b> [id=<code>{2}</code>]"
}
# endregion


# region FereyUserBot
l_usr_btn1 = {
    "ru": "👩🏽‍💻 Аккаунты",
    "en": "👩🏽‍💻 Accounts",
    "es": "👩🏽‍💻 Cuentas",
    "fr": "👩🏽‍💻 Comptes",
    "zh": "👩🏽‍💻 账户",
    "ar": "👩🏽‍💻 الحسابات",
}
l_usr_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_usr_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в #нейро-автоматизацию <b>Telegram</b>-аккаунтов:\n\n<blockquote>▪️авто-перевод/транскрибация\n▪️мониторинг групп/каналов\n▪️статусы и нейро-поиск\n▪️авто-реакции/декор\n▪️нотификации и команды</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the #neuro-automation of <b>Telegram</b>-accounts:\n\n<blockquote>▪️auto-translation/transcription\n▪️group/channel monitoring\n▪️statuses and neuro-search\n▪️auto-reactions/decor\n▪️notifications and commands</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la #neuroautomatización de cuentas de <b>Telegram</b>:\n\n<blockquote>▪️auto-traducción/transcripción\n▪️monitoreo de grupos/canales\n▪️estados y búsqueda neuronal\n▪️auto-reacciones/decoración\n▪️notificaciones y comandos</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans la #neuro-automatisation des comptes <b>Telegram</b>:\n\n<blockquote>▪️traduction/transcription automatique\n▪️surveillance des groupes/canaux\n▪️statuts et recherche neuro\n▪️auto-réactions/décor\n▪️notifications et commandes</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎使用<b>Telegram</b>账户的#神经自动化：\n\n<blockquote>▪️自动翻译/转录\n▪️群组/频道监控\n▪️状态和神经搜索\n▪️自动反应/装饰\n▪️通知和命令</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في #الأتمتة_العصبية لحسابات <b>Telegram</b>:\n\n<blockquote>▪️الترجمة/النسخ التلقائي\n▪️مراقبة المجموعات/القنوات\n▪️الحالات والبحث العصبي\n▪️ردود فعل/ديكور تلقائية\n▪️الإشعارات والأوامر</blockquote>"
}
l_add_owner_to_contacts = {
    "ru": "📇 Контакт <b>{0}</b> успешно добавлен!",
    "en": "📇 Contact <b>{0}</b> successfully added!",
    "es": "📇 Contacto <b>{0}</b> agregado exitosamente!",
    "fr": "📇 Contact <b>{0}</b> ajouté avec succès!",
    "zh": "📇 联系人 <b>{0}</b> 已成功添加！",
    "ar": "📇 تمت إضافة جهة الاتصال <b>{0}</b> بنجاح!",
}
l_commands_handler_userbot = {
    "ru": "⚙️ <b>Команды</b> /cmd для @{0} работают также и в @{1}\n\n<code>/info</code>   <i>информация об аккаунте</i>\n<code>/stat</code>   <i>аналитика</i>\n<code>/update</code> <i>обновление профиля</i>\n<code>/status</code> <i>статус</i>\n<code>/off</code>  <i>выключение</i>\n<code>/repair</code> <i>очистка: чтение истории</i>\n<code>/reset</code>  <i>сброс: удаление диалогов</i>\n\n<code>/parse</code>      <i>[ссылка/id на чат] [аргумент]</i>\n<code>/spambot</code>    <i>карма аккаунта</i>\n<code>/leave</code>   <i>покинуть все группы и каналы</i>\n<code>/delete</code>  <i>удалить все диалоги</i>\n\n👩🏽‍💻 <b>Только</b> от имени аккаунта\n<code>/screen</code> <i>скриншот-уведомление</i>\n<code>/type +сообщ</code>   <i>печатание</i>\n<code>/think</code>   <i>обдумывание</i>\n<code>/emoji</code>  <i>подвижный emoji</i>\n<code>* отправка 📍гео возвращает @username-список</code>\n\n💨 <b>Подписка</b>: <i>{2}</i>",
    "en": "⚙️ <b>Commands</b> /cmd for @{0} also work in @{1}\n\n<code>/info</code>   <i>account information</i>\n<code>/stat</code>   <i>analytics</i>\n<code>/update</code> <i>profile update</i>\n<code>/status</code> <i>status</i>\n<code>/off</code>  <i>shutdown</i>\n<code>/repair</code> <i>cleaning: reading history</i>\n<code>/reset</code>  <i>reset: deleting dialogs</i>\n\n<code>/parse</code>      <i>[chat link/id] [argument]</i>\n<code>/spambot</code>    <i>account karma</i>\n<code>/leave</code>   <i>leave all groups and channels</i>\n<code>/delete</code>  <i>delete all dialogs</i>\n\n👩🏽‍💻 <b>Only</b> on behalf of the account\n<code>/screen</code> <i>screenshot notification</i>\n<code>/type +message</code>   <i>typing</i>\n<code>/think</code>   <i>thinking</i>\n<code>/emoji</code>  <i>moving emoji</i>\n<code>* sending 📍geo returns @username-list</code>\n\n💨 <b>Subscription</b>: <i>{2}</i>",
    "es": "⚙️ <b>Comandos</b> /cmd para @{0} también funcionan en @{1}\n\n<code>/info</code>   <i>información de la cuenta</i>\n<code>/stat</code>   <i>analítica</i>\n<code>/update</code> <i>actualización del perfil</i>\n<code>/status</code> <i>estado</i>\n<code>/off</code>  <i>apagado</i>\n<code>/repair</code> <i>limpieza: lectura del historial</i>\n<code>/reset</code>  <i>restablecer: eliminar diálogos</i>\n\n<code>/parse</code>      <i>[enlace/id del chat] [argumento]</i>\n<code>/spambot</code>    <i>karma de la cuenta</i>\n<code>/leave</code>   <i>salir de todos los grupos y canales</i>\n<code>/delete</code>  <i>eliminar todos los diálogos</i>\n\n👩🏽‍💻 <b>Solo</b> en nombre de la cuenta\n<code>/screen</code> <i>notificación de captura</i>\n<code>/type +mensaje</code>   <i>escribiendo</i>\n<code>/think</code>   <i>pensando</i>\n<code>/emoji</code>  <i>emoji en movimiento</i>\n<code>* enviar 📍geo devuelve la lista de @username</code>\n\n💨 <b>Suscripción</b>: <i>{2}</i>",
    "fr": "⚙️ <b>Commandes</b> /cmd pour @{0} fonctionnent également dans @{1}\n\n<code>/info</code>   <i>informations du compte</i>\n<code>/stat</code>   <i>analyses</i>\n<code>/update</code> <i>mise à jour du profil</i>\n<code>/status</code> <i>statut</i>\n<code>/off</code>  <i>arrêt</i>\n<code>/repair</code> <i>nettoyage : lecture de l'historique</i>\n<code>/reset</code>  <i>réinitialisation : suppression des dialogues</i>\n\n<code>/parse</code>      <i>[lien/id du chat] [argument]</i>\n<code>/spambot</code>    <i>karma du compte</i>\n<code>/leave</code>   <i>quitter tous les groupes et chaînes</i>\n<code>/delete</code>  <i>supprimer tous les dialogues</i>\n\n👩🏽‍💻 <b>Uniquement</b> au nom du compte\n<code>/screen</code> <i>notification de capture d'écran</i>\n<code>/type +message</code>   <i>saisie</i>\n<code>/think</code>   <i>réflexion</i>\n<code>/emoji</code>  <i>emoji en mouvement</i>\n<code>* l'envoi de 📍geo renvoie la liste @username</code>\n\n💨 <b>Abonnement</b> : <i>{2}</i>",
    "zh": "⚙️ <b>命令</b> /cmd 适用于 @{0}，也适用于 @{1}\n\n<code>/info</code>   <i>帐户信息</i>\n<code>/stat</code>   <i>分析</i>\n<code>/update</code> <i>资料更新</i>\n<code>/status</code> <i>状态</i>\n<code>/off</code>  <i>关闭</i>\n<code>/repair</code> <i>清理：读取历史记录</i>\n<code>/reset</code>  <i>重置：删除对话</i>\n\n<code>/parse</code>      <i>[聊天链接/id] [参数]</i>\n<code>/spambot</code>    <i>账户业力</i>\n<code>/leave</code>   <i>离开所有群组和频道</i>\n<code>/delete</code>  <i>删除所有对话</i>\n\n👩🏽‍💻 <b>仅</b>代表帐户\n<code>/screen</code> <i>截图通知</i>\n<code>/type +message</code>   <i>打字</i>\n<code>/think</code>   <i>思考</i>\n<code>/emoji</code>  <i>移动表情符号</i>\n<code>* 发送📍geo 返回 @username 列表</code>\n\n💨 <b>订阅</b>：<i>{2}</i>",
    "ar": "⚙️ <b>الأوامر</b> /cmd لـ @{0} تعمل أيضًا في @{1}\n\n<code>/info</code>   <i>معلومات الحساب</i>\n<code>/stat</code>   <i>التحليلات</i>\n<code>/update</code> <i>تحديث الملف الشخصي</i>\n<code>/status</code> <i>الحالة</i>\n<code>/off</code>  <i>إيقاف التشغيل</i>\n<code>/repair</code> <i>تنظيف: قراءة السجل</i>\n<code>/reset</code>  <i>إعادة ضبط: حذف المحادثات</i>\n\n<code>/parse</code>      <i>[رابط/معرف الدردشة] [وسيطة]</i>\n<code>/spambot</code>    <i>كارما الحساب</i>\n<code>/leave</code>   <i>مغادرة جميع المجموعات والقنوات</i>\n<code>/delete</code>  <i>حذف جميع المحادثات</i>\n\n👩🏽‍💻 <b>فقط</b> نيابةً عن الحساب\n<code>/screen</code> <i>إشعار لقطة الشاشة</i>\n<code>/type +message</code>   <i>الكتابة</i>\n<code>/think</code>   <i>التفكير</i>\n<code>/emoji</code>  <i>رموز تعبيرية متحركة</i>\n<code>* إرسال 📍جغرافي يعيد قائمة @username</code>\n\n💨 <b>الاشتراك</b>: <i>{2}</i>",
}
l_current_auth = {
    "ru": "текущая",
    "en": "current",
    "es": "actual",
    "fr": "actuelle",
    "zh": "当前的",
    "ar": "الحالية",
}
l_ctranscribe_res = {
    "ru": "👩🏽‍💻 <b>Транскрибация</b> <i>{0}</i> для {1}",
    "en": "👩🏽‍💻 <b>Transcription</b> <i>{0}</i> for {1}",
    "es": "👩🏽‍💻 <b>Transcripción</b> <i>{0}</i> para {1}",
    "fr": "👩🏽‍💻 <b>Transcription</b> <i>{0}</i> pour {1}",
    "zh": "👩🏽‍💻 <b>转录</b> <i>{0}</i> 为 {1}",
    "ar": "👩🏽‍💻 <b>النسخ</b> <i>{0}</i> لـ {1}",
}
l_cservice_user_online = {
    "ru": "<b>👩🏽‍💻 Пользователь</b>: {0} в сети",
    "en": "<b>👩🏽‍💻 User</b>: {0} online",
    "es": "<b>👩🏽‍💻 Usuario</b>: {0} en línea",
    "fr": "<b>👩🏽‍💻 Utilisateur</b> : {0} en ligne",
    "zh": "<b>👩🏽‍💻 用户</b>：{0} 在线",
    "ar": "<b>👩🏽‍💻 المستخدم</b>: {0} متصل",
}
l_cword_find = {
    "ru": "👩🏽‍💻 <b>Мониторинг слов</b>: <code>{0}</code> [{1}]",
    "en": "👩🏽‍💻 <b>Word monitoring</b>: <code>{0}</code> [{1}]",
    "es": "👩🏽‍💻 <b>Monitoreo de palabras</b>: <code>{0}</code> [{1}]",
    "fr": "👩🏽‍💻 <b>Surveillance des mots</b> : <code>{0}</code> [{1}]",
    "zh": "👩🏽‍💻 <b>单词监控</b>：<code>{0}</code> [{1}]",
    "ar": "👩🏽‍💻 <b>مراقبة الكلمات</b>: <code>{0}</code> [{1}]",
}
l_delete_handler = {
    "ru": "👩🏽‍💻 <b>Удаление</b> диалогов выполнено",
    "en": "👩🏽‍💻 <b>Deletion</b> of dialogues completed",
    "es": "👩🏽‍💻 <b>Eliminación</b> de diálogos completada",
    "fr": "👩🏽‍💻 <b>Suppression</b> des dialogues terminée",
    "zh": "👩🏽‍💻 <b>删除</b> 对话已完成",
    "ar": "👩🏽‍💻 اكتمل <b>حذف</b> المحادثات",
}
l_forward_message = {
    "ru": "👩🏽‍💻 <b>Пересылка</b> от {0}:",
    "en": "👩🏽‍💻 <b>Forwarding</b> from {0}:",
    "es": "👩🏽‍💻 <b>Reenvío</b> desde {0}:",
    "fr": "👩🏽‍💻 <b>Transfert</b> depuis {0} :",
    "zh": "👩🏽‍💻 <b>转发</b>，来自 {0}：",
    "ar": "👩🏽‍💻 <b>إعادة التوجيه</b> من {0}:",
}
l_have_read = {
    "ru": "👩🏽‍💻 {0} прочитал сообщение",
    "en": "👩🏽‍💻 {0} read the message",
    "es": "👩🏽‍💻 {0} leyó el mensaje",
    "fr": "👩🏽‍💻 {0} a lu le message",
    "zh": "👩🏽‍💻 {0} 已阅读该消息",
    "ar": "👩🏽‍💻 {0} قرأ الرسالة",
}
l_idea = {
    "ru": "💡 <b>Идея!</b>",
    "en": "💡 <b>Idea!</b>",
    "es": "💡 <b>¡Idea!</b>",
    "fr": "💡 <b>Idée!</b>",
    "zh": "💡 <b>想法！</b>",
    "ar": "💡 <b>فكرة!</b>",
}

l_leave_handler = {
    "ru": "👩🏽‍💻 <b>Выход</b> из групп/каналов выполнен",
    "en": "👩🏽‍💻 <b>Exit</b> from groups/channels completed",
    "es": "👩🏽‍💻 <b>Salida</b> de grupos/canales completada",
    "fr": "👩🏽‍💻 <b>Sortie</b> des groupes/chaînes terminée",
    "zh": "👩🏽‍💻 <b>退出</b> 群组/频道已完成",
    "ar": "👩🏽‍💻 اكتمل <b>الخروج</b> من المجموعات/القنوات",
}
l_parse_handler_err = {
    "ru": "👩🏽‍💻 Вставь корректную ссылку, повтори операцию или попробуй вступить вручную",
    "en": "👩🏽‍💻 Insert the correct link, repeat the operation or try to join manually",
    "es": "👩🏽‍💻 Inserta el enlace correcto, repite la operación o intenta unirte manualmente",
    "fr": "👩🏽‍💻 Insérez le lien correct, répétez l'opération ou essayez de rejoindre manuellement",
    "zh": "👩🏽‍💻 插入正确的链接，重复操作或尝试手动加入",
    "ar": "👩🏽‍💻 أدخل الرابط الصحيح، كرر العملية أو حاول الانضمام يدوياً",
}
l_think_handler = {
    "ru": "💭 Думаю об этом.. {0}%",
    "en": "💭 Thinking about it.. {0}%",
    "es": "💭 Pensando en ello... {0}%",
    "fr": "💭 J'y pense.. {0}%",
    "zh": "💭 想想.. {0}%",
    "ar": "💭 أفكر في الأمر.. {0}%",
}
l_translated_in = {
    "ru": "👩🏽‍💻 <b>Переведено</b> в [{0}]-язык для {1} [<code>{2}</code>]",
    "en": "👩🏽‍💻 <b>Translated</b> into [{0}] language for {1} [<code>{2}</code>]",
    "es": "👩🏽‍💻 <b>Traducido</b> al idioma [{0}] para {1} [<code>{2}</code>]",
    "fr": "👩🏽‍💻 <b>Traduit</b> en langue [{0}] pour {1} [<code>{2}</code>]",
    "zh": "👩🏽‍💻 <b>已翻译</b> 为 [{0}] 语言，针对 {1} [<code>{2}</code>]",
    "ar": "👩🏽‍💻 <b>مترجمة</b> إلى لغة [{0}] لـ {1} [<code>{2}</code>]",
}
l_update_fun = {
    "ru": "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Био:</b> {3}\n\n✅ <i>Профиль обновлен</i>\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Bio:</b> {3}\n\n✅ <i>Profile updated</i>\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Biografía:</b> {3}\n\n✅ <i>Perfil actualizado</i>\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Bio :</b> {3}\n\n✅ <i>Profil mis à jour</i>\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>个人简介：</b> {3}\n\n✅ <i>个人资料已更新</i>\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>السيرة الذاتية:</b> {3}\n\n✅ <i>تم تحديث الملف الشخصي</i>\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_usr_flt_delhistory_done = {
    "ru": "👩🏽‍💻 <b>Удаление</b> <u>{0}</u> своих сообщений в <code>{1}</code> завершено",
    "en": "👩🏽‍💻 <b>Deletion</b> of <u>{0}</u>'s messages in <code>{1}</code> completed",
    "es": "👩🏽‍💻 <b>Eliminación</b> de los mensajes de <u>{0}</u> en <code>{1}</code> completada",
    "fr": "👩🏽‍💻 <b>Suppression</b> des messages de <u>{0}</u> dans <code>{1}</code> terminée",
    "zh": "👩🏽‍💻 <b>删除</b> <u>{0}</u> 在 <code>{1}</code> 的消息已完成",
    "ar": "👩🏽‍💻 اكتمل <b>حذف</b> رسائل <u>{0}</u> في <code>{1}</code>",
}
l_usr_flt_usrhistory = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> указать:\n\n<code>/usrhistory chat_id user_id cnt_limit</code>, где\n<blockquote>chat_id - группа\nuser_id - пользователь\ncnt_limit - количество сообщений\n</blockquote>",
    "en": "👩🏽‍💻 <b>Required</b> to specify:\n\n<code>/usrhistory chat_id user_id cnt_limit</code>, where\n<blockquote>chat_id - group\nuser_id - user\ncnt_limit - number of messages\n</blockquote>",
    "es": "👩🏽‍💻 <b>Es necesario</b> especificar:\n\n<code>/usrhistory chat_id user_id cnt_limit</code>, donde\n<blockquote>chat_id - grupo\nuser_id - usuario\ncnt_limit - número de mensajes\n</blockquote>",
    "fr": "👩🏽‍💻 <b>Il faut</b> indiquer :\n\n<code>/usrhistory chat_id user_id cnt_limit</code>, où\n<blockquote>chat_id - groupe\nuser_id - utilisateur\ncnt_limit - nombre de messages\n</blockquote>",
    "zh": "👩🏽‍💻 <b>需要</b> 指定：\n\n<code>/usrhistory chat_id user_id cnt_limit</code>，其中\n<blockquote>chat_id - 群组\nuser_id - 用户\ncnt_limit - 消息数量\n</blockquote>",
    "ar": "👩🏽‍💻 <b>مطلوب</b> تحديد:\n\n<code>/usrhistory chat_id user_id cnt_limit</code>، حيث\n<blockquote>chat_id - المجموعة\nuser_id - المستخدم\ncnt_limit - عدد الرسائل\n</blockquote>",
}
l_usr_flt_usrhistory_not_found = {
    "ru": "👩🏽‍💻 <b>Сообщений</b> от пользователя {0} в {1} не найдено",
    "en": "👩🏽‍💻 <b>No messages</b> from user {0} in {1} were found",
    "es": "👩🏽‍💻 <b>No se encontraron</b> mensajes del usuario {0} en {1}",
    "fr": "👩🏽‍💻 <b>Aucun message</b> de l'utilisateur {0} dans {1} n'a été trouvé",
    "zh": "👩🏽‍💻 <b>未找到</b> 用户 {0} 在 {1} 的消息",
    "ar": "👩🏽‍💻 <b>لا توجد رسائل</b> من المستخدم {0} في {1}",
}
l_usr_flt_usrhistory_done = {
    "ru": "👩🏽‍💻 <b>Сообщения</b> от пользователя {0} в {1}: <u>{2}</u>",
    "en": "👩🏽‍💻 <b>Messages</b> from user {0} in {1}: <u>{2}</u>",
    "es": "👩🏽‍💻 <b>Mensajes</b> del usuario {0} en {1}: <u>{2}</u>",
    "fr": "👩🏽‍💻 <b>Messages</b> de l'utilisateur {0} dans {1} : <u>{2}</u>",
    "zh": "👩🏽‍💻 <b>消息</b> 来自用户 {0} 在 {1}：<u>{2}</u>",
    "ar": "👩🏽‍💻 <b>الرسائل</b> من المستخدم {0} في {1}: <u>{2}</u>",
}
l_usr_karma_ok = {
    "ru": "👩🏽‍💻 <b>Карма</b>:\n{0} - локальная\n{1} - глобальная\n<i>{2}</i>\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Karma</b>:\n{0} - local\n{1} - global\n<i>{2}</i>\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Karma</b>:\n{0} - local\n{1} - global\n<i>{2}</i>\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Karma</b> :\n{0} - local\n{1} - global\n<i>{2}</i>\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>业力</b>：\n{0} - 本地\n{1} - 全局\n<i>{2}</i>\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الكارما</b>:\n{0} - محلي\n{1} - عالمي\n<i>{2}</i>\n\n⚙️ <b>الأوامر</b> /cmd",
}

l_userbot_cmd_acc = {
    "ru": "👩🏽‍💻 <b>Информация:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Био:</b> {2}",
    "en": "👩🏽‍💻 <b>Information:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Bio:</b> {2}",
    "es": "👩🏽‍💻 <b>Información:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Bio:</b> {2}",
    "fr": "👩🏽‍💻 <b>Informations :</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Bio :</b> {2}",
    "zh": "👩🏽‍💻 <b>信息：</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>个人简介：</b> {2}",
    "ar": "👩🏽‍💻 <b>معلومات:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>السيرة الذاتية:</b> {2}",
}
l_userbot_cmd_acc2 = {
    "ru": "👩🏽‍💻 <b>Информация:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    "en": "👩🏽‍💻 <b>Information:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    "es": "👩🏽‍💻 <b>Información:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    "fr": "👩🏽‍💻 <b>Informations :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    "zh": "👩🏽‍💻 <b>信息：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    "ar": "👩🏽‍💻 <b>معلومات:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
}
l_userbot_cmd_all = {
    "ru": "\n<b>Пользователи/боты/группы/каналы</b>: {0}",
    "en": "\n<b>Users/bots/groups/channels</b>: {0}",
    "es": "\n<b>Usuarios/bots/grupos/canales</b>: {0}",
    "fr": "\n<b>Utilisateurs/bots/groupes/canaux</b> : {0}",
    "zh": "\n<b>用户/机器人/组/频道</b>：{0}",
    "ar": "\n<b>المستخدمون/الروبوتات/المجموعات/القنوات</b>: {0}",
}
l_userbot_cmd_admin = {
    "ru": "\n\n<b>Администратор</b> <u>групп/каналов</u>: <code>{0}</code>\n{1}",
    "en": "\n\n<b>Admin</b> <u>groups/channels</u>: <code>{0}</code>\n{1}",
    "es": "\n\n<b>Admin</b> <u>grupos/canales</u>: <code>{0}</code>\n{1}",
    "fr": "\n\n<b>Administrateur</b> <u>groupes/canaux</u> : <code>{0}</code>\n{1}",
    "zh": "\n\n<b>管理员</b> <u>群组/频道</u>：<code>{0}</code>\n{1}",
    "ar": "\n\n<b>المسؤول</b> <u>المجموعات/القنوات</u>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_authorizations = {
    "ru": "\n<b>Авторизации:</b> <code>{0}</code>\n{1}",
    "en": "\n<b>Authorizations:</b> <code>{0}</code>\n{1}",
    "es": "\n<b>Autorizaciones:</b> <code>{0}</code>\n{1}",
    "fr": "\n<b>Autorisations :</b> <code>{0}</code>\n{1}",
    "zh": "\n<b>授权：</b> <code>{0}</code>\n{1}",
    "ar": "\n<b>التفويضات:</b> <code>{0}</code>\n{1}",
}
l_userbot_cmd_auto_archive = {
    "ru": "<b>Авто-архив spam-пользователей:</b> ",
    "en": "<b>Auto-archive of spam users:</b> ",
    "es": "<b>Archivado automático de usuarios de spam:</b> ",
    "fr": "<b>Archive automatique des utilisateurs indésirables :</b> ",
    "zh": "<b>垃圾邮件用户的自动存档：</b> ",
    "ar": "<b>الأرشفة التلقائية لمستخدمي البريد العشوائي:</b> ",
}
l_userbot_cmd_black = {
    "ru": "\n<b>Черный список</b>: <code>{0}</code>",
    "en": "\n<b>Blacklist</b>: <code>{0}</code>",
    "es": "\n<b>Lista negra</b>: <code>{0}</code>",
    "fr": "\n<b>Liste noire</b> : <code>{0}</code>",
    "zh": "\n<b>黑名单</b>：<code>{0}</code>",
    "ar": "\n<b>القائمة السوداء</b>: <code>{0}</code>",
}
l_userbot_cmd_bot_father = {
    "ru": "\n\n<b>Боты {0}</b>: <code>{1}/20</code>\n{2}",
    "en": "\n\n<b>Bots {0}</b>: <code>{1}/20</code>\n{2}",
    "es": "\n\n<b>Bots {0}</b>: <code>{1}/20</code>\n{2}",
    "fr": "\n\n<b>Bots {0}</b> : <code>{1}/20</code>\n{2}",
    "zh": "\n\n<b>机器人 {0}</b>：<code>{1}/20</code>\n{2}",
    "ar": "\n\n<b>الروبوتات {0}</b>: <code>{1}/20</code>\n{2}",
}
l_userbot_cmd_cmds = {
    "ru": "\n\n⚙️ <b>Команды</b> /cmd",
    "en": "\n\n⚙️ <b>Commands</b> /cmd",
    "es": "\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "\n\n⚙️ <b>命令</b> /cmd",
    "ar": "\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_cmd_cloud_pswd = {
    "ru": "<b>Облачный пароль</b>: <code>{0}</code>",
    "en": "<b>Cloud password</b>: <code>{0}</code>",
    "es": "<b>Contraseña de la nube</b>: <code>{0}</code>",
    "fr": "<b>Mot de passe cloud</b> : <code>{0}</code>",
    "zh": "<b>云密码</b>：<code>{0}</code>",
    "ar": "<b>كلمة مرور السحابة</b>: <code>{0}</code>",
}

l_userbot_cmd_common_chats = {
    "ru": "\n<b>Общие чаты:</b> {0}",
    "en": "\n<b>Common chats:</b> {0}",
    "es": "\n<b>Chats comunes:</b> {0}",
    "fr": "\n<b>Chats communs :</b> {0}",
    "zh": "\n<b>公共聊天：</b> {0}",
    "ar": "\n<b>الدردشات المشتركة:</b> {0}",
}
l_userbot_cmd_contacts = {
    "ru": "\n<b>Контакты</b> <u>взаимные/недавние/все</u>: {0}",
    "en": "\n<b>Contacts</b> <u>mutual/recent/all</u>: {0}",
    "es": "\n<b>Contactos</b> <u>mutuos/recientes/todos</u>: {0}",
    "fr": "\n<b>Contacts</b> <u>réciproques/récents/tous</u> : {0}",
    "zh": "\n<b>联系人</b> <u>相互/最近/全部</u>：{0}",
    "ar": "\n<b>جهات الاتصال</b> <u>متبادلة/حديثة/الكل</u>: {0}",
}
l_userbot_cmd_dlgs = {
    "ru": "\n<b>Диалоги</b> <u>архив/закреп/все</u>: {0}",
    "en": "\n<b>Dialogs</b> <u>archive/pinned/all</u>: {0}",
    "es": "\n<b>Diálogos</b> <u>archivo/fijados/todos</u>: {0}",
    "fr": "\n<b>Dialogues</b> <u>archive/épinglés/tous</u> : {0}",
    "zh": "\n<b>对话</b> <u>存档/置顶/全部</u>：{0}",
    "ar": "\n<b>المحادثات</b> <u>الأرشيف/المثبتة/الكل</u>: {0}",
}
l_userbot_cmd_drafts = {
    "ru": "\n<b>Черновики/помеченные:</b> <code>{0}/{1}</code>",
    "en": "\n<b>Drafts/marked:</b> <code>{0}/{1}</code>",
    "es": "\n<b>Borradores/marcados:</b> <code>{0}/{1}</code>",
    "fr": "\n<b>Brouillons/marqués :</b> <code>{0}/{1}</code>",
    "zh": "\n<b>草稿/已标记：</b> <code>{0}/{1}</code>",
    "ar": "\n<b>المسودات/المميزة:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_fld_bots = {
    "ru": "боты",
    "en": "bots",
    "es": "bots",
    "fr": "bots",
    "zh": "机器人",
    "ar": "بوتات",
}
l_userbot_cmd_fld_chns = {
    "ru": "каналы",
    "en": "channels",
    "es": "canales",
    "fr": "chaînes",
    "zh": "频道",
    "ar": "القنوات",
}
l_userbot_cmd_fld_grps = {
    "ru": "группы",
    "en": "groups",
    "es": "grupos",
    "fr": "groupes",
    "zh": "群组",
    "ar": "مجموعات",
}
l_userbot_cmd_fld_fave = {
    "ru": "избранное",
    "en": "favorites",
    "es": "favoritos",
    "fr": "favoris",
    "zh": "收藏夹",
    "ar": "المفضلة",
}
l_userbot_cmd_fld_users = {
    "ru": "пользователи",
    "en": "users",
    "es": "usuarios",
    "fr": "utilisateurs",
    "zh": "用户",
    "ar": "المستخدمون",
}
l_userbot_cmd_flds = {
    "ru": "\n<b>Папки</b>: <code>{0}</code>\n{1}",
    "en": "\n<b>Folders</b>: <code>{0}</code>\n{1}",
    "es": "\n<b>Carpetas</b>: <code>{0}</code>\n{1}",
    "fr": "\n<b>Dossiers</b> : <code>{0}</code>\n{1}",
    "zh": "\n<b>文件夹</b>：<code>{0}</code>\n{1}",
    "ar": "\n<b>المجلدات</b>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_info_fun = {
    "ru": "👩🏽‍💻 <b>Информация:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, цвет: {3}, тема: {4}, dc: {5}]\n<b>Био:</b> {6}",
    "en": "👩🏽‍💻 <b>Information:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, color: {3}, theme: {4}, dc: {5}]\n<b>Bio:</b> {6}",
    "es": "👩🏽‍💻 <b>Información:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, color: {3}, tema: {4}, dc: {5}]\n<b>Biografía:</b> {6}",
    "fr": "👩🏽‍💻 <b>Informations :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, couleur : {3}, thème : {4}, dc : {5}]\n<b>Bio :</b> {6}",
    "zh": "👩🏽‍💻 <b>信息：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, 颜色：{3}, 主题：{4}, dc：{5}]\n<b>简介：</b> {6}",
    "ar": "👩🏽‍💻 <b>المعلومات:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, اللون: {3}, الموضوع: {4}, dc: {5}]\n<b>السيرة الذاتية:</b> {6}",
}
l_userbot_cmd_info_confident = {
    "ru": "\n\n<b>Конфиденциальность:</b>\n{0}",
    "en": "\n\n<b>Privacy:</b>\n{0}",
    "es": "\n\n<b>Privacidad:</b>\n{0}",
    "fr": "\n\n<b>Confidentialité :</b>\n{0}",
    "zh": "\n\n<b>隐私：</b>\n{0}",
    "ar": "\n\n<b>الخصوصية:</b>\n{0}",
}
l_userbot_cmd_info_status = {
    "ru": "{0}-<i>эмоджи-статус</i>",
    "en": "{0}-<i>emoji-status</i>",
    "es": "{0}-<i>estado emoji</i>",
    "fr": "{0}-<i>statut emoji</i>",
    "zh": "{0}-<i>表情符号状态</i>",
    "ar": "{0}-<i>حالة الرموز التعبيرية</i>",
}
l_userbot_cmd_info_premium = {
    "ru": "\n<b>Премиум:</b> {0}",
    "en": "\n<b>Premium:</b> {0}",
    "es": "\n<b>Premium:</b> {0}",
    "fr": "\n<b>Premium :</b> {0}",
    "zh": "\n<b>高级：</b> {0}",
    "ar": "\n<b>المميز:</b> {0}",
}
l_userbot_cmd_info_fake = {
    "ru": "\n<b>Фейк:</b> да",
    "en": "\n<b>Fake:</b> yes",
    "es": "\n<b>Falso:</b> sí",
    "fr": "\n<b>Faux :</b> oui",
    "zh": "\n<b>假：</b>是",
    "ar": "\n<b>زائف:</b> نعم",
}
l_userbot_cmd_info_scam = {
    "ru": "\n<b>Скам:</b> да",
    "en": "\n<b>Scam:</b> yes",
    "es": "\n<b>Estafa:</b> sí",
    "fr": "\n<b>Arnaque :</b> oui",
    "zh": "\n<b>诈骗：</b>是",
    "ar": "\n<b>عملية احتيال:</b> نعم",
}
l_userbot_cmd_info_restricted = {
    "ru": "\n<b>Ограничен:</b> да",
    "en": "\n<b>Restricted:</b> yes",
    "es": "\n<b>Restringido:</b> sí",
    "fr": "\n<b>Restreint :</b> oui",
    "zh": "\n<b>受限：</b> 是",
    "ar": "\n<b>مقيد:</b> نعم",
}
l_userbot_cmd_info_extra = {
    "ru": "\n<b>Цвет:</b> да",
    "en": "\n<b>Color:</b> yes",
    "es": "\n<b>Color:</b> sí",
    "fr": "\n<b>Couleur :</b> oui",
    "zh": "\n<b>颜色：</b> 是",
    "ar": "\n<b>اللون:</b> نعم",
}
l_userbot_cmd_nsfw = {
    "ru": "<b>NSFW (/sensitive контент):</b> ",
    "en": "<b>NSFW (/sensitive content):</b> ",
    "es": "<b>NSFW (/contenido sensible):</b> ",
    "fr": "<b>NSFW (/contenu sensible) :</b> ",
    "zh": "<b>NSFW（/敏感内容）：</b> ",
    "ar": "<b>NSFW (/محتوى حساس):</b> ",
}
l_userbot_cmd_profile_photo = {
    "ru": "\n<b>Фото профиля</b>: {0}",
    "en": "\n<b>Profile photo</b>: {0}",
    "es": "\n<b>Foto de perfil</b>: {0}",
    "fr": "\n<b>Photo de profil</b> : {0}",
    "zh": "\n<b>个人资料照片</b>：{0}",
    "ar": "\n<b>صورة الملف الشخصي</b>: {0}",
}
l_userbot_cmd_lang = {
    "ru": "\n<b>Язык</b>: <code>{0}</code>",
    "en": "\n<b>Language</b>: <code>{0}</code>",
    "es": "\n<b>Idioma</b>: <code>{0}</code>",
    "fr": "\n<b>Langue</b> : <code>{0}</code>",
    "zh": "\n<b>语言</b>：<code>{0}</code>",
    "ar": "\n<b>اللغة</b>: <code>{0}</code>",
}
l_userbot_cmd_react = {
    "ru": "\n<b>Стандарт-реакции:</b> <code>{0}</code>",
    "en": "\n<b>Standard reactions:</b> <code>{0}</code>",
    "es": "\n<b>Reacciones estándar:</b> <code>{0}</code>",
    "fr": "\n<b>Réactions standard :</b> <code>{0}</code>",
    "zh": "\n<b>标准反应：</b> <code>{0}</code>",
    "ar": "\n<b>التفاعلات القياسية:</b> <code>{0}</code>",
}
l_userbot_cmd_gif_mask = {
    "ru": "\n<b>Сохраненные гиф/маски:</b> <code>{0}/{1}</code>",
    "en": "\n<b>Saved gifs/masks:</b> <code>{0}/{1}</code>",
    "es": "\n<b>Gifs/máscaras guardados:</b> <code>{0}/{1}</code>",
    "fr": "\n<b>Gifs/masques enregistrés :</b> <code>{0}/{1}</code>",
    "zh": "\n<b>已保存的 gif/蒙版：</b> <code>{0}/{1}</code>",
    "ar": "\n<b>الصور المتحركة/الأقنعة المحفوظة:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_theme_wall = {
    "ru": "\n<b>Темы/Обои:</b> <code>{0}/{1}</code> {2}",
    "en": "\n<b>Themes/Wallpapers:</b> <code>{0}/{1}</code> {2}",
    "es": "\n<b>Temas/Fondos de pantalla:</b> <code>{0}/{1}</code> {2}",
    "fr": "\n<b>Thèmes/Fonds d'écran :</b> <code>{0}/{1}</code> {2}",
    "zh": "\n<b>主题/壁纸：</b> <code>{0}/{1}</code> {2}",
    "ar": "\n<b>المظاهر/الخلفيات:</b> <code>{0}/{1}</code> {2}",
}
l_userbot_cmd_sick_emoj = {
    "ru": "\n<b>Stickers/Emoji</b>: <code>{0}/{1}</code>{2}",
    "en": "\n<b>Stickers/Emoji</b>: <code>{0}/{1}</code>{2}",
    "es": "\n<b>Stickers/Emoji</b>: <code>{0}/{1}</code>{2}",
    "fr": "\n<b>Stickers/Emoji</b> : <code>{0}/{1}</code>{2}",
    "zh": "\n<b>贴纸/表情符号</b>：<code>{0}/{1}</code>{2}",
    "ar": "\n<b>الملصقات/الرموز التعبيرية</b>: <code>{0}/{1}</code>{2}",
}
l_userbot_cmd_bot = {
    "ru": "\n\n<b>Бот:</b> @{0} ({1})",
    "en": "\n\n<b>Bot:</b> @{0} ({1})",
    "es": "\n\n<b>Bot:</b> @{0} ({1})",
    "fr": "\n\n<b>Bot :</b> @{0} ({1})",
    "zh": "\n\n<b>机器人：</b> @{0} ({1})",
    "ar": "\n\n<b>الروبوت:</b> @{0} ({1})",
}
l_userbot_cmd_chn = {
    "ru": "\n<b>Канал:</b> @{0} ({1})",
    "en": "\n<b>Channel:</b> @{0} ({1})",
    "es": "\n<b>Canal:</b> @{0} ({1})",
    "fr": "\n<b>Canal :</b> @{0} ({1})",
    "zh": "\n<b>频道：</b> @{0} ({1})",
    "ar": "\n<b>القناة:</b> @{0} ({1})",
}
l_userbot_cmd_bot_chn = {
    "ru": "\n<i>[бот и публичный канал необходимы для работы со сложными постами]</i>",
    "en": "\n<i>[a bot and a public channel are required to work with complex posts]</i>",
    "es": "\n<i>[se requiere un bot y un canal público para trabajar con publicaciones complejas]</i>",
    "fr": "\n<i>[un bot et une chaîne publique sont requis pour travailler avec des publications complexes]</i>",
    "zh": "\n<i>[处理复杂帖子需要机器人和公开频道]</i>",
    "ar": "\n<i>[مطلوب روبوت وقناة عامة للعمل مع منشورات معقدة]</i>",
}
l_userbot_cmd_top_send = {
    "ru": "\n@{0} написал(а): {1} сообщ",
    "en": "\n@{0} wrote: {1} messages",
    "es": "\n@{0} escribió: {1} mensajes",
    "fr": "\n@{0} a écrit : {1} messages",
    "zh": "\n@{0} 写了：{1} 条消息",
    "ar": "\n@{0} كتب: {1} رسالة",
}
l_userbot_cmd_top_users = {
    "ru": "<b>\n\n👩🏽‍💻 Топ пользователей (на 1000 сообщ)</b>: {0}\n",
    "en": "<b>\n\n👩🏽‍💻 Top users (per 1000 posts)</b>: {0}\n",
    "es": "<b>\n\n👩🏽‍💻 Usuarios principales (por cada 1000 publicaciones)</b>: {0}\n",
    "fr": "<b>\n\n👩🏽‍💻 Principaux utilisateurs (pour 1000 posts)</b> : {0}\n",
    "zh": "<b>\n\n👩🏽‍💻 热门用户（每 1000 帖）</b>：{0}\n",
    "ar": "<b>\n\n👩🏽‍💻 أهم المستخدمين (لكل 1000 مشاركة)</b>: {0}\n",
}
l_userbot_cmd_top_words = {
    "ru": "\n{0}. <i>{1}</i>..: встретилось {2} раз",
    "en": "\n{0}. <i>{1}</i>..: occurred {2} times",
    "es": "\n{0}. <i>{1}</i>..: ocurrió {2} veces",
    "fr": "\n{0}. <i>{1}</i>.. : s'est produit {2} fois",
    "zh": "\n{0}。 <i>{1}</i>..：出现 {2} 次",
    "ar": "\n{0}. <i>{1}</i>..: حدث {2} مرات",
}
l_userbot_cmd_top_msgs = {
    "ru": "<b>\n👩🏽‍💻 Топ сообщ (из 1000)</b>: {0}\n",
    "en": "<b>\n👩🏽‍💻 Top messages (out of 1000)</b>: {0}\n",
    "es": "<b>\n👩🏽‍💻 Mensajes principales (de 1000)</b>: {0}\n",
    "fr": "<b>\n👩🏽‍💻 Messages principaux (sur 1000)</b> : {0}\n",
    "zh": "<b>\n👩🏽‍💻 热门消息（共1000条）</b>：{0}\n",
    "ar": "<b>\n👩🏽‍💻 أهم الرسائل (من أصل 1000)</b>: {0}\n",
}
l_userbot_cmd_life_time = {
    "ru": "\n\n<b>Время жизни аккаунта:</b> ~{0} дней",
    "en": "\n\n<b>Account lifetime:</b> ~{0} days",
    "es": "\n\n<b>Vida útil de la cuenta:</b> ~{0} días",
    "fr": "\n\n<b>Durée de vie du compte :</b> ~{0} jours",
    "zh": "\n\n<b>帐户寿命：</b> ~{0} 天",
    "ar": "\n\n<b>عمر الحساب:</b> ~{0} يوم",
}
l_userbot_cmd_first_dlg = {
    "ru": "\n<b>Дата первого диалога:</b> ~{0}",
    "en": "\n<b>Date of first dialog:</b> ~{0}",
    "es": "\n<b>Fecha del primer diálogo:</b> ~{0}",
    "fr": "\n<b>Date du premier dialogue :</b> ~{0}",
    "zh": "\n<b>首次对话日期：</b> ~{0}",
    "ar": "\n<b>تاريخ المحادثة الأولى:</b> ~{0}",
}
l_userbot_cmd_first_karma = {
    "ru": "\n<b>Карма:</b> <code>{0}</code> /spambot",
    "en": "\n<b>Karma:</b> <code>{0}</code> /spambot",
    "es": "\n<b>Karma:</b> <code>{0}</code> /spambot",
    "fr": "\n<b>Karma :</b> <code>{0}</code> /spambot",
    "zh": "\n<b>业力：</b> <code>{0}</code> /spambot",
    "ar": "\n<b>الكارما:</b> <code>{0}</code> /spambot",
}
l_userbot_cmd_ring = {
    "ru": "\n<b>Рингтоны:</b> <code>{0}</code>",
    "en": "\n<b>Ringtones:</b> <code>{0}</code>",
    "es": "\n<b>Tonos de llamada:</b> <code>{0}</code>",
    "fr": "\n<b>Sonneries :</b> <code>{0}</code>",
    "zh": "\n<b>铃声：</b> <code>{0}</code>",
    "ar": "\n<b>نغمات الرنين:</b> <code>{0}</code>",
}
l_userbot_cmd_notify = {
    "ru": "\n<b>Особые уведомления:</b> {0}",
    "en": "\n<b>Special notices:</b> {0}",
    "es": "\n<b>Avisos especiales:</b> {0}",
    "fr": "\n<b>Avis spéciaux :</b> {0}",
    "zh": "\n<b>特别通知：</b> {0}",
    "ar": "\n<b>إشعارات خاصة:</b> {0}",
}
l_userbot_cmd_sched = {
    "ru": "\n<b>Отложенные/посты/офферы</b>: {0}",
    "en": "\n<b>Scheduled/posts/offers</b>: {0}",
    "es": "\n<b>Programados/publicaciones/ofertas</b>: {0}",
    "fr": "\n<b>Planifiés/messages/offres</b> : {0}",
    "zh": "\n<b>定时/帖子/优惠</b>：{0}",
    "ar": "\n<b>مجدولة/منشورات/عروض</b>: {0}",
}
l_userbot_cmd_last_react = {
    "ru": "\n<b>Последние реакции:</b> {0}",
    "en": "\n<b>Latest reactions:</b> {0}",
    "es": "\n<b>Últimas reacciones:</b> {0}",
    "fr": "\n<b>Dernières réactions :</b> {0}",
    "zh": "\n<b>最新反应：</b> {0}",
    "ar": "\n<b>أحدث التفاعلات:</b> {0}",
}
l_userbot_cmd_unread_react = {
    "ru": "\n<b>Непрочитанные @тэги/реакции:</b> <code>{0}/{1}</code>",
    "en": "\n<b>Unread @tags/reactions:</b> <code>{0}/{1}</code>",
    "es": "\n<b>@etiquetas/reacciones no leídas:</b> <code>{0}/{1}</code>",
    "fr": "\n<b>@tags/réactions non lus :</b> <code>{0}/{1}</code>",
    "zh": "\n<b>未读@标签/反应：</b> <code>{0}/{1}</code>",
    "ar": "\n<b>العلامات/التفاعلات غير المقروءة:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_unread_msgs = {
    "ru": "\n<b>Непрочитанные сообщ (и архив):</b> <code>{0}</code>",
    "en": "\n<b>Unread messages (and archive):</b> <code>{0}</code>",
    "es": "\n<b>Mensajes no leídos (y archivados):</b> <code>{0}</code>",
    "fr": "\n<b>Messages non lus (et archives) :</b> <code>{0}</code>",
    "zh": "\n<b>未读消息（及存档）：</b> <code>{0}</code>",
    "ar": "\n<b>الرسائل غير المقروءة (والأرشيف):</b> <code>{0}</code>",
}
l_userbot_cmd_owner = {
    "ru": "\n\n<b>Владелец</b> <u>групп/каналов</u>: <code>{0}</code>\n{1}",
    "en": "\n\n<b>Owner</b> <u>of groups/channels</u>: <code>{0}</code>\n{1}",
    "es": "\n\n<b>Propietario</b> <u>de grupos/canales</u>: <code>{0}</code>\n{1}",
    "fr": "\n\n<b>Propriétaire</b> <u>des groupes/canaux</u> : <code>{0}</code>\n{1}",
    "zh": "\n\n<b>所有者</b> <u>群组/频道</u>：<code>{0}</code>\n{1}",
    "ar": "\n\n<b>المالك</b> <u>المجموعات/القنوات</u>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_top_affects = {
    "ru": "\n\n<b>Топ взаимодействий</b>:\n{0}",
    "en": "\n\n<b>Top interactions</b>:\n{0}",
    "es": "\n\n<b>Interacciones principales</b>:\n{0}",
    "fr": "\n\n<b>Principales interactions</b> :\n{0}",
    "zh": "\n\n<b>热门互动</b>：\n{0}",
    "ar": "\n\n<b>أهم التفاعلات</b>:\n{0}",
}
l_userbot_cmd_last_msgs = {
    "ru": "\n\n<b>Последние сообщения</b>:\n{0}",
    "en": "\n\n<b>Latest messages</b>:\n{0}",
    "es": "\n\n<b>Últimos mensajes</b>:\n{0}",
    "fr": "\n\n<b>Derniers messages</b> :\n{0}",
    "zh": "\n\n<b>最新消息</b>：\n{0}",
    "ar": "\n\n<b>أحدث الرسائل</b>:\n{0}",
}
l_userbot_cmd_parse_fun = {
    "ru": "👩🏽‍💻 Готово! Для <b>{0}</b> собрано реальных <b>{1}</b>-участников: <u>{2}</u>{3}",
    "en": "👩🏽‍💻 Done! For <b>{0}</b> real <b>{1}</b> participants were collected: <u>{2}</u>{3}",
    "es": "👩🏽‍💻 ¡Listo! Para <b>{0}</b> se recopilaron <b>{1}</b> participantes reales: <u>{2}</u>{3}",
    "fr": "👩🏽‍💻 C'est fait ! Pour <b>{0}</b> de vrais <b>{1}</b> participants ont été collectés : <u>{2}</u>{3}",
    "zh": "👩🏽‍💻 完成！对于 <b>{0}</b> 收集到真实的 <b>{1}</b> 名参与者：<u>{2}</u>{3}",
    "ar": "👩🏽‍💻 تم! بالنسبة إلى <b>{0}</b> تم جمع <b>{1}</b> من المشاركين الحقيقيين: <u>{2}</u>{3}",
}
l_userbot_cmd_update_err = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> обновления профиля",
    "en": "👩🏽‍💻 <b>Error</b> updating profile",
    "es": "👩🏽‍💻 <b>Error</b> al actualizar el perfil",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors de la mise à jour du profil",
    "zh": "👩🏽‍💻 <b>错误</b> 更新个人资料",
    "ar": "👩🏽‍💻 <b>خطأ</b> في تحديث الملف الشخصي",
}
l_userbot_cmd_update_info = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> получения профиля",
    "en": "👩🏽‍💻 <b>Error</b> retrieving profile",
    "es": "👩🏽‍💻 <b>Error</b> al obtener el perfil",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors de la récupération du profil",
    "zh": "👩🏽‍💻 <b>获取个人资料时出错</b>",
    "ar": "👩🏽‍💻 <b>خطأ</b> في استلام الملف الشخصي",
}
l_userbot_cmd_update_stat = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> получения статистики",
    "en": "👩🏽‍💻 <b>Error</b> getting statistics",
    "es": "👩🏽‍💻 <b>Error</b> al obtener estadísticas",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors de l'obtention des statistiques",
    "zh": "👩🏽‍💻 <b>获取统计信息时出错</b>",
    "ar": "👩🏽‍💻 <b>خطأ</b> في الحصول على الإحصائيات",
}
l_userbot_res_repair = {
    "ru": "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Очистка черновиков..\n ✅ Открепление сообщений..\n ✅ Просмотр упоминаний..\n ✅ Сброс уведомлений..\n ✅ Чтение истории..\n ✅ Отмена таймеров удаления..\n ✅ Удаление отложенной отправки..\n ✅ Обновление папок..\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Cleaning drafts..\n ✅ Unpinning messages..\n ✅ Viewing mentions..\n ✅ Resetting notifications..\n ✅ Reading history..\n ✅ Cancelling deletion timers..\n ✅ Deleting scheduled sends..\n ✅ Updating folders..\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Limpieza de borradores..\n ✅ Desanclar mensajes..\n ✅ Ver menciones..\n ✅ Restablecer notificaciones..\n ✅ Leer historial..\n ✅ Cancelar temporizadores de eliminación..\n ✅ Eliminar envíos programados..\n ✅ Actualizar carpetas..\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Nettoyage des brouillons..\n ✅ Détachement des messages..\n ✅ Affichage des mentions..\n ✅ Réinitialisation des notifications..\n ✅ Lecture de l'historique..\n ✅ Annulation des minuteries de suppression..\n ✅ Suppression des envois programmés..\n ✅ Mise à jour des dossiers..\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ 清理草稿..\n ✅ 取消固定消息..\n ✅ 查看提及..\n ✅ 重置通知..\n ✅ 阅读历史..\n ✅ 取消删除计时器..\n ✅ 删除计划发送..\n ✅ 更新文件夹..\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ تنظيف المسودات..\n ✅ إلغاء تثبيت الرسائل..\n ✅ عرض الإشارات..\n ✅ إعادة تعيين الإشعارات..\n ✅ قراءة السجل..\n ✅ إلغاء مؤقتات الحذف..\n ✅ حذف الإرسالات المجدولة..\n ✅ تحديث المجلدات..\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_reset = {
    "ru": "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Сброс настроек..\n ✅ Удаление контактов..\n ✅ Удаление Telegram-ботов..\n ✅ Удаление диалогов..\n ✅ Выход из групп и каналов..\n ✅ Удаление платежной информации..\n ✅ Удаление истории звонков..\n ✅ Удаление стикеров/эможди..\n ✅ Сброс настроек оповещения..\n ✅ Очистка галереи обоев..\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Reset settings..\n ✅ Deleting contacts..\n ✅ Deleting Telegram bots..\n ✅ Deleting dialogs..\n ✅ Leaving groups and channels..\n ✅ Deleting payment information..\n ✅ Deleting call history..\n ✅ Deleting stickers/emoticons..\n ✅ Resetting notification settings..\n ✅ Clearing the wallpaper gallery..\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Restablecer configuración..\n ✅ Eliminar contactos..\n ✅ Eliminar bots de Telegram..\n ✅ Eliminar diálogos..\n ✅ Salir de grupos y canales..\n ✅ Eliminar información de pago..\n ✅ Eliminar historial de llamadas..\n ✅ Eliminar pegatinas/emoticones..\n ✅ Restablecer la configuración de notificaciones..\n ✅ Borrar la galería de fondos de pantalla..\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Réinitialiser les paramètres..\n ✅ Supprimer les contacts..\n ✅ Supprimer les bots Telegram..\n ✅ Supprimer les dialogues..\n ✅ Quitter les groupes et chaînes..\n ✅ Supprimer les informations de paiement..\n ✅ Supprimer l'historique des appels..\n ✅ Supprimer les autocollants/émoticônes..\n ✅ Réinitialisation des paramètres de notification..\n ✅ Effacement de la galerie de fonds d'écran..\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ 重置设置..\n ✅ 删除联系人..\n ✅ 删除 Telegram 机器人..\n ✅ 删除对话..\n ✅ 退出群组和频道..\n ✅ 删除付款信息..\n ✅ 删除通话记录..\n ✅ 删除贴纸/表情符号..\n ✅ 重置通知设置..\n ✅ 清除壁纸库..\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ إعادة تعيين الإعدادات..\n ✅ حذف جهات الاتصال..\n ✅ حذف روبوتات Telegram..\n ✅ حذف المحادثات..\n ✅ الخروج من المجموعات والقنوات..\n ✅ حذف معلومات الدفع..\n ✅ حذف سجل المكالمات..\n ✅ إزالة الملصقات/الرموز التعبيرية..\n ✅ إعادة ضبط إعدادات الإشعارات..\n ✅ مسح معرض الخلفيات..\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_spambot = {
    "ru": "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot: {3}\n\n👩🏽‍💻 <b>Карма:</b>\n{4}: локальная\n{5}: глобальная\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot: {3}\n\n👩🏽‍💻 <b>Karma:</b>\n{4}: local\n{5}: global\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot: {3}\n\n👩🏽‍💻 <b>Karma:</b>\n{4}: local\n{5}: global\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot: {3}\n\n👩🏽‍💻 <b>Karma :</b>\n{4} : local\n{5} : global\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot: {3}\n\n👩🏽‍💻 <b>业力：</b>\n{4}: 本地\n{5}: 全局\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot: {3}\n\n👩🏽‍💻 <b>الكارما:</b>\n{4}: محلي\n{5}: عالمي\n\n⚙️ <b>الأوامر</b> /cmd",
}

l_status_handler = {
    "ru": "👩🏽‍💻 <b>Аккаунт</b>-статус: {0}",
    "en": "👩🏽‍💻 <b>Account</b>-status: {0}",
    "es": "👩🏽‍💻 <b>Cuenta</b>-estado: {0}",
    "fr": "👩🏽‍💻 <b>Statut du compte</b> : {0}",
    "zh": "👩🏽‍💻<b>帐户</b>-状态：{0}",
    "ar": "👩🏽‍💻 <b>الحساب</b>-الحالة: {0}",
}
l_fsm_auth_done = {
    "ru": "👩🏽‍💻 <b>Готово!</b> Аккаунт <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] успешно <i>прикреплен</i> к @{3}\n\n👩🏽‍💻 <b>Добавь</b> <b>{4}</b> ({5}) в свои контакты и отправь любое сообщение",
    "en": "👩🏽‍💻 <b>Done!</b> Account <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] successfully <i>attached</i> to @{3}\n\n👩🏽‍💻 <b>Add</b> <b>{4}</b> ({5}) to your contacts and send any message",
    "es": "👩🏽‍💻 <b>¡Listo!</b> Cuenta <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] se <i>adjuntó</i> correctamente a @{3}\n\n👩🏽‍💻 <b>Agrega</b> <b>{4}</b> ({5}) a tus contactos y envía cualquier mensaje",
    "fr": "👩🏽‍💻 <b>Terminé !</b> Compte <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] a été <i>attaché</i> avec succès à @{3}\n\n👩🏽‍💻 <b>Ajoutez</b> <b>{4}</b> ( {5}) à vos contacts et envoyez n'importe quel message",
    "zh": "👩🏽‍💻 <b>完成！</b> 帐户 <b>{0}</b>\n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] 已成功 <i>附加</i> 到 @{3}\n\n👩🏽‍💻 <b>将</b> <b>{4}</b> ({5}) 添加到您的联系人并发送任何消息",
    "ar": "👩🏽‍💻 <b>تم!</b> الحساب <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] تم <i>إرفاقه</i> بنجاح بـ @{3}\n\n👩🏽‍💻 <b>أضف</b> <b>{4}</b> ( {5}) إلى جهات الاتصال الخاصة بك وأرسل أي رسالة",
}
l_fsm_cloud_current = {
    "ru": "👩🏽‍💻 <b>Укажи</b> текущий <i>облачный пароль</i>",
    "en": "👩🏽‍💻 <b>Specify</b> the current <i>cloud password</i>",
    "es": "👩🏽‍💻 <b>Especifica</b> la <i>contraseña en la nube</i> actual",
    "fr": "👩🏽‍💻 <b>Spécifiez</b> le <i>mot de passe cloud</i> actuel",
    "zh": "👩🏽‍💻<b>指定</b>当前<i>云密码</i>",
    "ar": "👩🏽‍💻 <b>حدد</b> <i>كلمة مرور السحابة</i> الحالية",
}
l_fsm_auth_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> Telegram, попробуй еще раз! <b>Создай</b>/<code>используй дополнительный</code> <i>Telegram</i>-аккаунт через <b>мобильное</b> приложение, а затем отправь его <u>номер</u> телефона℡\n\n👩🏽‍💻 Например, <code>34663072680</code>",
    "en": "👩🏽‍💻 <b>Error</b> Telegram, try again! <b>Create</b>/<code>use an additional</code> <i>Telegram</i> account via the <b>mobile</b> app, then send its <u>phone number</u>℡\n\n👩🏽‍💻 For example, <code>34663072680</code>",
    "es": "👩🏽‍💻 <b>Error</b> de Telegram, ¡inténtalo de nuevo! <b>Crea</b>/<code>usa una</code> cuenta <i>Telegram</i> adicional a través de la aplicación <b>móvil</b>, y luego envía su <u>número</u> de teléfono℡\n\n👩🏽‍💻 Por ejemplo, <code>34663072680</code>",
    "fr": "👩🏽‍💻 <b>Erreur</b> Telegram, réessayez ! <b>Créez</b>/<code>utilisez un</code> compte <i>Telegram</i> supplémentaire via l'application <b>mobile</b>, puis envoyez son <u>numéro</u> de téléphone℡\n\n👩🏽‍💻 Par exemple, <code>34663072680</code>",
    "zh": "👩🏽‍💻 <b>错误</b> Telegram，请重试！<b>创建</b>/<code>使用额外的</code> <i>Telegram</i> 账号通过 <b>移动</b> 应用，然后发送其<u>电话号码</u>℡\n\n👩🏽‍💻 例如，<code>34663072680</code>",
    "ar": "👩🏽‍💻 <b>خطأ</b> تيليجرام، حاول مرة أخرى! <b>قم بإنشاء</b>/<code>استخدم</code> حساب <i>Telegram</i> إضافي عبر تطبيق <b>الهاتف المحمول</b>، ثم أرسل <u>رقمه</u> الهاتفي℡\n\n👩🏽‍💻 على سبيل المثال، <code>34663072680</code>",
}
l_fsm_code_error = {
    "ru": "👩🏽‍💻 <b>Отправь</b> корректный числовой код",
    "en": "👩🏽‍💻 <b>Send</b> the correct numeric code",
    "es": "👩🏽‍💻 <b>Envía</b> el código numérico correcto",
    "fr": "👩🏽‍💻 <b>Envoyez</b> le code numérique correct",
    "zh": "👩🏽‍💻 <b>发送</b> 正确的数字代码",
    "ar": "👩🏽‍💻 <b>أرسل</b> الرمز الرقمي الصحيح",
}
l_fsm_code_ban = {
    "ru": "👩🏽‍💻 <b>Telegram</b> забанил аккаунт на отправку кода\n\n#длительность {0}",
    "en": "👩🏽‍💻 <b>Telegram</b> has banned the account from sending the code\n\n#duration {0}",
    "es": "👩🏽‍💻 <b>Telegram</b> ha prohibido a la cuenta enviar el código\n\n#duración {0}",
    "fr": "👩🏽‍💻 <b>Telegram</b> a interdit au compte d'envoyer le code\n\n#durée {0}",
    "zh": "👩🏽‍💻 <b>Telegram</b> 已禁止该帐户发送代码\n\n#持续时间 {0}",
    "ar": "👩🏽‍💻 <b>Telegram</b> قام بحظر الحساب من إرسال الرمز\n\n#المدة {0}",
}
l_parse_done_app = {
    'ru': "👩🏽‍💻 <b>Список</b> реальных участников <code>{0}</code> (режим: {1}, количество: {2})\n\n<blockquote>{3}</blockquote>",
    'en': "👩🏽‍💻 <b>List</b> of real participants: <u>{0}</u>",
    'es': "👩🏽‍💻 <b>Lista</b> de participantes reales: <u>{0}</u>",
    'fr': "👩🏽‍💻 <b>Liste</b> des vrais participants : <u>{0}</u>",
    'zh': "👩🏽‍💻 真实参与者<b>列表</b>：<u>{0}</u>",
    'ar': "👩🏽‍💻 <b>قائمة</b> من المشاركين الحقيقيين: <u>{0}</u>",
}
# endregion


# --------


# region FereyPostBot
l_post_btn1 = {
    'ru': "👩🏽‍💻 Посты",
    'en': "👩🏽‍💻 Posts",
    'es': "👩🏽‍💻 Publicaciones",
    'fr': "👩🏽‍💻 Messages",
    'zh': "👩🏽‍💻 帖子",
    'ar': "👩🏽‍💻 المشاركات",
}
l_post_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_post_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания креативных постов:\n\n<blockquote>▪️кнопочный счетчик\n▪️винил/инлайн-телескопы\n▪️выгрузка просмотров/кликов\n▪️шёпот-сообщения\n▪️веб-мини постинг</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for creating creative posts:\n\n<blockquote>▪️button counter\n▪️vinyl/inline telescopes\n▪️export of views/clicks\n▪️whisper messages\n▪️web mini posting</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la <i>@tg-aplicación</i> para crear publicaciones creativas:\n\n<blockquote>▪️contador de botones\n▪️vinilo/telescopios en línea\n▪️exportación de vistas/clics\n▪️mensajes susurro\n▪️micropublicación web</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans l’<i>@tg-application</i> de création de posts créatifs :\n\n<blockquote>▪️compteur à boutons\n▪️vinyle/télescopes en ligne\n▪️exportation des vues/clics\n▪️messages chuchotés\n▪️micro-postage web</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎使用<i>@tg-应用</i>创建创意帖子：\n\n<blockquote>▪️按钮计数器\n▪️唱片/内联望远镜\n▪️导出浏览量/点击量\n▪️耳语消息\n▪️网络微型发布</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-تطبيق</i> لإنشاء منشورات إبداعية:\n\n<blockquote>▪️عداد الأزرار\n▪️فينيل/تلسكوبات مدمجة\n▪️تصدير المشاهدات/النقرات\n▪️رسائل الهمس\n▪️نشر ويب مصغر</blockquote>",
}
l_post_bot_button_push = {
    'ru': "👩🏽‍💻 <b>Пользователь</b>: {0} нажал на: [{1}] (пост #<u>{2}</u>)\n\n<code>/parse {3}</code> - все клики поста",
    'en': "👩🏽‍💻 <b>User</b>: {0} clicked on: [{1}] (post #<u>{2}</u>)\n\n<code>/parse {3} </code>-all post clicks",
    'es': "👩🏽‍💻 <b>Usuario</b>: {0} hizo clic en: [{1}] (publicación #<u>{2}</u>)\n\n<code>/parse {3} </code>-todos los clics en publicaciones",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> : {0} a cliqué sur : [{1}] (post #<u>{2}</u>)\n\n<code>/parse {3} </code>-tous les clics sur les publications",
    'zh': "👩🏽‍💻<b>用户</b>：{0}点击了：[{1}]（帖子#<u>{2}</u>）\n\n<code>/parse {3} </code>-所有帖子点击",
    'ar': "👩🏽‍💻 <b>المستخدم</b>: {0} تم النقر عليه: [{1}] (المشاركة #<u>{2}</u>)\n\n<code>/parse {3} </code>-جميع النقرات على المنشور",
}
l_post_parse = {
    'ru': "👩🏽‍💻 <b>Список</b> кликов поста #{0}: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>Оформи</b> <a href='{2}'>💨Подписку</a> для получения имен пользователей</blockquote>",
    'en': "👩🏽‍💻 <b>List</b> of post #{0} clicks: <u>{1}</u>\n\n👩🏽‍💻 <b>Check out</b> <a href=' {2}'>💨Subscribe</a> to receive usernames",
    'es': "👩🏽‍💻 <b>Lista</b> de publicaciones #{0} clics: <u>{1}</u>\n\n👩🏽‍💻 <b>Consultar</b> <a href =' {2}'>💨Suscríbete</a> para recibir nombres de usuario",
    'fr': "👩🏽‍💻 <b>Liste</b> des publications #{0} clics : <u>{1}</u>\n\n👩🏽‍💻 <b>Découvrez</b> <a href =' {2}'>💨Abonnez-vous</a> pour recevoir les noms d'utilisateurs",
    'zh': "👩🏽‍💻 <b>列表</b>，帖子 #{0} 次点击：<u>{1}</u>\n\n👩🏽‍💻 <b>查看</b> <a href =' {2}'>💨订阅</a>以接收用户名",
    'ar': "👩🏽‍💻 <b>قائمة</b> المنشورات التي #{0} نقرات: <u>{1}</u>\n\n👩🏽‍💻 <b>الخروج</b> <a href =' {2}'>💨اشترك</a> لتلقي أسماء المستخدمين",
}

l_post_whisper_btn = {
    'ru': "Показать",
    'en': "Show",
    'es': "Espectáculo",
    'fr': "Montrer",
    'zh': "展示",
    'ar': "يعرض",
}
l_post_whisper_message_text = {
    'ru': "👩🏽‍💻 <b>Секретный</b> шёпот только для: ",
    'en': "👩🏽‍💻 <b>Secret</b> whisper only for: ",
    'es': "👩🏽‍💻 <b>Secreto</b> susurro solo para: ",
    'fr': "👩🏽‍💻 <b>Secret</b> murmure uniquement pour : ",
    'zh': "👩🏽‍💻 <b>秘密</b>耳语仅适用于：",
    'ar': "👩🏽‍💻 <b>سري</b> همس فقط لـ: ",
}
l_post_whisper_title = {
    'ru': "👩🏽‍💻 Шёпот",
    'en': "👩🏽‍💻 Whisper",
    'es': "👩🏽‍💻 Susurro",
    'fr': "👩🏽‍💻 Chuchotement",
    'zh': "👩🏽‍💻 耳语",
    'ar': "👩🏽‍💻 همس",
}
l_post_whisper_deleted = {
    'ru': "👩🏽‍💻 Шёпот удален",
    'en': "👩🏽‍💻 Whisper removed",
    'es': "👩🏽‍💻 Susurro eliminado",
    'fr': "👩🏽‍💻 Chuchotement supprimé",
    'zh': "👩🏽‍💻 低语已移除",
    'ar': "👩🏽‍💻 تم إزالة الهمس",
}
l_post_whisper_outdate = {
    'ru': "👩🏽‍💻 Шёпот просрочен после 3х дней",
    'en': "👩🏽‍💻 Whisper expired after 3 days",
    'es': "👩🏽‍💻 El susurro expiró después de 3 días",
    'fr': "👩🏽‍💻 Le chuchotement a expiré après 3 jours",
    'zh': "👩🏽‍💻 私语在 3 天后过期",
    'ar': "👩🏽‍💻 انتهت صلاحية الهمس بعد 3 أيام",
}
l_post_whisper_skip = {
    'ru': "👩🏽‍💻 Ты не видишь этот шёпот, потому что он был отправлен не тебе",
    'en': "👩🏽‍💻 You don’t see this whisper because it wasn’t sent to you",
    'es': "👩🏽‍💻 No puedes ver este susurro porque no fue enviado a ti",
    'fr': "👩🏽‍💻 Vous ne voyez pas ce chuchotement car il ne vous était pas destiné",
    'zh': "👩🏽‍💻 你看不到这条私语，因为它不是发给你的",
    'ar': "👩🏽‍💻 لا يمكنك رؤية هذا الهمس لأنه لم يُرسل إليك",
}
l_post_whisper_alert = {
    'ru': "👩🏽‍💻 <b>Пользователь</b>: {0} прочитал шёпот: [{1}]",
    'en': "👩🏽‍💻 <b>User</b>: {0} read the whisper: [{1}]",
    'es': "👩🏽‍💻 <b>Usuario</b>: {0} leyó el susurro: [{1}]",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> : {0} a lu le chuchotement : [{1}]",
    'zh': "👩🏽‍💻 <b>用户</b>：{0} 阅读了私语：[{1}]",
    'ar': "👩🏽‍💻 <b>المستخدم</b>: {0} قرأ الهمس: [{1}]",
}
l_post_whisper_text = {
    'ru': "👩🏽‍💻 <b>Шепот</b> - секретные сообщения для заданного количества пользователей в группе, которые открываются нажатием на кнопку",
    'en': "👩🏽‍💻 <b>Whisper</b> - secret messages for a specified number of users in a group, opened by pressing a button",
    'es': "👩🏽‍💻 <b>Susurro</b>: mensajes secretos para un número determinado de usuarios en el grupo, que se abren al pulsar un botón",
    'fr': "👩🏽‍💻 <b>Chuchotement</b> – messages secrets pour un nombre défini d’utilisateurs dans un groupe, accessibles par un clic sur un bouton",
    'zh': "👩🏽‍💻 <b>耳语</b> - 面向群组中指定数量用户的私密消息，点击按钮即可查看",
    'ar': "👩🏽‍💻 <b>همس</b> - رسائل سرية لعدد محدد من المستخدمين في المجموعة تُفتح عند الضغط على الزر",
}
l_post_whisper_txt = {
    'ru': "посмотри личные сообщения",
    'en': "check private messages",
    'es': "revisa los mensajes privados",
    'fr': "regarde les messages privés",
    'zh': "查看私密消息",
    'ar': "تحقق من الرسائل الخاصة",
}
l_post_whisper_example = {
    'ru': "💨 Например",
    'en': "💨 For example",
    'es': "💨 Por ejemplo",
    'fr': "💨 Par exemple",
    'zh': "💨 例如",
    'ar': "💨 على سبيل المثال",
}
# endregion


# region FereyMediaBot
l_media_btn1 = {
    'ru': "👩🏽‍💻 Медиа",
    'en': "👩🏽‍💻 Media",
    'es': "👩🏽‍💻 Medios",
    'fr': "👩🏽‍💻 Médias",
    'zh': "👩🏽‍💻媒体",
    'ar': "👩🏽‍💻 وسائل الإعلام",
}
l_media_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_media_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания медиа-креативов:\n\n<blockquote>▪️стикеры из текста и фото\n▪️аудио-тренды\n▪️видео-заметки\n▪️кнопочные нейро-титры</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for creating media creatives:\n\n<blockquote>▪️stickers from text and photos\n▪️audio trends\n▪️video notes\n▪️push-button neuro-captions</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la <i>@tg-app</i> para crear contenido creativo:\n\n<blockquote>▪️pegatinas de texto y fotos\n▪️tendencias de audio\n▪️notas de video\n▪️subtítulos neuronales con botón</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue sur <i>@tg-app</i> pour créer des médias créatifs :\n\n<blockquote>▪️autocollants à partir de texte et de photos\n▪️tendances audio\n▪️notes vidéo\n▪️légendes neuronales à bouton</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎使用<i>@tg-app</i> 创建媒体创意：\n\n<blockquote>▪️来自文本和照片的贴纸\n▪️音频趋势\n▪️视频笔记\n▪️按钮式神经字幕</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-app</i> لإنشاء الإبداعات الإعلامية:\n\n<blockquote>▪️ملصقات من النصوص والصور\n▪️اتجاهات صوتية\n▪️ملاحظات فيديو\n▪️تسميات توضيحية عصبية بزر</blockquote>",
}
l_media_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> тип выпадающих медиа-креативов (/add | /del)",
    'en': "👩🏽‍💻 <b>Select</b> the type of drop-down media creatives (/add | /del)",
    'es': "👩🏽‍💻 <b>Selecciona</b> el tipo de contenido multimedia desplegable (/add | /del)",
    'fr': "👩🏽‍💻 <b>Sélectionnez</b> le type de média créatif déroulant (/add | /del)",
    'zh': "👩🏽‍💻<b>选择</b>下拉式媒体创意类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>اختر</b> نوع الإبداع الإعلامي المنسدل (/add | /del)",
}
l_media_del = {
    'ru': "👩🏽‍💻 <b>Выбери</b> медиа-креатив для удаления",
    'en': "👩🏽‍💻 <b>Select</b> a media creative to delete",
    'es': "👩🏽‍💻 <b>Selecciona</b> un contenido multimedia para eliminar",
    'fr': "👩🏽‍💻 <b>Sélectionnez</b> un média créatif à supprimer",
    'zh': "👩🏽‍💻<b>选择</b>要删除的媒体创意",
    'ar': "👩🏽‍💻 <b>اختر</b> الإبداع الإعلامي المراد حذفه",
}
l_media_show = {
    'ru': "👩🏽‍💻 <b>Введи</b> запрос для поиска по медиа-креативам",
    'en': "👩🏽‍💻 <b>Enter</b> a query to search media creatives",
    'es': "👩🏽‍💻 <b>Ingresa</b> una consulta para buscar contenidos multimedia",
    'fr': "👩🏽‍💻 <b>Entrez</b> une requête pour rechercher des médias créatifs",
    'zh': "👩🏽‍💻<b>输入</b>关键词以搜索媒体创意",
    'ar': "👩🏽‍💻 <b>أدخل</b> استعلامًا للبحث في الإبداعات الإعلامية",
}

l_media_random = {
    'ru': "🎲 Случайный выбор",
    'en': "🎲 Random selection",
    'es': "🎲 Selección aleatoria",
    'fr': "🎲 Sélection aléatoire",
    'zh': "🎲 随机选择",
    'ar': "🎲 اختيار عشوائي",
}
l_media_none = {
    'ru': "👩🏽‍💻 <b>Медиа</b>-креатива не найдено",
    'en': "👩🏽‍💻 <b>Media</b> creative not found",
    'es': "👩🏽‍💻 <b>Contenido multimedia</b> no encontrado",
    'fr': "👩🏽‍💻 <b>Média</b> créatif introuvable",
    'zh': "👩🏽‍💻 未找到<b>媒体</b>创意",
    'ar': "👩🏽‍💻 <b>الإبداع الإعلامي</b> غير موجود",
}
l_media_file = {
    'ru': "👩🏽‍💻 1/2. <b>Прикрепи</b> аудио/видео, текст/фото контент для создания медиа-креатива",
    'en': "👩🏽‍💻 1/2. <b>Attach</b> audio/video, text/photo content to create a media creative",
    'es': "👩🏽‍💻 1/2. <b>Adjunta</b> contenido de audio/vídeo o texto/foto para crear un contenido multimedia",
    'fr': "👩🏽‍💻 1/2. <b>Joignez</b> du contenu audio/vidéo ou texte/photo pour créer un média créatif",
    'zh': "👩🏽‍💻 1/2。<b>附加</b>音频/视频、文本/照片内容以创建媒体创意",
    'ar': "👩🏽‍💻 1/2. <b>أرفق</b> محتوى صوت/فيديو أو نص/صورة لإنشاء إبداع إعلامي",
}
l_media_title1 = {
    'ru': "👩🏽‍💻 2/2. <b>Введи</b> <code>ключевые слова</code> для твоего медиа-креатива\n\n<blockquote>изменить ключевые слова нельзя</blockquote>",
    'en': "👩🏽‍💻 2/2. <b>Enter</b> <code>keywords</code> for your media creative\n\n<blockquote><code>Keywords</code> cannot be changed</blockquote>",
    'es': "👩🏽‍💻 2/2. <b>Ingresa</b> <code>palabras clave</code> para tu contenido multimedia\n\n<blockquote>no se pueden cambiar</blockquote>",
    'fr': "👩🏽‍💻 2/2. <b>Saisissez</b> des <code>mots-clés</code> pour votre média créatif\n\n<blockquote>ils ne peuvent pas être modifiés</blockquote>",
    'zh': "👩🏽‍💻 2/2。<b>输入</b><code>关键字</code>用于媒体创意\n\n<blockquote><code>关键字</code>无法更改</blockquote>",
    'ar': "👩🏽‍💻 2/2. <b>أدخل</b> <code>الكلمات الرئيسية</code> لإبداعك الإعلامي\n\n<blockquote>لا يمكن تغييرها</blockquote>",
}
l_media_title2 = {
    'ru': "👩🏽‍💻 2/2. <b>Текущие</b> ключевые слова для твоего медиа-креатива\n\n<blockquote>{0}</blockquote>\n\n[отправь новые или жми {1}]",
    'en': "👩🏽‍💻 2/2. <b>Current</b> keywords for your media creative\n\n<blockquote>{0}</blockquote>\n\n[send new ones or press {1}]",
    'es': "👩🏽‍💻 2/2. <b>Palabras clave actuales</b> para tu contenido multimedia\n\n<blockquote>{0}</blockquote>\n\n[envía nuevas o pulsa {1}]",
    'fr': "👩🏽‍💻 2/2. <b>Mots-clés actuels</b> pour votre média créatif\n\n<blockquote>{0}</blockquote>\n\n[envoyez-en de nouveaux ou appuyez sur {1}]",
    'zh': "👩🏽‍💻 2/2。<b>当前</b>媒体创意关键字\n\n<blockquote>{0}</blockquote>\n\n[发送新关键字或点击 {1}]",
    'ar': "👩🏽‍💻 2/2. <b>الكلمات الرئيسية الحالية</b> لإبداعك الإعلامي\n\n<blockquote>{0}</blockquote>\n\n[أرسل كلمات جديدة أو اضغط {1}]",
}
l_media_confirm = {
    'ru': "🏁 Завершить",
    'en': "🏁 Complete",
    'es': "🏁 Completo",
    'fr': "🏁 Terminé",
    'zh': "🏁 完成",
    'ar': "🏁 كاملة",
}
l_media_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b>: попробуй позже или загрузи другой медиа-файл",
    'en': "👩🏽‍💻 <b>Error</b> (try later or load another media)",
    'es': "👩🏽‍💻 <b>Error</b> (inténtalo más tarde o carga otro medio)",
    'fr': "👩🏽‍💻 <b>Erreur</b> (essayez plus tard ou chargez un autre média)",
    'zh': "👩🏽‍💻<b>错误</b>（稍后再试或加载其他媒体）",
    'ar': "👩🏽‍💻 <b>خطأ</b> (حاول لاحقًا أو قم بتحميل وسائط أخرى)",
}
l_media_finish = {
    'ru': "👩🏽‍💻 <b>Медиа</b>-креатив успешно создан",
    'en': "👩🏽‍💻 <b>Media</b> creative successfully created",
    'es': "👩🏽‍💻 <b>Contenido multimedia</b> creado con éxito",
    'fr': "👩🏽‍💻 <b>Média</b> créatif créé avec succès",
    'zh': "👩🏽‍💻<b>媒体</b>创意已成功创建",
    'ar': "👩🏽‍💻 تم إنشاء <b>الإبداع الإعلامي</b> بنجاح",
}
l_media_publish = {
    'ru': "🔗 Список",
    'en': "🔗 List",
    'es': "🔗 Lista",
    'fr': "🔗 Liste",
    'zh': "🔗 列表",
    'ar': "🔗 القائمة",
}
l_media_check = {
    'ru': "🔗 Проверка",
    'en': "🔗 Check",
    'es': "🔗 Consultar",
    'fr': "🔗 Vérifiez",
    'zh': "🔗 检查",
    'ar': "🔗 فحص",
}
l_media_hasdeleted = {
    'ru': "👩🏽‍💻 <b>Медиа</b>-креатив удален",
    'en': "👩🏽‍💻 <b>Media</b> creative deleted",
    'es': "👩🏽‍💻 <b>Contenido multimedia</b> eliminado",
    'fr': "👩🏽‍💻 <b>Média</b> créatif supprimé",
    'zh': "👩🏽‍💻<b>媒体</b>创意已删除",
    'ar': "👩🏽‍💻 تم حذف <b>الإبداع الإعلامي</b>",
}
l_media_delprepare = {
    'ru': "🔗 Выбрать",
    'en': "🔗 Select",
    'es': "🔗 Seleccionar",
    'fr': "🔗 Sélectionnez",
    'zh': "🔗 选择",
    'ar': "🔗 اختر",
}

l_media_share = {
    'ru': "🔗 Поделиться",
    'en': "🔗 Share",
    'es': "🔗 Compartir",
    'fr': "🔗 Partager",
    'zh': "🔗 分享",
    'ar': "🔗 مشاركة",
}
l_titles_file = {
    'ru': "👩🏽‍💻 1/2. <b>Прикрепи</b> аудио/видео-контент со звуком для создания #нейро-титров",
    'en': "👩🏽‍💻 1/2. <b>Attach</b> audio/video content with sound to generate #neuro-captions",
    'es': "👩🏽‍💻 1/2. <b>Adjunta</b> contenido de audio/vídeo con sonido para generar #neuro-subtítulos",
    'fr': "👩🏽‍💻 1/2. <b>Joins</b> du contenu audio/vidéo avec du son pour générer des #neuro-sous-titres",
    'zh': "👩🏽‍💻 1/2。<b>附加</b>带声音的音频/视频内容以生成#神经字幕",
    'ar': "👩🏽‍💻 1/2. <b>أرفق</b> محتوى صوتي/مرئي مع صوت لإنشاء #ترجمات_عصبية",
}
l_titles_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> создания титров к медиа-креативу: попробуй ещё раз позже или загрузи другой медиа-файл",
    'en': "👩🏽‍💻 <b>Error</b> generating captions for the media content: try again later or upload a different media file",
    'es': "👩🏽‍💻 <b>Error</b> al generar subtítulos para el contenido multimedia: inténtalo más tarde o sube otro archivo",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de la génération des sous-titres du contenu média : réessayez plus tard ou envoyez un autre fichier",
    'zh': "👩🏽‍💻 <b>生成媒体字幕</b>时出错：请稍后重试或上传其他媒体文件",
    'ar': "👩🏽‍💻 <b>حدث خطأ</b> في إنشاء ترجمات الوسائط: حاول مرة أخرى لاحقًا أو قم بتحميل ملف آخر",
}
# endregion


# region FereyFindBot
l_find_btn1 = {
    'ru': "👩🏽‍💻 Поиск",
    'en': "👩🏽‍💻 Search",
    'es': "👩🏽‍💻 Buscar",
    'fr': "👩🏽‍💻 Rechercher",
    'zh': "👩🏽‍💻 搜索",
    'ar': "👩🏽‍💻 بحث",
}
l_find_btn2 = {
    'ru': "📍 Гео поиск",
    'en': "📍 Geo search",
    'es': "📍 Búsqueda geográfica",
    'fr': "📍 Recherche géographique",
    'zh': "📍 地理搜索",
    'ar': "📍 البحث الجغرافي",
}
l_find_btn3 = {
    'ru': "🔔 Уведомления",
    'en': "🔔 Notifications",
    'es': "🔔 Notificaciones",
    'fr': "🔔Notifications",
    'zh': "🔔 通知",
    'ar': "🔔 الإخطارات",
}
l_find_btn4 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_find_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> премиум поиска в <b>Telegram</b>:\n\n<blockquote>▪️поиск каналов/групп\n▪️приложения web/nft</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to <i>@tg-app</i> premium search in <b>Telegram</b>:\n\n<blockquote>▪️search channels/groups\n▪️web/nft applications</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la búsqueda premium de <i>@tg-app</i> en <b>Telegram</b>:\n\n<blockquote>▪️búsqueda de canales/grupos\n▪️aplicaciones web/nft</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans la recherche premium de <i>@tg-app</i> sur <b>Telegram</b> :\n\n<blockquote>▪️recherche de chaînes/groupes\n▪️applications web/nft</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎来到 <i>@tg-app</i> 在 <b>Telegram</b> 中的高级搜索：\n\n<blockquote>▪️搜索频道/群组\n▪️web/nft 应用</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في البحث المميز في <i>@tg-app</i> على <b>Telegram</b>:\n\n<blockquote>▪️بحث القنوات/المجموعات\n▪️تطبيقات web/nft</blockquote>",
}
l_subscribe_find = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>22</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️<b>уведомления</b> о ключевых словах\n(<i>ссылка на сообщение</i>)\n▪️<b>увеличение</b> лимитов уведомлений\n(<i>до 10 ключевых слов/групп/каналов</i>)\n▪️<b>приоритетная</b> выдача при поиске\n(<i>выше чем premium/verified</i>)</blockquote>",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>22</u>%)]\n² [@{0 }-bot]:\n▪️<b>notifications</b> about keywords\n(<i>link to message</i>)\n▪️<b>increase</b> notification limits\n(<i>up to 10 keywords/groups/channels</i>)\n▪️<b>priority</b> search results\n(<i>higher than premium/verified</i>)",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>22</u>%)]\n² [@ {0 }-bot]:\n▪️<b>notificaciones</b> sobre palabras clave\n(<i>enlace al mensaje</i>)\n▪️<b>aumentar</b> límites de notificaciones\n(<i>hasta 10 palabras clave/grupos/canales</i>)\n▪️<b>resultados de búsqueda prioritarios</b>\n(<i>superiores a premium/verificados</i>)",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>22</u>%)]\n² [@ {0 }-bot] :\nnoyance<b>notifications</b> concernant les mots clés\n(<i>lien vers le message</i>)\nnoyance<b>augmenter</b> les limites de notification\n(<i>jusqu'à 10 mots clés/groupes/chaînes</i>)\nnounced<b>priorité</b> résultats de recherche\n(<i>supérieur à premium/vérifié</i>)",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n1 [<b>所有机器人</b>和项目 (-<u>22</u>%)]\n² [@ {0 }-bot]：\n▪️关于关键字的<b>通知</b>\n（<i>消息链接</i>）\n▪️<b>增加</b>通知限制\n(<i>最多 10 个关键字/组/频道</i>)\n▪️<b>优先级</b>搜索结果\n（<i>高于高级/已验证</i>）",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>22</u>%)]\n² [@ {0 }-bot]:\n▪️<b>إشعارات</b> حول الكلمات الرئيسية\n(<i>رابط إلى الرسالة</i>)\n▪️<b>زيادة</b> حدود الإشعارات\n(<<i>ما يصل إلى 10 كلمات رئيسية/مجموعات/قنوات</i>)\n▪️<b>أولوية</b> نتائج البحث\n(<i>أعلى من المميزة/التي تم التحقق منها</i>)",
}
l_find_bot_text_find = {
    'ru': "👩🏽‍💻 <b>Источник</b>: {0}, ссылка на публикацию: [{1}] (ключевое слово: <u>{2}</u>)",
    'en': "👩🏽‍💻 <b>Source</b>: {0}, publication link: [{1}] (keyword: <u>{2}</u>)",
    'es': "👩🏽‍💻 <b>Fuente</b>: {0}, enlace de publicación: [{1}] (palabra clave: <u>{2}</u>)",
    'fr': "👩🏽‍💻 <b>Source</b> : {0}, lien de publication : [{1}] (mot clé : <u>{2}</u>)",
    'zh': "👩🏽‍💻<b>来源</b>：{0}，发布链接：[{1}]（关键字：<u>{2}</u>）",
    'ar': "👩🏽‍💻 <b>المصدر</b>: {0}، رابط النشر: [{1}] (الكلمة الرئيسية: <u>{2}</u>)",
}

l_geo_minus = {
    'ru': "-",
    'en': "-",
    'es': "-",
    'fr': "-",
    'zh': "-",
    'ar': "-",
}
l_geo_current = {
    'ru': "📍R: {0}m",
    'en': "📍R: {0}m",
    'es': "📍R: {0}m",
    'fr': "📍R : {0}mois",
    'zh': "📍R：{0}米",
    'ar': "📍ر: {0}م",
}
l_geo_plus = {
    'ru': "+",
    'en': "+",
    'es': "+",
    'fr': "+",
    'zh': "+",
    'ar': "+",
}
l_geo_text1 = {
    'ru': "📍 <b>Гео</b>-поиск пользователей\n\n<blockquote>👩🏽‍💻 <b>Жми</b> на -/+, чтобы настроить [<b>📍Radius</b>]</blockquote>",
    'en': "📍 <b>GEO search</b> users\n\n👩🏽‍💻 <b>Press</b> on-/+ to configure 📍Radius",
    'es': "📍 Usuarios de <b>búsqueda GEO</b>\n\n👩🏽‍💻 <b>Presione</b> en-/+ para configurar 📍Radio",
    'fr': "📍 <b>Utilisateurs de recherche GEO</b>\n\n👩🏽‍💻 <b>Appuyez</b> sur-/+ pour configurer 📍Radius",
    'zh': "📍 <b>GEO 搜索</b>用户\n\n👩🏽‍💻 <b>按</b>-/+ 配置📍Radius",
    'ar': "📍 <b>بحث الموقع الجغرافي</b> المستخدمين\n\n👩🏽‍💻 <b>اضغط</b> على-/+ لتهيئة 📍Radius",
}
l_geo_text2 = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> геопозицию через 📎-меню вложений или <b>жми</b> на кнопку ниже:\n\n<blockquote>[📍Отправить гео]</blockquote>",
    'en': "👩🏽‍💻 <b>Attach</b> your geolocation via the 📎 attachment menu or <b>click</b> on the button below\n[📍Send geo] 👇🏽",
    'es': "👩🏽‍💻 <b>Adjunte</b> su geolocalización a través del 📎 menú de archivos adjuntos o <b>haga clic</b> en el botón a continuación\n[📍Enviar geo] 👇🏽",
    'fr': "👩🏽‍💻 <b>Joignez</b> votre géolocalisation via le menu 📎 pièce jointe ou <b>cliquez</b> sur le bouton ci-dessous\n[📍Envoyer la géo] 👇🏽",
    'zh': "👩🏽‍💻通过📎附件菜单<b>附加</b>您的地理位置或<b>点击</b>下面的按钮\n[📍发送地理信息]👇🏽",
    'ar': "👩🏽‍💻 <b>أرفق</b> موقعك الجغرافي عبر قائمة 📎 المرفقات أو <b>انقر</b> على الزر أدناه\n[📍أرسل الموقع الجغرافي] 👇🏽",
}
l_geo_send = {
    'ru': "📍Отправить гео",
    'en': "📍Send geo",
    'es': "📍Enviar geo",
    'fr': "📍Envoyer la géo",
    'zh': "📍发送地理信息",
    'ar': "📍أرسل الموقع الجغرافي",
}
l_geo_start = {
    'ru': "🔎 <b>Начинаем</b> поиск..",
    'en': "🔎 <b>Let's start</b> the search..",
    'es': "🔎 <b>Comencemos</b> la búsqueda..",
    'fr': "🔎 <b>Commençons</b> la recherche..",
    'zh': "🔎<b>让我们开始</b>搜索..",
    'ar': "🔎 <b>لنبدأ</b> البحث..",
}
l_geo_no = {
    'ru': "📍 Пользователей (@username) в данной геопозиции не найдено",
    'en': "📍 No users ( @username ) found in this location",
    'es': "📍 No se encontraron usuarios ( @username ) en esta ubicación",
    'fr': "📍 Aucun utilisateur ( @username ) trouvé à cet endroit",
    'zh': "📍 在此位置找不到用户 ( @username )",
    'ar': "📍 لم يتم العثور على مستخدمين ( @username ) في هذا الموقع",
}
l_geo_finish = {
    'ru': "📍 <b>В <a href='https://maps.google.com/?q={0},{1}'>геолокации</a></b> найдено пользователей: <u>{2}</u>",
    'en': "📍 <b>Users found in <a href=' https://maps.google.com/?q={0},{1} '> geolocation</a></b>: <u>{2} </u>",
    'es': "📍 <b>Usuarios encontrados en <a href=' https://maps.google.com/?q={0},{1} '> geolocalización</a></b>: <u>{2} </u>",
    'fr': "📍 <b>Utilisateurs trouvés dans la <a href=' https://maps.google.com/?q={0},{1} '> géolocalisation</a></b> : <u>{2} </u>",
    'zh': "📍<b>在<a href=' https://maps.google.com/?q={0},{1} '>地理位置</a></b>中找到的用户：<u>{2} </u>",
    'ar': "📍 <b>تم العثور على المستخدمين في <a href=' https://maps.google.com/?q={0},{1} '> الموقع الجغرافي</a></b>: <u>{2} </ش>",
}

l_find_add_cmd = {
    'ru': "👩🏽‍💻 <b>Отправь</b> ссылку на канал/группу/пользователя/бота",
    'en': "👩🏽‍💻 <b>Come</b> link to channel/group/user/bot",
    'es': "👩🏽‍💻 <b>Ven</b> enlace al canal/grupo/usuario/bot",
    'fr': "👩🏽‍💻 <b>Viens</b> lien vers le canal/groupe/utilisateur/bot",
    'zh': "👩🏽‍💻<b>来</b>链接到频道/组/用户/机器人",
    'ar': "👩🏽‍💻 <b>تعال</b> رابط القناة/المجموعة/المستخدم/الروبوت",
}
l_find_err_cmd = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> (вставь корректную ссылку или повтори позже)",
    'en': "👩🏽‍💻 <b>Error</b> (insert the correct link or try again later)",
    'es': "👩🏽‍💻 <b>Error</b> (inserta el enlace correcto o vuelve a intentarlo más tarde)",
    'fr': "👩🏽‍💻 <b>Erreur</b> (insérez le bon lien ou réessayez plus tard)",
    'zh': "👩🏽‍💻<b>错误</b>（插入正确的链接或稍后重试）",
    'ar': "👩🏽‍💻 <b>خطأ</b> (أدخل الرابط الصحيح أو حاول مرة أخرى لاحقًا)",
}
l_find_ok_cmd = {
    'ru': "👩🏽‍💻 <b>Ссылка</b> успешно добавлена!",
    'en': "👩🏽‍💻 <b>Link</b> successfully added!",
    'es': "👩🏽‍💻 ¡<b>Enlace</b> agregado exitosamente!",
    'fr': "👩🏽‍💻 <b>Lien</b> ajouté avec succès !",
    'zh': "👩🏽‍💻 <b>链接</b>已成功添加！",
    'ar': "👩🏽‍💻 تمت إضافة <b>الرابط</b> بنجاح!",
}
l_find_check = {
    'ru': "🔗 Проверка",
    'en': "🔗 Check",
    'es': "🔗 Consultar",
    'fr': "🔗 Vérifiez",
    'zh': "🔗 检查",
    'ar': "🔗 فحص",
}

l_find_menu = {
    'ru': "↩ Menu",
    'en': "↩ Menu",
    'es': "↩ Menú",
    'fr': "↩ Menu",
    'zh': "↩ 菜单",
    'ar': "↩ القائمة",
}
l_find_text = {
    'ru': "<b>🔎 Сбор целевой аудитории (ЦА)</b>\n\n<blockquote>▪️<b>top</b> каналы/группы ЦА\n▪️<b>lead</b> конкуренты по нише\n▪️каталог <b>vip</b> ботов</blockquote>",
    'en': "<b>🔎 Gathering the target audience (TA)</b>\n\n▪️thematic <b>top</b> channels/TA groups\n▪️uploading <b>lead</b> competitors in the niche\n▪️ catalog of <b>vip</b> bots",
    'es': "<b>🔎 Reunir el público objetivo (TA)</b>\n\n▪️canales/grupos de TA <b>principales</b> temáticos\n▪️subir competidores <b>principales</b> en el nicho\n▪️ catálogo de bots <b>vip</b>",
    'fr': "<b>🔎 Rassembler le public cible (TA)</b>\n\nnoyer les <b>meilleures</b> chaînes thématiques/groupes TA\nnoyer️télécharger les <b>principaux</b> concurrents dans la niche\n ▪️ catalogue de robots <b>vip</b>",
    'zh': "<b>🔎收集目标受众 (TA)</b>\n\n▪️主题<b>顶级</b>频道/TA 群体\n▪️上传利基市场中的<b>领先</b>竞争对手\n▪️ <b>vip</b> 机器人目录",
    'ar': "<b>🔎 جمع الجمهور المستهدف (TA)</b>\n\n▪️القنوات <b>أهم</b> المواضيعية/مجموعات TA\n▪️تحميل <b>الرائد</b> المنافسين في المجال المتخصص\n▪️ كتالوج لروبوتات <b>vip</b>",
}
l_find_category_typing = {
    'ru': "✅ ввести свои параметры",
    'en': "✅ ввести your parameters",
    'es': "✅ ввести tus parámetros",
    'fr': "✅ ввести vos paramètres",
    'zh': "✅ ввести您的参数",
    'ar': "✅ ввести معلماتك",
}
l_find_desc = {
    'ru': "<b>Описание:</b> {0}",
    'en': "<b>Description:</b> {0}",
    'es': "<b>Descripción:</b> {0}",
    'fr': "<b>Description :</b> {0}",
    'zh': "<b>说明：</b>{0}",
    'ar': "<b>الوصف:</b> {0}",
}
l_find_reacts = {
    'ru': "<b>Реакции:</b> {0}",
    'en': "<b>Reactions:</b> {0}",
    'es': "<b>Reacciones:</b> {0}",
    'fr': "<b>Réactions :</b> {0}",
    'zh': "<b>反应：</b>{0}",
    'ar': "<b>ردود الفعل:</b> {0}",
}
l_find_send = {
    'ru': "<b>Сообщ/медиа/инлайн/инвайт:</b> {0}/{1}/{2}/{3}",
    'en': "<b>Message/media/online/invite:</b> {0}/{1}/{2}/{3}",
    'es': "<b>Mensaje/medios/en línea/invitación:</b> {0}/{1}/{2}/{3}",
    'fr': "<b>Message/média/en ligne/invitation :</b> {0}/{1}/{2}/{3}",
    'zh': "<b>消息/媒体/在线/邀请：</b> {0}/{1}/{2}/{3}",
    'ar': "<b>رسالة/وسائط/متصل/دعوة:</b> {0}/{1}/{2}/{3}",
}
l_find_bio = {
    'ru': "<b>Био:</b> {0}",
    'en': "<b>Was:</b> {0}",
    'es': "<b>Era:</b> {0}",
    'fr': "<b>Était :</b> {0}",
    'zh': "<b>曾经：</b> {0}",
    'ar': "<b>كان:</b> {0}",
}
l_find_about = {
    'ru': "<b>Описание:</b> {0}",
    'en': "<b>Description:</b> {0}",
    'es': "<b>Descripción:</b> {0}",
    'fr': "<b>Description :</b> {0}",
    'zh': "<b>说明：</b>{0}",
    'ar': "<b>الوصف:</b> {0}",
}
l_find_description = {
    'ru': "<b>Подробнее:</b> {0}",
    'en': "<b>More details:</b> {0}",
    'es': "<b>Más detalles:</b> {0}",
    'fr': "<b>Plus de détails :</b> {0}",
    'zh': "<b>更多详细信息：</b>{0}",
    'ar': "<b>مزيد من التفاصيل:</b> {0}",
}
l_find_commands = {
    'ru': "<b>Команды:</b> {0}",
    'en': "<b>Commands:</b> {0}",
    'es': "<b>Comandos:</b> {0}",
    'fr': "<b>Commandes :</b> {0}",
    'zh': "<b>命令：</b> {0}",
    'ar': "<b>الأوامر:</b> {0}",
}

l_find_chn = {
    'ru': "📰 Каналы",
    'en': "📰 Channels",
    'es': "📰 Canales",
    'fr': "📰 Chaînes",
    'zh': "📰 频道",
    'ar': "📰 القنوات",
}
l_find_grp = {
    'ru': "📁 Группы",
    'en': "📁 Groups",
    'es': "📁 Grupos",
    'fr': "📁 Groupes",
    'zh': "📁 团体",
    'ar': "📁 المجموعات",
}
l_find_usr = {
    'ru': "🕵️ Конкуренты",
    'en': "🕵️Competitors",
    'es': "🕵️Competidores",
    'fr': "🕵️Concurrents",
    'zh': "🕵️竞争对手",
    'ar': "🕵️المنافسون",
}
l_find_bot = {
    'ru': "🫥 Боты",
    'en': "🫥 Boots",
    'es': "🫥 Botas",
    'fr': "🫥 Bottes",
    'zh': "🫥 靴子",
    'ar': "🫥حذاء",
}

l_find_chn_choose = {
    'ru': "📰 <b>Выбери категорию</b> для выгрузки каналов",
    'en': "📰 <b>Select a category</b> to download channels",
    'es': "📰 <b>Seleccione una categoría</b> para descargar canales",
    'fr': "📰 <b>Sélectionnez une catégorie</b> pour télécharger les chaînes",
    'zh': "📰<b>选择类别</b>下载频道",
    'ar': "📰 <b>اختر فئة</b> لتنزيل القنوات",
}
l_find_grp_choose = {
    'ru': "📁 <b>Выбери категорию</b> для выгрузки групп",
    'en': "📁 <b>Select a category</b> to upload groups",
    'es': "📁 <b>Seleccione una categoría</b> para cargar grupos",
    'fr': "📁 <b>Sélectionnez une catégorie</b> pour télécharger des groupes",
    'zh': "📁 <b>选择类别</b>以上传群组",
    'ar': "📁 <b>اختر فئة</b> لتحميل المجموعات",
}
l_find_usr_choose = {
    'ru': "🕵️ <b>Выбери категорию</b> для выгрузки пользователей",
    'en': "🕵️ <b>Select a category</b> to upload users",
    'es': "🕵️ <b>Seleccione una categoría</b> para subir usuarios",
    'fr': "🕵️ <b>Sélectionnez une catégorie</b> pour télécharger des utilisateurs",
    'zh': "🕵️ <b>选择类别</b>来上传用户",
    'ar': "🕵️ <b>حدد فئة</b> لتحميل المستخدمين",
}
l_find_bot_choose = {
    'ru': "🫥 <b>Выбери категорию</b> для выгрузки ботов",
    'en': "🫥 <b>Select a category</b> to upload bots",
    'es': "🫥 <b>Seleccione una categoría</b> para cargar bots",
    'fr': "🫥 <b>Sélectionnez une catégorie</b> pour télécharger des robots",
    'zh': "🫥<b>选择类别</b>以上传机器人",
    'ar': "🫥 <b>حدد فئة</b> لتحميل الروبوتات",
}

l_find_chn_find = {
    'ru': "🔎 Поиск каналов",
    'en': "🔎 Channel search",
    'es': "🔎 Búsqueda de canales",
    'fr': "🔎 Recherche de chaînes",
    'zh': "🔎 频道搜索",
    'ar': "🔎 البحث عن القناة",
}
l_find_grp_find = {
    'ru': "🔎 Поиск групп",
    'en': "🔎 Search for groups",
    'es': "🔎 Búsqueda de grupos",
    'fr': "🔎 Rechercher des groupes",
    'zh': "🔎 搜索群组",
    'ar': "🔎 البحث عن المجموعات",
}
l_find_usr_find = {
    'ru': "🔎 Поиск конкурентов",
    'en': "🔎 Search for competitors",
    'es': "🔎 Búsqueda de competidores",
    'fr': "🔎 Recherche de concurrents",
    'zh': "🔎 寻找竞争对手",
    'ar': "🔎 البحث عن المنافسين",
}
l_find_bot_find = {
    'ru': "🔎 Поиск ботов",
    'en': "🔎 Search for bots",
    'es': "🔎 Búsqueda de robots",
    'fr': "🔎 Rechercher des robots",
    'zh': "🔎 搜索机器人",
    'ar': "🔎 البحث عن الروبوتات",
}

l_find_chn_link = {
    'ru': "🔗 Перейти к каналу",
    'en': "🔗 Go to channel",
    'es': "🔗 Ir al canal",
    'fr': "🔗 Accédez à la chaîne",
    'zh': "🔗 前往频道",
    'ar': "🔗 اذهب إلى القناة",
}
l_find_grp_link = {
    'ru': "🔗 Перейти к группе",
    'en': "🔗 Go to group",
    'es': "🔗 Ir al grupo",
    'fr': "🔗 Aller au groupe",
    'zh': "🔗 进群",
    'ar': "🔗 اذهب إلى المجموعة",
}
l_find_usr_link = {
    'ru': "🔗 Перейти к пользователю",
    'en': "🔗 Go to user",
    'es': "🔗 Ir al usuario",
    'fr': "🔗 Accédez à l'utilisateur",
    'zh': "🔗 转到用户",
    'ar': "🔗 اذهب إلى المستخدم",
}
l_find_bot_link = {
    'ru': "🔗 Перейти к боту",
    'en': "🔗 Go to bot",
    'es': "🔗 Ir al bot",
    'fr': "🔗 Aller au bot",
    'zh': "🔗 前往机器人",
    'ar': "🔗 اذهب إلى البوت",
}

l_find_category_blog = {
    'ru': "#блогер",
    'en': "#blogger",
    'es': "#blogger",
    'fr': "#blogueur",
    'zh': "#博主",
    'ar': "#مدَّوِن",
}
l_find_category_digit = {
    'ru': "#оцифровка",
    'en': "#digitizer",
    'es': "#digitalizador",
    'fr': "#numériseur",
    'zh': "#数字化仪",
    'ar': "#محول الأرقام",
}
l_find_category_smm = {
    'ru': "#смм",
    'en': "#smm",
    'es': "#mmm",
    'fr': "#mmm",
    'zh': "#斯姆",
    'ar': "#smm",
}
l_find_category_recruit = {
    'ru': "#рекрут",
    'en': "#recruit",
    'es': "#recluta",
    'fr': "#recruter",
    'zh': "#招募",
    'ar': "#تجنيد",
}
l_find_category_design = {
    'ru': "#дизайн",
    'en': "#design",
    'es': "#diseño",
    'fr': "#conception",
    'zh': "#设计",
    'ar': "#تصميم",
}
l_find_category_coach = {
    'ru': "#коуч",
    'en': "#coach",
    'es': "#entrenador",
    'fr': "#entraîneur",
    'zh': "#教练",
    'ar': "#مدرب",
}
l_find_category_it = {
    'ru': "#ИТ",
    'en': "#DOG",
    'es': "#PERRO",
    'fr': "#CHIEN",
    'zh': "#狗",
    'ar': "#كلب",
}
l_find_category_course = {
    'ru': "#курсы",
    'en': "#courses",
    'es': "#cursos",
    'fr': "#cours",
    'zh': "#培训班",
    'ar': "#الدورات",
}
l_find_category_business = {
    'ru': "#бизнес",
    'en': "#business",
    'es': "#negocio",
    'fr': "#entreprise",
    'zh': "#商业",
    'ar': "#عمل",
}
l_find_category_goods = {
    'ru': "#товарка",
    'en': "#cargo",
    'es': "#carga",
    'fr': "#cargaison",
    'zh': "#货物",
    'ar': "#البضائع",
}
l_find_category_offline = {
    'ru': "#оффлайн",
    'en': "#offline",
    'es': "#desconectado",
    'fr': "#hors ligne",
    'zh': "#离线",
    'ar': "#غير متصل على الانترنت",
}
l_find_category_lawyer = {
    'ru': "#юрист",
    'en': "#lawyer",
    'es': "#abogado",
    'fr': "#avocat",
    'zh': "#律师",
    'ar': "#محامي",
}
l_find_category_verified = {
    'ru': "#верифиц",
    'en': "#verification",
    'es': "#verificación",
    'fr': "#vérification",
    'zh': "#确认",
    'ar': "#تَحَقّق",
}
l_find_category_premium = {
    'ru': "#премиум",
    'en': "#premium",
    'es': "#de primera calidad",
    'fr': "#prime",
    'zh': "#优质的",
    'ar': "#غالي",
}
l_find_category_health = {
    'ru': "#здоровье",
    'en': "#health",
    'es': "#salud",
    'fr': "#santé",
    'zh': "#健康",
    'ar': "#صحة",
}

l_find_category_getting = {
    'ru': "🔎 Выгружаем <b>категорию</b> {0}..\n\n#длительность 0мин",
    'en': "🔎 Upload <b>category</b> {0}..\n\n#duration 0 min",
    'es': "🔎 Subir <b>categoría</b> {0}..\n\n#duración 0 min",
    'fr': "🔎 Télécharger <b>catégorie</b> {0}..\n\n#durée 0 min",
    'zh': "🔎 上传<b>类别</b> {0}..\n\n#duration 0 分钟",
    'ar': "🔎 تحميل <b>الفئة</b> {0}..\n\n#duration 0 min",
}
l_find_keyword_getting = {
    'ru': "🔎 Выгружаем базу по ключевым словам <i>{0}</i>..\n\n#длительность 1мин",
    'en': "🔎 Unload the database using the keywords <i>{0}</i>..\n\n#duration 1 min",
    'es': "🔎 Descargue la base de datos usando las palabras clave <i>{0}</i>..\n\n#duración 1 min",
    'fr': "🔎 Déchargez la base de données en utilisant les mots-clés <i>{0}</i>..\n\n#durée 1 min",
    'zh': "🔎 使用关键字 <i>{0}</i> 卸载数据库..\n\n#duration 1 分钟",
    'ar': "🔎 قم بإلغاء تحميل قاعدة البيانات باستخدام الكلمات الأساسية <i>{0}</i>..\n\n#duration 1 min",
}
l_find_category_keywords = {
    'ru': "📰 <b>Введи</b> ключевые слова для поиска через пробелы или разделители",
    'en': "📰 <b>Enter</b> keywords to search using spaces or delimiters",
    'es': "📰 <b>Ingrese</b> palabras clave para buscar usando espacios o delimitadores",
    'fr': "📰 <b>Saisissez</b> des mots-clés à rechercher à l'aide d'espaces ou de délimiteurs",
    'zh': "📰 <b>输入</b>关键字以使用空格或分隔符进行搜索",
    'ar': "📰 <b>أدخل</b> الكلمات الرئيسية للبحث باستخدام المسافات أو المحددات",
}
l_find_reached = {
    'ru': "<b>Охват</b>: <u>{0}</u> польз.",
    'en': "<b>Coverage</b>: <u>{0}</u> user.",
    'es': "<b>Cobertura</b>: <u>{0}</u> usuario.",
    'fr': "<b>Couverture</b> : <u>{0}</u> utilisateur.",
    'zh': "<b>覆盖范围</b>：<u>{0}</u> 位用户。",
    'ar': "<b>التغطية</b>: <u>{0}</u> مستخدم.",
}
l_find_watch = {
    'ru': "🔎 Просмотр",
    'en': "🔎 View",
    'es': "🔎 Ver",
    'fr': "🔎 Voir",
    'zh': "🔎 查看",
    'ar': "🔎 عرض",
}
l_add_join_err = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> (вставь корректную ссылку или повтори позже)",
    'en': "👩🏽‍💻 <b>Error</b> (insert the correct link or try again later)",
    'es': "👩🏽‍💻 <b>Error</b> (inserta el enlace correcto o vuelve a intentarlo más tarde)",
    'fr': "👩🏽‍💻 <b>Erreur</b> (insérez le bon lien ou réessayez plus tard)",
    'zh': "👩🏽‍💻<b>错误</b>（插入正确的链接或稍后重试）",
    'ar': "👩🏽‍💻 <b>خطأ</b> (أدخل الرابط الصحيح أو حاول مرة أخرى لاحقًا)",
}

l_add_chn_fail = {
    'ru': "🚫 <b>Канал</b> {0} не добавлен в базу\n\n<blockquote>{1} аватар\n{2} описание\n{3} более {4} подписчиков\n{5} последний пост менее {6} дней назад\n{7} скам</blockquote>",
    'en': "🚫 <b>Channel</b> {0} not added to the database\n\n{1} avatar\n{2} description\n{3} more than {4} subscribers\n{5} last post less than {6 } days ago\n{7} scam",
    'es': "🚫 <b>Canal</b> {0} no agregado a la base de datos\n\n{1} avatar\n{2} descripción\n{3} más de {4} suscriptores\n{5} última publicación menos hace más de {6 } días\n{7} estafa",
    'fr': "🚫 <b>Chaîne</b> {0} non ajoutée à la base de données\n\n{1} avatar\n{2} description\n{3} plus de {4} abonnés\n{5} dernier message moins il y a plus de {6 } jours\n{7} arnaque",
    'zh': "🚫 <b>频道</b> {0} 未添加到数据库\n\n{1} 头像\n{2} 说明\n{3} 超过 {4} 个订阅者\n{5} 最新帖子较少{6 } 天前\n{7} 诈骗",
    'ar': "🚫 <b>القناة</b> {0} لم تتم إضافتها إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} الوصف\n{3} أكثر من {4} مشتركين\n{5} آخر مشاركة أقل قبل أكثر من {6 } أيام\n{7} عملية احتيال",
}
l_add_grp_fail = {
    'ru': "🚫 <b>Группа</b> {0} не добавлена в базу\n\n<blockquote>{1} аватар\n{2} описание\n{3} более {4} участников\n{5} последний пост менее {6} дней назад\n{7} скам</blockquote>",
    'en': "🚫 <b>Group</b> {0} not added to the database\n\n{1} avatar\n{2} description\n{3} more than {4} members\n{5} last post less than {6 } days ago\n{7} scam",
    'es': "🚫 <b>Grupo</b> {0} no agregado a la base de datos\n\n{1} avatar\n{2} descripción\n{3} más de {4} miembros\n{5} última publicación menos hace más de {6 } días\n{7} estafa",
    'fr': "🚫 <b>Groupe</b> {0} non ajouté à la base de données\n\n{1} avatar\n{2} description\n{3} plus de {4} membres\n{5} dernier message moins il y a plus de {6 } jours\n{7} arnaque",
    'zh': "🚫 <b>群组</b> {0} 未添加到数据库\n\n{1} 头像\n{2} 描述\n{3} 超过 {4} 个成员\n{5} 上次发帖较少{6 } 天前\n{7} 诈骗",
    'ar': "🚫 <b>المجموعة</b> {0} لم تتم إضافتها إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} الوصف\n{3} أكثر من {4} أعضاء\n{5} آخر مشاركة أقل قبل أكثر من {6 } أيام\n{7} عملية احتيال",
}
l_add_usr_fail = {
    'ru': "🚫 <b>Пользователь</b> {0} не добавлен в базу\n\n<blockquote>{1} аватар\n{2} @username\n{3} био\n{4} скам</blockquote>",
    'en': "🚫 <b>User</b> {0} not added to the database\n\n{1} avatar\n{2} @username\n{3} bio\n{4} scam",
    'es': "🚫 <b>Usuario</b> {0} no agregado a la base de datos\n\n{1} avatar\n{2} @username\n{3} biografía\n{4} estafa",
    'fr': "🚫 <b>Utilisateur</b> {0} non ajouté à la base de données\n\n{1} avatar\n{2} @username\n{3} bio\n{4} arnaque",
    'zh': "🚫 <b>用户</b> {0} 未添加到数据库\n\n{1} 头像\n{2} @username\n{3} 简介\n{4} 骗局",
    'ar': "🚫 <b>المستخدم</b> {0} لم تتم إضافته إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} @username\n{3} السيرة الذاتية\n{4} عملية احتيال",
}
l_add_bot_fail = {
    'ru': "🚫 <b>Бот</b> {0} не добавлен в базу\n\n<blockquote>{1} аватар\n{2} описание\n{3} скам</blockquote>",
    'en': "🚫 <b>Bot</b> {0} not added to the database\n\n{1} avatar\n{2} description\n{3} scam",
    'es': "🚫 <b>Bot</b> {0} no agregado a la base de datos\n\n{1} avatar\n{2} descripción\n{3} estafa",
    'fr': "🚫 <b>Bot</b> {0} non ajouté à la base de données\n\n{1} avatar\n{2} description\n{3} arnaque",
    'zh': "🚫 <b>机器人</b> {0} 未添加到数据库\n\n{1} 头像\n{2} 描述\n{3} 骗局",
    'ar': "🚫 <b>الروبوت</b> {0} لم تتم إضافته إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} الوصف\n{3} عملية احتيال",
}

l_add_chn_done = {
    'ru': "✅ <b>Канал</b> {0} - добавлен в базу и обновлен",
    'en': "✅ <b>Channel</b> {0}-added to the database and updated",
    'es': "✅ <b>Canal</b> {0}: agregado a la base de datos y actualizado",
    'fr': "✅ <b>Chaîne</b> {0}-ajoutée à la base de données et mise à jour",
    'zh': "✅ <b>频道</b> {0}-添加到数据库并更新",
    'ar': "✅ <b>القناة</b> {0}-تمت إضافتها إلى قاعدة البيانات وتحديثها",
}
l_add_grp_done = {
    'ru': "✅ <b>Группа</b> {0} - добавлена в базу и обновлена",
    'en': "✅ <b>Group</b> {0}-added to the database and updated",
    'es': "✅ <b>Grupo</b> {0}: agregado a la base de datos y actualizado",
    'fr': "✅ <b>Groupe</b> {0}-ajouté à la base de données et mis à jour",
    'zh': "✅ <b>组</b> {0}-添加到数据库并更新",
    'ar': "✅ <b>المجموعة</b> {0}-تمت إضافتها إلى قاعدة البيانات وتحديثها",
}
l_add_usr_done = {
    'ru': "✅ <b>Пользователь</b> {0} - добавлен в базу и обновлен",
    'en': "✅ <b>User</b> {0}-added to the database and updated",
    'es': "✅ <b>Usuario</b> {0}: agregado a la base de datos y actualizado",
    'fr': "✅ <b>Utilisateur</b> {0}-ajouté à la base de données et mis à jour",
    'zh': "✅ <b>用户</b> {0}-添加到数据库并更新",
    'ar': "✅ <b>المستخدم</b> {0}-تمت إضافته إلى قاعدة البيانات وتحديثه",
}
l_add_bot_done = {
    'ru': "✅ <b>Бот</b> {0} - добавлен в базу и обновлен",
    'en': "✅ <b>Bot</b> {0}-added to the database and updated",
    'es': "✅ <b>Bot</b> {0}: agregado a la base de datos y actualizado",
    'fr': "✅ <b>Bot</b> {0}-ajouté à la base de données et mis à jour",
    'zh': "✅ <b>Bot</b> {0}-添加到数据库并更新",
    'ar': "✅ <b>Bot</b> {0}-تمت إضافته إلى قاعدة البيانات وتحديثه",
}

l_find_chn_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> каналов, сегментированных по <i>ключевым</i> словам\n\n<blockquote><b>Охват</b>: <u>{2}</u> польз\n\nМожно связаться с администраторами каналов, чтобы заказать рекламу</blockquote>",
    'en': "👩🏽‍💻 <b>Ready!</b> {0} collected <u>{1}</u> channels, segmented by <i>key</i> words\n\n<b>Coverage</b>: <u>{2}</u> user\n\nYou can contact channel administrators to order advertising",
    'es': "👩🏽‍💻 <b>¡Listo!</b> {0} canales <u>{1}</u> recopilados, segmentados por palabras <i>clave</i>\n\n<b>Cobertura</i> / b>: <u>{2}</u> usuario\n\nPuedes contactar con los administradores del canal para solicitar publicidad",
    'fr': "👩🏽‍💻 <b>Prêt !</b> {0} chaînes <u>{1}</u> collectées, segmentées par <i>mots clés</i>\n\n<b>Couverture< / b> : <u>{2}</u> utilisateur\n\nVous pouvez contacter les administrateurs de chaîne pour commander de la publicité.",
    'zh': "👩🏽‍💻 <b>准备好了！</b> {0} 收集了 <u>{1}</u> 个频道，按<i>关键词</i>个词进行细分\n\n<b>覆盖范围</ b>：<u>{2}</u>用户\n\n您可以联系频道管理员订购广告",
    'ar': "👩🏽‍💻 <b>جاهز!</b> {0} تم جمع <u>{1}</u> القنوات، مقسمة حسب <i>الكلمات الرئيسية</i>\n\n<b>التغطية< / b>: <u>{2}</u> user\n\nيمكنك الاتصال بمسؤولي القناة لطلب الإعلانات",
}
l_find_grp_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> чатов, сегментированных по <i>ключевым</i> словам\n\n<blockquote><b>Охват</b>: <u>{2}</u> польз\n\nМожно сделать <b>рассылку</b> по группам</blockquote>",
    'en': "👩🏽‍💻 <b>Done!</b> {0} collected <u>{1}</u> chats, segmented by <i>key</i> words\n\n<b>Coverage</b>: <u>{2}</u> user\n\nYou can make <b>mailing</b> to groups",
    'es': "👩🏽‍💻 <b>¡Listo!</b> {0} chats <u>{1}</u> recopilados, segmentados por palabras <i>clave</i>\n\n<b>Cobertura</i> b>: <u>{2}</u> usuario\n\nPuedes realizar <b>envíos de correo</b> a grupos",
    'fr': "👩🏽‍💻 <b>Terminé !</b> {0} <u>{1}</u> chats collectés, segmentés par <i>mots clés</i>\n\n<b>Couverture< / b> : <u>{2}</u> utilisateur\n\nVous pouvez effectuer des <b>envois</b> à des groupes",
    'zh': "👩🏽‍💻 <b>完成！</b> {0} 收集了 <u>{1}</u> 条聊天记录，按<i>关键词</i>个字进行细分\n\n<b>覆盖范围</ b>：<u>{2}</u> 用户\n\n您可以向群组<b>发送邮件</b>",
    'ar': "👩🏽‍💻 <b>تم!</b> {0} تم جمع <u>{1}</u> الدردشات، مقسمة حسب <i>الكلمات الرئيسية</i>\n\n<b>التغطية< / b>: <u>{2}</u> مستخدم\n\nيمكنك إرسال <b>بريد</b> إلى المجموعات",
}
l_find_usr_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> пользователей, сегментированных по <i>ключевым</i> словам",
    'en': "👩🏽‍💻 <b>Done!</b> {0} collected <u>{1}</u> users, segmented by <i>key</i> words",
    'es': "👩🏽‍💻 <b>¡Listo!</b> {0} usuarios recopilados <u>{1}</u>, segmentados por palabras <i>clave</i>",
    'fr': "👩🏽‍💻 <b>Terminé !</b> {0} utilisateurs <u>{1}</u> collectés, segmentés par mots <i>clés</i>",
    'zh': "👩🏽‍💻 <b>完成！</b> {0} 收集了 <u>{1}</u> 个用户，按<i>关键词</i>个词进行细分",
    'ar': "👩🏽‍💻 <b>تم!</b> {0} تم جمع <u>{1}</u> من المستخدمين، مقسمين حسب الكلمات <i>الرئيسية</i>",
}
l_find_bot_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> ботов, сегментированных по <i>ключевым</i> словам",
    'en': "👩🏽‍💻 <b>Done!</b> <u>{1}</u> bots have been collected for {0}, segmented by <i>key</i> words",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Se han recopilado <u>{1}</u> bots para {0}, segmentados por palabras <i>clave</i>",
    'fr': "👩🏽‍💻 <b>Terminé !</b> <u>{1}</u> des robots ont été collectés pour {0}, segmentés par mots <i>clés</i>",
    'zh': "👩🏽‍💻 <b>完成！</b> 已为 {0} 收集 <u>{1}</u> 个机器人，并按<i>关键字</i>个词进行细分",
    'ar': "👩🏽‍💻 <b>تم!</b> <u>{1}</u> تم جمع الروبوتات لـ {0}، مقسمة حسب الكلمات <i>الرئيسية</i>",
}
l_hashtag_categories = {
    "BLOG": [
        "блог", "влог", "блогер", "контентмейкер", "ютуб", "путешестви",
        "курс", "геткурс", "английск", "школ", "запуск", "заняти", "урок", "воркшоп",
        "языков", "онлайн-школ", "лингвист", "марафон", "практикум", "семинар",
        "вебинар", "лаборатор", "хакатон", "интенсив", "обучени", "колледж", "институт",
        "университет", "лекци", "мастермайнд", "симпозиум", "тренинг", "тимбилдинг", "мастерск", "образовани",
        "blog", "vlog", "blogger", "contentmak", "youtube", "travel",
        "course", "getcourse", "english", "school", "launch", "lesson", "workshop",
        "languag", "online-school", "linguist", "marathon", "practicum", "seminar",
        "webinar", "laborat", "hackathon", "intensiv", "educat", "college", "institut",
        "university", "lectur", "mastermind", "symposium", "train", "teambuild", "masterclass",
        "blogue", "vlogue", "blogueur", "créateurdecontenu", "voyag",
        "cours", "école", "lancement", "leçon", "atelier", "langue", "école-en-ligne",
        "linguiste", "pratic", "séminaire", "webinaire", "laboratoire",
        "éducation", "collège", "conférenc", "formation", "teambuilding", "maîtredeclasse",
        "تعليم", "مدرسة", "لغة", "دورة", "سفر", "يوتيوب", "ندوة", "محاضرة",
        "ورشة", "تعليمي", "هاكاثون", "مؤتمر", "فريق", "إطلاق",
        "bloguear", "vloguear", "bloguero", "creadordecontenidos", "viaj",
        "curso", "escuela", "lanzamiento", "lección", "taller", "idioma", "escuela-online",
        "lingüist", "maratón", "práctica", "seminario", "webinario", "laboratori",
        "hackatón", "educación", "colegio", "conferencia", "simposio", "entrenamiento", "clase",
        "博客", "视频博客", "内容创作者", "旅行", "课程", "英语", "学校", "网络学校",
        "语言", "马拉松", "实践", "研讨会", "在线研讨会", "实验室", "教育", "大学", "学院",
        "发布", "密集", "讲座", "专题研讨会", "培训", "团队建设", "大师课"
    ],
    "BUSINESS": [
        "бизнес", "инвест", "франш", "кредит", "торг", "консалт",
        "доход", "представит", "предпринимат", "коммерц", "фирм", "предприят", "компани", "промышл",
        "производст", "капитал", "корпорац", "агентств", "пассив",
        "дистриб", "акцио", "холдин", "прибыл", "рубл", "стартап",
        "business", "invest", "franchis", "credit", "trade", "consult",
        "income", "represent", "entrepreneu", "commerc", "firm", "enterpris", "compan", "industr",
        "product", "capital", "corporat", "agency", "passiv",
        "distrib", "sharehold", "holding", "profit", "rubl", "startup",
        "affaire", "investiss", "franchis", "crédit", "commerce", "consult",
        "revenu", "représent", "entrepren", "commercial", "entrepris", "compagn", "industr",
        "product", "capital", "corporat", "agenc", "passif",
        "distrib", "action", "holding", "bénéf", "rouble", "start-up",
        "أعمال", "استثمار", "فرانش", "ائتمان", "تجارة", "استشارة",
        "دخل", "ممثل", "ريادة", "تجاري", "شركة", "مؤسسة", "صناعة",
        "إنتاج", "رأس مال", "شركة", "وكالة", "سلبي", "توزيع",
        "مساهم", "ربح", "روبل", "شركة ناشئة",
        "negocio", "invers", "franquic", "crédit", "comerc", "consult",
        "ingres", "represent", "emprend", "comercial", "firm", "empresa", "industr",
        "product", "capital", "corporat", "agenc", "pasiv",
        "distrib", "accion", "holding", "benefic", "rublo", "startup",
        "商业", "投资", "特许经营", "信用", "贸易", "咨询",
        "收入", "代表", "企业家", "商业", "公司", "企业", "工业",
        "生产", "资本", "公司", "代理", "被动", "分销",
        "股东", "盈利", "卢布", "初创"
    ],
    "HEALTH": [
        "бьюти", "красота", "здоров", "нутрициол", "косметик", "косметол", "йога",
        "питани", "доктор", "диет", "похуден", "волос", "маникюр", "макияж", "клиник", "ресниц", "эпиляц",
        "парикмах", "медицин", "медик", "стоматол", "психо",
        "врач", "фитнес", "медиц", "лекарств", "спортив",
        "семья", "дети", "ребенок",
        "beauty", "health", "nutrition", "cosmetic", "cosmetolog", "yoga",
        "diet", "doctor", "slim", "hair", "manicur", "makeup", "clinic", "lash", "epilat",
        "hairdress", "medicin", "medic", "dentist", "psycho",
        "fitness", "drug", "sport", "family", "child", "kid",
        "beauté", "santé", "nutrition", "cosmét", "cosmétolog", "yoga",
        "régime", "docteur", "maigri", "cheveu", "manicure", "maquill", "clinique", "cil", "épilat",
        "coiffeur", "médecin", "dentist", "psycho",
        "forme", "médicament", "sportif", "famille", "enfant",
        "صحة", "جمال", "تغذية", "تجميل", "يوغا", "حمية", "طبيب",
        "تنحيف", "شعر", "أظافر", "ماكياج", "عيادة", "رموش", "إزالة الشعر",
        "حلاق", "طب", "طبيب أسنان", "نفسية", "رياضة", "أسرة", "طفل",
        "salud", "bellez", "nutrición", "cosmétic", "yoga",
        "dieta", "doctor", "adelgaz", "cabello", "manicura", "maquill", "clínic", "pestaña", "depilat",
        "peluquer", "medicin", "dentista", "psicol", "deport", "famil", "niño",
        "健康", "美容", "营养", "化妆品", "瑜伽", "饮食", "医生", "减肥",
        "头发", "美甲", "化妆", "诊所", "睫毛", "脱毛", "理发", "医学",
        "药物", "牙医", "心理", "健身", "运动", "家庭", "孩子"
    ],
    "NEURO": [
      "нейросет", "нейрон", "нейросеть", "нейро", "искусствен", "искусственныйинтеллект", "искусственный интеллект",
      "чатгпт", "чат-gpt", "чат gpt", "gpt", "llm", "модельязыка", "генеративн", "генеративный",
      "машинн", "машинноеобучен", "машинное обучение", "глубок", "глубокоеобучен", "deeplearn", "deep learn",
      "deep learning", "machinelearn", "machine learning", "transformer", "нейроинженер", "инференц",
      "diffus", "diffusion", "stable diffusion", "dall", "dalle", "midjourney", "imagen", "gan",
      "ai", "artificialintellig", "artificial intelligence", "neural", "neuralnet", "neural network", "large language",
      "chatgpt", "generative ai", "generative", "model", "inference", "prompt", "prompting", "fine-tun",
      "人工智能", "AI", "神经网", "神经网络", "神经", "生成式", "生成 模型", "大模型", "大语言模型", "聊天gpt",
      "chatgpt", "机器学", "机器学习", "深度学", "深度学习", "图像生成", "文生图",
      "ذكاء اصطناعي", "AI", "تعلم الآلة", "شبكة عصبية", "عصب", "نماذج كبيرة", "تشات جي بي تي", "شات جي بي تي",
      "تعلّم عميق", "توليد", "مولد", "نموذج لغوي", "LLM", "برمجة الذكاء", "تحفيز",
      "inteligenciaartificial", "inteligenc", "ia", "aprendizaje", "aprendizaje automático", "machinelearning",
      "red neuronal", "neural", "chatgpt", "gpt", "modelo de lenguaje", "modelo grande", "generativo", "difusión",
      "aprendizaje profundo",
      "intelligenceartificielle", "ia", "intellig", "apprentissage", "apprentissage automatique", "réseauneur",
      "réseauneuronal", "réseauneurones", "réseauréel", "chatgpt", "gpt", "modèledelangage", "LLM", "transformer",
      "génératif", "diffusion", "apprentissage profond"
    ],
    "SMM": [
        "смм", "инст", "фейсбук", "тикток", "тик-ток", "ютуб", "маркето",
        "маркет", "таргет", "распаковка", "продвижение", "сео", "бренд", "агентство",
        "лиды", "вконтакте", "лидов", "реклам", "таплинк", "прогрев", "блог", "визуал", "запуск",
        "трафик", "мвп", "редакция", "директ",
        "smm", "insta", "facebook", "tiktok", "youtube", "marketo",
        "market", "target", "unboxing", "promotion", "seo", "brand", "agency",
        "leads", "vk", "lead", "adver", "taplink", "warmup", "blog", "visual", "launch",
        "traffic", "mvp", "edit", "direct",
        "smm", "insta", "facebook", "tiktok", "youtube", "marché",
        "ciblage", "déballage", "promotion", "seo", "marque", "agence",
        "pistes", "vk", "annonce", "taplink", "réchauff", "blog", "visuel", "lancement",
        "trafic", "mvp", "rédaction", "direct",
        "تسويق", "انستغرام", "فيسبوك", "تيك توك", "يوتيوب", "سوق", "استهداف",
        "تفريغ", "ترويج", "سيو", "علامة تجارية", "وكالة", "عملاء متوقعون", "vk",
        "إعلانات", "تاپلينك", "إحماء", "مدونة", "مرئي", "إطلاق", "حركة مرور", "mvp",
        "تحرير", "مباشر",
        "smm", "insta", "facebook", "tiktok", "youtube", "mercado",
        "objetivo", "desempaquet", "promoción", "seo", "marca", "agencia",
        "clientes", "vk", "anuncio", "taplink", "calentam", "blog", "visual", "lanzamiento",
        "tráfico", "mvp", "edición", "directo",
        "社交媒体", "微博", "脸书", "抖音", "油管", "市场", "目标",
        "开箱", "推广", "搜索引擎优化", "品牌", "代理", "潜在客户", "vk",
        "广告", "taplink", "预热", "博客", "视觉", "发布", "流量", "mvp",
        "编辑", "直达"
    ],
    "GOODS": [
        "вайлд", "ozon", "озон", "авито", "авторск", "одежд", "китай",
        "китая", "складчина", "подарк", "модн", "маркетплейс", "вещи",
        "одежда", "обувь", "товар",
        "wild", "ozon", "avito", "author", "cloth", "china",
        "gift", "fashion", "marketplac", "thing", "shoe", "product", "item",
        "sauvage", "ozon", "avito", "auteur", "vêtement", "chine",
        "cadeau", "mode", "place de marché", "objet", "chaussure", "produit",
        "بضاعة", "أوزون", "أفيتو", "مؤلف", "ملابس", "صين", "هدية", "موضة",
        "سوق", "أشياء", "أحذية", "منتجات", "سلع",
        "mercancías", "ozon", "avito", "autor", "ropa", "china",
        "regalo", "moda", "mercado", "cosas", "zapatos", "producto",
        "商品", "野生", "ozon", "avito", "作者", "衣服", "中国",
        "礼物", "时尚", "市场", "物品", "鞋", "产品"
    ],
    "EDUCATION": [
        "коуч", "консульт", "продюсер", "бизнес", "наставн", "оратор", "энерг", "эксперт", "психо",
        "трекер", "гайд",
        "практик", "бренд", "тайм", "мотива", "логопед", "мышлен", "нумеролог", "таролог", "йог",
        "ментор", "тренер", "гештальт", "предприним", "метафори", "денеж", "диагност",
        "coach", "consult", "producer", "business", "mentor", "speaker", "energ", "expert", "psycho",
        "tracker", "guide",
        "practic", "brand", "time", "motivat", "speech", "think", "numerolog", "tarot", "yoga",
        "mentor", "trainer", "gestalt", "entrepreneu", "metaphor", "money", "diagnost",
        "coach", "conseil", "producteur", "business", "mentor", "orateur", "énergie", "expert", "psycho",
        "suivi", "guide",
        "pratiqu", "marque", "temps", "motivat", "orthophon", "pensé", "numérolog", "tarot", "yoga",
        "formateur", "gestalt", "entrepren", "métaphore", "argent", "diagnost",
        "مدرب", "مستشار", "منتج", "عمل", "مرشد", "متحدث", "طاقة", "خبير", "نفسي",
        "متعقب", "دليل", "ممارس", "علامة", "وقت", "تحفيز", "أخصائي نطق", "تفكير", "علم الأعداد",
        "تاروت", "يوغا", "مرشد", "مدرب", "جشتالت", "ريادة", "استعارة", "مال", "تشخيص",
        "educación", "coach", "consult", "productor", "negocio", "mentor", "orador", "energ", "experto", "psico",
        "rastreador", "guía", "práctic", "marca", "tiempo", "motivac", "logopeda", "pensam", "numerolog", "tarot",
        "yoga", "mentor", "entrenador", "gestalt", "emprend", "metáfora", "dinero", "diagnóstic",
        "教育", "教练", "顾问", "制作人", "商业", "导师", "演讲者", "能量", "专家", "心理",
        "追踪器", "指南", "实践", "品牌", "时间", "激励", "语言治疗", "思维", "数字学", "塔罗",
        "瑜伽", "指导", "教练", "格式塔", "创业", "隐喻", "金钱", "诊断"
    ],
    "RECRUIT": [
        "рекрут", "роп", "работа", "фрила", "найм", "эйчар", "пиар", "персонал", "менеджер",
        "продаж", "ассист", "риелтор", "млм", "управлен", "наем", "сотрудн", "делегир", "карьер",
        "recruit", "rop", "job", "freelanc", "hire", "hr", "pr", "staff", "manager",
        "sales", "assist", "realtor", "mlm", "manag", "employ", "collabor", "delegat", "career",
        "recrut", "rop", "travail", "freelanc", "embauch", "rh", "pr", "personnel", "manager",
        "vente", "assist", "agent immobilier", "mlm", "gestion", "employé", "délég", "carrièr",
        "توظيف", "روپ", "عمل", "عمل حر", "تعيين", "موارد بشرية", "علاقات عامة", "طاقم", "مدير",
        "مبيعات", "مساعد", "سمسار", "تسويق شبكي", "إدارة", "موظف", "تفويض", "مسار وظيفي",
        "reclut", "rop", "trabajo", "freelanc", "contrat", "rh", "pr", "personal", "gerente",
        "ventas", "asist", "realtor", "mlm", "gestión", "emple", "colabor", "deleg", "carrer",
        "招聘", "工作", "自由职业", "雇用", "人力资源", "公关", "员工", "经理",
        "销售", "助理", "房地产", "传销", "管理", "雇员", "委托", "职业"
    ],
    "FINANCE": [
        "оцифров", "фин.", "финан", "бух", "инвест", "франш", "трейд", "бирж", "кредит", "учет",
        "банк", "торг", "кассы", "денежн", "консалт", "выручка", "доход", "прибыль",
        "digit", "fin.", "financ", "accoun", "invest", "franchis", "trade", "exchang", "credit", "account",
        "bank", "commerc", "cash", "money", "consult", "revenue", "income", "profit",
        "numéris", "fin.", "financ", "comptab", "invest", "franchis", "échange", "crédit", "compt",
        "banque", "commerce", "caisse", "monétaire", "conseil", "revenu", "bénéfice", "profit",
        "تمويل", "مال.", "مالية", "محاسب", "استثمار", "فرانشايز", "تجارة", "بورصة", "ائتمان", "حساب",
        "بنك", "تداول", "نقد", "أموال", "استشارة", "إيرادات", "دخل", "أرباح",
        "finanzas", "digit", "fin.", "financ", "contabilid", "invers", "franquicia", "comerc", "bolsa", "crédit",
        "banco", "comerci", "caja", "dinero", "consult", "ingres", "benefici", "gananci",
        "财务", "数字化", "金融", "会计", "投资", "特许经营", "交易", "交易所", "信贷", "账目",
        "银行", "贸易", "现金", "金钱", "咨询", "收入", "收益", "利润"
    ],
    "OFFLINE": [
        "салон", "студи", "логист", "грузопер", "свечи", "букеты", "клиник",
        "магазин", "производств", "эпиляц", "парикмах", "кондитер",
        "пищев", "кулинар", "оффлайн", "адрес", "храм", "церковь", "транспорт",
        "недвижимость", "стоматол",
        "salon", "studio", "logist", "freight", "candl", "bouquet", "clinic",
        "store", "product", "epilat", "hairdress", "confection",
        "food", "culinar", "offline", "address", "temple", "church", "transport",
        "realest", "dentist",
        "salon", "studio", "logistiqu", "fret", "bougi", "bouquet", "clinique",
        "magasin", "production", "épilation", "coiffur", "pâtisseri",
        "alimentair", "culinair", "hors ligne", "adress", "temple", "église", "transpor",
        "immobili", "dentair",
        "صالون", "استوديو", "لوجستيات", "نقل بضائع", "شموع", "باقة", "عيادة",
        "متجر", "إنتاج", "إزالة الشعر", "حلاق", "حلواني",
        "غذائي", "طبخ", "غير متصل", "عنوان", "معبد", "كنيسة", "نقل",
        "عقارات", "طبيب أسنان",
        "salón", "estudio", "logístic", "transporte de carga", "vela", "ramo", "clínica",
        "tienda", "producción", "depilación", "peluquer", "pasteler",
        "alimentar", "culinar", "desconectado", "dirección", "templo", "iglesia", "transporte",
        "inmobiliari", "dentist",
        "沙龙", "工作室", "物流", "货运", "蜡烛", "花束", "诊所",
        "商店", "生产", "脱毛", "理发师", "糕点师",
        "食品", "烹饪", "离线", "地址", "寺庙", "教堂", "运输",
        "房地产", "牙医"
    ],
    "ART": [
        "дизайн", "интерьер", "декор", "мебел", "3д", "архитект", "двери", "ремонт", "строител",
        "фасад", "тексти", "рису", "креатив", "визуал", "ландшафт", "художн", "картин",
        "имидж", "камин", "монтаж", "граф", "искусств", "рукодел",
        "design", "interior", "decor", "furnitur", "3d", "architect", "door", "repair", "builder",
        "facad", "text", "draw", "creativ", "visual", "landscap", "art", "paint",
        "image", "fireplac", "mount", "graph", "art", "handcraft",
        "design", "intérieur", "décor", "meubl", "3d", "architect", "porte", "réparation", "constructeur",
        "façad", "texte", "dessin", "créatif", "visuel", "paysag", "art", "peintur",
        "image", "cheminée", "montage", "graph", "art", "artisanat",
        "تصميم", "ديكور", "أثاث", "ثلاثي الأبعاد", "معمار", "باب", "إصلاح", "بناء",
        "واجهة", "نص", "رسم", "إبداعي", "بصري", "مناظر طبيعية", "فن", "لوحة",
        "صورة", "مدفأة", "تركيب", "رسوم بيانية", "فن", "حرف يدوي",
        "diseño", "interior", "decoración", "mueble", "3d", "arquitecto", "puerta", "reparación", "constructor",
        "fachada", "texto", "dibujo", "creatividad", "visual", "paisaj", "arte", "pintura",
        "imagen", "chimenea", "montaje", "gráfico", "arte", "artesanía",
        "设计", "室内", "装饰", "家具", "3d", "建筑", "门", "修理", "建筑工",
        "立面", "文本", "画", "创意", "视觉", "景观", "艺术", "画作",
        "形象", "壁炉", "安装", "图形", "艺术", "手工艺"
    ],
    "TECHNOLOGY": [
        "лендинг", "блокчейн", "срм", "программирова", "тильда", "битрикс", "автоматизаци", "автоворон",
        "разработч", "нфт", "смарт-контракт", "кодинг", "стартап",
        "java", "kotlin", "swift", "flutter", "c++", "c#", "unity", "angular",
        "amocrm", "powerbi", "frontend", "backend", "python", "ux/ui",
        "landing", "blockchain", "crm", "programming", "tilda", "bitrix", "automation", "autoresp",
        "developer", "nft", "smart-contract", "coding", "startup",
        "الصفحة المقصودة", "بلوك تشين", "إدارة علاقات العملاء", "برمجة", "تيلدا", "بيتركس", "أتمتة", "مسار تلقائي",
        "مطور", "NFT", "عقد ذكي", "ترميز", "شركة ناشئة",
        "جافا", "كوتلن", "سويفت", "فلاتر", "C++", "C#", "يونيتي", "أنغولار",
        "着陆页", "区块链", "客户关系管理", "编程", "Tilda", "Bitrix", "自动化", "自动漏斗",
        "开发者", "NFT", "智能合约", "编码", "初创企业",
    ],
    "WEB3": [
      "блокч", "блокчейн", "смарт", "смартконтракт", "смарт-контракт", "биткоин", "btc", "эфир", "эфириум", "ethereum", "ton", "тон", "toncoin",
      "дефи", "defi", "gamefi", "socialfi", "nft", "нфт", "ft", "фт", "токен", "токены", "token", "tokens",
      "ванити", "vanity", "vanityaddress", "ванитиадрес", "адресванити", "vantity", "vantity address",
      "tact", "func", "fift", "tolk", "tact-lang", "func-lang",
      "роялти", "royalty", "royalties", "tv l", "tvl", "тоталлокд", "total value locked", "распределённ", "распределённаяликвидност",
      "ликвидн", "ликвидность", "кошел", "кошелёк", "wallet", "транзакц", "транзакция", "tx", "txs",
      "телеграмподар", "telegramgift", "telegramgifts", "подаркителеграм", "nftusername", "nft username",
      "nftтелефон", "nft номера", "nft номера телефонов", "nftпост", "nftпосты", "nftдиалог", "nftдиалоги",
      "nft коллекц", "nft коллекция", "sbt", "soulbound", "soulboundtoken", "минтлесс", "mintless", "минт", "минтинг",
      "смартассет", "onchain", "offchain", "multisig", "seed", "mnemonic", "custodi", "noncustodial", "dex", "dexpool",
      "тонкеепер", "tonkeeper", "ton dns", "ton dns", "tvm", "blockexplorer", "scan", "bridge", "wrapped", "wrapping",

      "blockchain", "block", "smart", "smartcontract", "smart-contract", "bitcoin", "btc", "ethereum", "eth", "ton", "toncoin",
      "defi", "decentralized finance", "gamefi", "socialfi", "nft", "ft", "token", "tokens", "vanity", "vanity address",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "royalty", "royalties", "tvl", "total value locked", "distributed liquidity", "liquidity", "wallet", "transaction", "tx",
      "telegram gift", "telegramgifts", "nft username", "nft phone", "nft phone number", "nft posts", "nft dialogues",
      "nft collections", "sbt", "soulbound", "mintless", "mintless minting", "on-chain", "off-chain", "multisig", "seedphrase",
      "mnemonic", "non-custodial", "custodial", "dex", "amm", "bridge", "wrapped", "tonkeeper", "ton dns", "explorer",

      "区块链", "区块", "智能合约", "智能合", "比特币", "btc", "以太坊", "以太", "eth", "TON", "TON币", "ton",
      "去中心化金", "DeFi", "GameFi", "SocialFi", "NFT", "FT", "代币", "token", "代币",
      "范式地址", "虚荣地址", "vanity", "vanity地址",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "版税", "版税收益", "royalty", "TVL", "总锁仓价值", "分布式流动性", "流动性", "钱包", "交易", "tx",
      "电报礼物", "Telegram礼物", "NFT用户名", "NFT手机号", "NFT帖子", "NFT对话", "NFT合集", "SBT", "灵魂绑定",
      "免铸造", "mintless", "链上", "链下", "多签", "助记词", "种子短语", "桥", "浏览器", "Tonkeeper",

      "بلوكتشين", "بلوك", "عقود ذكية", "عقد ذكي", "بتكوين", "btc", "إيثريوم", "eth", "تون", "TON", "toncoin",
      "دي فاي", "DeFi", "GameFi", "SocialFi", "NFT", "FT", "توكن", "توكنات", "token",
      "عناوين فانيتي", "vanity address", "vanity",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "رويالتي", "عوائد الملكية", "TVL", "القيمة الإجمالية المغلقة", "السيولة الموزعة", "سيولة", "محفظة", "معاملة", "tx",
      "هدايا تليجرام", "هدية تليجرام", "nft اسم مستخدم", "nft رقم هاتف", "nft منشورات", "nft حوارات", "مجموعات nft",
      "SBT", "توكن مربوط بالروح", "mintless", "بدون مينت", "سلسلة", "خارج السلسلة", "محفظة متعددة توقيع",

      "blockchain", "bloque", "contrato inteligente", "smartcontract", "bitcoin", "btc", "ethereum", "eth", "ton", "toncoin",
      "defi", "decentralized finance", "gamefi", "socialfi", "nft", "ft", "token", "tokens",
      "dirección vanity", "vanity", "vanity address",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "royalties", "regalías", "tvl", "valor total bloqueado", "liquidez distribuida", "liquidez", "cartera", "wallet",
      "transacción", "tx", "regalos telegram", "nft username", "nft teléfono", "nft posts", "nft diálogos", "colecciones nft",
      "sbt", "soulbound", "mintless", "sin mint", "onchain", "offchain", "multisig", "seed", "mnemonic", "bridge",

      "blockchain", "bloc", "contrat intelligent", "smartcontract", "bitcoin", "btc", "ethereum", "eth", "ton", "toncoin",
      "defi", "finance décentralisée", "gamefi", "socialfi", "nft", "ft", "jeton", "token",
      "adresse vanity", "vanity", "vanity address",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "redevances", "royalties", "TVL", "valeur totale verrouillée", "liquidité distribuée", "liquidité", "portefeuille", "wallet",
      "transaction", "tx", "cadeaux telegram", "nft username", "nft téléphone", "nft posts", "nft dialogues", "collections nft",
      "sbt", "soulbound", "mintless", "sans mint", "on-chain", "off-chain", "multisig", "mnemonic"
    ],
    "GAME": [
        "игр", "игра", "игры", "геймер", "геймин", "игров", "стрим", "стример", "стриминг",
        "консол", "пк", "мобил", "мобайл", "телефон", "плейстейш", "пс", "xbox", "ниндзя", "nintendo",
        "шутер", "fps", "рпг", "rpg", "ммо", "mmo", "моба", "moba", "инди", "казуал", "аркад",
        "платформ", "квест", "загадк", "стратег", "тактик", "кооп", "pvp", "ранк", "турнир", "киберспорт",
        "донат", "донатит", "микротранзакц", "внутриигр", "скин", "лот", "loot", "гайд", "проход", "speedrun",
        "мод", "моды", "сервер", "мап", "маяч", "matchmak", "leaderboard", "ачив", "achievement",

        "game", "games", "gamer", "gaming", "stream", "streamer", "twitch", "steam", "ps", "playstation",
        "xbox", "nintendo", "pc", "mobile", "console", "shooter", "fps", "rpg", "mmo", "moba",
        "indie", "casual", "arcade", "platformer", "puzzle", "quest", "strategy", "tactical",
        "coop", "pvp", "rank", "tournament", "esport", "esports", "donate", "microtrans", "in-game",
        "skin", "loot", "mod", "server", "map", "matchmaking", "leaderboard", "walkthrough", "guide",

        "游戏", "游玩", "玩家", "手游", "端游", "主机", "单机", "网游", "多人", "独立", "独立游", "射击",
        "角色", "扮演", "策略", "解谜", "关卡", "任务", "皮肤", "掉落", "Loot", "模组", "mod", "服务器",
        "联机", "匹配", "速通", "直播", "主播", "腾讯", "网易", "任天堂",

        "لعب", "لعبة", "ألعاب", "لاعب", "لاعبين", "بلايستيشن", "اكس_بوكس", "نينتندو", "محمول", "هاتف",
        "كمبيوتر", "كونسول", "متعدد", "شوتر", "تصويب", "تقمص", "استراتيجي", "ألغاز", "مهمة", "مستوى",
        "سكين", "غنيمة", "loot", "مود", "خادم", "توصيل_مباراة", "بث", "ستريمر", "بطولة", "رياضات_إلكترونية",

        "jueg", "juego", "juegos", "jugador", "gaming", "stream", "streamer", "twitch", "steam",
        "consola", "ps", "xbox", "nintendo", "pc", "móvil", "movil", "shooter", "disparos", "rpg",
        "mmo", "moba", "indie", "casual", "arcade", "plataforma", "puzzle", "misión", "nivel", "skin",
        "botín", "loot", "mod", "servidor", "mapa", "matchmaking", "torneo", "esports", "guía",

        "jeu", "jeux", "joueur", "joueuse", "gaming", "stream", "streamer", "twitch", "steam",
        "console", "ps", "playstation", "xbox", "nintendo", "pc", "mobile", "shooter", "fps", "rpg",
        "mmo", "moba", "indé", "indie", "casual", "arcade", "plateforme", "puzzle", "quête", "niveau",
        "skin", "loot", "mod", "serveur", "carte", "matchmaking", "tournoi", "esport", "guide"
    ],
    "UTILITIES": [
        "утилит", "утилита", "сервис", "сервис", "инструм", "инструмент", "обслуживан", "поддержк",
        "мессендж", "почт", "почта", "скрипт", "скрипты", "плагин", "плагин", "модуль", "апи", "api", "sdk",
        "драйвер", "драйв", "бэкап", "резерв", "архив", "хранилищ", "облачн", "cloud", "хостинг", "хост",
        "сетев", "сетевы", "безопасн", "антивирус", "фаервол", "файрвол", "vpn", "прокси", "proxy",
        "аутентиф", "аутентикац", "auth", "логин", "регистрац", "парол", "шифрован", "шифр", "encrypt",
        "encrypt", "шифровани", "compress", "сжат", "архивир", "конверт", "converter", "convertidor",
        "монитор", "мониторинг", "uptime", "метрик", "телеметр", "scheduler", "cron", "демон", "daemon",
        "cli", "gui", "hook", "webhook", "интеграц", "middleware", "автоматиз", "automation", "devops",
        "подключени", "connector", "sync", "синхр", "репликац", "replic", "backup-tool", "restore",
        "support", "техподдержк", "поддержка", "управлен", "админ", "администр", "manage", "управл",
        "service-mesh", "observab", "логг", "логирование", "log", "storage", "файлов", "файловая",
        "почтов", "email", "mail", "smtp", "imap", "pop3", "ftp", "sftp", "ssh", "proxy", "gateway",

        "utilit", "utility", "utilities", "service", "services", "tool", "tools", "cloud", "storage",
        "backup", "archive", "encrypt", "encryption", "security", "antivirus", "firewall", "email",
        "script", "plugin", "extension", "driver", "converter", "compress", "network", "proxy", "vpn",
        "auth", "authenticate", "login", "api", "sdk", "support", "maintenance", "monitor", "monitoring",
        "scheduler", "cron", "daemon", "cli", "gui", "webhook", "integration", "automation", "devops",

        "实用", "工具", "服务", "云", "存储", "备份", "加密", "安全", "防火墙", "杀毒", "邮箱", "邮件",
        "脚本", "插件", "驱动", "转换", "压缩", "网络", "代理", "认证", "登录", "接口", "api", "sdk",
        "监控", "维护", "自动化", "集成", "同步", "还原",

        "أداه", "أدوات", "خدم", "خدمة", "خدمات", "سحابي", "تخزين", "نسخ", "نسخاحتياطي", "أمان", "تشفير",
        "جدارناري", "جدار_ناري", "مكافح_فيروسات", "بريد", "بريد_إلكتروني", "سكريبت", "ملحق", "سائق",
        "محول", "ضغط", "شبكة", "وكيل", "vpn", "توثيق", "تسجيل", "api", "sdk", "دعم", "صيانة", "مراقب",

        "utilit", "utilidad", "utilidades", "servic", "servicio", "servicios", "herramient", "herramienta",
        "nube", "almacen", "copia", "respaldo", "segurid", "cifrad", "antivirus", "firewall", "correo",
        "email", "script", "plugin", "driver", "convertidor", "comprimir", "red", "proxy", "vpn", "auth",
        "login", "api", "sdk", "soporte", "mantenimiento", "monitor", "automatiz",

        "outil", "outils", "service", "services", "utilit", "cloud", "stockag", "sauvegard", "backup",
        "sécur", "chiffr", "antivirus", "pare-feu", "mail", "courriel", "script", "plugin", "pilote",
        "convertiss", "compresse", "réseau", "proxy", "vpn", "authent", "connexion", "api", "sdk",
        "support", "maintenance", "monitor", "automatis", "intégration"
    ]
}
l_hashtag_translate = {
    "BLOG": {
        'ru': "#блогер",
        'en': "#blogger",
        'es': "#blogger",
        'fr': "#blogueur",
        'zh': "#博客作者",
        'ar': "#مدون",
    },
    "DIGIT": {
        'ru': "#оцифровка",
        'en': "#digit",
        'es': "#digitalización",
        'fr': "#numérisation",
        'zh': "#数字化",
        'ar': "#الرقمنة",
    },
    "SMM": {
        'ru': "#смм",
        'en': "#smm",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#سم",
    },
    "RECRUIT": {
        'ru': "#рекрут",
        'en': "#recruit",
        'es': "#recluta",
        'fr': "#recruter",
        'zh': "#招聘人员",
        'ar': "#تجنيد",
    },
    "DESIGN": {
        'ru': "#дизайн",
        'en': "#design",
        'es': "#diseño",
        'fr': "#conception",
        'zh': "#设计",
        'ar': "#التصميم",
    },
    "COACH": {
        'ru': "#коуч",
        'en': "#coach",
        'es': "#entrenador",
        'fr': "#entraîneur",
        'zh': "#教练",
        'ar': "#مدرب",
    },
    "IT": {
        'ru': "#ИТ",
        'en': "#IT",
        'es': "#IT",
        'fr': "#IT",
        'zh': "#信息技术",
        'ar': "#تقانةالمعلومات",
    },
    "BUSINESS": {
        'ru': "#бизнес",
        'en': "#business",
        'es': "#negocios",
        'fr': "#affaires",
        'zh': "#业务",
        'ar': "#الأعمال",
    },
    "GOODS": {
        'ru': "#товарка",
        'en': "#products",
        'es': "#mercancía",
        'fr': "#articles",
        'zh': "#产品中心",
        'ar': "#المنتجات",
    },
    "OFFLINE": {
        'ru': "#оффлайн",
        'en': "#offline",
        'es': "#fueradelínea",
        'fr': "#horsligne",
        'zh': "#离线状态",
        'ar': "#غيرمتصل",
    },
    "HEALTH": {
        'ru': "#здоровье",
        'en': "#health",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "ISVERIFIED": {
        'ru': "#верифиц",
        'en': "#verified",
        'es': "#verificado",
        'fr': "#vérifié",
        'zh': "#已核实",
        'ar': "#التحقق",
    },
    "ISPREMIUM": {
        'ru': "#премиум",
        'en': "#premium",
        'es': "#prima",
        'fr': "#prime",
        'zh': "#保费",
        'ar': "#قسط",
    },
}

l_find_alert = {
    'ru': "👩🏽‍💻 <b>Жми</b> на ✅/☑️, чтобы вкл/выкл <i>уведомления</i> о появлении отслеживаемых слов в публичных группах/каналах\n\n<blockquote>🔔 <b>Отслеживаемые</b> слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    'en': "👩🏽‍💻 <b>Press</b> on ✅/☑️ to turn on/off <i>notifications</i> about the appearance of tracked words in public groups/channels\n\n🔔 <b>Tracked</b > words: <code>{0}</code>\n🔔 <b>Monitored</b> groups/channels: <code>{1}</code>",
    'es': "👩🏽‍💻 <b>Presiona</b> en ✅/☑️ para activar/desactivar las <i>notificaciones</i> sobre la aparición de palabras rastreadas en grupos/canales públicos\n\n🔔 <b>Rastreado< /b > palabras: <code>{0}</code>\n🔔 Grupos/canales <b>monitoreados</b>: <code>{1}</code>",
    'fr': "👩🏽‍💻 <b>Appuyez</b> sur ✅/☑️ pour activer/désactiver les <i>notifications</i> concernant l'apparition de mots suivis dans les groupes/chaînes publics\n\n🔔 <b>Suivi< /b > mots : <code>{0}</code>\n🔔 <b>Groupes/canaux surveillés</b> : <code>{1}</code>",
    'zh': "👩🏽‍💻 <b>按 ✅/☑️ 上的</b> 打开/关闭有关公共群组/频道中所跟踪单词出现的<i>通知</i>\n\n🔔 <b>已跟踪< /b > 单词：<code>{0}</code>\n🔔 <b>受监控</b>组/频道：<code>{1}</code>",
    'ar': "👩🏽‍💻 <b>اضغط</b> على ✅/☑️ لتشغيل/إيقاف <i>الإشعارات</i> حول ظهور الكلمات التي يتم تتبعها في المجموعات/القنوات العامة\n\n🔔 <b>تم تتبعها< /b > الكلمات: <code>{0}</code>\n🔔 المجموعات/القنوات <b>المراقبة</b>: <code>{1}</code>",
}
l_find_alert_alert = {
    'ru': "🔔 Нет отслеживаемых слов/групп/каналов\nЖми ⚙️Настроить",
    'en': "🔔 No words/groups/channels to track\nClick ⚙️Customize",
    'es': "🔔 No hay palabras/grupos/canales para rastrear\nHaga clic en ⚙️Personalizar",
    'fr': "🔔 Aucun mot/groupe/canal à suivre\nCliquez sur ⚙️Personnaliser",
    'zh': "🔔 没有要跟踪的单词/组/频道\n单击 ⚙️自定义",
    'ar': "🔔 لا توجد كلمات/مجموعات/قنوات لتتبعها\nانقر على ⚙️تخصيص",
}
l_find_alert_words = {
    'ru': "👩🏽‍💻 <b>1. Вставь</b> отслеживаемые слова (более <u>3</u> символов) через <i>пробельные или разделительные</i> символы (без 💨Подписки: <u>1</u> слово)\n\n<blockquote>▪️регистр не важен\n▪️* в конце слова учитывает вхождение</blockquote>\n\n👩🏽‍💻 <b>Например</b>, для <b>психо*</b> отслеживание сработает на фразы: <i>анти<u>психо</u>лог, <u>Психо</u>терапевт..</i>\n\n<blockquote>🔔 <b>Отслеживаемые</b>  слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    'en': "👩🏽‍💻 <b>1. Insert</b>tracked words (more than <u>3</u> characters) separated by <i>space or separator</i> characters (without 💨Subscription: <u>1</u> word)\n▪️case not important\n▪️* at the end of the word takes into account the occurrence\n\n👩🏽‍💻 <b>For example</b>, for <b>psycho*</b> tracking will work on the phrases: <i>anti<u> psycho</u>logist, <u>Psycho</u>therapist..</i>\n🔔 <b>Tracked</b> words: <code>{0}</code>\n🔔 <b >Monitored</b>groups/channels: <code>{1}</code>",
    'es': "👩🏽‍💻 <b>1. Insertar</b>palabras rastreadas (más de <u>3</u> caracteres) separadas por <i>espacio o separador</i> caracteres (sin 💨Suscripción: <u>1</u> palabra)\n▪️caso no importante\n▪️* al final de la palabra tiene en cuenta la ocurrencia\n\n👩🏽‍💻 <b>Por ejemplo</b>, para <b>psico*</b> el seguimiento funcionará en las frases: <i>anti<u> psico</u>logista, <u>Psico</u>terapeuta...</i>\n🔔 Palabras <b>seguidas</b>: <code>{ 0}</code>\n🔔 <b >Grupos/canales</b>monitoreados: <code>{1}</code>",
    'fr': "👩🏽‍💻 <b>1. Insérer</b>des mots suivis (plus de <u>3</u> caractères) séparés par des caractères <i>espace ou séparateur</i> (sans 💨Abonnement : <u>1</u> mot)\n▪️cas sans importance\n▪️* à la fin du mot prend en compte l'occurrence\n\n👩🏽‍💻 <b>Par exemple</b>, pour le <b>psycho*</b> le tracking fonctionnera sur les phrases : <i>anti<u>psychologue</u>logue, <u>Psycho</u>thérapeute..</i>\n🔔 <b>Mots suivis</b> : <code>{ 0}</code>\n🔔 <b >Groupes/canaux surveillés</b> : <code>{1}</code>",
    'zh': "👩🏽‍💻 <b>1.插入</b>跟踪的单词（超过<u>3</u>个字符），并用<i>空格或分隔符</i>个字符分隔（不含💨订阅：<u>1</u>个单词）\n▪️大小写不重要\n▪️* 位于单词末尾会考虑出现情况\n\n👩🏽‍💻 <b>例如</b>，对于 <b>psycho*</b> 跟踪将起作用关于短语：<i>反<u>心理学家</u>，<u>心理</u>治疗师..</i>\n🔔<b>跟踪</b>单词：<code>{ 0}</code>\n🔔<b>监控</b>组/频道：<code>{1}</code>",
    'ar': "👩🏽‍💻<b>1. أدخل</b>الكلمات المتعقبة (أكثر من <u>3</u> أحرف) مفصولة بأحرف <i>مسافة أو فاصل</i> (بدون 💨الاشتراك: <u>1</u> كلمة)\n▪️الحالة غير مهمة\n▪️* في نهاية الكلمة تأخذ في الاعتبار حدوث\n\n👩🏽‍💻 <b>على سبيل المثال</b>، بالنسبة إلى <b>النفسية*</b> سيعمل التتبع على العبارات: <i>أخصائي <u> نفسي</u>، معالج <u>نفسي</u>..</i>\n🔔 <b>كلمات متعقبة</b>: <code>{ 0}</code>\n🔔 <b >المجموعات/القنوات</b>المراقبة: <code>{1}</code>",
}
l_find_alert_sources = {
    'ru': "👩🏽‍💻 <b>2. Вставь</b> публичные ссылки на группы/каналы (для отслеживаемых слов) через <i>пробелы/раздели</i> (без 💨Подписки: <u>1</u> группа/канал)\n\n<blockquote>🔔 <b>Отслеживаемые</b>  слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    'en': "👩🏽‍💻 <b>2. Insert</b> public links to groups/channels (for tracked words) separated by <i>spaces/separated</i> (without 💨Subscription: <u>1</u> group/channel)\n\n🔔 <b>Watched</b> words: <code>{0}</code>\n🔔 <b>Monitored</b> groups/channels: <code>{1}</code>",
    'es': "👩🏽‍💻 <b>2. Insertar</b> enlaces públicos a grupos/canales (para palabras rastreadas) separados por <i>espacios/separados</i> (sin 💨Suscripción: <u>1</u> grupo/canal)\n\n🔔 <b>Palabras vistas</b>: <code>{0}</code>\n🔔 Grupos/canales <b>monitoreados</b>: <code>{1}</code>",
    'fr': "👩🏽‍💻 <b>2. Insérer</b> des liens publics vers des groupes/canaux (pour les mots suivis) séparés par des <i>espaces/séparés</i> (sans 💨Abonnement : <u>1</u> groupe/canal)\n\n🔔 <b>Mots surveillés</b> : <code>{0}</code>\n🔔 <b>Groupes/chaînes surveillés</b> : <code>{1}</code>",
    'zh': "👩🏽‍💻 <b>2.插入</b>到群组/频道的公共链接（用于跟踪的单词），以<i>空格/分隔</i>分隔（无💨订阅：<u>1</u>群组/频道）\n\n🔔 <b>观看</b>字词：<code>{0}</code>\n🔔<b>监控</b>组/频道：<code>{1}</code>",
    'ar': "👩🏽‍💻<b>2. أدخل</b> روابط عامة للمجموعات/القنوات (للكلمات المتعقبة) مفصولة <i>بمسافات/مفصولة</i> (بدون 💨الاشتراك: <u>1</u> مجموعة/قناة)\n\n🔔 <b>الكلمات</b> التي تمت مشاهدتها: <code>{0}</code>\n🔔 المجموعات/القنوات <b>المراقبة</b>: <code>{1}</code>",
}
l_find_need_subscribe = {
    'ru': "👩🏽‍💻 <b>Для</b> получения ссылки на сообщение и заказчика оформи 💨Подписку на @FereyFindBot-бота:\n\nhttps://t.me",
    'en': "👩🏽‍💻 <b>To</b> receive a link to the message and the customer, subscribe 💨Subscribe to @FereyFindBot-bot:\n\nhttps://t.me",
    'es': "👩🏽‍💻 <b>Para</b> recibir un enlace al mensaje y al cliente, suscríbete 💨Suscríbete a @FereyFindBot-bot:\n\nhttps://t.me",
    'fr': "👩🏽‍💻 <b>Pour</b> recevoir un lien vers le message et le client, abonnez-vous 💨Abonnez-vous à @FereyFindBot-bot :\n\nhttps://t.me",
    'zh': "👩🏽‍💻<b>要</b>接收消息和客户的链接，请订阅💨订阅@FereyFindBot-bot：\n\nhttps://t.me",
    'ar': "👩🏽‍💻 <b>للحصول</b> على رابط الرسالة والعميل، اشترك 💨Subscribe to @FereyFindBot-bot:\n\nhttps://t.me",
}

# endregion


# region FereyTONestBot
l_tonest_btn1 = {
    "ru": "👩🏽‍💻 Блокчейн-активы",
    "en": "👩🏽‍💻 Blockchain assets",
    "es": "👩🏽‍💻 Activos de blockchain",
    "fr": "👩🏽‍💻 Actifs blockchain",
    "zh": "👩🏽‍💻 区块链资产",
    "ar": "👩🏽‍💻 أصول البلوك تشين",
}
l_tonest_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}

l_tonest_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания Web3ᵀᴼᴺ-проектов на блокчейне:\n\n<blockquote>▪️соло/альбом NFT\n▪️монеты (токены) FT\n▪️смарт-контракты\n▪️NFT-диалоги</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for creating Web3ᵀᴼᴺ projects on the blockchain:\n\n<blockquote>▪️solo/NFT album\n▪️coins (tokens) FT\n▪️smart contracts\n▪️NFT dialogues</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la <i>@tg-app</i> para la creación de proyectos Web3ᵀᴼᴺ en la blockchain:\n\n<blockquote>▪️álbum solo/NFT\n▪️monedas (tokens) FT\n▪️contratos inteligentes\n▪️diálogos NFT</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans l’<i>@tg-app</i> de création de projets Web3ᵀᴼᴺ sur la blockchain:\n\n<blockquote>▪️solo/album NFT\n▪️pièces (jetons) FT\n▪️contrats intelligents\n▪️dialogues NFT</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎来到<i>@tg-app</i>区块链上创建Web3ᵀᴼᴺ项目：\n\n<blockquote>▪️单独/NFT专辑\n▪️货币（代币）FT\n▪️智能合约\n▪️NFT对话</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-app</i> لإنشاء مشاريع Web3ᵀᴼᴺ على البلوكتشين:\n\n<blockquote>▪️ألبوم منفرد/NFT\n▪️عملات (رموز) FT\n▪️العقود الذكية\n▪️حوارات NFT</blockquote>",
}
l_tonest_dialog_online = {
    "ru": "в сети",
    "en": "online",
    "es": "en línea",
    "fr": "en ligne",
    "zh": "在线",
    "ar": "متصل",
}
l_tonest_participants_of_dialog = {
    "ru": "участников диалога",
    "en": "participants of the dialog",
    "es": "participantes del diálogo",
    "fr": "participants du dialogue",
    "zh": "对话参与者",
    "ar": "المشاركون في الحوار",
}

l_tonest_dialog_without_sub = {
    "ru": "👩🏽‍💻 <b>Без подписки</b> можно отчеканить не более 10 реплик в NFT-диалог",
    "en": "👩🏽‍💻 <b>Without subscription</b> you can mint no more than 10 replies in an NFT dialog",
    "es": "👩🏽‍💻 <b>Sin suscripción</b> puedes acuñar no más de 10 réplicas en un diálogo NFT",
    "fr": "👩🏽‍💻 <b>Sans abonnement</b> vous pouvez frapper jusqu'à 10 répliques dans un dialogue NFT",
    "zh": "👩🏽‍💻 <b>没有订阅</b>最多可铸造10条NFT对话回复",
    "ar": "👩🏽‍💻 <b>بدون اشتراك</b> يمكنك سكّ ما لا يزيد عن 10 ردود في حوار NFT",
}
l_tonest_dialog_limit_50 = {
    "ru": "👩🏽‍💻 <b>Можно</b> отчеканить не более 50 реплик в NFT-диалог",
    "en": "👩🏽‍💻 <b>You can</b> mint up to 50 replies in an NFT dialog",
    "es": "👩🏽‍💻 <b>Puedes</b> acuñar hasta 50 réplicas en un diálogo NFT",
    "fr": "👩🏽‍💻 <b>Vous pouvez</b> frapper jusqu'à 50 répliques dans un dialogue NFT",
    "zh": "👩🏽‍💻 <b>你可以</b>在NFT对话中铸造最多50条回复",
    "ar": "👩🏽‍💻 <b>يمكنك</b> سكّ ما يصل إلى 50 ردًا في حوار NFT",
}
l_tonest_dialog_need_correct_msgs = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> переслать корректные сообщения (сообщения от бота или аудио формат невозможно переслать)",
    "en": "👩🏽‍💻 <b>You need</b> to forward valid messages (audio format cannot be forwarded)",
    "es": "👩🏽‍💻 <b>Necesitas</b> reenviar mensajes válidos (el formato de audio no se puede reenviar)",
    "fr": "👩🏽‍💻 <b>Vous devez</b> transférer des messages valides (le format audio ne peut pas être transféré)",
    "zh": "👩🏽‍💻 <b>你需要</b>转发有效的消息（音频格式无法转发）",
    "ar": "👩🏽‍💻 <b>يجب</b> إعادة توجيه رسائل صحيحة (لا يمكن إعادة توجيه تنسيق الصوت)",
}

l_tonest_nft_dialog = {
    "ru": "💬 NFT-диалог",
    "en": "💬 NFT dialog",
    "es": "💬 Diálogo NFT",
    "fr": "💬 Dialogue NFT",
    "zh": "💬 NFT对话",
    "ar": "💬 حوار NFT",
}
l_tonest_dialog_creating = {
    "ru": "👩🏽‍💻 <b>Жми</b> на [💬 NFT-диалог], чтобы просмотреть и подтвердить создание NFT-диалога",
    "en": "👩🏽‍💻 <b>Tap</b> on [💬 NFT dialog] to preview and confirm the creation of the NFT dialog",
    "es": "👩🏽‍💻 <b>Pulsa</b> en [💬 Diálogo NFT] para ver y confirmar la creación del diálogo NFT",
    "fr": "👩🏽‍💻 <b>Appuyez</b> sur [💬 Dialogue NFT] pour prévisualiser et confirmer la création du dialogue NFT",
    "zh": "👩🏽‍💻 <b>点击</b>[💬 NFT对话]以预览并确认创建NFT对话",
    "ar": "👩🏽‍💻 <b>اضغط</b> على [💬 حوار NFT] لمعاينة وإنشاء حوار NFT",
}

# endregion


# region FereyStickerBot
l_sticker_btn1 = {
    "ru": "👩🏽‍💻 Стикеры",
    "en": "👩🏽‍💻 Stickers",
    "es": "👩🏽‍💻 Stickers",
    "fr": "👩🏽‍💻 Autocollants",
    "zh": "👩🏽‍💻 贴纸",
    "ar": "👩🏽‍💻 الملصقات",
}
l_sticker_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_sticker_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания эмоджи/стикер наборов:\n\n<blockquote>▪️<b>static/video/animated</b>\n▪️преобразование фото в видео</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for creating emoji/sticker packs:\n\n<blockquote>▪️<b>static/video/animated</b>\n▪️photo-to-video conversion</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la <i>@tg-aplicación</i> para crear paquetes de emoji/stickers:\n\n<blockquote>▪️<b>estático/video/animado</b>\n▪️conversión de foto a video</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> de création de packs d’emojis/autocollants :\n\n<blockquote>▪️<b>statique/vidéo/animé</b>\n▪️conversion photo en vidéo</blockquote>",
    "zh": "🌱 <b>{0}</b>，欢迎使用<i>@tg-应用</i>创建表情符号/贴纸包：\n\n<blockquote>▪️<b>静态/视频/动画</b>\n▪️照片转视频</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-تطبيق</i> لإنشاء حزم الإيموجي/الملصقات:\n\n<blockquote>▪️<b>ثابت/فيديو/متحرك</b>\n▪️تحويل الصور إلى فيديو</blockquote>",
}

l_pack_type = {
    "ru": "✏️ 1. <b>Выбери</b> тип создаваемого набора <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a>\n\n(<i>жми «➡️️/Next», чтобы перейти к следующему шагу</i>)",
    "en": "✏️ 1. <b>Select</b> the type of the <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a> pack you want to create\n\n(<i>click “➡️️/Next” to proceed to the next step</i>)",
    "es": "✏️ 1. <b>Elige</b> el tipo de paquete que deseas crear: <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a>\n\n(<i>pulsa «➡️️/Siguiente» para continuar al siguiente paso</i>)",
    "fr": "✏️ 1. <b>Choisissez</b> le type de pack à créer : <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a>\n\n(<i>cliquez sur « ➡️️/Suivant » pour passer à l’étape suivante</i>)",
    "zh": "✏️ 1. <b>选择</b>要创建的<a href='https://t.me/addstickers/ResistanceDog'>贴纸</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>表情</a>包类型\n\n（<i>点击“➡️️/下一步”进入下一步</i>）",
    "ar": "✏️ 1. <b>اختر</b> نوع الحزمة التي تريد إنشاؤها: <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a>\n\n(<i>انقر على '➡️️/التالي' للانتقال إلى الخطوة التالية</i>)",
}
l_pack_username = {
    "ru": "✏️ 2. <b>Введи</b> @username <b>{0}</b>-набора (до 45 символов), отображаемого в ссылке\n\n<i>или жми «➡️️/Next», чтобы использовать рандомный:\n<blockquote>{1}</blockquote></i>",
    "en": "✏️ 2. <b>Enter</b> the @username of the <b>{0}</b> pack (up to 45 characters), shown in the link\n\n<i>or click “➡️️/Next” to use a random one:\n<blockquote>{1}</blockquote></i>",
    "es": "✏️ 2. <b>Introduce</b> el @username del paquete <b>{0}</b> (hasta 45 caracteres), que aparecerá en el enlace\n\n<i>o pulsa «➡️️/Siguiente» para usar uno aleatorio:\n<blockquote>{1}</blockquote></i>",
    "fr": "✏️ 2. <b>Entrez</b> le @username du pack <b>{0}</b> (jusqu’à 45 caractères), affiché dans le lien\n\n<i>ou cliquez sur « ➡️️/Suivant » pour en générer un au hasard :\n<blockquote>{1}</blockquote></i>",
    "zh": "✏️ 2. <b>输入</b><b>{0}</b>包的@用户名（最多45个字符），将显示在链接中\n\n<i>或点击“➡️️/下一步”使用随机用户名：\n<blockquote>{1}</blockquote></i>",
    "ar": "✏️ 2. <b>أدخل</b> @username لحزمة <b>{0}</b> (بحد أقصى 45 حرفًا)، والذي سيظهر في الرابط\n\n<i>أو انقر على '➡️️/التالي' لاستخدام اسم عشوائي:\n<blockquote>{1}</blockquote></i>",
}
l_pack_title = {
    "ru": "✏️ 3. <b>Введи</b> название <b>{0}</b>-набора (до 64 символов), отображаемого в заголовке: <b>Title</b>\n\n<i>или жми «➡️️/Next», чтобы использовать рандомное:\n<blockquote>{1}</blockquote></i>",
    "en": "✏️ 3. <b>Enter</b> the name of the <b>{0}</b> pack (up to 64 characters), which will appear as the <b>Title</b>\n\n<i>or click “➡️️/Next” to use a random one:\n<blockquote>{1}</blockquote></i>",
    "es": "✏️ 3. <b>Introduce</b> el nombre del paquete <b>{0}</b> (hasta 64 caracteres), que se mostrará como <b>Title</b>\n\n<i>o pulsa «➡️️/Siguiente» para usar uno aleatorio:\n<blockquote>{1}</blockquote></i>",
    "fr": "✏️ 3. <b>Entrez</b> le nom du pack <b>{0}</b> (jusqu’à 64 caractères), affiché comme <b>Title</b>\n\n<i>ou cliquez sur « ➡️️/Suivant » pour en générer un au hasard :\n<blockquote>{1}</blockquote></i>",
    "zh": "✏️ 3. <b>输入</b><b>{0}</b>包的名称（最多64个字符），将显示为<b>Title</b>\n\n<i>或点击“➡️️/下一步”使用随机名称：\n<blockquote>{1}</blockquote></i>",
    "ar": "✏️ 3. <b>أدخل</b> اسم حزمة <b>{0}</b> (حتى 64 حرفًا)، الذي سيظهر كـ <b>Title</b>\n\n<i>أو انقر على '➡️️/التالي' لاستخدام اسم عشوائي:\n<blockquote>{1}</blockquote></i>",
}
l_pack_kind = {
    "ru": "✏️ 4. <b>Укажи</b> вид <b>{0}</b>-набора: ¹<a href='{1}'>статический</a>/²<a href='{2}'>видео</a>/³<a href='{3}'>анимация</a>\n\n<blockquote>¹static (.webp/.png, px: {7}, 512Kb, max: {4})\n²video (.webm/3 сек, px: {7}, 256Kb, max: {5})\n³animated (.tgs/3 сек, px: {7}, 64Kb, max: {6})</blockquote>",
    "en": "✏️ 4. <b>Specify</b> the type of the <b>{0}</b> pack: ¹<a href='{1}'>static</a>/²<a href='{2}'>video</a>/³<a href='{3}'>animated</a>\n\n<blockquote>¹static (.webp/.png, px: {7}, 512Kb, max: {4})\n²video (.webm/3 sec, px: {7}, 256Kb, max: {5})\n³animated (.tgs/3 sec, px: {7}, 64Kb, max: {6})</blockquote>",
    "es": "✏️ 4. <b>Especifica</b> el tipo de paquete <b>{0}</b>: ¹<a href='{1}'>estático</a>/²<a href='{2}'>video</a>/³<a href='{3}'>animado</a>\n\n<blockquote>¹estático (.webp/.png, px: {7}, 512Kb, máx: {4})\n²video (.webm/3 seg, px: {7}, 256Kb, máx: {5})\n³animado (.tgs/3 seg, px: {7}, 64Kb, máx: {6})</blockquote>",
    "fr": "✏️ 4. <b>Indiquez</b> le type de pack <b>{0}</b> : ¹<a href='{1}'>statique</a>/²<a href='{2}'>vidéo</a>/³<a href='{3}'>animé</a>\n\n<blockquote>¹statique (.webp/.png, px : {7}, 512Ko, max : {4})\n²vidéo (.webm/3 sec, px : {7}, 256Ko, max : {5})\n³animé (.tgs/3 sec, px : {7}, 64Ko, max : {6})</blockquote>",
    "zh": "✏️ 4. <b>指定</b><b>{0}</b>包的类型：¹<a href='{1}'>静态</a>/²<a href='{2}'>视频</a>/³<a href='{3}'>动画</a>\n\n<blockquote>¹静态 (.webp/.png, 像素: {7}, 512Kb, 最大: {4})\n²视频 (.webm/3 秒, 像素: {7}, 256Kb, 最大: {5})\n³动画 (.tgs/3 秒, 像素: {7}, 64Kb, 最大: {6})</blockquote>",
    "ar": "✏️ 4. <b>حدد</b> نوع حزمة <b>{0}</b>: ¹<a href='{1}'>ثابتة</a>/²<a href='{2}'>فيديو</a>/³<a href='{3}'>متحركة</a>\n\n<blockquote>¹ثابتة (.webp/.png، بكسل: {7}، 512Kb، الحد الأقصى: {4})\n²فيديو (.webm/3 ثوان، بكسل: {7}، 256Kb، الحد الأقصى: {5})\n³متحركة (.tgs/3 ثوان، بكسل: {7}، 64Kb، الحد الأقصى: {6})</blockquote>",
}
l_pck_new = {
    "ru": "🏔️ Создать",
    "en": "🏔️ Create",
    "es": "🏔️ Crear",
    "fr": "🏔️ Créer",
    "zh": "🏔️ 创建",
    "ar": "🏔️ إنشاء",
}
l_pck_edt = {
    "ru": "♻️ Изменить",
    "en": "♻️ Edit",
    "es": "♻️ Editar",
    "fr": "♻️ Modifier",
    "zh": "♻️ 编辑",
    "ar": "♻️ تعديل",
}
l_pck_del = {
    "ru": "🚫 Удалить",
    "en": "🚫 Delete",
    "es": "🚫 Eliminar",
    "fr": "🚫 Supprimer",
    "zh": "🚫 删除",
    "ar": "🚫 حذف",
}
l_pack_sticker = {
    "ru": "стикер",
    "en": "sticker",
    "es": "sticker",
    "fr": "autocollant",
    "zh": "贴纸",
    "ar": "ملصق",
}
l_pack_emoji = {
    "ru": "эмоджи",
    "en": "emoji",
    "es": "emoji",
    "fr": "emoji",
    "zh": "表情符号",
    "ar": "رموز تعبيرية",
}
l_pack_static = {
    "ru": "статический",
    "en": "static",
    "es": "estático",
    "fr": "statique",
    "zh": "静态",
    "ar": "ثابت",
}
l_pack_video = {
    "ru": "видео",
    "en": "video",
    "es": "video",
    "fr": "vidéo",
    "zh": "视频",
    "ar": "فيديو",
}
l_pack_animation = {
    "ru": "анимация",
    "en": "animation",
    "es": "animación",
    "fr": "animation",
    "zh": "动画",
    "ar": "رسوم متحركة",
}

l_item_media = {
    "ru": "✏️ 1. <b>Отправь</b> sticker/emoji или photo/video/gif для добавления в [{0}]\n\n<blockquote>или выбери из набора существующий <b>{1}</b> для редактирования/удаления - чтобы ускорить изменения удали и добавь набор снова</blockquote>\n<blockquote>жми ⚫️/🙌🏽/🔄, чтобы закруглить/удалить фон фото/конвертировать фото в видео</blockquote>",
    "en": "✏️ 1. <b>Send</b> sticker/emoji or photo/video/gif to add to [{0}]\n\n<blockquote>or choose an existing <b>{1}</b> from the set for editing/deleting - to speed up changes delete and add the set again</blockquote>\n<blockquote>press ⚫️/🙌🏽/🔄 to round/remove photo background/convert photo to video</blockquote>",
    "es": "✏️ 1. <b>Envía</b> sticker/emoji o foto/video/gif para agregar a [{0}]\n\n<blockquote>o elige un <b>{1}</b> existente del conjunto para editar/eliminar - para acelerar los cambios elimina y vuelve a agregar el conjunto</blockquote>\n<blockquote>presiona ⚫️/🙌🏽/🔄 para redondear/eliminar fondo de la foto/convertir foto en video</blockquote>",
    "fr": "✏️ 1. <b>Envoie</b> sticker/emoji ou photo/vidéo/gif pour ajouter à [{0}]\n\n<blockquote>ou choisis un <b>{1}</b> existant du lot pour modifier/supprimer - pour accélérer les modifications supprime et réajoute le lot</blockquote>\n<blockquote>appuie sur ⚫️/🙌🏽/🔄 pour arrondir/supprimer le fond de la photo/convertir la photo en vidéo</blockquote>",
    "zh": "✏️ 1. <b>发送</b> 贴纸/表情或照片/视频/GIF 添加到 [{0}]\n\n<blockquote>或从集合中选择已有的 <b>{1}</b> 进行编辑/删除 - 为加快更改请删除并重新添加集合</blockquote>\n<blockquote>点击 ⚫️/🙌🏽/🔄 进行圆角/移除照片背景/将照片转换为视频</blockquote>",
    "ar": "✏️ 1. <b>أرسل</b> ملصق/رمز تعبيري أو صورة/فيديو/GIF لإضافتها إلى [{0}]\n\n<blockquote>أو اختر <b>{1}</b> موجود من المجموعة للتعديل/الحذف - لتسريع التغييرات احذف وأعد إضافة المجموعة</blockquote>\n<blockquote>اضغط ⚫️/🙌🏽/🔄 لتدوير/إزالة خلفية الصورة/تحويل الصورة إلى فيديو</blockquote>"
}
l_item_format = {
    "ru": "✏️ 2. <b>Выбери</b> формат для <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    "en": "✏️ 2. <b>Choose</b> format for <b>{0}</b>\n\n<blockquote>or press “➡️️/Next” to proceed to the next step</blockquote>",
    "es": "✏️ 2. <b>Elige</b> formato para <b>{0}</b>\n\n<blockquote>o presiona “➡️️/Siguiente” para pasar al siguiente paso</blockquote>",
    "fr": "✏️ 2. <b>Choisis</b> le format pour <b>{0}</b>\n\n<blockquote>ou appuie sur « ➡️️/Suivant » pour passer à l’étape suivante</blockquote>",
    "zh": "✏️ 2. 为 <b>{0}</b> <b>选择</b> 格式\n\n<blockquote>或点击“➡️️/下一步”进入下一步</blockquote>",
    "ar": "✏️ 2. <b>اختر</b> التنسيق لـ <b>{0}</b>\n\n<blockquote>أو اضغط “➡️️/التالي” للانتقال إلى الخطوة التالية</blockquote>",
}
l_item_emoji = {
    "ru": "✏️ 2. <b>Укажи</b> эмоджи (до 20), которые будут ассоциированы с загруженным <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    "en": "✏️ 2. <b>Specify</b> emojis (up to 20) that will be associated with the uploaded <b>{0}</b>\n\n<blockquote>or press “➡️️/Next” to proceed to the next step</blockquote>",
    "es": "✏️ 2. <b>Indica</b> emojis (hasta 20) que estarán asociados con el <b>{0}</b> subido\n\n<blockquote>o presiona “➡️️/Siguiente” para pasar al siguiente paso</blockquote>",
    "fr": "✏️ 2. <b>Indique</b> les emojis (jusqu’à 20) qui seront associés au <b>{0}</b> téléchargé\n\n<blockquote>ou appuie sur « ➡️️/Suivant » pour passer à l’étape suivante</blockquote>",
    "zh": "✏️ 2. <b>指定</b> 与上传的 <b>{0}</b> 关联的表情符号（最多20个）\n\n<blockquote>或点击“➡️️/下一步”进入下一步</blockquote>",
    "ar": "✏️ 2. <b>حدد</b> الرموز التعبيرية (حتى 20) التي سترتبط بـ <b>{0}</b> الذي تم تحميله\n\n<blockquote>أو اضغط “➡️️/التالي” للانتقال إلى الخطوة التالية</blockquote>",
}
l_item_keyword = {
    "ru": "✏️ 3. <b>Укажи</b> ключевые слова (до 64 символов), которые будут ассоциированы с загруженным <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    "en": "✏️ 3. <b>Specify</b> keywords (up to 64 characters) that will be associated with the uploaded <b>{0}</b>\n\n<blockquote>or press “➡️️/Next” to proceed to the next step</blockquote>",
    "es": "✏️ 3. <b>Indica</b> palabras clave (hasta 64 caracteres) que estarán asociadas con el <b>{0}</b> subido\n\n<blockquote>o presiona “➡️️/Siguiente” para pasar al siguiente paso</blockquote>",
    "fr": "✏️ 3. <b>Indique</b> les mots-clés (jusqu’à 64 caractères) qui seront associés au <b>{0}</b> téléchargé\n\n<blockquote>ou appuie sur « ➡️️/Suivant » pour passer à l’étape suivante</blockquote>",
    "zh": "✏️ 3. <b>指定</b> 与上传的 <b>{0}</b> 关联的关键词（最多64个字符）\n\n<blockquote>或点击“➡️️/下一步”进入下一步</blockquote>",
    "ar": "✏️ 3. <b>حدد</b> الكلمات المفتاحية (حتى 64 حرفًا) التي سترتبط بـ <b>{0}</b> الذي تم تحميله\n\n<blockquote>أو اضغط “➡️️/التالي” للانتقال إلى الخطوة التالية</blockquote>",
}
l_pck_title = {
    "ru": "🏔️ Название",
    "en": "🏔️ Title",
    "es": "🏔️ Título",
    "fr": "🏔️ Titre",
    "zh": "🏔️ 标题",
    "ar": "🏔️ العنوان",
}
l_itm_words = {
    "ru": "💬 Слова",
    "en": "💬 Words",
    "es": "💬 Palabras",
    "fr": "💬 Mots",
    "zh": "💬 词语",
    "ar": "💬 كلمات",
}
l_itm_emoji = {
    "ru": "❤️ Эмоджи",
    "en": "❤️ Emojis",
    "es": "❤️ Emojis",
    "fr": "❤️ Emojis",
    "zh": "❤️ 表情符号",
    "ar": "❤️ الرموز التعبيرية",
}
l_itm_delete = {
    "ru": "❌ Удалить",
    "en": "❌ Delete",
    "es": "❌ Eliminar",
    "fr": "❌ Supprimer",
    "zh": "❌ 删除",
    "ar": "❌ حذف",
}
l_itm_thumb = {
    "ru": "🖼️ Обложка",
    "en": "🖼️ Cover",
    "es": "🖼️ Portada",
    "fr": "🖼️ Couverture",
    "zh": "🖼️ 封面",
    "ar": "🖼️ غلاف",
}
l_itm_shift = {
    "ru": "🔛 Сдвиг",
    "en": "🔛 Shift",
    "es": "🔛 Desplazar",
    "fr": "🔛 Décalage",
    "zh": "🔛 移动",
    "ar": "🔛 تحريك",
}
l_itm_back = {
    "ru": "🔙 Назад",
    "en": "🔙 Back",
    "es": "🔙 Atrás",
    "fr": "🔙 Retour",
    "zh": "🔙 返回",
    "ar": "🔙 رجوع",
}
l_pack_warn = {
    "ru": "👩🏽‍💻 <b>@username набора</b> не может начинаться с цифр/подчеркиваний, содержать не латинские символы и несколько подчеркиваний подряд",
    "en": "👩🏽‍💻 <b>@username of the pack</b> cannot start with digits/underscores, contain non-latin characters or multiple underscores in a row",
    "es": "👩🏽‍💻 <b>@username del conjunto</b> no puede comenzar con números/guiones bajos, contener caracteres no latinos ni varios guiones bajos seguidos",
    "fr": "👩🏽‍💻 <b>@username du pack</b> ne peut pas commencer par des chiffres/soulignements, contenir des caractères non latins ni plusieurs soulignements consécutifs",
    "zh": "👩🏽‍💻 <b>@username 的包</b> 不能以数字/下划线开头，不能包含非拉丁字符或多个连续下划线",
    "ar": "👩🏽‍💻 <b>@username للحزمة</b> لا يمكن أن يبدأ بأرقام/شرطات سفلية، أو يحتوي على أحرف غير لاتينية أو عدة شرطات سفلية متتالية",
}
l_pack_exist = {
    "ru": "👩🏽‍💻 {0} уже существует, выбери другой @username-набора",
    "en": "👩🏽‍💻 {0} already exists, choose another @username for the pack",
    "es": "👩🏽‍💻 {0} ya existe, elige otro @username para el conjunto",
    "fr": "👩🏽‍💻 {0} existe déjà, choisissez un autre @username pour le pack",
    "zh": "👩🏽‍💻 {0} 已存在，选择另一个包的 @username",
    "ar": "👩🏽‍💻 {0} موجود بالفعل، اختر @username آخر للحزمة",
}
l_pack_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> создания набора: повтори попытку позже или загрузи другой media-файл",
    "en": "👩🏽‍💻 <b>Error</b> creating the pack: try again later or upload another media file",
    "es": "👩🏽‍💻 <b>Error</b> al crear el conjunto: inténtalo de nuevo más tarde o sube otro archivo multimedia",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors de la création du pack : réessayez plus tard ou téléchargez un autre fichier média",
    "zh": "👩🏽‍💻 创建包时发生<b>错误</b>：请稍后重试或上传其他媒体文件",
    "ar": "👩🏽‍💻 <b>خطأ</b> في إنشاء الحزمة: حاول مرة أخرى لاحقًا أو قم بتحميل ملف وسائط آخر",
}
l_pack_full = {
    "ru": "👩🏽‍💻 {0}-набор уже заполнен. Выбери из набора существующий <b>{1}</b> для редактирования/удаления",
    "en": "👩🏽‍💻 {0} pack is already full. Choose an existing <b>{1}</b> from the pack to edit/delete",
    "es": "👩🏽‍💻 El conjunto {0} ya está lleno. Elige un <b>{1}</b> existente del conjunto para editar/eliminar",
    "fr": "👩🏽‍💻 Le pack {0} est déjà plein. Choisissez un <b>{1}</b> existant dans le pack pour modifier/supprimer",
    "zh": "👩🏽‍💻 {0} 包已满。选择包中已有的 <b>{1}</b> 进行编辑/删除",
    "ar": "👩🏽‍💻 حزمة {0} ممتلئة بالفعل. اختر <b>{1}</b> موجودًا من الحزمة للتحرير/الحذف",
}
l_pack_full2 = {
    "ru": "👩🏽‍💻 Набор уже заполнен ({1}/{2}). Выбери из набора существующий {3} для редактирования/удаления",
    "en": "👩🏽‍💻 Pack is already full ({1}/{2}). Choose an existing {3} from the pack to edit/delete",
    "es": "👩🏽‍💻 El conjunto ya está lleno ({1}/{2}). Elige un {3} existente del conjunto para editar/eliminar",
    "fr": "👩🏽‍💻 Le pack est déjà plein ({1}/{2}). Choisissez un {3} existant dans le pack pour modifier/supprimer",
    "zh": "👩🏽‍💻 包已满 ({1}/{2})。选择包中已有的 {3} 进行编辑/删除",
    "ar": "👩🏽‍💻 الحزمة ممتلئة بالفعل ({1}/{2}). اختر {3} موجودًا من الحزمة للتحرير/الحذف",
}
l_pack_delete = {
    "ru": "👩🏽‍💻 <b>Удалить</b> набор: {0}",
    "en": "👩🏽‍💻 <b>Delete</b> pack: {0}",
    "es": "👩🏽‍💻 <b>Eliminar</b> conjunto: {0}",
    "fr": "👩🏽‍💻 <b>Supprimer</b> le pack : {0}",
    "zh": "👩🏽‍💻 <b>删除</b> 套装: {0}",
    "ar": "👩🏽‍💻 <b>حذف</b> الحزمة: {0}",
}
l_item_thumb = {
    "ru": "✏️ 3. <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> режим обложки для загруженного файла\n\n(<i>жми «➡️️/Next», чтобы перейти к следующему шагу</i>)",
    "en": "✏️ 3. <b>Press</b> ✅/☑️ to <b>Enable/Disable</b> cover mode for the uploaded file\n\n(<i>press “➡️️/Next” to proceed to the next step</i>)",
    "es": "✏️ 3. <b>Presiona</b> ✅/☑️ para <b>activar/desactivar</b> el modo de portada para el archivo subido\n\n(<i>presiona “➡️️/Siguiente” para continuar al siguiente paso</i>)",
    "fr": "✏️ 3. <b>Appuyez</b> sur ✅/☑️ pour <b>activer/désactiver</b> le mode couverture pour le fichier téléchargé\n\n(<i>appuyez sur « ➡️️/Suivant » pour passer à l’étape suivante</i>)",
    "zh": "✏️ 3. <b>点击</b> ✅/☑️ 来<b>开启/关闭</b>上传文件的封面模式\n\n(<i>点击“➡️️/下一步”进入下一步</i>)",
    "ar": "✏️ 3. <b>اضغط</b> على ✅/☑️ لتفعيل/تعطيل وضع الغلاف للملف المرفوع\n\n(<i>اضغط على “➡️️/التالي” للانتقال للخطوة التالية</i>)",
}
l_choose_from_pack = {
    "ru": "👩🏽‍💻 Выбрать из набора",
    "en": "👩🏽‍💻 Choose from pack",
    "es": "👩🏽‍💻 Elegir del conjunto",
    "fr": "👩🏽‍💻 Choisir dans le pack",
    "zh": "👩🏽‍💻 从套装中选择",
    "ar": "👩🏽‍💻 اختر من الحزمة",
}
l_item_unawailable = {
    "ru": "👩🏽‍💻 Преобразование недоступно",
    "en": "👩🏽‍💻 Transformation unavailable",
    "es": "👩🏽‍💻 Transformación no disponible",
    "fr": "👩🏽‍💻 Transformation indisponible",
    "zh": "👩🏽‍💻 转换不可用",
    "ar": "👩🏽‍💻 التحويل غير متاح",
}
l_item_notfound = {
    "ru": "👩🏽‍💻 Стикер/эмоджи не найден в {0}",
    "en": "👩🏽‍💻 Sticker/emoji not found in {0}",
    "es": "👩🏽‍💻 Pegatina/emoji no encontrado en {0}",
    "fr": "👩🏽‍💻 Autocollant/emoji non trouvé dans {0}",
    "zh": "👩🏽‍💻 未在 {0} 中找到贴纸/表情符号",
    "ar": "👩🏽‍💻 لم يتم العثور على ملصق/رمز تعبيري في {0}",
}
l_item_incorrect = {
    "ru": "👩🏽‍💻 <b>Тип</b> загружаемого <b>{0}-{1}</b> не соответствует типу набора <b>{2}</b>",
    "en": "👩🏽‍💻 <b>Type</b> of uploaded <b>{0}-{1}</b> does not match pack type <b>{2}</b>",
    "es": "👩🏽‍💻 <b>Tipo</b> de <b>{0}-{1}</b> subido no coincide con el tipo de conjunto <b>{2}</b>",
    "fr": "👩🏽‍💻 Le <b>type</b> du fichier <b>{0}-{1}</b> téléchargé ne correspond pas au type de pack <b>{2}</b>",
    "zh": "👩🏽‍💻 上传的<b>{0}-{1}</b>类型与套装类型<b>{2}</b>不符",
    "ar": "👩🏽‍💻 <b>نوع</b> الملف المرفوع <b>{0}-{1}</b> لا يتطابق مع نوع الحزمة <b>{2}</b>",
}
l_pack_title_edit = {
    'ru': "🏔️ <b>Введи</b> новое название для [<b>{0}</b>]-набора (до 64 символов), отображаемого в заголовке\n\n👩🏽‍💻 <b>Текущее название</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить название</i>)",
    'en': "🏔️ <b>Enter</b> a new title for the [<b>{0}</b>] pack (up to 64 characters), shown in the header\n\n👩🏽‍💻 <b>Current title</b>: {1}\n(<i>send <code>0</code> to clear the title</i>)",
    'es': "🏔️ <b>Introduce</b> un nuevo título para el paquete [<b>{0}</b>] (hasta 64 caracteres), que se muestra en el encabezado\n\n👩🏽‍💻 <b>Título actual</b>: {1}\n(<i>envía <code>0</code> para borrar el título</i>)",
    'fr': "🏔️ <b>Entrez</b> un nouveau titre pour le pack [<b>{0}</b>] (jusqu’à 64 caractères), affiché dans l’en-tête\n\n👩🏽‍💻 <b>Titre actuel</b> : {1}\n(<i>envoyez <code>0</code> pour effacer le titre</i>)",
    'zh': "🏔️ 为 [<b>{0}</b>] 包输入新的标题（最多64个字符），显示在标题中\n\n👩🏽‍💻 当前标题：{1}\n（<i>发送 <code>0</code> 以清除标题</i>）",
    'ar': "🏔️ <b>أدخل</b> عنوانًا جديدًا لحزمة [<b>{0}</b>] (حتى 64 حرفًا)، يتم عرضه في العنوان\n\n👩🏽‍💻 <b>العنوان الحالي</b>: {1}\n(<i>أرسل <code>0</code> لمسح العنوان</i>)",
}
l_item_words_edit = {
    'ru': "💬 <b>Укажи</b> ключевые слова (до 64 символов), которые будут ассоциированы с загруженным <b>{0}</b>\n\n👩🏽‍💻 <b>Текущие слова</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить ключевые слова</i>)",
    'en': "💬 <b>Specify</b> keywords (up to 64 characters) associated with the uploaded <b>{0}</b>\n\n👩🏽‍💻 <b>Current keywords</b>: {1}\n(<i>send <code>0</code> to clear keywords</i>)",
    'es': "💬 <b>Especifica</b> palabras clave (hasta 64 caracteres) asociadas con el <b>{0}</b> cargado\n\n👩🏽‍💻 <b>Palabras clave actuales</b>: {1}\n(<i>envía <code>0</code> para borrar palabras clave</i>)",
    'fr': "💬 <b>Spécifiez</b> les mots-clés (jusqu’à 64 caractères) associés au <b>{0}</b> téléchargé\n\n👩🏽‍💻 <b>Mots-clés actuels</b> : {1}\n(<i>envoyez <code>0</code> pour effacer les mots-clés</i>)",
    'zh': "💬 指定与上传的<b>{0}</b>相关的关键词（最多64个字符）\n\n👩🏽‍💻 当前关键词：{1}\n（<i>发送 <code>0</code> 以清除关键词</i>）",
    'ar': "💬 <b>حدد</b> الكلمات المفتاحية (حتى 64 حرفًا) المرتبطة بـ <b>{0}</b> المحمّل\n\n👩🏽‍💻 <b>الكلمات المفتاحية الحالية</b>: {1}\n(<i>أرسل <code>0</code> لمسح الكلمات المفتاحية</i>)",
}
l_item_emoji_edit = {
    'ru': "❤️ <b>Укажи</b> эмоджи (до 20), которые будут ассоциированы с загруженным <b>{0}</b>\n\n👩🏽‍💻 <b>Текущие эмоджи</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить эмоджи</i>)",
    'en': "❤️ <b>Specify</b> emojis (up to 20) associated with the uploaded <b>{0}</b>\n\n👩🏽‍💻 <b>Current emojis</b>: {1}\n(<i>send <code>0</code> to clear emojis</i>)",
    'es': "❤️ <b>Especifica</b> emojis (hasta 20) asociados con el <b>{0}</b> cargado\n\n👩🏽‍💻 <b>Emojis actuales</b>: {1}\n(<i>envía <code>0</code> para borrar emojis</i>)",
    'fr': "❤️ <b>Spécifiez</b> les emojis (jusqu’à 20) associés au <b>{0}</b> téléchargé\n\n👩🏽‍💻 <b>Emojis actuels</b> : {1}\n(<i>envoyez <code>0</code> pour effacer les emojis</i>)",
    'zh': "❤️ 指定与上传的<b>{0}</b>相关的表情符号（最多20个）\n\n👩🏽‍💻 当前表情符号：{1}\n（<i>发送 <code>0</code> 以清除表情符号</i>）",
    'ar': "❤️ <b>حدد</b> الرموز التعبيرية (حتى 20) المرتبطة بـ <b>{0}</b> المحمّل\n\n👩🏽‍💻 <b>الرموز التعبيرية الحالية</b>: {1}\n(<i>أرسل <code>0</code> لمسح الرموز التعبيرية</i>)",
}
l_item_delete_edit = {
    "ru": "❌ <b>Удалить</b> выбранный <b>{0}</b> из набора [{1}]",
    "en": "❌ <b>Delete</b> selected <b>{0}</b> from set [{1}]",
    "es": "❌ <b>Eliminar</b> seleccionado <b>{0}</b> del conjunto [{1}]",
    "fr": "❌ <b>Supprimer</b> le <b>{0}</b> sélectionné du jeu [{1}]",
    "zh": "❌ <b>删除</b>选定的<b>{0}</b>从集合[{1}]",
    "ar": "❌ <b>حذف</b> <b>{0}</b> المحدد من المجموعة [{1}]",
}
l_item_thumb_edit = {
    "ru": "🖼️ <b>Установить</b> выбранный <b>{0}</b> в качестве обложки [{1}]-набора",
    "en": "🖼️ <b>Set</b> selected <b>{0}</b> as cover for [{1}] set",
    "es": "🖼️ <b>Establecer</b> seleccionado <b>{0}</b> como portada del conjunto [{1}]",
    "fr": "🖼️ <b>Définir</b> le <b>{0}</b> sélectionné comme couverture du jeu [{1}]",
    "zh": "🖼️ <b>设置</b>选定的<b>{0}</b>作为[{1}]集合的封面",
    "ar": "🖼️ <b>تعيين</b> <b>{0}</b> المحدد كغطاء لمجموعة [{1}]",
}
l_item_shift_edit = {
    "ru": "🔛 <b>Жми</b> на ⬅️/➡️, чтобы сдвинуть <b>влево/вправо</b> выбранный <b>{0}</b> в наборе [{1}]\n\n<blockquote>позиция обновится в течение часа</blockquote>",
    "en": "🔛 <b>Press</b> ⬅️/➡️ to shift selected <b>{0}</b> <b>left/right</b> in set [{1}]\n\n<blockquote>position will update within an hour</blockquote>",
    "es": "🔛 <b>Pulsa</b> ⬅️/➡️ para mover el <b>{0}</b> seleccionado <b>izquierda/derecha</b> en el conjunto [{1}]\n\n<blockquote>la posición se actualizará en una hora</blockquote>",
    "fr": "🔛 <b>Cliquez</b> sur ⬅️/➡️ pour déplacer le <b>{0}</b> sélectionné <b>gauche/droite</b> dans le jeu [{1}]\n\n<blockquote>la position sera mise à jour dans l'heure</blockquote>",
    "zh": "🔛 <b>按</b> ⬅️/➡️ 将选定的 <b>{0}</b> 在集合 [{1}] 中向<b>左/右</b>移动\n\n<blockquote>位置将在一小时内更新</blockquote>",
    "ar": "🔛 <b>اضغط</b> على ⬅️/➡️ لتحريك <b>{0}</b> المحدد <b>يسارًا/يمينًا</b> في المجموعة [{1}]\n\n<blockquote>سيتم تحديث الموقع خلال ساعة</blockquote>",
}

l_pack_title_done = {
    "ru": "🏔️ <b>Название</b>: <b>{0}</b> установлено",
    "en": "🏔️ <b>Title</b>: <b>{0}</b> set",
    "es": "🏔️ <b>Título</b>: <b>{0}</b> establecido",
    "fr": "🏔️ <b>Titre</b> : <b>{0}</b> défini",
    "zh": "🏔️ <b>标题</b>：<b>{0}</b> 已设置",
    "ar": "🏔️ <b>العنوان</b>: <b>{0}</b> تم تعيينه",
}
l_item_words_done = {
    "ru": "💬 <b>Ключевые слова</b>: [<b>{0}</b>] установлены",
    "en": "💬 <b>Keywords</b>: [<b>{0}</b>] set",
    "es": "💬 <b>Palabras clave</b>: [<b>{0}</b>] establecidas",
    "fr": "💬 <b>Mots-clés</b> : [<b>{0}</b>] définis",
    "zh": "💬 <b>关键词</b>：[<b>{0}</b>] 已设置",
    "ar": "💬 <b>الكلمات المفتاحية</b>: [<b>{0}</b>] تم تعيينها",
}
l_item_emoji_done = {
    "ru": "❤️ <b>Эмоджи</b>: <b>{0}</b> установлены",
    "en": "❤️ <b>Emoji</b>: <b>{0}</b> set",
    "es": "❤️ <b>Emojis</b>: <b>{0}</b> establecidos",
    "fr": "❤️ <b>Émojis</b> : <b>{0}</b> définis",
    "zh": "❤️ <b>表情符号</b>：<b>{0}</b> 已设置",
    "ar": "❤️ <b>الإيموجي</b>: <b>{0}</b> تم تعيينها",
}
l_item_delete_done = {
    "ru": "❌ <b>{0}</b> удален",
    "en": "❌ <b>{0}</b> deleted",
    "es": "❌ <b>{0}</b> eliminado",
    "fr": "❌ <b>{0}</b> supprimé",
    "zh": "❌ <b>{0}</b> 已删除",
    "ar": "❌ <b>{0}</b> تم الحذف",
}
l_item_thumb_done = {
    "ru": "🖼️ <b>{0}</b> установлен в качестве обложки",
    "en": "🖼️ <b>{0}</b> set as cover",
    "es": "🖼️ <b>{0}</b> establecido como portada",
    "fr": "🖼️ <b>{0}</b> défini comme couverture",
    "zh": "🖼️ <b>{0}</b> 设为封面",
    "ar": "🖼️ <b>{0}</b> تم تعيينه كغلاف",
}
l_item_shift_done = {
    "ru": "🔛 <b>{0}</b> сдвинут",
    "en": "🔛 <b>{0}</b> shifted",
    "es": "🔛 <b>{0}</b> desplazado",
    "fr": "🔛 <b>{0}</b> décalé",
    "zh": "🔛 <b>{0}</b> 移动",
    "ar": "🔛 <b>{0}</b> تم تحريكه",
}
l_item_need_animated = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> загрузить .tgs-файл для <b>animated</b>-набора",
    "en": "👩🏽‍💻 <b>Need</b> to upload .tgs file for <b>animated</b> set",
    "es": "👩🏽‍💻 <b>Necesario</b> subir archivo .tgs para el conjunto <b>animated</b>",
    "fr": "👩🏽‍💻 <b>Nécessaire</b> de télécharger un fichier .tgs pour l'ensemble <b>animated</b>",
    "zh": "👩🏽‍💻 需要上传用于<b>animated</b>套装的.tgs文件",
    "ar": "👩🏽‍💻 <b>مطلوب</b> تحميل ملف .tgs لمجموعة <b>animated</b>",
}
l_pack_title_error = {
    "ru": "🏔️ <b>Ошибка</b> установки названия",
    "en": "🏔️ <b>Error</b> setting the title",
    "es": "🏔️ <b>Error</b> al establecer el título",
    "fr": "🏔️ <b>Erreur</b> lors de la définition du titre",
    "zh": "🏔️ <b>设置标题错误</b>",
    "ar": "🏔️ <b>خطأ</b> في تعيين العنوان",
}
l_item_words_error = {
    "ru": "💬 <b>Ошибка</b> установки ключевых слов",
    "en": "💬 <b>Error</b> setting keywords",
    "es": "💬 <b>Error</b> al establecer palabras clave",
    "fr": "💬 <b>Erreur</b> lors de la définition des mots-clés",
    "zh": "💬 <b>设置关键词错误</b>",
    "ar": "💬 <b>خطأ</b> في تعيين الكلمات المفتاحية",
}
l_item_emoji_error = {
    "ru": "❤️ <b>Ошибка</b> установки эмоджи",
    "en": "❤️ <b>Error</b> setting emoji",
    "es": "❤️ <b>Error</b> al establecer emoji",
    "fr": "❤️ <b>Erreur</b> lors de la définition de l’emoji",
    "zh": "❤️ <b>设置表情错误</b>",
    "ar": "❤️ <b>خطأ</b> في تعيين الإيموجي",
}
l_item_delete_error = {
    "ru": "❌ <b>Ошибка</b> удаления",
    "en": "❌ <b>Deletion</b> error",
    "es": "❌ <b>Error</b> de eliminación",
    "fr": "❌ <b>Erreur</b> de suppression",
    "zh": "❌ <b>删除</b>错误",
    "ar": "❌ <b>خطأ</b> في الحذف",
}
l_item_thumb_error = {
    "ru": "🖼️ <b>Ошибка</b> установки обложки",
    "en": "🖼️ <b>Cover</b> setting error",
    "es": "🖼️ <b>Error</b> al establecer la portada",
    "fr": "🖼️ <b>Erreur</b> lors de la mise en place de la couverture",
    "zh": "🖼️ <b>封面</b>设置错误",
    "ar": "🖼️ <b>خطأ</b> في تعيين الغلاف",
}
l_item_shift_error = {
    "ru": "🔛 <b>Ошибка</b> установки сдвига",
    "en": "🔛 <b>Shift</b> setting error",
    "es": "🔛 <b>Error</b> al establecer el desplazamiento",
    "fr": "🔛 <b>Erreur</b> de réglage du décalage",
    "zh": "🔛 <b>偏移</b>设置错误",
    "ar": "🔛 <b>خطأ</b> في تعيين الإزاحة",
}
l_item_restart = {
    "ru": "(удали и сразу добавь набор снова для ускорения изменений)",
    "en": "(delete and immediately add the set again to speed up changes)",
    "es": "(elimina y añade el conjunto de nuevo inmediatamente para acelerar los cambios)",
    "fr": "(supprimez et ajoutez immédiatement l’ensemble à nouveau pour accélérer les changements)",
    "zh": "(删除并立即重新添加该集合以加快更改)",
    "ar": "(احذف وأعد إضافة المجموعة فوراً لتسريع التغييرات)",
}
l_item_shift_thumb = {
    "ru": "🖼️ Используй [🔛 Cдвиг] на первую позицию для видео-обложки",
    "en": "🖼️ Use [🔛 Shift] in the first position for the video cover",
    "es": "🖼️ Usa [🔛 Desplazamiento] en la primera posición para la portada del video",
    "fr": "🖼️ Utilisez [🔛 Décalage] en première position pour la couverture vidéo",
    "zh": "🖼️ 在第一位置使用[🔛偏移]作为视频封面",
    "ar": "🖼️ استخدم [🔛 الإزاحة] في الموضع الأول لغطاء الفيديو",
}
l_item_rbg_only_photo = {
    "ru": "🙌🏽 Удаление фона доступно только для фото",
    "en": "🙌🏽 Background removal is available only for photos",
    "es": "🙌🏽 La eliminación del fondo está disponible solo para fotos",
    "fr": "🙌🏽 La suppression de l'arrière-plan est disponible uniquement pour les photos",
    "zh": "🙌🏽 背景移除仅适用于照片",
    "ar": "🙌🏽 إزالة الخلفية متاحة فقط للصور",
}

l_pack_item_add = {
    "ru": "👩🏽‍💻 <b>Отправь</b> sticker/emoji или photo/video/gif для добавления в <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>жми ⚫️/🙌🏽/🔄, чтобы закруглить/удалить фон фото/конвертировать фото в видео</blockquote>",
    "en": "👩🏽‍💻 <b>Send</b> sticker/emoji or photo/video/gif to add to <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>press ⚫️/🙌🏽/🔄 to round/remove photo background/convert photo to video</blockquote>",
    "es": "👩🏽‍💻 <b>Envía</b> sticker/emoji o foto/video/gif para añadir a <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>presiona ⚫️/🙌🏽/🔄 para redondear/eliminar fondo de la foto/convertir foto en video</blockquote>",
    "fr": "👩🏽‍💻 <b>Envoie</b> sticker/emoji ou photo/vidéo/gif pour ajouter à <b>{0}</b> : <a href='{1}'>{2}</a>\n\n<blockquote>appuie sur ⚫️/🙌🏽/🔄 pour arrondir/supprimer le fond de la photo/конвертировать la photo en vidéo</blockquote>",
    "zh": "👩🏽‍💻 <b>发送</b> 贴纸/表情或照片/视频/GIF 以添加到 <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>点击 ⚫️/🙌🏽/🔄 来圆角/移除照片背景/将照片转换为视频</blockquote>",
    "ar": "👩🏽‍💻 <b>أرسل</b> ملصق/رمز تعبيري أو صورة/فيديو/GIF للإضافة إلى <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>اضغط ⚫️/🙌🏽/🔄 لتدوير/إزالة خلفية الصورة/تحويل الصورة إلى فيديو</blockquote>"
}
l_pack_sub_for_many_media = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> оформить подписку для загрузки нескольких медиа-файлов за раз",
    "en": "👩🏽‍💻 <b>Necessary</b> to subscribe to upload multiple media files at once",
    "es": "👩🏽‍💻 <b>Necesario</b> suscribirse para cargar varios archivos multimedia a la vez",
    "fr": "👩🏽‍💻 <b>Nécessaire</b> de s’abonner pour télécharger plusieurs fichiers médias à la fois",
    "zh": "👩🏽‍💻 <b>需要</b>订阅才能一次上传多个媒体文件",
    "ar": "👩🏽‍💻 <b>ضروري</b> الاشتراك لتحميل عدة ملفات وسائط مرة واحدة",
}
l_pack_success_need_wait = {
    "ru": "👩🏽‍💻 <b>Добавление:</b> успешно! Переходи к настройкам элемента или добавь еще\n\n📍 <b>Изменения</b> в наборе применятся в течение получаса",
    "en": "👩🏽‍💻 <b>Addition:</b> successful! Proceed to item settings or add more\n\n📍 <b>Changes</b> in the pack will take effect within half an hour",
    "es": "👩🏽‍💻 <b>Adición:</b> ¡éxito! Continúa con la configuración del elemento o añade más\n\n📍 <b>Los cambios</b> en el paquete se aplicarán en media hora",
    "fr": "👩🏽‍💻 <b>Ajout :</b> réussi ! Passez aux paramètres de l’élément ou ajoutez-en plus\n\n📍 <b>Les modifications</b> dans le pack seront effectives dans une demi-heure",
    "zh": "👩🏽‍💻 <b>添加：</b>成功！进入项目设置或添加更多\n\n📍 <b>更改</b>将在半小时内生效",
    "ar": "👩🏽‍💻 <b>الإضافة:</b> ناجحة! انتقل إلى إعدادات العنصر أو أضف المزيد\n\n📍 <b>التغييرات</b> في الحزمة ستسري خلال نصف ساعة",
}
l_pack_replace_success = {
    "ru": "👩🏽‍💻 <b>Замена:</b> успешно\n\n📍 <b>Изменения</b> в наборе применятся в течение получаса",
    "en": "👩🏽‍💻 <b>Replacement:</b> successful\n\n📍 <b>Changes</b> in the pack will take effect within half an hour",
    "es": "👩🏽‍💻 <b>Reemplazo:</b> exitoso\n\n📍 <b>Los cambios</b> en el paquete se aplicarán en media hora",
    "fr": "👩🏽‍💻 <b>Remplacement :</b> réussi\n\n📍 <b>Les modifications</b> dans le pack seront effectives dans une demi-heure",
    "zh": "👩🏽‍💻 <b>替换：</b>成功\n\n📍 <b>更改</b>将在半小时内生效",
    "ar": "👩🏽‍💻 <b>الاستبدال:</b> ناجح\n\n📍 <b>التغييرات</b> في الحزمة ستسري خلال نصف ساعة",
}
l_pack_item_add2 = {
    "ru": "👩🏽‍💻 <b>Отправь</b> sticker/emoji или photo/video/gif для замены элемента в <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>жми ⚫️/🙌🏽/🔄, чтобы закруглить/удалить фон фото/конвертировать фото в видео</blockquote>",
    "en": "👩🏽‍💻 <b>Send</b> sticker/emoji or photo/video/gif to replace an item in <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>press ⚫️/🙌🏽/🔄 to round/remove photo background/convert photo to video</blockquote>",
    "es": "👩🏽‍💻 <b>Envía</b> sticker/emoji o foto/video/gif para reemplazar un elemento en <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>presiona ⚫️/🙌🏽/🔄 para redondear/eliminar fondo de la foto/convertir foto en video</blockquote>",
    "fr": "👩🏽‍💻 <b>Envoie</b> sticker/emoji ou photo/vidéo/gif pour remplacer un élément dans <b>{0}</b> : <a href='{1}'>{2}</a>\n\n<blockquote>appuie sur ⚫️/🙌🏽/🔄 pour arrondir/supprimer le fond de la photo/convertir la photo en vidéo</blockquote>",
    "zh": "👩🏽‍💻 <b>发送</b> 贴纸/表情或照片/视频/GIF 来替换 <b>{0}</b> 中的项目: <a href='{1}'>{2}</a>\n\n<blockquote>点击 ⚫️/🙌🏽/🔄 来圆角/移除照片背景/将照片转换为视频</blockquote>",
    "ar": "👩🏽‍💻 <b>أرسل</b> ملصق/رمز تعبيري أو صورة/فيديو/GIF لاستبدال عنصر في <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>اضغط ⚫️/🙌🏽/🔄 لتدوير/إزالة خلفية الصورة/تحويل الصورة إلى فيديو</blockquote>"
}

# endregion


# region FereyCodexBot
l_codex_btn1 = {
    "ru": "👩🏽‍💻 Кодекс",
    "en": "👩🏽‍💻 Codex",
    "es": "👩🏽‍💻 Código",
    "fr": "👩🏽‍💻 Code",
    "zh": "👩🏽‍💻 守则",
    "ar": "👩🏽‍💻 المدونة",
}
l_codex_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_codex_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в [<b>Кодекс {1}</b>] - <i>@tg-приложение</i> быстрого погружения в новые @tg-инструменты #нейро-маркетинга и блокчейна:\n\n▪️<b>экспресс</b>-интенсив 3 мин\n▪️@tg-<b>приложения</b>\n▪️<b>нейро</b>-инструменты\n▪️<b>веб3</b>-интеграции",
    "en": "🌱 <b>{0}</b>, welcome to [<b>Codex {1}</b>] - <i>@tg-app</i> for quick immersion into new @tg-tools of #neuro-marketing and blockchain:\n\n▪️<b>express</b> 3-min intensive\n▪️@tg-<b>apps</b>\n▪️<b>neuro</b>-tools\n▪️<b>web3</b>-integrations",
    "es": "🌱 <b>{0}</b>, bienvenido a [<b>Código {1}</b>] - <i>@tg-aplicación</i> para una inmersión rápida en nuevas herramientas @tg de #neuro-marketing y blockchain:\n\n▪️<b>intensivo</b> exprés de 3 min\n▪️@tg-<b>aplicaciones</b>\n▪️<b>neuro</b>-herramientas\n▪️integraciones <b>web3</b>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans [<b>Code {1}</b>] - <i>@tg-application</i> pour une immersion rapide dans les nouveaux outils @tg de #neuro-marketing et blockchain :\n\n▪️intensif <b>express</b> de 3 min\n▪️@tg-<b>applications</b>\n▪️<b>neuro</b>-outils\n▪️intégrations <b>web3</b>",
    "zh": "🌱<b>{0}</b>，欢迎来到 [<b>守则 {1}</b>] - 一个<i>@tg 应用</i>，可快速进入#神经营销与区块链的全新 @tg 工具：\n\n▪️<b>速成</b>3分钟密训\n▪️@tg-<b>应用</b>\n▪️<b>神经</b>工具\n▪️<b>web3</b>集成",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في [<b>المدونة {1}</b>] - <i>تطبيق @tg</i> للغوص السريع في أدوات @tg الجديدة لتسويق الأعصاب و البلوكتشين:\n\n▪️<b>كثيف</b> سريع لمدة 3 دقائق\n▪️@tg-<b>تطبيقات</b>\n▪️<b>أدوات</b> عصبية\n▪️تكاملات <b>web3</b>",
}

l_codex_warm1 = {
    "ru": "👩🏽‍💻 <b>Кодекс {0}</b> - это программа практического обзора новых <code>@tg</code>-инструментов #нейро-маркетинга и блокчейна:\n\n<blockquote>за несколько минут познакомишься с новым @tg-функционалом, чтобы сэкономить несколько часов</blockquote>\n<blockquote>увидишь связки нейросетей и @tg-приложений, чтобы снизить затраты на подрядчиков</blockquote>\n<blockquote>узнаешь новые способы генерации/администрирования/поиска @tg-контента, чтобы обогнать конкурентов</blockquote>\n<blockquote>сможешь в один клик интегрировать web3-инструменты геймификации в канал/группу/бота</blockquote>\n\n🌱 После изучения <b>кодекса</b>, у тебя появится возможность подробнее разобрать @tg-функционал на <i>экспертном</i> уровне в нашем <u>реалити-фесте</u>, ссылка на который будет в конце кодекса\n\n🍃 <b>Жми [⭐️ Кодекс: взнос], чтобы открыть доступ к кодексу</b>\n\n©️ данный текст написан нейросетью",
    "en": "👩🏽‍💻 <b>Codex {0}</b> is a practical overview program of new <code>@tg</code> tools for #neuro-marketing and blockchain:\n\n<blockquote>in a few minutes you'll explore new @tg functionality to save hours</blockquote>\n<blockquote>see combinations of neural networks and @tg apps to reduce contractor costs</blockquote>\n<blockquote>learn new ways of generating/administering/searching @tg content to outpace competitors</blockquote>\n<blockquote>integrate web3 gamification tools into a channel/group/bot with one click</blockquote>\n\n🌱 After studying the <b>codex</b>, you can explore @tg functionality in more detail at an <i>expert</i> level in our <u>reality fest</u>, the link will be at the end of the codex\n\n🍃 <b>Click [⭐️ Codex: fee] to access the codex</b>\n\n©️ this text was written by a neural network",
    "es": "👩🏽‍💻 <b>Código {0}</b> es un programa de revisión práctica de nuevas herramientas <code>@tg</code> de #neuro-marketing y blockchain:\n\n<blockquote>en pocos minutos conocerás nuevas funciones de @tg para ahorrar horas</blockquote>\n<blockquote>verás combinaciones de redes neuronales y apps de @tg para reducir costes</blockquote>\n<blockquote>descubrirás nuevas formas de generar/administrar/buscar contenido @tg para superar a la competencia</blockquote>\n<blockquote>podrás integrar herramientas web3 de gamificación en canal/grupo/bot con un solo clic</blockquote>\n\n🌱 Tras estudiar el <b>código</b>, podrás profundizar en funciones @tg a nivel <i>experto</i> en nuestro <u>reality fest</u>, cuyo enlace estará al final del código\n\n🍃 <b>Haz clic en [⭐️ Código: contribución] para acceder al código</b>\n\n©️ este texto fue escrito por una red neuronal",
    "fr": "👩🏽‍💻 <b>Codex {0}</b> est un programme d’examen pratique des nouveaux outils <code>@tg</code> pour le #neuro-marketing et la blockchain :\n\n<blockquote>en quelques minutes, tu découvriras de nouvelles fonctionnalités @tg pour gagner des heures</blockquote>\n<blockquote>tu verras des combinaisons de réseaux neuronaux et d’apps @tg pour réduire les coûts</blockquote>\n<blockquote>tu apprendras de nouvelles façons de générer/administrer/rechercher du contenu @tg pour dépasser tes concurrents</blockquote>\n<blockquote>tu pourras intégrer des outils web3 de gamification dans un canal/groupe/bot en un clic</blockquote>\n\n🌱 Après avoir étudié le <b>codex</b>, tu pourras approfondir les fonctionnalités @tg à un niveau <i>expert</i> lors de notre <u>reality fest</u>, dont le lien sera à la fin du codex\n\n🍃 <b>Clique sur [⭐️ Codex : contribution] pour accéder au codex</b>\n\n©️ ce texte a été rédigé par un réseau neuronal",
    "zh": "👩🏽‍💻 <b>Codex {0}</b> 是一个关于新 <code>@tg</code> 工具的实用概览项目，聚焦 #神经营销 和 区块链：\n\n<blockquote>几分钟内了解新的 @tg 功能，节省数小时</blockquote>\n<blockquote>看到神经网络与 @tg 应用的组合，降低外包成本</blockquote>\n<blockquote>学习生成/管理/搜索 @tg 内容的新方法，超越竞争对手</blockquote>\n<blockquote>一键将 web3 游戏化工具集成到频道/群组/机器人</blockquote>\n\n🌱 学习完 <b>codex</b> 后，你将在我们的 <u>现实节</u> 中以 <i>专家</i> 水平深入探索 @tg 功能，链接将在 codex 末尾提供\n\n🍃 <b>点击 [⭐️ Codex: 费用] 即可访问 codex</b>\n\n©️ 本文由神经网络编写",
    "ar": "👩🏽‍💻 <b>كودكس {0}</b> هو برنامج عملي لاستعراض أدوات <code>@tg</code> الجديدة في #التسويق_العصبي والبلوكشين:\n\n<blockquote>في بضع دقائق ستتعرف على وظائف @tg الجديدة لتوفير ساعات</blockquote>\n<blockquote>سترى ترابطات بين الشبكات العصبية وتطبيقات @tg لتقليل التكاليف</blockquote>\n<blockquote>ستتعلم طرقًا جديدة لإنشاء/إدارة/البحث عن محتوى @tg لتسبق المنافسين</blockquote>\n<blockquote>ستتمكن من دمج أدوات web3 للألعاب في القناة/المجموعة/البوت بنقرة واحدة</blockquote>\n\n🌱 بعد دراسة <b>الكودكس</b>، يمكنك التعمق في وظائف @tg على مستوى <i>خبير</i> في <u>الواقع-فيست</u>، الرابط سيكون في نهاية الكودكس\n\n🍃 <b>اضغط على [⭐️ كودكس: المساهمة] لفتح الوصول إلى الكودكس</b>\n\n©️ هذا النص كتبه الذكاء الاصطناعي"
}
l_codex_warm2 = {
    "ru": "👩🏽‍💻 <b>Содержание Кодекса {0}:</b>\n\n<b>Акт #1</b>: <code>мастер генераций</code>\n<blockquote>• нейро-блоки\n• нейро-цепочки\n• нейро-постинг\n• нейро-ответ\n• нейро-диалог</blockquote>\n\n<b>Акт #2</b>: <code>мастер администрирования</code>\n<blockquote>• авто-бан\n• авто-декор\n• авто-вход\n• авто-постинг\n• авто-подкаст\n• авто-ответ</blockquote>\n\n<b>Акт #3</b>: <code>мастер поиска</code>\n<blockquote>• премиум поиск\n• пассивный поиск\n• встроенный поиск\n• поиск креативов\n• нейро поиск\n• лайк поиск\n• гео поиск</blockquote>\n\n<b>Акт #4</b>: <code>мастер блокчейна</code>\n<blockquote>• мастер смарт-контрактов\n• мастер NFT\n• мастер токеномики</blockquote>\n\n<b>Акт #5</b>: <code>заключение</code>\n\n🌱 После изучения <b>кодекса</b>, у тебя появится возможность стать резидентом <u>закрытого канала</u> и получить доступ к обновляемой рабочей книге со всеми @tg-инструментами\n\n🍃 <b>Жми [⭐️ Кодекс: взнос], чтобы открыть доступ к кодексу</b>",
    "en": "👩🏽‍💻 <b>Contents of the Codex {0}:</b>\n\n<b>Act #1</b>: <code>generation master</code>\n<blockquote>• neuro-blocks\n• neuro-chains\n• neuro-posting\n• neuro-reply\n• neuro-dialogue</blockquote>\n\n<b>Act #2</b>: <code>administration master</code>\n<blockquote>• auto-ban\n• auto-decor\n• auto-login\n• auto-posting\n• auto-podcast\n• auto-reply</blockquote>\n\n<b>Act #3</b>: <code>search master</code>\n<blockquote>• premium search\n• passive search\n• built-in search\n• creative search\n• neuro search\n• like search\n• geo search</blockquote>\n\n<b>Act #4</b>: <code>blockchain master</code>\n<blockquote>• smart contract master\n• NFT master\n• tokenomics master</blockquote>\n\n<b>Act #5</b>: <code>conclusion</code>\n\n🌱 After studying the <b>codex</b>, you can become a resident of the <u>private channel</u> and get access to the updated workbook with all @tg-tools\n\n🍃 <b>Click [⭐️ Codex: access], to unlock the codex</b>",
    "es": "👩🏽‍💻 <b>Contenido del Código {0}:</b>\n\n<b>Acto #1</b>: <code>maestro de generación</code>\n<blockquote>• neuro-bloques\n• neuro-cadenas\n• neuro-publicación\n• neuro-respuesta\n• neuro-diálogo</blockquote>\n\n<b>Acto #2</b>: <code>maestro de administración</code>\n<blockquote>• auto-baneo\n• auto-decoración\n• auto-ingreso\n• auto-publicación\n• auto-podcast\n• auto-respuesta</blockquote>\n\n<b>Acto #3</b>: <code>maestro de búsqueda</code>\n<blockquote>• búsqueda premium\n• búsqueda pasiva\n• búsqueda integrada\n• búsqueda creativa\n• búsqueda neuro\n• búsqueda por me gusta\n• búsqueda geográfica</blockquote>\n\n<b>Acto #4</b>: <code>maestro de blockchain</code>\n<blockquote>• maestro de contratos inteligentes\n• maestro de NFT\n• maestro de tokenómica</blockquote>\n\n<b>Acto #5</b>: <code>conclusión</code>\n\n🌱 Después de estudiar el <b>código</b>, podrás convertirte en residente del <u>canal privado</u> y acceder al libro de trabajo actualizado con todas las herramientas @tg\n\n🍃 <b>Haz clic en [⭐️ Código: acceso] para desbloquear el código</b>",
    "fr": "👩🏽‍💻 <b>Contenu du Codex {0} :</b>\n\n<b>Acte #1</b> : <code>maître des générations</code>\n<blockquote>• neuro-blocs\n• neuro-chaînes\n• neuro-publication\n• neuro-réponse\n• neuro-dialogue</blockquote>\n\n<b>Acte #2</b> : <code>maître de l’administration</code>\n<blockquote>• auto-ban\n• auto-décor\n• auto-connexion\n• auto-publication\n• auto-podcast\n• auto-réponse</blockquote>\n\n<b>Acte #3</b> : <code>maître de la recherche</code>\n<blockquote>• recherche premium\n• recherche passive\n• recherche intégrée\n• recherche créative\n• recherche neuro\n• recherche par likes\n• recherche géographique</blockquote>\n\n<b>Acte #4</b> : <code>maître de la blockchain</code>\n<blockquote>• maître des contrats intelligents\n• maître des NFT\n• maître de la tokenomique</blockquote>\n\n<b>Acte #5</b> : <code>conclusion</code>\n\n🌱 Après avoir étudié le <b>codex</b>, tu pourras devenir résident du <u>canal privé</u> et accéder au carnet de travail mis à jour avec tous les outils @tg\n\n🍃 <b>Clique sur [⭐️ Codex : accès] pour débloquer le codex</b>",
    "zh": "👩🏽‍💻 <b>Codex {0} 的内容：</b>\n\n<b>第一幕</b>：<code>生成大师</code>\n<blockquote>• 神经模块\n• 神经链\n• 神经发布\n• 神经回复\n• 神经对话</blockquote>\n\n<b>第二幕</b>：<code>管理大师</code>\n<blockquote>• 自动封禁\n• 自动装饰\n• 自动登录\n• 自动发布\n• 自动播客\n• 自动回复</blockquote>\n\n<b>第三幕</b>：<code>搜索大师</code>\n<blockquote>• 高级搜索\n• 被动搜索\n• 内置搜索\n• 创意搜索\n• 神经搜索\n• 点赞搜索\n• 地理搜索</blockquote>\n\n<b>第四幕</b>：<code>区块链大师</code>\n<blockquote>• 智能合约大师\n• NFT 大师\n• 代币经济大师</blockquote>\n\n<b>第五幕</b>：<code>结论</code>\n\n🌱 学习完 <b>codex</b> 后，你可以成为 <u>私密频道</u> 的成员，并获得包含所有 @tg 工具的更新工作手册的访问权限\n\n🍃 <b>点击 [⭐️ Codex: access] 解锁 codex</b>",
    "ar": "👩🏽‍💻 <b>محتوى المدونة {0}:</b>\n\n<b>الفصل #1</b>: <code>سيد التوليد</code>\n<blockquote>• كتل عصبية\n• سلاسل عصبية\n• نشر عصبي\n• رد عصبي\n• حوار عصبي</blockquote>\n\n<b>الفصل #2</b>: <code>سيد الإدارة</code>\n<blockquote>• حظر تلقائي\n• تزيين تلقائي\n• تسجيل دخول تلقائي\n• نشر تلقائي\n• بودكاست تلقائي\n• رد تلقائي</blockquote>\n\n<b>الفصل #3</b>: <code>سيد البحث</code>\n<blockquote>• بحث متميز\n• بحث سلبي\n• بحث مدمج\n• بحث إبداعي\n• بحث عصبي\n• بحث بالإعجاب\n• بحث جغرافي</blockquote>\n\n<b>الفصل #4</b>: <code>سيد البلوكتشين</code>\n<blockquote>• سيد العقود الذكية\n• سيد NFT\n• سيد الاقتصاد الرمزي</blockquote>\n\n<b>الفصل #5</b>: <code>الخاتمة</code>\n\n🌱 بعد دراسة <b>المدونة</b>، يمكنك أن تصبح مقيمًا في <u>القناة الخاصة</u> والحصول على الوصول إلى دفتر العمل المحدث مع جميع أدوات @tg\n\n🍃 <b>انقر [⭐️ المدونة: الوصول] لفتح المدونة</b>"
}
l_codex_warm3 = {
    "ru": "👩🏽‍💻 <b>Все</b> @tg-инструменты <b>Кодекса {0}</b> поддерживаются официальными сервисами <b>Ferey</b>-проекта:\n\n<blockquote>• Bot\n• Channel\n• Group\n• User\n• Post\n• Media\n• AI\n• Find\n• Tools\n• Tonest\n• и другие •</blockquote>\n\n🌱 После изучения <b>кодекса</b>, у тебя появится возможность узнать как работать с каждым из <u>сервисов</u>, ссылки на которые найдешь внутри кодекса\n\n🍃 <b>Жми [⭐️ Кодекс: взнос], чтобы открыть доступ к кодексу</b>",
    "en": "👩🏽‍💻 <b>All</b> @tg-tools of the <b>Codex {0}</b> are supported by the official <b>Ferey</b>-project services:\n\n<blockquote>• Bot\n• Channel\n• Group\n• User\n• Post\n• Media\n• AI\n• Find\n• Tools\n• Tonest\n• and more •</blockquote>\n\n🌱 After studying the <b>codex</b>, you will know how to work with each <u>service</u>, with links found inside the codex\n\n🍃 <b>Click [⭐️ Codex: access] to unlock the codex</b>",
    "es": "👩🏽‍💻 <b>Todos</b> los @tg-herramientas del <b>Código {0}</b> están respaldados por los servicios oficiales del proyecto <b>Ferey</b>:\n\n<blockquote>• Bot\n• Canal\n• Grupo\n• Usuario\n• Publicación\n• Multimedia\n• IA\n• Buscar\n• Herramientas\n• Tonest\n• y más •</blockquote>\n\n🌱 Después de estudiar el <b>código</b>, sabrás cómo trabajar con cada <u>servicio</u>, con enlaces dentro del código\n\n🍃 <b>Haz clic en [⭐️ Código: acceso] para desbloquear el código</b>",
    "fr": "👩🏽‍💻 <b>Tous</b> les @tg-outils du <b>Codex {0}</b> sont pris en charge par les services officiels du projet <b>Ferey</b> :\n\n<blockquote>• Bot\n• Canal\n• Groupe\n• Utilisateur\n• Publication\n• Média\n• IA\n• Recherche\n• Outils\n• Tonest\n• et plus encore •</blockquote>\n\n🌱 Après avoir étudié le <b>codex</b>, tu sauras comment utiliser chaque <u>service</u>, avec des liens dans le codex\n\n🍃 <b>Clique sur [⭐️ Codex : accès] pour débloquer le codex</b>",
    "zh": "👩🏽‍💻 <b>所有</b> <b>Codex {0}</b> 的 @tg-工具 由 <b>Ferey</b> 项目的官方服务支持：\n\n<blockquote>• Bot\n• 频道\n• 群组\n• 用户\n• 帖子\n• 媒体\n• AI\n• 查找\n• 工具\n• Tonest\n• 以及更多 •</blockquote>\n\n🌱 学习完 <b>codex</b> 后，你将知道如何使用每个<u>服务</u>，相关链接可在 codex 中找到\n\n🍃 <b>点击 [⭐️ Codex: access] 解锁 codex</b>",
    "ar": "👩🏽‍💻 <b>جميع</b> أدوات @tg في <b>المدونة {0}</b> مدعومة من قبل خدمات مشروع <b>Ferey</b> الرسمية:\n\n<blockquote>• بوت\n• قناة\n• مجموعة\n• مستخدم\n• منشور\n• وسائط\n• ذكاء اصطناعي\n• بحث\n• أدوات\n• Tonest\n• والمزيد •</blockquote>\n\n🌱 بعد دراسة <b>المدونة</b>، ستعرف كيفية استخدام كل <u>خدمة</u>، مع الروابط داخل المدونة\n\n🍃 <b>انقر على [⭐️ المدونة: الوصول] لفتح المدونة</b>"
}
l_codex_warm4 = {
    "ru": "👩🏽‍💻 <b>Приобретай</b> доступ к Кодексу {0} или поддержи <i>проект</i> донатом",
    "en": "👩🏽‍💻 <b>Get</b> access to Codex {0} or support the <i>project</i> with a donation",
    "es": "👩🏽‍💻 <b>Obtén</b> acceso al Código {0} o apoya el <i>proyecto</i> con una donación",
    "fr": "👩🏽‍💻 <b>Obtiens</b> l'accès au Codex {0} ou soutiens le <i>projet</i> par un don",
    "zh": "👩🏽‍💻 <b>获取</b> Codex {0} 的访问权限，或通过捐赠支持该<i>项目</i>",
    "ar": "👩🏽‍💻 <b>احصل</b> على الوصول إلى المدونة {0} أو ادعم <i>المشروع</i> بتبرع"
}

l_codex_pay_text = {
    "ru": "Кодекс: взнос",
    "en": "Codex: contribution",
    "es": "Códice: contribución",
    "fr": "Codex : contribution",
    "zh": "Codex：捐助",
    "ar": "المدونة: مساهمة"
}
l_codex_pay_check = {
    "ru": "👩🏽‍💻 Проверка взноса",
    "en": "👩🏽‍💻 Contribution check",
    "es": "👩🏽‍💻 Verificación de contribución",
    "fr": "👩🏽‍💻 Vérification de la contribution",
    "zh": "👩🏽‍💻 检查捐助",
    "ar": "👩🏽‍💻 التحقق من المساهمة"
}
l_codex_transcribation_btn = {
    "ru": "💨 Конспект",
    "en": "💨 Summary",
    "es": "💨 Resumen",
    "fr": "💨 Résumé",
    "zh": "💨 摘要",
    "ar": "💨 ملخص"
}

l_codex_caption_0 = {
    "ru": "👩🏽‍💻 <b>Акт #1</b>: <code>введение</code>\n\n00:03 - актуальность\n00:05 - цель\n00:07 - задачи\n\n<blockquote>Жми на • 2 • страницу, чтобы перейти к следующему акту</blockquote>",
    "en": "👩🏽‍💻 <b>Act #1</b>: <code>introduction</code>\n\n00:03 - relevance\n00:05 - goal\n00:07 - tasks\n\n<blockquote>Click on • 2 • page to go to the next act</blockquote>",
    "es": "👩🏽‍💻 <b>Acto #1</b>: <code>introducción</code>\n\n00:03 - relevancia\n00:05 - objetivo\n00:07 - tareas\n\n<blockquote>Haz clic en • 2 • página para ir al siguiente acto</blockquote>",
    "fr": "👩🏽‍💻 <b>Acte #1</b> : <code>introduction</code>\n\n00:03 - pertinence\n00:05 - objectif\n00:07 - tâches\n\n<blockquote>Cliquez sur • 2 • page pour passer à l'acte suivant</blockquote>",
    "zh": "👩🏽‍💻 <b>第1幕</b>：<code>介绍</code>\n\n00:03 - 相关性\n00:05 - 目标\n00:07 - 任务\n\n<blockquote>点击 • 2 • 页进入下一幕</blockquote>",
    "ar": "👩🏽‍💻 <b>الفصل #1</b>: <code>مقدمة</code>\n\n00:03 - الأهمية\n00:05 - الهدف\n00:07 - المهام\n\n<blockquote>اضغط على • 2 • الصفحة للانتقال إلى الفصل التالي</blockquote>",
}
l_codex_caption_1 = {
    "ru": "👩🏽‍💻 <b>Акт #1</b>: <code>мастер генераций</code>\n\n00:05 нейро-блоки\n00:10 нейро-постинг\n00:15 нейро-цепочки\n00:25 нейро-дилог\n\n<blockquote>Используемые в видео @tg-приложения:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>",
    "en": "👩🏽‍💻 <b>Act #1</b>: <code>generation master</code>\n\n00:05 neuro-blocks\n00:10 neuro-posting\n00:15 neuro-chains\n00:25 neuro-dialog\n\n<blockquote>Used @tg-apps in the video:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>",
    "es": "👩🏽‍💻 <b>Acto #1</b>: <code>maestro de generaciones</code>\n\n00:05 neuro-bloques\n00:10 neuro-posting\n00:15 neuro-cadenas\n00:25 neuro-diálogo\n\n<blockquote>Aplicaciones @tg usadas en el video:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>",
    "fr": "👩🏽‍💻 <b>Acte #1</b> : <code>maître des générations</code>\n\n00:05 neuro-blocs\n00:10 neuro-posting\n00:15 neuro-chaînes\n00:25 neuro-dialogue\n\n<blockquote>Applications @tg utilisées dans la vidéo :</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>",
    "zh": "👩🏽‍💻 <b>第1幕</b>：<code>生成大师</code>\n\n00:05 神经模块\n00:10 神经发布\n00:15 神经链\n00:25 神经对话\n\n<blockquote>视频中使用的 @tg 应用：</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>",
    "ar": "👩🏽‍💻 <b>الفصل #1</b>: <code>ماستر التوليد</code>\n\n00:05 كتل عصبية\n00:10 النشر العصبي\n00:15 سلاسل عصبية\n00:25 حوار عصبي\n\n<blockquote>تطبيقات @tg المستخدمة في الفيديو:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>",
}
l_codex_caption_2 = {
    "ru": "👩🏽‍💻 <b>Акт #2</b>: <code>мастер автоматизации</code>\n\n00:05 авто-бан\n00:15 авто-декор\n00:20 авто-постинг\n00:25 авто-подкаст\n00:30 авто-геймификация\n\n<blockquote>Используемые в видео @tg-приложения:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "en": "👩🏽‍💻 <b>Act #2</b>: <code>automation master</code>\n\n00:05 auto-ban\n00:15 auto-decor\n00:20 auto-posting\n00:25 auto-podcast\n00:30 auto-gamification\n\n<blockquote>Used @tg-apps in the video:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "es": "👩🏽‍💻 <b>Acto #2</b>: <code>maestro de automatización</code>\n\n00:05 auto-baneo\n00:15 auto-decoración\n00:20 auto-posting\n00:25 auto-podcast\n00:30 auto-gamificación\n\n<blockquote>Aplicaciones @tg usadas en el video:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "fr": "👩🏽‍💻 <b>Acte #2</b> : <code>maître de l'automatisation</code>\n\n00:05 auto-ban\n00:15 auto-décor\n00:20 auto-posting\n00:25 auto-podcast\n00:30 auto-gamification\n\n<blockquote>Applications @tg utilisées dans la vidéo :</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "zh": "👩🏽‍💻 <b>第2幕</b>：<code>自动化大师</code>\n\n00:05 自动封禁\n00:15 自动装饰\n00:20 自动发布\n00:25 自动播客\n00:30 自动游戏化\n\n<blockquote>视频中使用的 @tg 应用：</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "ar": "👩🏽‍💻 <b>الفصل #2</b>: <code>ماستر الأتمتة</code>\n\n00:05 الحظر التلقائي\n00:15 الديكور التلقائي\n00:20 النشر التلقائي\n00:25 البودكاست التلقائي\n00:30 اللعب التلقائي\n\n<blockquote>تطبيقات @tg المستخدمة في الفيديو:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
}
l_codex_caption_3 = {
    "ru": "👩🏽‍💻 <b>Акт #3</b>: <code>мастер поиска</code>\n\n00:05 премиум-поиск\n00:15 пассивный-поиск\n00:20 поиск-креативов\n00:25 нейро-поиск\n00:30 маркетплейс-поиск\n\n<blockquote>Используемые в видео @tg-приложения:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "en": "👩🏽‍💻 <b>Act #3</b>: <code>search master</code>\n\n00:05 premium search\n00:15 passive search\n00:20 creative search\n00:25 neuro search\n00:30 marketplace search\n\n<blockquote>Used @tg-apps in the video:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "es": "👩🏽‍💻 <b>Acto #3</b>: <code>maestro de búsqueda</code>\n\n00:05 búsqueda premium\n00:15 búsqueda pasiva\n00:20 búsqueda creativa\n00:25 búsqueda neuro\n00:30 búsqueda en el mercado\n\n<blockquote>Aplicaciones @tg usadas en el video:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "fr": "👩🏽‍💻 <b>Acte #3</b> : <code>maître de la recherche</code>\n\n00:05 recherche premium\n00:15 recherche passive\n00:20 recherche créative\n00:25 recherche neuro\n00:30 recherche sur le marketplace\n\n<blockquote>Applications @tg utilisées dans la vidéo :</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "zh": "👩🏽‍💻 <b>第3幕</b>：<code>搜索大师</code>\n\n00:05 高级搜索\n00:15 被动搜索\n00:20 创意搜索\n00:25 神经搜索\n00:30 市场搜索\n\n<blockquote>视频中使用的 @tg 应用：</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "ar": "👩🏽‍💻 <b>الفصل #3</b>: <code>ماستر البحث</code>\n\n00:05 البحث المميز\n00:15 البحث السلبي\n00:20 البحث الإبداعي\n00:25 البحث العصبي\n00:30 البحث في السوق\n\n<blockquote>تطبيقات @tg المستخدمة في الفيديو:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
}
l_codex_caption_4 = {
    "ru": "👩🏽‍💻 <b>Акт #4</b>: <code>мастер блокчейна</code>\n\n00:05 мастер смарт-контрактов\n00:20 мастер NFT\n00:35 мастер токеномики\n\n<blockquote>Используемые в видео @tg-приложения:</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "en": "👩🏽‍💻 <b>Act #4</b>: <code>blockchain master</code>\n\n00:05 smart contract master\n00:20 NFT master\n00:35 tokenomics master\n\n<blockquote>Used @tg-apps in the video:</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "es": "👩🏽‍💻 <b>Acto #4</b>: <code>maestro de blockchain</code>\n\n00:05 maestro de contratos inteligentes\n00:20 maestro NFT\n00:35 maestro de tokenómica\n\n<blockquote>Aplicaciones @tg usadas en el video:</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "fr": "👩🏽‍💻 <b>Acte #4</b> : <code>maître de la blockchain</code>\n\n00:05 maître des smart contracts\n00:20 maître NFT\n00:35 maître de la tokenomie\n\n<blockquote>Applications @tg utilisées dans la vidéo :</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "zh": "👩🏽‍💻 <b>第4幕</b>：<code>区块链大师</code>\n\n00:05 智能合约大师\n00:20 NFT 大师\n00:35 代币经济学大师\n\n<blockquote>视频中使用的 @tg 应用：</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "ar": "👩🏽‍💻 <b>الفصل #4</b>: <code>ماستر البلوكشين</code>\n\n00:05 ماستر العقود الذكية\n00:20 ماستر NFT\n00:35 ماستر الاقتصاد الرمزي\n\n<blockquote>تطبيقات @tg المستخدمة في الفيديو:</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
}
l_codex_caption_5 = {
    "ru": "👩🏽‍💻 <b>Акт #5</b>: <code>заключение</code>\n\n00:05 - результаты\n00:10 - вывод\n\n<blockquote>Рассмотрены @tg-приложения #нейро-генерации/администрирования/поиска/блокчейн интеграции</blockquote>\n\n🌱 <b>Переходи</b> к <a href='{0}'>реалити-фесту</a>, чтобы подробно в режиме <b>реального времени</b> собрать все @tg-инструменты для развития своего продукта/услуги\n\n🍃 <b>Становись</b> резидентом <a href='{1}'>закрытого канала</a>, чтобы приобрести <b>рабочую книгу</b> с актуальными знаниями и в числе первых получать инструкции нового @tg-функционала",
    "en": "👩🏽‍💻 <b>Act #5</b>: <code>conclusion</code>\n\n00:05 - results\n00:10 - summary\n\n<blockquote>Considered @tg-apps #neuro-generation/administration/search/blockchain integration</blockquote>\n\n🌱 <b>Go</b> to the <a href='{0}'>reality fest</a> to gather all @tg-tools for developing your product/service in <b>real time</b>\n\n🍃 <b>Become</b> a resident of the <a href='{1}'>closed channel</a> to get a <b>workbook</b> with current knowledge and be among the first to receive instructions for new @tg features",
    "es": "👩🏽‍💻 <b>Acto #5</b>: <code>conclusión</code>\n\n00:05 - resultados\n00:10 - resumen\n\n<blockquote>Se consideraron aplicaciones @tg #neuro-generación/administración/búsqueda/integración blockchain</blockquote>\n\n🌱 <b>Ve</b> al <a href='{0}'>festival de realidad</a> para reunir todas las herramientas @tg para desarrollar tu producto/servicio en <b>tiempo real</b>\n\n🍃 <b>Conviértete</b> en residente del <a href='{1}'>canal cerrado</a> para obtener un <b>cuaderno de trabajo</b> con conocimientos actualizados y ser de los primeros en recibir instrucciones sobre nuevas funciones @tg",
    "fr": "👩🏽‍💻 <b>Acte #5</b> : <code>conclusion</code>\n\n00:05 - résultats\n00:10 - résumé\n\n<blockquote>Applications @tg considérées #neuro-génération/administration/recherche/intégration blockchain</blockquote>\n\n🌱 <b>Allez</b> au <a href='{0}'>festival de la réalité</a> pour rassembler tous les outils @tg pour développer votre produit/service en <b>temps réel</b>\n\n🍃 <b>Devenez</b> résident du <a href='{1}'>canal fermé</a> pour obtenir un <b>carnet de travail</b> avec des connaissances à jour et être parmi les premiers à recevoir des instructions sur les nouvelles fonctionnalités @tg",
    "zh": "👩🏽‍💻 <b>第5幕</b>：<code>结论</code>\n\n00:05 - 结果\n00:10 - 总结\n\n<blockquote>考虑了 @tg 应用 #神经生成/管理/搜索/区块链集成</blockquote>\n\n🌱 <b>前往</b> <a href='{0}'>现实节</a>，实时收集所有用于开发你的产品/服务的 @tg 工具\n\n🍃 <b>成为</b> <a href='{1}'>封闭频道</a> 的居民，以获取包含最新知识的 <b>工作手册</b>，并率先获得新 @tg 功能的指令",
    "ar": "👩🏽‍💻 <b>الفصل #5</b>: <code>الخاتمة</code>\n\n00:05 - النتائج\n00:10 - الملخص\n\n<blockquote>تم النظر في تطبيقات @tg #التوليد_العصبي/الإدارة/البحث/تكامل البلوكشين</blockquote>\n\n🌱 <b>انتقل</b> إلى <a href='{0}'>مهرجان الواقع</a> لجمع جميع أدوات @tg لتطوير منتجك/خدمتك في <b>الوقت الحقيقي</b>\n\n🍃 <b>كن</b> مقيمًا في <a href='{1}'>القناة المغلقة</a> للحصول على <b>دفتر عمل</b> بالمعرفة الحالية وكن من الأوائل في تلقي تعليمات الميزات الجديدة لـ @tg",
}
# endregion


# --------


# region FereyAdsBot
l_ads_btn1 = {
    'ru': "👩🏽‍💻 Посты",
    'en': "👩🏽‍💻 Posts",
    'es': "👩🏽‍💻 Publicaciones",
    'fr': "👩🏽‍💻 Messages",
    'zh': "👩🏽‍💻 帖子",
    'ar': "👩🏽‍💻 المشاركات",
}
l_ads_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_ads_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания креативных постов:\n\n<blockquote>▪️️реклама в ferey-проектах\n▪️️заказ рекламы на канале</blockquote>",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> for creating creative posts <b>Ferey</b>:\n\n▪️️advertising in ferey-projects\n▪️ ️order advertising on the channel",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> para crear publicaciones creativas <b>Ferey</b>:\n\n▪️️publicidad en ferey-projects\n▪️ ️pedir publicidad en el canal",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> pour créer des publications créatives <b>Ferey</b> :\n\nƒ️️publicité dans les projets ferey\nwithout ️commander de la publicité sur la chaîne",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i>来创建创意帖子<b>Ferey</b>：\n\n▪️️ferey-projects 中的广告\n▪️ ️在频道上订购广告\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> لإنشاء منشورات إبداعية <b>Ferey</b>:\n\n▪️️الإعلان في مشاريع ferey\n▪️ ️اطلب الإعلان على القناة\n\n❗️<b>عادي</b>-محدث/محتوى",
}

l_subscribe_ads = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>22</u>%)]\n² [<b>Донат</b> на баланс]:\n<blockquote>▪️рассылка по всем ботам\n▪️редактирование чаевых\n(<i>чтобы указать точную сумму</i>)</blockquote>",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>22</u>%)]\n² [<b> Donate</b>to balance]:\n▪️mailing to all bots\n▪️editing tips\n(<i>to indicate the exact amount</i>)",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>22</u>%)]\n² [<b> Donar</b>al saldo]:\n▪️enviar por correo a todos los bots\n▪️consejos de edición\n(<i>para indicar la cantidad exacta</i>)\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>22</u>%)]\n² [<b> Faire un don</b> pour équilibrer] :\n▪️envoi par mail à tous les robots\n▪️conseils d'édition\n(<i>pour indiquer le montant exact</i>)\n\n👩🏽‍💻 /solde",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>22</u>%)]\n² [<b> 捐赠</b>以平衡]：\n▪️邮寄给所有机器人\n▪️编辑提示\n（<i>指示确切金额</i>）",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>22</u>%)]\n² [<b> التبرع</b>للرصيد]:\n▪️إرسال بريد إلكتروني إلى جميع الروبوتات\n▪️نصائح التعديل\n(<i>للإشارة إلى المبلغ الدقيق</i>)",
}

l_post_media_ads = {
    'ru': "✏️ 2. Прикрепи <b>медиа</b> контент: фото/гиф/видео до 5Mb\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    'en': "✏️ 2. Attach <b>media</b> content: photo/GIF/video up to 5Mb\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 2. Adjunte contenido <b>media</b>: foto/GIF/vídeo de hasta 5 Mb\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 2. Joignez du contenu <b>média</b> : photo/GIF/vidéo jusqu'à 5 Mo\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 2. 附加<b>媒体</b>内容：照片/GIF/视频，最大5Mb\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 2. قم بإرفاق محتوى <b>وسائط</b>: صورة/GIF/فيديو يصل حجمه إلى 5 ميجابايت\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
# endregion


# region FereyVPNBot
l_vpn_btn1 = {
    'ru': "👩🏽‍💻 VPN",
    'en': "👩🏽‍💻 VPN",
    'es': "👩🏽‍💻VPN",
    'fr': "👩🏽‍💻VPN",
    'zh': "👩🏽‍💻VPN",
    'ar': "👩🏽‍💻 VPN",
}
l_vpn_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_vpn_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i>:\n\n<blockquote>▪️<b>open vpn</b>\n▪️<b>wire guard</b>\n▪️<b>shadow socks</b></blockquote>",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> of the Ferey project:\n\n▪️<b>open vpn</b>\n▪️<b>wire guard </b>\n▪️<b>shadow socks</b>",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> del proyecto Ferey:\n\n▪️<b>open vpn</b>\n▪️<b>wire guardia </b>\n▪️<b>calcetines de sombra</b>",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> du projet Ferey :\n\nnoyer<b>open vpn</b>\nnoyer<b>wire garde </b>\n▪️<b>chaussettes fantômes</b>",
    'zh': "🌱<b>{0}</b>，欢迎使用 Ferey 项目的<i>登陆机器人</i>：\n\n▪️<b>开放VPN</b>\n▪️<b>wire守护</b>\n▪️<b>影子袜子</b>",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت الهبوطي</i> لمشروع Ferey:\n\n▪️<b>open vpn</b>\n▪️<b>wire حارس </b>\n▪️<b>جوارب الظل</b>\n\n❗️<b>بانتظام</b>-يتم تحديث /المحتوى",
}
l_subscribe_vpn = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>22</u>%)]",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>22</u>%)]",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>22</u>%)]",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>22</u>%)]",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>22</u>%)]",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>22</u>%)]",
}

l_vpn_1 = {
    'ru': "👩🏽‍💻 <b>Open vpn</b>\n\n{0}",
    'en': "👩🏽‍💻 <b>Open vpn</b>\n\n{0}",
    'es': "👩🏽‍💻 <b>Abrir VPN</b>\n\n{0}",
    'fr': "👩🏽‍💻 <b>Ouvrir le VPN</b>\n\n{0}",
    'zh': "👩🏽‍💻 <b>打开 VPN</b>\n\n{0}",
    'ar': "👩🏽‍💻 <b>فتح VPN</b>\n\n{0}",
}
l_vpn_2 = {
    'ru': "👩🏽‍💻 <b>Wire guard</b>\n\n{0}",
    'en': "👩🏽‍💻 <b>Wire guard</b>\n\n{0}",
    'es': "👩🏽‍💻 <b>Protector de alambre</b>\n\n{0}",
    'fr': "👩🏽‍💻 <b>Grille de protection</b>\n\n{0}",
    'zh': "👩🏽‍💻<b>电线护罩</b>\n\n{0}",
    'ar': "👩🏽‍💻 <b>واقي الأسلاك</b>\n\n{0}",
}
l_vpn_3 = {
    'ru': "👩🏽‍💻 <b>Shadow socks</b>\n\n{0}",
    'en': "👩🏽‍💻 <b>Shadow socks</b>\n\n{0}",
    'es': "👩🏽‍💻 <b>Calcetines de sombras</b>\n\n{0}",
    'fr': "👩🏽‍💻 <b>Chaussettes ombre</b>\n\n{0}",
    'zh': "👩🏽‍💻 <b>影子袜子</b>\n\n{0}",
    'ar': "👩🏽‍💻 <b>جوارب الظل</b>\n\n{0}",
}
# endregion


# region FereySupportBot
l_support_btn1 = {
    'ru': "👩🏽‍💻 Проекты",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_support_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_support_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i>: служба <b>заботы</b> Ferey-проекта:\n\n<blockquote>▪️<b>задавай</b> вопросы\n▪️<b>присылай</b> любые медиа-файлы</blockquote>",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_subscribe_support = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>22</u>%)]",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>22</u>%)]",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>22</u>%)]",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>22</u>%)]",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>22</u>%)]",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>22</u>%)]",
}
# endregion


# region FereyWorkBot
l_work_btn1 = {
    'ru': "👩🏽‍💻 Вакансии",
    'en': "👩🏽‍💻Vacancies",
    'es': "👩🏽‍💻Vacantes",
    'fr': "👩🏽‍💻Postes vacants",
    'zh': "👩🏽‍💻职位空缺",
    'ar': "👩🏽‍💻 وظائف شاغرة",
}
l_work_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_work_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> вакансий <b>Ferey</b>-проекта:\n\n<blockquote>▪️<b>вакансии</b> проекта\n▪️конкурсы и <b>задания</b>\n▪️<b>партнеры</b> и инвесторы\n▪️услуги и <b>пожертвования</b></blockquote>",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> vacancies of the <b>Ferey</b>-project:\n\n▪️<b>vacancies</b> project\n▪️competitions and <b>tasks</b>\n▪️<b>partners</b> and investors\n▪️services and <b>donations</b>",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> vacantes del proyecto <b>Ferey</b>:\n\n▪️<b>vacantes</b > proyecto\n▪️concursos y <b>tareas</b>\n▪️<b>socios</b> e inversores\n▪️servicios y <b>donaciones</b>",
    'fr': "🌱 <b>{0}</b>, bienvenue sur les <i>landing bot</i> postes vacants du <b>projet Ferey</b> :\n\nnoyer<b>postes vacants</b > projets\n▪️compétitions et <b>tâches</b>\n▪️<b>partenaires</b> et investisseurs\n▪️services et <b>dons</b>",
    'zh': "🌱 <b>{0}</b>，欢迎使用 <b>Ferey</b> 项目的<i>登陆机器人</i>职位空缺：\n\n▪️<b>空缺</b > 项目\n▪️竞赛和<b>任务</b>\n▪️<b>合作伙伴</b>和投资者\n▪️服务和<b>捐赠</b>\n\n❗️<b>定期</b>-可更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الهبوط الآلي</i> الوظائف الشاغرة في <b>Ferey</b>-project:\n\n▪️<b>الوظائف الشاغرة</b > المشروع\n▪️المسابقات و<b>المهام</b>\n▪️<b>الشركاء</b> والمستثمرون\n▪️الخدمات و<b>التبرعات</b>\n\n❗️<b>بانتظام </b>-محتوى /قابل للتحديث",
}
l_subscribe_work = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>22</u>%)]",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>22</u>%)]",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>22</u>%)]",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>22</u>%)]",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>22</u>%)]",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>22</u>%)]",
}

l_vacancy_1 = {
    'ru': "👩🏽‍💻 <b>Text to video ai-designer</b>\n\n<blockquote><b>Tasks</b>: create <i>ferey-masks</i> (realistic video) for any human\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: share of the company</blockquote>",
    'en': "👩🏽‍💻 <b>Text to video ai-designer</b>\n\n<b>Tasks</b>: create <i>ferey-masks</i> (realistic video) for any human\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: share of the company",
    'es': "👩🏽‍💻 <b>Diseñador de texto a vídeo</b>\n\n<b>Tareas</b>: crear <i>máscaras ferey</i> (vídeo realista) para cualquier humano\n<b>Género</b>: niña\n<b>Edad</b>: menos de 30\n<b>Pago</b>: participación en la empresa",
    'fr': "👩🏽‍💻 <b>Texte vers vidéo ai-designer</b>\n\n<b>Tâches</b> : créer des <i>masques ferey</i> (vidéo réaliste) pour n'importe quel humain\n<b>Sexe</b> : fille\n<b>Âge</b> : moins de 30 ans\n<b>Salaire</b> : part de l'entreprise",
    'zh': "👩🏽‍💻<b>文本到视频人工智能设计师</b>\n\n<b>任务</b>：为任何人创建<i>ferey-masks</i>（逼真的视频）\n<b>性别</b>：女孩\n<b>年龄</b>：30岁以下\n<b>薪酬</b>：公司股份",
    'ar': "👩🏽‍💻 <b>مصمم الذكاء الاصطناعي لتحويل النص إلى فيديو</b>\n\n<b>المهام</b>: إنشاء <i>أقنعة فيري</i> (فيديو واقعي) لأي إنسان\n<b>الجنس</b>: فتاة\n<b>العمر</b>: أقل من 30\n<b>الدفع</b>: حصة الشركة",
}
l_vacancy_2 = {
    'ru': "👩🏽‍💻 <b>Content/video maker</b>\n\n<blockquote><b>Tasks</b>: generate creatives for all <i>ferey-socials</i>\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: 1 TON per 1 post</blockquote>",
    'en': "👩🏽‍💻 <b>Content/video maker</b>\n\n<b>Tasks</b>: generate creatives for all <i>ferey-socials</i>\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: 1 TON per 1 post",
    'es': "👩🏽‍💻 <b>Creador de contenido/video</b>\n\n<b>Tareas</b>: generar creatividades para todos los <i>ferey-socials</i>\n<b>Género</ b>: chica\n<b>Edad</b>: menos de 30\n<b>Pago</b>: 1 TONELADA por 1 publicación",
    'fr': "👩🏽‍💻 <b>Créateur de contenu/vidéo</b>\n\n<b>Tâches</b> : générer des créations pour tous les <i>ferey-socials</i>\n<b>Genre</ b> : fille\n<b>Âge</b> : moins de 30 ans\n<b>Salaire</b> : 1 TON pour 1 message",
    'zh': "👩🏽‍💻<b>内容/视频制作者</b>\n\n<b>任务</b>：为所有<i>ferey-socials</i>\n<b>性别生成广告素材</b> b>：女孩\n<b>年龄</b>：小于 30\n<b>报酬</b>：每 1 个帖子 1 TON",
    'ar': "👩🏽‍💻 <b>صانع المحتوى/الفيديو</b>\n\n<b>المهام</b>: إنشاء تصميمات إبداعية لجميع <i>الشبكات الاجتماعية</i>\n<b>الجنس</ ب>: فتاة\n<b>العمر</b>: أقل من 30\n<b>الدفع</b>: 1 طن لكل مشاركة واحدة",
}
l_vacancy_3 = {
    'ru': "👩🏽‍💻 <b>TON-api-space/TWA/Aio/pyro/hydro-gram developer</b>\n\n<blockquote><b>Tasks</b>: dev and support all projects\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: share of the company</blockquote>",
    'en': "👩🏽‍💻 <b>TWA/Aio/pyro-gram developer</b>\n\n<b>Tasks</b>: dev and support all projects\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: share of the company",
    'es': "👩🏽‍💻 <b>Desarrollador TWA/Aio/pyro-gram</b>\n\n<b>Tareas</b>: desarrollo y soporte de todos los proyectos\n<b>Género</b>: niña\n<b>Edad</b>: menos de 30\n<b>Pago</b>: participación en la empresa",
    'fr': "👩🏽‍💻 <b>Développeur TWA/Aio/pyro-gram</b>\n\n<b>Tâches</b> : développer et soutenir tous les projets\n<b>Genre</b> : fille\n<b>Âge</b> : moins de 30 ans\n<b>Salaire</b> : part de l'entreprise",
    'zh': "👩🏽‍💻 <b>TWA/Aio/pyro-gram 开发人员</b>\n\n<b>任务</b>：开发和支持所有项目\n<b>性别</b>：女孩\n<b>年龄</b>：30岁以下\n<b>薪酬</b>：公司股份",
    'ar': "👩🏽‍💻 <b>مطور TWA/Aio/pyro-gram</b>\n\n<b>المهام</b>: تطوير ودعم جميع المشاريع\n<b>الجنس</b>: فتاة\n<b>العمر</b>: أقل من 30\n<b>الدفع</b>: حصة الشركة",
}
l_vacancy_4 = {
    'ru': "👩🏽‍💻 <b>Telegram Ads - partner/investor</b>\n\n<blockquote><b>Investment</b>: <a href='https://promote.telegram.org/account/budget/add_funds'>€2,000,000</a>\n<b>Pay</b>: share of the company</blockquote>",
    'en': "👩🏽‍💻 <b>Telegram Ads-partner/investor</b>\n\n<b>Investment</b>: <a href='https://promote.telegram.org/account/budget/add_funds'>€2,000,000</a>\n<b>Pay</b>: share of the company",
    'es': "👩🏽‍💻 <b>Anuncios de Telegram: socio/inversor</b>\n\n<b>Inversión</b>: <a href=' https://promote.telegram.org/account/budget/add_funds '>2.000.000€</a>\n<b>Pago</b>: participación de la empresa",
    'fr': "👩🏽‍💻 <b>Telegram Ads-partenaire/investisseur</b>\n\n<b>Investissement</b> : <a href=' https://promote.telegram.org/account/budget/add_funds '>2 000 000€</a>\n<b>Salaire</b> : part de la société",
    'zh': "👩🏽‍💻 <b>Telegram 广告-合作伙伴/投资者</b>\n\n<b>投资</b>：<a href=' https://promote.telegram.org/account/budget/add_funds '>2,000,000 欧元</a>\n<b>支付</b>：公司股份",
    'ar': "👩🏽‍💻 <b>إعلانات تيليجرام-شريك/مستثمر</b>\n\n<b>الاستثمار</b>: <a href=' https://promote.telegram.org/account/budget/add_funds '>2,000,000 يورو</a>\n<b>الدفع</b>: حصة الشركة",
}
l_vacancy_5 = {
    'ru': "👩🏽‍💻 <b>Philanthropist</b>\n\n<blockquote><b>Requirements</b>: any simple game for @gamee-project as <i>ferey-company</i>\n<b>Pay</b>: 10 TON</blockquote>",
    'en': "👩🏽‍💻 <b>Philanthropist</b>\n\n<b>Requirements</b>: any simple game for @gamee-project as <i>ferey-company</i>\n<b>Pay</b>: 10 TON",
    'es': "👩🏽‍💻 <b>Filántropo</b>\n\n<b>Requisitos</b>: cualquier juego simple para @gamee-proyecto como <i>ferey-company</i>\n<b>Pagar </b>: 10 TONELADAS",
    'fr': "👩🏽‍💻 <b>Philanthrope</b>\n\n<b>Exigences</b> : n'importe quel jeu simple pour @gamee-project en tant que <i>ferey-company</i>\n<b>Payer </b> : 10 TONNES",
    'zh': "👩🏽‍💻 <b>慈善家</b>\n\n<b>要求</b>： @gamee-project 作为<i>ferey-company</i>\n<b>支付的任何简单游戏</b>：10 吨",
    'ar': "👩🏽‍💻 <b>فاعل خير</b>\n\n<b>المتطلبات</b>: أي لعبة بسيطة لـ @gamee-project كـ <i>ferey-company</i>\n<b>الدفع </b>: 10 طن",
}
l_vacancy_6 = {
    'ru': "👩🏽‍💻 <b>Bot Premium</b>\n\n<blockquote><b>Requirements</b>: <a href='https://fragment.com/my/assets'><s>5000</s> 1000 TON</a>\n<b>Pay</b>: share of the company</blockquote>",
    'en': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>Requirements</b>: <a href='https://fragment.com/my/assets'>5000 TON</a>\n<b>Pay</b>: share of the company",
    'es': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>Requisitos</b>: <a href=' https://fragment.com/my/assets '> 5000 TON</a>\n<b>Pago</b>: participación de la empresa",
    'fr': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>Exigences</b> : <a href=' https://fragment.com/my/assets '> 5000 TON</a>\n<b>Rémunération</b> : part de l'entreprise",
    'zh': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>要求</b>： <a href=' https://fragment.com/my/assets '> 5000 吨</a>\n<b>支付</b>：公司股份",
    'ar': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>المتطلبات</b>: <a href=' https://fragment.com/my/assets '> 5000 طن</a>\n<b>الدفع</b>: حصة الشركة",
}
l_vacancy_7 = {
    'ru': "👩🏽‍💻 <b>Aesthetic Bot</b>\n\n<blockquote><b>Requirements</b>: creative idea for <code>@YourBot</code>\n<b>Cost</b>: 500 TON for <code>@YourBot</code>-template.bot</blockquote>",
    'en': "👩🏽‍💻 <b>Aesthetic Bot</b>\n\n<b>Requirements</b>: creative idea for <code>@YourBot</code>\n<b>Cost</b>: 500 TON for <code>@YourBot</code>-template.bot",
    'es': "👩🏽‍💻 <b>Aesthetic Bot</b>\n\n<b>Requisitos</b>: idea creativa para <code> @YourBot </code>\n<b>Costo</b>: 500 TON para <code> @YourBot </code>-template.bot",
    'fr': "👩🏽‍💻 <b>Aesthetic Bot</b>\n\n<b>Exigences</b> : idée créative pour <code> @YourBot </code>\n<b>Coût</b> : 500 TON pour <code> @YourBot </code>-template.bot",
    'zh': "👩🏽‍💻 <b>美学机器人</b>\n\n<b>要求</b>：<code> @YourBot的创意</code>\n<b>成本</b>：500 TON for <code> @YourBot </code>-template.bot",
    'ar': "👩🏽‍💻 <b>الروبوت الجمالي</b>\n\n<b>المتطلبات</b>: فكرة إبداعية لـ <code> @YourBot </code>\n<b>التكلفة</b>: 500 TON لـ <code> @YourBot </code>-template.bot",
}
# endregion


# region FereyFestBot
l_fest_btn1 = {
    'ru': "👩🏽‍💻 Реалити",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_fest_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_fest_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> службу <b>заботы</b> Ferey-проекта:\n\n▪️<b>задавай</b> вопросы\n▪️<b>присылай</b> любые медиа-файлы",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_subscribe_fest = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>22</u>%)]",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>22</u>%)]",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>22</u>%)]",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>22</u>%)]",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>22</u>%)]",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>22</u>%)]",
}
# endregion
